
 .. Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at

 ..   http://www.apache.org/licenses/LICENSE-2.0

 .. Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.

 .. NOTE! THIS FILE IS AUTOMATICALLY GENERATED AND WILL BE OVERWRITTEN!

 .. IF YOU WANT TO MODIFY THIS FILE, YOU SHOULD MODIFY THE TEMPLATE
    `PROVIDER_COMMITS_TEMPLATE.rst.jinja2` IN the `dev/breeze/src/airflow_breeze/templates` DIRECTORY

 .. THE REMAINDER OF THE FILE IS AUTOMATICALLY GENERATED. IT WILL BE OVERWRITTEN!

Package apache-airflow-providers-google
------------------------------------------------------

Google services including:

  - `Google Ads <https://ads.google.com/>`__
  - `Google Cloud (GCP) <https://cloud.google.com/>`__
  - `Google Firebase <https://firebase.google.com/>`__
  - `Google LevelDB <https://github.com/google/leveldb/>`__
  - `Google Marketing Platform <https://marketingplatform.google.com/>`__
  - `Google Workspace <https://workspace.google.com/>`__ (formerly Google Suite)


This is detailed commit list of changes for versions provider package: ``google``.
For high-level changelog, see :doc:`package information including changelog <index>`.



15.1.0
......

Latest change: 2025-04-16

==================================================================================================  ===========  ===================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===================================================================================================
`c85dd5442d <https://github.com/apache/airflow/commit/c85dd5442de2d729abfb8e4c7117bca0cf0b9131>`__  2025-04-16   ``Fix xcom for system tests (#49337)``
`098ed33b9a <https://github.com/apache/airflow/commit/098ed33b9a33ff4cbe897682d55716e65b4c0b58>`__  2025-04-16   ``type: annotate miss type in 'provider' (#49130)``
`47bd8961a9 <https://github.com/apache/airflow/commit/47bd8961a9ce4e2cea0dbabd400d2508eb291948>`__  2025-04-15   ``Use contextlib.suppress(exception) instead of try-except-pass and add SIM105 ruff rule (#49251)``
`18c99df954 <https://github.com/apache/airflow/commit/18c99df9541811173f98a80d710dd6071c925f4b>`__  2025-04-14   ``Add ORC support to GCSToBigQueryOperator and test for external tables (#49188)``
`cb295c351a <https://github.com/apache/airflow/commit/cb295c351a016c0a10cab07f2a628b865cff3ca3>`__  2025-04-14   ``remove superfluous else block (#49199)``
`e519ca76dd <https://github.com/apache/airflow/commit/e519ca76dddf258115c8fa6e2de5b166759886c5>`__  2025-04-14   ``Fix default value wait_for_operation_result (#49121)``
`2379398366 <https://github.com/apache/airflow/commit/23793983669f92ffee3ea2646bea7550df228d94>`__  2025-04-14   ``Deprecate start_sql_job in DataflowHook (#48663)``
`76a96086b6 <https://github.com/apache/airflow/commit/76a96086b6bedd99e8ebeec277fed0ddc436810c>`__  2025-04-14   ``Fix get_confluent_token callback for Managed Kafka service (#48926)``
`c932dab6a2 <https://github.com/apache/airflow/commit/c932dab6a2232650e5e01e41be34c4b1de5e5583>`__  2025-04-11   ``Fix: BigQuery connection UI defaults 'Use Legacy SQL' to true on edit (#49038)``
==================================================================================================  ===========  ===================================================================================================

15.0.1
......

Latest change: 2025-04-10

==================================================================================================  ===========  ==================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==================================================================================
`4a8567b20b <https://github.com/apache/airflow/commit/4a8567b20bdd6555cbdc936d6674bf4fa390b0d5>`__  2025-04-10   ``Prepare docs for Apr 2nd wave of providers (#49051)``
`4b87d52184 <https://github.com/apache/airflow/commit/4b87d52184746c7d0c779b6b3ec496c067a7e36b>`__  2025-04-09   ``Add missing license comment in google docs (#48985)``
`fa5a6c7e1a <https://github.com/apache/airflow/commit/fa5a6c7e1a9e8d064f4bc92267bd969ae6f1417f>`__  2025-04-08   ``Fix false friends in implicit string concatenation (#48871)``
`d3073c243c <https://github.com/apache/airflow/commit/d3073c243cf8f8df3a4de66e5bf2238743d9f2d4>`__  2025-04-08   ``Deprecate Life Scrience service (#48862)``
`7b2ec33c7a <https://github.com/apache/airflow/commit/7b2ec33c7ad4998d9c9735b79593fcdcd3b9dd1f>`__  2025-04-08   ``Remove unnecessary entries in get_provider_info and update the schema (#48849)``
`9470998c91 <https://github.com/apache/airflow/commit/9470998c919d6fb575299f0927638351a96b81a9>`__  2025-04-08   ``Small fixies for system tests in google-provider (#48861)``
`139673d3ce <https://github.com/apache/airflow/commit/139673d3ce5552c2cf8bcb2d202e97342c4b237c>`__  2025-04-07   ``Remove fab from preinstalled providers (#48457)``
`67858fd7e7 <https://github.com/apache/airflow/commit/67858fd7e7ac82788854844c1e6ef5a35f1d0d23>`__  2025-04-06   ``Improve documentation building iteration (#48760)``
==================================================================================================  ===========  ==================================================================================

15.0.0
......

Latest change: 2025-04-06

==================================================================================================  ===========  =================================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =================================================================================================================================================
`adbb062b50 <https://github.com/apache/airflow/commit/adbb062b50e2e128fe475a76b7ce10ec93c39ee2>`__  2025-04-06   ``Prepare docs for Apr 1st wave of providers (#48828)``
`1025474d28 <https://github.com/apache/airflow/commit/1025474d28a240b460d7ef8800c565f95d9dc012>`__  2025-04-04   ``Add 'ti' to the RemoteLogIO read and upload methods (#48804)``
`9057c130e1 <https://github.com/apache/airflow/commit/9057c130e19692567d5e0e2926b947323b5e29cd>`__  2025-04-04   ``fix: remove extra slash character from file URI formation in 'MetastoreHivePartitionSensor.poke' method. (#48731)``
`c1088b6720 <https://github.com/apache/airflow/commit/c1088b672025aae5706034c601c1d54811448e54>`__  2025-04-02   ``Rework remote task log handling for the structlog era. (#48491)``
`d4473555c0 <https://github.com/apache/airflow/commit/d4473555c0e7022e073489b7163d49102881a1a6>`__  2025-04-02   ``Simplify tooling by switching completely to uv (#48223)``
`3a4fa6108c <https://github.com/apache/airflow/commit/3a4fa6108c33c2bde3a79d0c3a72c3d01e09c13a>`__  2025-04-02   ``Disallowing types-protobuf 5.29.1.20250402 for google to fix mypy (#48666)``
`b7603b5b60 <https://github.com/apache/airflow/commit/b7603b5b6084d37e7ada44799823a19c4330482f>`__  2025-04-01   ``SFTPToGCSOperator: Added option to stream data directly to GCS without saving to disk (#48107)``
`b5ccbe50f5 <https://github.com/apache/airflow/commit/b5ccbe50f5bfac27b597af80105aad922a20543e>`__  2025-03-31   ``Remove deprecated for February and March 2025 in providers/google. Deprecation period for LifeScienceHook extended to july 08, 2025. (#48018)``
`47002feacd <https://github.com/apache/airflow/commit/47002feacd8aaf794b47c2dd241aa25068354a2a>`__  2025-03-30   ``Upgrade ruff to latest version (#48553)``
`fde5051eac <https://github.com/apache/airflow/commit/fde5051eaca10b81364cca43307c30f49bc7e529>`__  2025-03-28   ``Move bases classes to 'airflow.sdk.bases' (#48487)``
`347c98cd8c <https://github.com/apache/airflow/commit/347c98cd8c285b7b8ca3a8a626be89d16a572bbf>`__  2025-03-28   ``Move 'BaseSensorOperator' to TaskSDK definitions (#48244)``
==================================================================================================  ===========  =================================================================================================================================================

14.1.0
......

Latest change: 2025-03-26

==================================================================================================  ===========  ====================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================================================
`c762e17820 <https://github.com/apache/airflow/commit/c762e17820cae6b162caa3eec5123760e07d56cc>`__  2025-03-26   ``Prepare docs for Mar 2nd wave of providers (#48383)``
`6adb2dbae4 <https://github.com/apache/airflow/commit/6adb2dbae47341eb61dbc62dbc56176d9aa83fd9>`__  2025-03-25   ``Upgrade providers flit build requirements to 3.12.0 (#48362)``
`dfb6a89df7 <https://github.com/apache/airflow/commit/dfb6a89df7906421309ab6275aef76775e51d2db>`__  2025-03-25   ``Vendor-in json-merge-patch and add '--no-dev' to direct uv tool install (#48210)``
`84aa6539e6 <https://github.com/apache/airflow/commit/84aa6539e6bf7e315597148b1e88f8fdecac2a4b>`__  2025-03-22   ``Add DNS endpoint support for GKE Hooks and Operators (#48075)``
`b96547dedc <https://github.com/apache/airflow/commit/b96547dedc497bc3001fb3a3f30682b046dc7735>`__  2025-03-22   ``serialize http transports contained in composite transport (#47444)``
`243fe86d4b <https://github.com/apache/airflow/commit/243fe86d4b3e59bb12977b3e36ca3f2ed27ca0f8>`__  2025-03-21   ``Move airflow sources to airflow-core package (#47798)``
`91b0f610ab <https://github.com/apache/airflow/commit/91b0f610ab109f39e27a5a00d9f6d5bf590b47ff>`__  2025-03-17   ``AIP-72: Handle Custom XCom Backend on Task SDK (#47339)``
`935d2831fe <https://github.com/apache/airflow/commit/935d2831fe8fd509b618a738bf00e0c34e186e11>`__  2025-03-15   ``Remove links to x/twitter.com (#47801)``
`48f00a7093 <https://github.com/apache/airflow/commit/48f00a7093e5da53a61fc97afdecd8fe97bfe170>`__  2025-03-14   ``FIX: BigQuery traceability labels missing in TaskGroup (#47583)``
`8d0203ba24 <https://github.com/apache/airflow/commit/8d0203ba24d4097c84e9b4c19983af01d792e96e>`__  2025-03-14   ``misc: update API version of Google ADS (#47772)``
`2862775eb0 <https://github.com/apache/airflow/commit/2862775eb0b0ff5e04e113ecb0ef8ea127e4927f>`__  2025-03-13   ``Introduce operation helper class and refactor (#45354)``
`ec39ba4810 <https://github.com/apache/airflow/commit/ec39ba481061ba1621ec14d846adf7cc8ad27ec1>`__  2025-03-12   ``Remove auth backends from core Airflow (#47399)``
`7727db55b7 <https://github.com/apache/airflow/commit/7727db55b7ef27084e8ab04d241049ff3c579d02>`__  2025-03-12   ``Mark Google Oauth2 backend as Airflow 2 only (#47622)``
`2dcb15f3d1 <https://github.com/apache/airflow/commit/2dcb15f3d1ffa8fa1474d6833a39a81dc3500a96>`__  2025-03-09   ``Add Dataflow Apache Beam Java streaming system test (#47209)``
`4bc7ffb86d <https://github.com/apache/airflow/commit/4bc7ffb86df0515bee5703ffe4d2be97412ddb5d>`__  2025-03-09   ``feat: allow to set task/dag labels for 'DataprocCreateBatchOperator' (#46781)``
`492ecfe5c0 <https://github.com/apache/airflow/commit/492ecfe5c03102bfb710108038ebd5fc50cb55b5>`__  2025-03-09   ``Prepare docs for Mar 1st wave of providers (#47545)``
`aa07160892 <https://github.com/apache/airflow/commit/aa0716089235407f555fee06ac6363419b390bcc>`__  2025-03-07   ``AIP-72: Moving BaseOperatorLink to task sdk (#47008)``
`5484b7b624 <https://github.com/apache/airflow/commit/5484b7b624471fb368c2e7ab6f6984daa08e36dc>`__  2025-03-07   ``Bugfix typing after google-ads release 26.0.0 release (#47471)``
`9f344f2730 <https://github.com/apache/airflow/commit/9f344f27309f85b23fd30b5a7e7b3de13639053c>`__  2025-03-06   ``Remove extra string interpolation from fstrings (#47436)``
`c50541142b <https://github.com/apache/airflow/commit/c50541142b91269c2afc55bd666293500da1102b>`__  2025-03-05   ``Base AWS classes - S3 (#47321)``
`e4002c3305 <https://github.com/apache/airflow/commit/e4002c3305a757f5926f96c996e701e8f998a042>`__  2025-03-05   ``Move tests_common package to devel-common project (#47281)``
`96c0df6673 <https://github.com/apache/airflow/commit/96c0df667395c4299a9d998b72ddd7948a74a879>`__  2025-03-04   ``Remove unused methods from auth managers (#47316)``
`8f4fc4f107 <https://github.com/apache/airflow/commit/8f4fc4f107697079841c1f63c3feb00b58b8c12a>`__  2025-03-04   ``Remove 'airflow.www' module (#47318)``
`6008483efe <https://github.com/apache/airflow/commit/6008483efe83b149d0fd3732e4889aba06b2e5c0>`__  2025-03-03   ``Create operators for working with Consumer Groups for GCP Apache Kafka (#47056)``
`a1df83bacf <https://github.com/apache/airflow/commit/a1df83bacf60bcaa11fbbb17a04592aaec5c0615>`__  2025-03-02   ``doc: Add GCSListObjectsOperator to operators listed in documentation in Google Provider for GCS  #39290 (#47002)``
`001f25a3b8 <https://github.com/apache/airflow/commit/001f25a3b883c700ff235e26eb46b6ddc40f8fd9>`__  2025-03-02   ``Deprecating email, email_on_retry, email_on_failure in BaseOperator (#47146)``
`10da1a02f3 <https://github.com/apache/airflow/commit/10da1a02f30713e1a29a34f881334b25f498f017>`__  2025-02-28   ``Implement stale dag bundle cleanup (#46503)``
`1addb55154 <https://github.com/apache/airflow/commit/1addb55154fbef31bfa021537cfbd4395696381c>`__  2025-02-28   ``Improve documentation for updating provider dependencies (#47203)``
`c3c56e6b24 <https://github.com/apache/airflow/commit/c3c56e6b244dad314a8800dec1ef68db8809ede2>`__  2025-02-27   ``doc: fix the typo for glob regex  #47116 (#47134)``
`aa61371a07 <https://github.com/apache/airflow/commit/aa61371a071c92214bcc1bd29842fc8d4b0e33a2>`__  2025-02-27   ``Render structured logs in the new UI rather than showing raw JSON (#46827)``
`51415547d6 <https://github.com/apache/airflow/commit/51415547d681942ec389f143125e8f9f163d690c>`__  2025-02-26   ``Remove old UI and webserver (#46942)``
`c6c4f95ed9 <https://github.com/apache/airflow/commit/c6c4f95ed9e3220133815b9126c135e805637022>`__  2025-02-25   ``Add legacy namespace packages to airflow.providers (#47064)``
`1abd63731a <https://github.com/apache/airflow/commit/1abd63731ae07352514f03c54a9d68a8b22376dc>`__  2025-02-25   ``Remove example_dags folder (#47052)``
`94145446d1 <https://github.com/apache/airflow/commit/94145446d1a803af3dc2424b4d3bee30c91d795d>`__  2025-02-24   ``Update documentation for Dataflow operators (#46954)``
`dbf8bb4092 <https://github.com/apache/airflow/commit/dbf8bb409223687c7d2ad10649a92d02c24bb3b4>`__  2025-02-24   ``Remove extra whitespace in provider readme template (#46975)``
`a215880563 <https://github.com/apache/airflow/commit/a21588056367699bb83a838ba67ff58c7e7030c0>`__  2025-02-23   ``Fix 'exists' method to support using Requester Pays (#46759)``
`0883f21f3d <https://github.com/apache/airflow/commit/0883f21f3d0db259a197c8b0815f9809a6eef23b>`__  2025-02-22   ``Bump min. 'google-cloud-pubsub' ver. to v2.21.3 (#46984)``
`b28c336e8b <https://github.com/apache/airflow/commit/b28c336e8b7aa1d69c0f9520b182b1b661377337>`__  2025-02-21   ``Upgrade flit to 3.11.0 (#46938)``
==================================================================================================  ===========  ====================================================================================================================

14.0.0
......

Latest change: 2025-02-21

==================================================================================================  ===========  ===================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===================================================================================================================
`0653ffe78e <https://github.com/apache/airflow/commit/0653ffe78e4a0acaf70801a5ceef8dbabdac8b15>`__  2025-02-21   ``Prepare docs for Feb 1st wave of providers (fixed) (#46962)``
`5d87bddf0a <https://github.com/apache/airflow/commit/5d87bddf0aa5f485f3684c909fb95f461e5a2ab6>`__  2025-02-21   ``Prepare docs for Feb 1st wave of providers (#46893)``
`6557e7a474 <https://github.com/apache/airflow/commit/6557e7a47484deefdb847388bc791b1553092024>`__  2025-02-21   ``Bump cloud build to 3.31.0 (#46953)``
`a54d1d9a2e <https://github.com/apache/airflow/commit/a54d1d9a2eb2517f4ba6501a06972ac9a5fe4c38>`__  2025-02-21   ``Add dependencies section to gcp cloud build instance response (#46947)``
`b99cb7ce10 <https://github.com/apache/airflow/commit/b99cb7ce108ea013f755f770928a00d9e8d0944d>`__  2025-02-20   ``Create operators for working with Topics for GCP Apache Kafka (#46865)``
`ee68ddf605 <https://github.com/apache/airflow/commit/ee68ddf605cdcc457af2cb56f8443571757fe32f>`__  2025-02-20   ``Refactor deferrable mode for BeamRunPythonPipelineOperator and BeamRunJavaPipelineOperator (#46678)``
`18396ed808 <https://github.com/apache/airflow/commit/18396ed8083f38eebe7db062110d8c569cb4fa3d>`__  2025-02-18   ``Rework the TriggererJobRunner to run triggers in a process without DB access (#46677)``
`c4091ab02e <https://github.com/apache/airflow/commit/c4091ab02e4e95cc930fefde5af3120cfdaec7dc>`__  2025-02-17   ``Remove tests from example_dags folder (#46819)``
`fece9c7dfc <https://github.com/apache/airflow/commit/fece9c7dfc5f496dd673ce394a8e742a4f6e3866>`__  2025-02-17   ``Create operators for working with Clusters for GCP Apache Kafka (#45795)``
`4c786c42dd <https://github.com/apache/airflow/commit/4c786c42dd68b656a9434a0b0bc27760134e53c6>`__  2025-02-17   ``Deprecate old bigquery operators and introduce CreateTableOperator (#46673)``
`b5d6a391e5 <https://github.com/apache/airflow/commit/b5d6a391e5132129c06695b601ac91b999556e49>`__  2025-02-17   ``Add operators for Entry resource (#46647)``
`e67c89294c <https://github.com/apache/airflow/commit/e67c89294cc282c6936c34ee352fc46c5f3d738d>`__  2025-02-17   ``Speedup test collection for 'tests/www' (#46812)``
`4d5846f58f <https://github.com/apache/airflow/commit/4d5846f58fe0de9b43358c0be75dd72e968dacc4>`__  2025-02-16   ``Move provider_tests to unit folder in provider tests (#46800)``
`7ae64e9d24 <https://github.com/apache/airflow/commit/7ae64e9d24177245347ec2662257525e68547668>`__  2025-02-15   ``fix return job_id when async finish before deffed in BigQueryInsertJobOperator (#46753)``
`e027457a24 <https://github.com/apache/airflow/commit/e027457a24d0c6235bfed9c2a8399f75342e82f1>`__  2025-02-15   ``Removed the unused provider's distribution (#46608)``
`fe5a2ea7a0 <https://github.com/apache/airflow/commit/fe5a2ea7a0b57901bb6239d666b875f6c71cd7e8>`__  2025-02-13   ``AIP-72: Improving Operator Links Interface to Prevent User Code Execution in Webserver (#46613)``
`69c58e2497 <https://github.com/apache/airflow/commit/69c58e249765f1de33c244c42028fe90e3d8cf92>`__  2025-02-12   ``Add deferrable mode to the PubSubPullOperator (#45835)``
`a8601c7cf6 <https://github.com/apache/airflow/commit/a8601c7cf686745f888a1124025967ba7723ec94>`__  2025-02-09   ``Remove Airflow 3 Deprecation Warning in Google Provider, Move to Private Warning (#46599)``
`4f2743c25d <https://github.com/apache/airflow/commit/4f2743c25d2ea514c7415aebddd0eecb8aae33db>`__  2025-02-07   ``fix: Dataproc operators fail to import without OpenLineage (#46561)``
`eb05869b6d <https://github.com/apache/airflow/commit/eb05869b6de611185b47539a443bf131ad7702bd>`__  2025-02-04   ``Move Google provider to new provider structure (#46344)``
`53963c6e12 <https://github.com/apache/airflow/commit/53963c6e12844ca5c935b08303f9af69c68aa7e0>`__  2025-02-01   ``Reducing dedent to fix doc building issues in CI (#46350)``
`d6df9cfb84 <https://github.com/apache/airflow/commit/d6df9cfb8438311b4bbf5a372b010de447ed79cf>`__  2025-02-01   ``Add deferrable mode to google cloud storage transfer sensor and operators (#45754)``
`dc510d00f4 <https://github.com/apache/airflow/commit/dc510d00f428cf1a77238666cb5202b71ffb96cb>`__  2025-02-01   ``Add operators for AspectType resource (#46240)``
`826fcc9832 <https://github.com/apache/airflow/commit/826fcc9832fd715d14a980b6567ffd556b08b35c>`__  2025-01-31   ``Remove deprecated functionality from google provider (#46235)``
`baf54a8b1b <https://github.com/apache/airflow/commit/baf54a8b1becd6fb7bd7396229dadd0a6ff589a1>`__  2025-01-30   ``Add evaluation extra to google-cloud-aiplatform (#46270)``
`e3baba0c44 <https://github.com/apache/airflow/commit/e3baba0c44658306811f26e1f6501451ed52e5ce>`__  2025-01-29   ``Limit 'google-cloud-aiplatform' to fix issues in CI (#46242)``
`fbf0f0ef34 <https://github.com/apache/airflow/commit/fbf0f0ef34f10e9cf6d8ff66e598ad1870bc1dc3>`__  2025-01-26   ``Add backward compatibility for old Airflow version for CloudComposerDAGRunSensor (#46011)``
`0639343bba <https://github.com/apache/airflow/commit/0639343bbae092f069b1f07cc65f751b8720c0ed>`__  2025-01-24   ``feat: Add OpenLineage support for BigQueryDataTransferServiceStartTransferRunsOperator (#45801)``
`40590edc49 <https://github.com/apache/airflow/commit/40590edc49556d9c7fa8ca410ccd8f7f92237c88>`__  2025-01-22   ``feat: Add OpenLineage support for CloudSQLExecuteQueryOperator (#45182)``
`81bfacbb3c <https://github.com/apache/airflow/commit/81bfacbb3cb1b1d3a27c9be1c66bfa159819470f>`__  2025-01-20   ``Add new operators for Entry Type (#45799)``
`3b50a065ae <https://github.com/apache/airflow/commit/3b50a065ae6a06e72b031411ca8353b58926087d>`__  2025-01-18   ``Add Dataplex Catalog Entry Group operators (#45751)``
`d8f023d2a8 <https://github.com/apache/airflow/commit/d8f023d2a83e8eb4c4575ccc4ac74098bc371724>`__  2025-01-16   ``Improve grammar in cloud_composer.rst (#45708)``
`4fe78dd876 <https://github.com/apache/airflow/commit/4fe78dd87673a809ca9b2aa42733b7b8447c0615>`__  2025-01-16   ``feat: Add Hook Level Lineage support for BigQueryHook (#45706)``
`61ecbedfa2 <https://github.com/apache/airflow/commit/61ecbedfa22a075de42fafffd3f579145a96a84b>`__  2025-01-16   ``feat: Add OpenLineage support for MsSqlHook and MSSQLToGCSOperator (#45637)``
`f616c62209 <https://github.com/apache/airflow/commit/f616c62209d6b51d293ecf6f5c900f89a7fdc3a3>`__  2025-01-15   ``AIP-72: Support better type-hinting for Context dict in SDK  (#45583)``
`8e6e9c44a5 <https://github.com/apache/airflow/commit/8e6e9c44a5e13008887955ce0c0a7821d1646c71>`__  2025-01-13   ``Improve google credentials error message (#45553)``
`0f53716e65 <https://github.com/apache/airflow/commit/0f53716e65b8d4453db9a65aa3aad2f88d591115>`__  2025-01-10   ``Adding holiday_region parameter  to create_auto_ml_forecasting_training_job in AutoMl hook (#45465)``
`ac2de474fb <https://github.com/apache/airflow/commit/ac2de474fbf9980242599116cff4d1064cf81531>`__  2025-01-09   ``feat: automatically inject OL transport info into spark jobs (#45326)``
`42f513e891 <https://github.com/apache/airflow/commit/42f513e891e1794b47a69daf5a4fdafd89f2fdfd>`__  2025-01-08   ``feat: Add OpenLineage support for transfer operators between GCS and SFTP (#45485)``
`1f56cfc691 <https://github.com/apache/airflow/commit/1f56cfc6917ac86c35d2aa4f6b2b43ad05b8718c>`__  2025-01-08   ``add case of aarch64 environments (#45488)``
`68c7f89574 <https://github.com/apache/airflow/commit/68c7f8957499261f79f64d74076cc7493d4d2af4>`__  2025-01-08   ``Implement AlloyDB create/update/delete user and backups operators (#45378)``
`ab730b1b5f <https://github.com/apache/airflow/commit/ab730b1b5fa3d3a5ad383f1f6dde9f74cefcf121>`__  2025-01-08   ``feat: Add OpenLineage support for some SQL to GCS operators (#45242)``
`4c5d85aeec <https://github.com/apache/airflow/commit/4c5d85aeec5382d4da6505f33581076b526c37de>`__  2025-01-07   ``feat: Add OpenLineage support for some BQ operators (#45422)``
`228127036a <https://github.com/apache/airflow/commit/228127036a8368ec1487d91a688b7c04b8e2501a>`__  2025-01-07   ``Deprecate page_size parameter for Google Ads API v17 and later versions (#45239)``
`b1f709b724 <https://github.com/apache/airflow/commit/b1f709b7243213b838ef43941792482fe674ed84>`__  2025-01-04   ``Remove obsolete pandas specfication for pre-python 3.9 (#45399)``
`6f9cf5a4f3 <https://github.com/apache/airflow/commit/6f9cf5a4f3f4ed31d5353433203f7afc291ef672>`__  2025-01-03   ``feat: Add OpenLineage support for non-query jobs in BigQueryInsertJobOperator (#44996)``
`48a5a0aae9 <https://github.com/apache/airflow/commit/48a5a0aae9782d2df66f91cdc5f8cf46985026c8>`__  2025-01-02   ``feat: automatically inject OL info into spark job in DataprocInstantiateInlineWorkflowTemplateOperator (#44697)``
`f09bd4ed1b <https://github.com/apache/airflow/commit/f09bd4ed1bdb09cac3070a7c26ea90b8209e026d>`__  2024-12-30   ``feat: Add CLL to OpenLineage in BigQueryInsertJobOperator (#44872)``
`e9412bf69e <https://github.com/apache/airflow/commit/e9412bf69e5f25a815b660e6f06fa1aeec6b062a>`__  2024-12-30   ``feat: automatically inject OL info into spark job in DataprocCreateBatchOperator (#44612)``
`c9badd7e67 <https://github.com/apache/airflow/commit/c9badd7e670a7c5110de0713be50d69c835b90d0>`__  2024-12-27   ``Implement AlloyDB create/update/delete instance operators (#45241)``
`3ad1cf5ab5 <https://github.com/apache/airflow/commit/3ad1cf5ab55c3c13cdc4cd035ef181daae547891>`__  2024-12-26   ``Add BigQuery job link (#45020) (#45222)``
`c81dcb4934 <https://github.com/apache/airflow/commit/c81dcb4934bbd4f5ca86cafb769c9f65fd782f2f>`__  2024-12-26   ``fix GCSToGCSOperator bug when copy single object with replace to False (#45181)``
`56a75c480e <https://github.com/apache/airflow/commit/56a75c480e399217fd8392a20a8bfc153935f754>`__  2024-12-24   ``Deprecation policy for apache-airflow-providers-google package (#44985)``
`f56038e06a <https://github.com/apache/airflow/commit/f56038e06af324127e9a9781bcf5e0edb3187071>`__  2024-12-24   ``Add lower bound for alloydb (#45180)``
`3af90fd838 <https://github.com/apache/airflow/commit/3af90fd838f923caf0da6c533ef0b693477b8d12>`__  2024-12-20   ``Introduce gcp translation(V3) glossaries providers (#45085)``
`5d7739506c <https://github.com/apache/airflow/commit/5d7739506c5028c69e1a0a841af10ec5a407c851>`__  2024-12-20   ``Deprecate gcp AutoML module (#44875)``
==================================================================================================  ===========  ===================================================================================================================

12.0.0
......

Latest change: 2024-12-20

==================================================================================================  ===========  ==============================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==============================================================================================================
`2723508345 <https://github.com/apache/airflow/commit/2723508345d5cf074aeb673955ce72996785f2bc>`__  2024-12-20   ``Prepare docs for Nov 1st wave of providers Dec 2024 (#45042)``
`7fe46e12e2 <https://github.com/apache/airflow/commit/7fe46e12e2bccc1312fe5e4aadc2a3729d34b385>`__  2024-12-19   ``Google provider delete deprecated reaching removal date (December 2024) (#45084)``
`04ccef9b3a <https://github.com/apache/airflow/commit/04ccef9b3a4073eaf313db3905803e7ef3f910fb>`__  2024-12-19   ``feat: automatically inject OL info into spark job in DataprocSubmitJobOperator (#44477)``
`60b04ae724 <https://github.com/apache/airflow/commit/60b04ae724b4d23985105c25541d442c0c360de5>`__  2024-12-19   ``Implement AlloyDB operators: create/update/delete clusters (#45027)``
`553ddf3b99 <https://github.com/apache/airflow/commit/553ddf3b992d4335aadbd6a8dd653f7575e61477>`__  2024-12-18   ``Fix MetastoreHivePartitionSensor failing due to duplicate aliases (#45001)``
`2a33da0246 <https://github.com/apache/airflow/commit/2a33da0246c811a98d5cdaf0af2bcca0dee8556a>`__  2024-12-18   ``Remove references to AIRFLOW_V_2_9_PLUS (#44987)``
`51584b8c37 <https://github.com/apache/airflow/commit/51584b8c371263bf34725afedd3c2f1b35468a8e>`__  2024-12-18   ``Introduce gcp translation(V3), translate document providers (#44971)``
`16022e008c <https://github.com/apache/airflow/commit/16022e008cc2eef122c5cd254cdb52d2c1b7e026>`__  2024-12-16   ``Add Google Vertex AI Feature Store - Feature View Sync Operators, Sensor (#44891)``
`4b38bed76c <https://github.com/apache/airflow/commit/4b38bed76c1ea5fe84a6bc678ce87e20d563adc0>`__  2024-12-16   ``Bump min version of Providers to 2.9 (#44956)``
`9d6801353c <https://github.com/apache/airflow/commit/9d6801353c48569cfe0756f4cd0f02f0630e8baf>`__  2024-12-15   ``Support multiple SQL queries in Dataproc SQL job (#44890)``
`7f1d54ad4b <https://github.com/apache/airflow/commit/7f1d54ad4b14a4b255b20dfb162ee3667341d6f6>`__  2024-12-11   ``chore: remove deprecated bigquery facets from OpenLineage utils (#44838)``
`8480460da4 <https://github.com/apache/airflow/commit/8480460da45e1e8fe7069ead1d0a936233b2d73a>`__  2024-12-11   ``Implement KubernetesInstallKueueOperator + (#44568)``
`5079f7d855 <https://github.com/apache/airflow/commit/5079f7d8557ac2334aadfdbb9ce209199116fb06>`__  2024-12-10   ``Fix failing OpenLineage emition for InsertBigQueryOperator  (#44650)``
`391ad6bbf2 <https://github.com/apache/airflow/commit/391ad6bbf20d86d2aa18b0605738706df22bf579>`__  2024-12-10   ``feat: add OpenLineage support for BigQuery Create Table operators (#44783)``
`490b5e816b <https://github.com/apache/airflow/commit/490b5e816b804f338b0eb97f240ae874d4e15810>`__  2024-12-10   ``Consistent way of checking Airflow version in providers (#44686)``
`ea3aa67891 <https://github.com/apache/airflow/commit/ea3aa67891b68c69d35af455ad3106c1253244fe>`__  2024-12-06   ``Fix system test for dataform operators (#44729)``
`7717985775 <https://github.com/apache/airflow/commit/7717985775fa42f5722ea1b624c09ac1e2fcfa75>`__  2024-12-06   ``Introduce the translation API v3 (advanced) models operators. (#44627)``
`f332c770f5 <https://github.com/apache/airflow/commit/f332c770f5b2a18733c0f0352411ca9f73b90e1f>`__  2024-12-06   ``Deprecate VertexAI PaLM text generative model (#44719)``
`d2eed7a0d6 <https://github.com/apache/airflow/commit/d2eed7a0d6008890135c747eda8656581030f8ba>`__  2024-12-01   ``BigQueryInsertJobOperator: log transient error and check job state before marking task as success (#44279)``
`4d90f145c8 <https://github.com/apache/airflow/commit/4d90f145c848fbb49be6954768da48783caa5c5c>`__  2024-11-30   ``Make 'CloudBatchSubmitJobOperator' fail when job fails (#44425)``
`35000c91ea <https://github.com/apache/airflow/commit/35000c91ea7b2ce0851a8af117fdfc3683ec07bb>`__  2024-11-29   ``Show prominent warning for deprecations in docs (#44479)``
`0334901451 <https://github.com/apache/airflow/commit/03349014513114f1eaa413a9831b0027e4fbfa67>`__  2024-11-29   ``Fix yoda-conditions (#44466)``
`1fdaebd904 <https://github.com/apache/airflow/commit/1fdaebd90472b32823bd14cb75cb28dc9ed55e20>`__  2024-11-28   ``feat: add OpenLineage support for S3ToGCSOperator (#44426)``
`1de5a96592 <https://github.com/apache/airflow/commit/1de5a965921e75162fa23f2fcd8514beea428429>`__  2024-11-27   ``feat: add OpenLineage support for transfer operators between gcs and local (#44417)``
`9bae4a5b48 <https://github.com/apache/airflow/commit/9bae4a5b48256982310d079df8ece0d95a643cc9>`__  2024-11-27   ``chore: unify handling of gcs paths (#44410)``
==================================================================================================  ===========  ==============================================================================================================

11.0.0
......

Latest change: 2024-11-24

==================================================================================================  ===========  =============================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =============================================================================================================
`f0da8eeab3 <https://github.com/apache/airflow/commit/f0da8eeab3efba4d4e43439db30a273bfd67c9f1>`__  2024-11-24   ``Prepare docs for Nov 2nd wave of ad hoc providers (#44321)``
`1275fec92f <https://github.com/apache/airflow/commit/1275fec92fd7cd7135b100d66d41bdcb79ade29d>`__  2024-11-24   ``Use Python 3.9 as target version for Ruff & Black rules (#44298)``
`3c58e01266 <https://github.com/apache/airflow/commit/3c58e01266f884544fdebc70f92b63848c610d2d>`__  2024-11-23   ``Bump 'google-cloud-translate' to '3.16' (#44297)``
`da94686520 <https://github.com/apache/airflow/commit/da9468652056794a4a4cd5f11ef4abaac6a16a9a>`__  2024-11-22   ``Fix incorrect query in 'BigQueryAsyncHook.create_job_for_partition_get'. (#44225)``
`5f6b233906 <https://github.com/apache/airflow/commit/5f6b233906e69c6437bf556827844842683a5555>`__  2024-11-22   ``feat: add OpenLineage support for BigQueryToBigQueryOperator (#44214)``
`b22e3c1fcd <https://github.com/apache/airflow/commit/b22e3c1fcd5d92238f0c187c8338c11bdae73acb>`__  2024-11-22   ``Fix Dataplex Data Quality partial update (#44262)``
`91bd1eafb0 <https://github.com/apache/airflow/commit/91bd1eafb035ff311a9d573b3004699e68200e08>`__  2024-11-22   ``Introduce gcp advance API (V3) translate native datasets operators (#44271)``
`f6bbc633cb <https://github.com/apache/airflow/commit/f6bbc633cb4fd05ae26137e5f5ca99b5f6d64abb>`__  2024-11-22   ``fix google datacatalog operator tests (#44281)``
`8440016d3e <https://github.com/apache/airflow/commit/8440016d3e8c50056cad5da346ac24289a52670d>`__  2024-11-20   ``Introduce new gcp TranslateText and TranslateTextBatch operators (#43860)``
`a0f3353c47 <https://github.com/apache/airflow/commit/a0f3353c471e4d9a2cd4b23f0c358d0ae908580a>`__  2024-11-20   ``Move Asset user facing components to task_sdk (#43773)``
`8f03ab24e0 <https://github.com/apache/airflow/commit/8f03ab24e0c5d552decfbd891fe59f06c217f3bf>`__  2024-11-20   ``Add gcloud command to DataprocCreateClusterOperator to be able to create dataproc on GKE cluster (#44185)``
`3256e432d7 <https://github.com/apache/airflow/commit/3256e432d718fdd121c8fcf5687eec972e0c3f6c>`__  2024-11-16   ``Remove deprecated functionality from Google provider (#43953)``
`123dadda0e <https://github.com/apache/airflow/commit/123dadda0e0648ef1412053d1743128333eecb63>`__  2024-11-15   ``Rename execution_date to logical_date across codebase (#43902)``
==================================================================================================  ===========  =============================================================================================================

10.26.0
.......

Latest change: 2024-11-14

==================================================================================================  ===========  ================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ================================================================================================
`a53d9f6d25 <https://github.com/apache/airflow/commit/a53d9f6d257f193ea5026ba4cd007d5ddeab968f>`__  2024-11-14   ``Prepare docs for Nov 1st wave of providers (#44011)``
`e4426c3d36 <https://github.com/apache/airflow/commit/e4426c3d361c0e5cc12d68d0921685207fb752ed>`__  2024-11-14   ``Remove non-existing field  from the ListCustomTrainingJobOperator's template_fields (#43924)``
`e7194dff6a <https://github.com/apache/airflow/commit/e7194dff6a816bf3a721cbf579ceac19c11cd111>`__  2024-11-13   ``Add support for semicolon stripping to DbApiHook, PrestoHook, and TrinoHook (#41916)``
`be870f6843 <https://github.com/apache/airflow/commit/be870f6843d851a16bdfae17f17b2d4baf97f7e3>`__  2024-11-13   ``Remove Airflow 2.1 compat code in Google provider (#43952)``
`d8bd9993de <https://github.com/apache/airflow/commit/d8bd9993de6dc2fb40be64d705e8bf9be5c6bcf0>`__  2024-11-12   ``Add support for IAM database authentication for CloudSQL connection (#43631)``
`28d0a7e90a <https://github.com/apache/airflow/commit/28d0a7e90a5a56bc20ba582a0af355f53504aa28>`__  2024-11-12   ``Fix CI ruff format static checks (#43908)``
`606ef453a1 <https://github.com/apache/airflow/commit/606ef453a1cb3f2c54f90fe756d9044b8edf0121>`__  2024-11-11   ``Provide option to 'force_delete' for 'GCSToBigQueryOperator' (#43785)``
`229c6a3e46 <https://github.com/apache/airflow/commit/229c6a3e4673db03119c78828e546ebae272ef75>`__  2024-11-02   ``Explain how to use uv with airflow virtualenv and make it works (#43604)``
`533ad403ef <https://github.com/apache/airflow/commit/533ad403ef3ce74c53f14b0afe6bce64acd3e6a7>`__  2024-10-31   ``Unify reattach_states parameter logic across BigQuery operators (#43259)``
`06088a3abc <https://github.com/apache/airflow/commit/06088a3abcbb46533e74de360746db766d50cf66>`__  2024-10-31   ``Standard provider python operator (#42081)``
`85b095e888 <https://github.com/apache/airflow/commit/85b095e8885fa1347b7039e8bcb1213f5349f650>`__  2024-10-29   ``Update version of Google ADS (#43474)``
`b344cc1474 <https://github.com/apache/airflow/commit/b344cc1474de8f150773bd01e78514788ee88cc7>`__  2024-10-29   ``Fix validating 'parent_model' parameter in 'UploadModelOperator' (#43473)``
==================================================================================================  ===========  ================================================================================================

10.25.0
.......

Latest change: 2024-10-27

==================================================================================================  ===========  ========================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ========================================================================================
`78ff0a9970 <https://github.com/apache/airflow/commit/78ff0a99700125121b7f0647023503750f14a11b>`__  2024-10-27   ``Prepare docs for Oct 2nd wave of providers (#43409)``
`b4363f4684 <https://github.com/apache/airflow/commit/b4363f4684b4a878c04ce100b260d783f4d96d81>`__  2024-10-25   ``Add a debug log for creating batch workloads in dataproc (#43265)``
`cc762293ca <https://github.com/apache/airflow/commit/cc762293ca5ce20d475af787822ea48b6d3c874f>`__  2024-10-23   ``feat: add Hook Level Lineage support for GCSHook (#42507)``
`ca2c809b30 <https://github.com/apache/airflow/commit/ca2c809b30607af7ee320510587fe93b1ab90218>`__  2024-10-23   ``feat: sensor to check status of Dataform action (#43055)``
`d186d3fb50 <https://github.com/apache/airflow/commit/d186d3fb50bf4ba684886ecd132cdeb187d2cd05>`__  2024-10-23   ``Rename dataset as asset in UI (#43073)``
`014808b362 <https://github.com/apache/airflow/commit/014808b3622d8791ea0b28a1e59a8b2d2a610bfc>`__  2024-10-20   ``Fix outdated CloudRunExecuteJobOperator docs (#43195)``
`424cf507a8 <https://github.com/apache/airflow/commit/424cf507a849a0bf3239f1055beda7d7f36c785b>`__  2024-10-18   ``add min version to plyvel (#43129)``
`aeb7e90f0e <https://github.com/apache/airflow/commit/aeb7e90f0e680d32ad78216e7de3cf2d135fdbf5>`__  2024-10-17   ``Fix TestTranslationLegacyModelPredictLink dataset_id error (#42463)``
`f587edf2ee <https://github.com/apache/airflow/commit/f587edf2ee74169f1da6a408a04d7ed3c372d270>`__  2024-10-17   ``vertex ai training operators: add display_name to rendered fields (#43028)``
`f1f9201a21 <https://github.com/apache/airflow/commit/f1f9201a2199c7fd78c7146ca3a02ab25ca8de91>`__  2024-10-15   ``Create Operators for Google Cloud Vertex AI Context Caching (#43008)``
`732e0564d4 <https://github.com/apache/airflow/commit/732e0564d47813dfb05b22b9b30a108d4668a3e5>`__  2024-10-15   ``Make google provider pyarrow dependency explicit (#42996)``
`7d8ea68bda <https://github.com/apache/airflow/commit/7d8ea68bdaae3258bd391b8f6ae0277258a7c437>`__  2024-10-12   ``Restrict looker-sdk version 24.18.0 and microsoft-kiota-http 1.3.4 (#42954)``
`70b8e50ddc <https://github.com/apache/airflow/commit/70b8e50ddce305582802b6d08b1c948fa3ef086a>`__  2024-10-10   ``Remove dag.run() method (#42761)``
`857ca4c06c <https://github.com/apache/airflow/commit/857ca4c06c9008593674cabdd28d3c30e3e7f97b>`__  2024-10-09   ``Split providers out of the main "airflow/" tree into a UV workspace project (#42505)``
==================================================================================================  ===========  ========================================================================================

10.24.0
.......

Latest change: 2024-10-09

==================================================================================================  ===========  ======================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ======================================================================================================================
`2bb8628463 <https://github.com/apache/airflow/commit/2bb862846358d1c5a59b354adb39bc68d5aeae5e>`__  2024-10-09   ``Prepare docs for Oct 1st adhoc wave of providers (#42862)``
`a5ffbbda17 <https://github.com/apache/airflow/commit/a5ffbbda17450a5c99037b292844087119b5676a>`__  2024-10-09   ``Standard provider bash operator (#42252)``
`1cb9294c64 <https://github.com/apache/airflow/commit/1cb9294c6442f4e6792c1ea2b1948b1d38284326>`__  2024-10-06   ``Removed conditional check for task context logging in airflow version 2.8.0 and above (#42764)``
`2ffc389574 <https://github.com/apache/airflow/commit/2ffc389574042939f11fcae75a35a8b697583b8d>`__  2024-10-04   ``Add 'retry_if_resource_not_ready' logic for DataprocCreateClusterOperator and DataprocCreateBatchOperator (#42703)``
`8a255f3e1e <https://github.com/apache/airflow/commit/8a255f3e1e32d5084623527053116777cc4f72f9>`__  2024-10-04   ``Publish Dataproc Serverless Batch link after it starts if batch_id was provided (#41153)``
`9ec21405c0 <https://github.com/apache/airflow/commit/9ec21405c0abe23f6de2e0acd704faa6631fbe76>`__  2024-10-03   ``fix PubSubAsyncHook in PubsubPullTrigger to use gcp_conn_id (#42671)``
`64e972c977 <https://github.com/apache/airflow/commit/64e972c977fd4fa03b8db9df23410adb9862d5eb>`__  2024-10-02   ``Fix consistent return response from PubSubPullSensor (#42080)``
`ede7cb27fd <https://github.com/apache/airflow/commit/ede7cb27fd39e233889d127490a2255df8c5d27d>`__  2024-09-30   ``Rename dataset related python variable names to asset (#41348)``
`5689d64911 <https://github.com/apache/airflow/commit/5689d64911fbfd5176fc129f06e7483cc5e4ed03>`__  2024-09-27   ``Undo partition exclusion from the table name when splitting a full BigQuery table name (#42541)``
`dc43d31c5a <https://github.com/apache/airflow/commit/dc43d31c5a80b1b58cb1c2be4f6b1e0079d579fa>`__  2024-09-27   ``Fix gcp text to speech uri fetch (#42309)``
`56ab422a97 <https://github.com/apache/airflow/commit/56ab422a97768f59dc7ff4dc4f3262c0bb11002c>`__  2024-09-27   ``Deprecate AutoMLBatchPredictOperator and refactor AutoMl system tests (#42260)``
`b266d8b7b5 <https://github.com/apache/airflow/commit/b266d8b7b5faf7aa28385d120e3832e364b38cbc>`__  2024-09-27   ``Update docs regarding the AutoMLText deprecation (#42415)``
`b0234cbaf7 <https://github.com/apache/airflow/commit/b0234cbaf73bdf28640b77e2f1c378d5c489b26a>`__  2024-09-27   ``Refactor ''bucket.get_blob'' calls in ''GCSHook'' to handle validation for non-existent objects. (#42474)``
`79a8882d2f <https://github.com/apache/airflow/commit/79a8882d2f60eea5d189e07dcbe778b403cc968d>`__  2024-09-25   ``Remove deprecated CloudSQL HA functionality from the system test (#42461)``
`eed1d0d254 <https://github.com/apache/airflow/commit/eed1d0d2548a98bc3cd66d469ff09e1e2bc0945e>`__  2024-09-24   ``Bugfix/dataflow job location passing (#41887)``
==================================================================================================  ===========  ======================================================================================================================

10.23.0
.......

Latest change: 2024-09-21

==================================================================================================  ===========  ====================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================================================================
`7628d47d04 <https://github.com/apache/airflow/commit/7628d47d0481966d9a9b25dfd4870b7a6797ebbf>`__  2024-09-21   ``Prepare docs for Sep 1st wave of providers (#42387)``
`c051d0aa4c <https://github.com/apache/airflow/commit/c051d0aa4c7215b35a4390822aa6ece3ac945900>`__  2024-09-20   ``Add ability to create Flink Jobs in dataproc cluster (#42342)``
`f278e62255 <https://github.com/apache/airflow/commit/f278e62255e513c26f26c76e41a8734ec36fb07a>`__  2024-09-19   ``Minor fixes to ensure successful Vertex AI LLMops pipeline (#41997)``
`d7343816b3 <https://github.com/apache/airflow/commit/d7343816b3406470dd7f963e1959171c32ef956f>`__  2024-09-19   ``Mark VertexAI AutoMLText deprecation (#42251)``
`567926535a <https://github.com/apache/airflow/commit/567926535a719f7ea93565e3fee3f2fbd9a03cb9>`__  2024-09-19   ``Add new Google Search 360 Reporting Operators (#42255)``
`73f7d89158 <https://github.com/apache/airflow/commit/73f7d891583b023239c73a926cf1fdc69069176b>`__  2024-09-11   ``Exclude partition from BigQuery table name (#42130)``
`1a255f53e4 <https://github.com/apache/airflow/commit/1a255f53e40b5b1dd7f3db7bf74328f8bc8c5787>`__  2024-09-09   ``Add return_immediately as argument to the PubSubPullSensor class (#41842)``
`96640a7580 <https://github.com/apache/airflow/commit/96640a758065224d6d0e4fcc35ab2ef205956634>`__  2024-09-09   ``Add parent_model param in 'UploadModelOperator' (#42091)``
`a2ea35ba49 <https://github.com/apache/airflow/commit/a2ea35ba49eee12cdc0a846587478d12960f48c9>`__  2024-09-04   ``Exclude google-cloud-spanner 3.49.0 (#42011)``
`7d3a402f48 <https://github.com/apache/airflow/commit/7d3a402f4882387c9ca31a435ef41441254304bc>`__  2024-09-02   ``Add DataflowStartYamlJobOperator (#41576)``
`7f9f923d64 <https://github.com/apache/airflow/commit/7f9f923d6469760d298a2a0525a1cb098eb1cd99>`__  2024-09-02   ``[Fix #41763]: Redundant forward slash in SFTPToGCSOperator when destination_path is not specified or have default value (#41928)``
`d59db11cb5 <https://github.com/apache/airflow/commit/d59db11cb5cc9764cbbee753141c533898a37bf7>`__  2024-09-02   ``Add RunEvaluationOperator for Google Vertex AI Rapid Evaluation API (#41940)``
`f52bfd987e <https://github.com/apache/airflow/commit/f52bfd987e75612ddb837d63d8a82f3c1a992c78>`__  2024-09-02   ``Remove system test for derepcated Google analytics operators (#41946)``
`7cf54a734e <https://github.com/apache/airflow/commit/7cf54a734e1eefa04ab710cb2eb364d529c6b1b1>`__  2024-09-01   ``Add CountTokensOperator for Google Generative AI CountTokensAPI (#41908)``
`2823acd125 <https://github.com/apache/airflow/commit/2823acd1257494cdd69588f421363873ba3b795d>`__  2024-09-01   ``Fix poll_interval in GKEJobTrigger (#41712)``
`9a66882ed5 <https://github.com/apache/airflow/commit/9a66882ed5bad1f08c716ecf3db10c1a6aa8406f>`__  2024-09-01   ``update pattern for dataflow job id extraction (#41794)``
`86e3d2919c <https://github.com/apache/airflow/commit/86e3d2919c74e01905029c8c6c912effb8af0dec>`__  2024-09-01   ``Enforce deprecation message format with EOL for google provider package (#41637)``
`35ce2f1566 <https://github.com/apache/airflow/commit/35ce2f1566e1c61e12876a7513345d778309a3dc>`__  2024-08-30   ``Add Supervised Fine Tuning Train Operator, Hook, Tests, Docs (#41807)``
`bbb0085603 <https://github.com/apache/airflow/commit/bbb0085603ae679c2bf4cc90c3509349ac8933e6>`__  2024-08-30   ``Update min version of google-cloud-bigquery package (#41882)``
`2af908db00 <https://github.com/apache/airflow/commit/2af908db003343d299cb1ac64eddd49a71d9349d>`__  2024-08-29   ``Unpin google-cloud-bigquery package version for Google provider (#41839)``
`ef80f6b028 <https://github.com/apache/airflow/commit/ef80f6b028f215574b08b124c44d8c28d719635b>`__  2024-08-28   ``Move away from deprecated DAG.following_schedule() method (#41773)``
`1613e9ec1c <https://github.com/apache/airflow/commit/1613e9ec1c4e5523953e045c8adcef1b9d4ce95d>`__  2024-08-25   ``remove soft_fail (#41710)``
`170b9ce907 <https://github.com/apache/airflow/commit/170b9ce90793191f7c97c6dbd09adab492082970>`__  2024-08-22   ``Fix 'do_xcom_push' and 'get_logs' functionality for KubernetesJobOperator (#40814)``
`2727d5db92 <https://github.com/apache/airflow/commit/2727d5db9261e9bdec6f6488adc67fe11b3cddc8>`__  2024-08-21   ``Update the version of google-ads (#41638)``
`716c4300a6 <https://github.com/apache/airflow/commit/716c4300a6507609ae64148b9726272fd5071492>`__  2024-08-20   ``Remove deprecated log handler argument filename_template (#41552)``
==================================================================================================  ===========  ====================================================================================================================================

10.22.0
.......

Latest change: 2024-08-19

==================================================================================================  ===========  ====================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================================
`75fb7acbac <https://github.com/apache/airflow/commit/75fb7acbaca09a040067f0a5a37637ff44eb9e14>`__  2024-08-19   ``Prepare docs for Aug 2nd wave of providers (#41559)``
`55d49cc12f <https://github.com/apache/airflow/commit/55d49cc12f31f669a5bd2b3a4b8e66e97a406077>`__  2024-08-16   ``Refactor DataprocCreateBatchOperator and Dataproc system tests (#41527)``
`b1e506b1a7 <https://github.com/apache/airflow/commit/b1e506b1a7dd49ecdbefe0463a05e3dbbcb02f31>`__  2024-08-13   ``fix(providers/google): add missing sync_hook_class to CloudDataTransferServiceAsyncHook (#41417)``
`fcbff15bda <https://github.com/apache/airflow/commit/fcbff15bda151f70db0ca13fdde015bace5527c4>`__  2024-08-12   ``Bump minimum Airflow version in providers to Airflow 2.8.0 (#41396)``
`0aad0c8107 <https://github.com/apache/airflow/commit/0aad0c81078530a3512612d6424e1dcbd01f6752>`__  2024-08-10   ``Add 'CloudRunServiceHook' and 'CloudRunCreateServiceOperator' (#40008)``
`16abb911e8 <https://github.com/apache/airflow/commit/16abb911e8f6a8b44fff519612b75ef612a58c79>`__  2024-08-06   ``Upgrade package gcloud-aio-auth>=5.2.0 (#41262)``
==================================================================================================  ===========  ====================================================================================================

10.21.1
.......

Latest change: 2024-08-03

==================================================================================================  ===========  ========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ========================================================================================================
`d23881c648 <https://github.com/apache/airflow/commit/d23881c6489916113921dcedf85077441b44aaf3>`__  2024-08-03   ``Prepare docs for Aug 1st wave of providers (#41230)``
`8f616551ca <https://github.com/apache/airflow/commit/8f616551cadbaee53b1bb5952936c163093b0b40>`__  2024-07-30   ``Fix cloudsql-query system tests (#41092)``
`7126678e87 <https://github.com/apache/airflow/commit/7126678e87c11665c06ec29595472cfaa0c7fdd6>`__  2024-07-28   ``Prepare Providers docs ad hoc release (#41074)``
`6e3bc84905 <https://github.com/apache/airflow/commit/6e3bc84905f7671ea60aa7e612ddf8c4095b70b8>`__  2024-07-26   ``fix unnecessary imports for CloudSQL hook (#41009)``
`95b5a0a2ac <https://github.com/apache/airflow/commit/95b5a0a2ac457ff5b0258845eb3e2c790cfaea41>`__  2024-07-24   ``Refactor dataproc system tests (#40720)``
`0eaa6117bf <https://github.com/apache/airflow/commit/0eaa6117bf0310be798ad2be5c82905bd6fa30b5>`__  2024-07-24   ``Move sensitive information to the secret manager for the system test google_analytics_admin (#40951)``
`0206a4cbcf <https://github.com/apache/airflow/commit/0206a4cbcfbf85ab035c25533b12f022c22cae3a>`__  2024-07-23   ``openlineage: migrate OpenLineage provider to V2 facets. (#39530)``
`67befb71bf <https://github.com/apache/airflow/commit/67befb71bfcebf6288f960a6b6986d7db6cfe3c0>`__  2024-07-18   ``Resolve CloudSQLDatabaseHook deprecation warning (#40834)``
`519b0d028c <https://github.com/apache/airflow/commit/519b0d028c4bd8a27dbd10785139a260fb98154b>`__  2024-07-16   ``Fix BeamRunJavaPipelineOperator fails without job_name set (#40645)``
`f09b2201fa <https://github.com/apache/airflow/commit/f09b2201fa1d7370cb4ba4d3c80f79acb4f91970>`__  2024-07-13   ``Fix Custom Training Job operators to accept results without managed model (#40685)``
`c29eeb18ec <https://github.com/apache/airflow/commit/c29eeb18ec0f4ba260775f71968e5d75291b208f>`__  2024-07-10   ``Fix behavior for reattach_state parameter in BigQueryInsertJobOperator (#40664)``
==================================================================================================  ===========  ========================================================================================================

10.21.0
.......

Latest change: 2024-07-09

==================================================================================================  ===========  =======================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =======================================================================================================
`09a7bd1d58 <https://github.com/apache/airflow/commit/09a7bd1d585d2d306dd30435689f22b614fe0abf>`__  2024-07-09   ``Prepare docs 1st wave July 2024 (#40644)``
`f12714d0c7 <https://github.com/apache/airflow/commit/f12714d0c7d0f6a8a5d7b6b6910c23dce4d8c71a>`__  2024-07-08   ``Update dataproc.py (#40643)``
`be271827e0 <https://github.com/apache/airflow/commit/be271827e04d91ef65fbf51eb2d2f105482177db>`__  2024-07-07   ``Resolve google deprecations in tests (#40629)``
`9c9706730c <https://github.com/apache/airflow/commit/9c9706730c06c1f4eecd5e72efa5cac1a8d95d83>`__  2024-07-04   ``Update Google Cloud Generative Model Hooks/Operators to bring parity with Vertex AI API (#40484)``
`93488d09f9 <https://github.com/apache/airflow/commit/93488d09f9754d7652824f2fe43743d6f9cd4b08>`__  2024-07-04   ``DataflowStartFlexTemplateOperator. Check for Dataflow job type each check cycle. (#40584)``
`3c1120afd9 <https://github.com/apache/airflow/commit/3c1120afd9e63a5faf637b8d36aea0f5a27e31b2>`__  2024-07-04   ``Resolve google vertex ai deprecations in tests (#40506)``
`3583329c1b <https://github.com/apache/airflow/commit/3583329c1b53530c4c2e551e37affe78761ed3e5>`__  2024-07-03   ``Add notes about reverting the change in GCSToGCSOperator (#40579)``
`c5c50cc07f <https://github.com/apache/airflow/commit/c5c50cc07f6fcd704981139beb54095d8b9938c7>`__  2024-07-03   ``Revert "Fix 'GCSToGCSOperator' behavior difference for moving single object (#40162)" (#40577)``
`7e80dc6afa <https://github.com/apache/airflow/commit/7e80dc6afa665bed166f4b78a439ba8ce225dc28>`__  2024-07-03   ``Add support for query parameters to BigQueryCheckOperator (#40556) (#40558)``
`bd7306455e <https://github.com/apache/airflow/commit/bd7306455ee289b1290a9845d1ed59c0dfc5ed1f>`__  2024-07-02   ``40559: fix add project_id to submit_batch_job hook (#40560)``
`db16eeb6ef <https://github.com/apache/airflow/commit/db16eeb6efd6006efc94d2ec9f7740fe96edf37c>`__  2024-07-02   ``fix BigQueryInsertJobOperator's return value and openlineage extraction in deferrable mode (#40457)``
`47e7e254ba <https://github.com/apache/airflow/commit/47e7e254ba171fc950a69c41d94cb80019d83661>`__  2024-07-01   ``fix OpenLineage extraction for GCP deferrable operators (#40521)``
`26768d9408 <https://github.com/apache/airflow/commit/26768d94085e8fb6ab188be01f860f18278293cc>`__  2024-06-28   ``Update example_cloud_run.py to show job resource limit setting (#40456)``
`a62bd83188 <https://github.com/apache/airflow/commit/a62bd831885957c55b073bf309bc59a1d505e8fb>`__  2024-06-27   ``Enable enforcing pydocstyle rule D213 in ruff. (#40448)``
`68a87f7676 <https://github.com/apache/airflow/commit/68a87f7676a32c5646792b916fcf82135bbc0edc>`__  2024-06-23   ``Added chunk_size parameter to LocalFilesystemToGCSOperator  (#40379)``
==================================================================================================  ===========  =======================================================================================================

10.20.0
.......

Latest change: 2024-06-22

==================================================================================================  ===========  =================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =================================================================================================
`6e5ae26382 <https://github.com/apache/airflow/commit/6e5ae26382b328e88907e8301d4b2352ef8524c5>`__  2024-06-22   ``Prepare docs 2nd wave June 2024 (#40273)``
`2f2796f675 <https://github.com/apache/airflow/commit/2f2796f675e238e0b266b8d6e4fdfe5c0b7d1bf3>`__  2024-06-21   ``Fix 'GCSToGCSOperator' behavior difference for moving single object (#40162)``
`19fc7d2e73 <https://github.com/apache/airflow/commit/19fc7d2e7336d31d2c7d01097096fb50f14b52f5>`__  2024-06-20   ``feat: added OL support for AzureBlobStorageToGCSOperator in google provider package (#40290)``
`ca7e2a05b5 <https://github.com/apache/airflow/commit/ca7e2a05b597bbb5a74b7a2f06a401013e730a38>`__  2024-06-20   ``Fix replace parameter for BigQueryToPostgresOperator (#40278)``
`81c331e29a <https://github.com/apache/airflow/commit/81c331e29a0e112380b634966c69342fa69bdd55>`__  2024-06-17   ``Update pandas minimum requirement for Python 3.12 (#40272)``
`35871f8bb5 <https://github.com/apache/airflow/commit/35871f8bb537390fc435a4b83e53da452494725f>`__  2024-06-15   ``Add dependency to httpx >= 0.25.0 everywhere (#40256)``
`1a8d12ffe5 <https://github.com/apache/airflow/commit/1a8d12ffe50c947583c6419d4e952d0f59461135>`__  2024-06-14   ``openlineage: execute extraction and message sending in separate process (#40078)``
`3e88f47c2c <https://github.com/apache/airflow/commit/3e88f47c2cb7f4eb97b3f2da1d778a680e7a366a>`__  2024-06-14   ``Refactor datapipeline operators and fix system tests (#39716)``
`d8a325705d <https://github.com/apache/airflow/commit/d8a325705d97cfb18ba3e2af186ce9aa3dc3628f>`__  2024-06-14   ``fix bigquery_to_gcs documentation (#40219)``
`e2b8f68ddf <https://github.com/apache/airflow/commit/e2b8f68ddf84bf55f350461aaf1c801e9a152ac1>`__  2024-06-14   ``add generation_config and safety_settings to google cloud multimodal model operators (#40126)``
`f0bae33ee1 <https://github.com/apache/airflow/commit/f0bae33ee1011e9d6120a40c7f44bf1ac40d46aa>`__  2024-06-14   ``Add missing location param to 'BigQueryUpdateTableSchemaOperator' (#40237)``
`23a0152de2 <https://github.com/apache/airflow/commit/23a0152de215f60dc1febbee2371b5feed1beff2>`__  2024-06-12   ``Bump minimum version of google auth (#40190)``
`a586ea8b3a <https://github.com/apache/airflow/commit/a586ea8b3ac55ec691e3dc20e705d14428438a00>`__  2024-06-11   ``Add support for external IdP OIDC token retrieval for Google Cloud Operators. (#39873)``
`8e7b48984b <https://github.com/apache/airflow/commit/8e7b48984b86dafba2bda298547c5d2bee44363a>`__  2024-06-11   ``Bump google-ads version to use v17 by default (#40158)``
`5c5a495c2c <https://github.com/apache/airflow/commit/5c5a495c2cad9faa703eb8ccde47b368fb3eea9a>`__  2024-06-11   ``Add encryption_configuration parameter to BigQuery operators (#40063)``
`f7708acab9 <https://github.com/apache/airflow/commit/f7708acab91a4728131e4a4ccabe22819cb45885>`__  2024-06-10   ``Fix hive_partition_sensor system test (#40023)``
`65dbf86f72 <https://github.com/apache/airflow/commit/65dbf86f72ed7be779e7dadd8e8e57c1216c7c07>`__  2024-06-07   ``Fix openai 1.32 breaking openai tests (#40110)``
`86e613029b <https://github.com/apache/airflow/commit/86e613029b871b0a8327d64c040da56f537c0727>`__  2024-06-07   ``Implement CloudComposerDAGRunSensor (#40088)``
`013523e5d3 <https://github.com/apache/airflow/commit/013523e5d32dd4169f0535804e94762bd4463f79>`__  2024-06-07   ``Fix credentials intialization revealed by mypy version of google auth (#40108)``
`f2a5b1dee1 <https://github.com/apache/airflow/commit/f2a5b1dee1e01ebd34517f7bfd928b3189d760fe>`__  2024-06-06   ``feat(providers/google): add default gcp_conn_id to GoogleBaseAsyncHook (#40080)``
`fe9159635f <https://github.com/apache/airflow/commit/fe9159635fdad1346a36d0ebada7f4ace3b25873>`__  2024-06-06   ``google: move openlineage imports inside methods (#40062)``
`f6148e6e33 <https://github.com/apache/airflow/commit/f6148e6e33afb5c2ce1e0644b6f1b86d004ebd2b>`__  2024-06-04   ``Update dataplex.py (#40041)``
`c0f27094ab <https://github.com/apache/airflow/commit/c0f27094abc2d09d626ef8a38cf570274a0a42ff>`__  2024-06-04   ``iMPlement per-provider tests with lowest-direct dependency resolution (#39946)``
`385d79bfd7 <https://github.com/apache/airflow/commit/385d79bfd75f236f59dab012d3e5952021e4965e>`__  2024-06-02   ``Added ordering key option for PubSubPublishMessageOperator GCP Operator (#39955)``
`933d80c1aa <https://github.com/apache/airflow/commit/933d80c1aaedf24135eab7f5a59fcf7da67338af>`__  2024-06-01   ``Update dataproc.rst (#39395)``
`ce5cd52635 <https://github.com/apache/airflow/commit/ce5cd52635280e412eacef3a9705e7d12954cdfd>`__  2024-06-01   ``Change regular expression to exclude double quote and newline (#39991)``
`a2c09d203e <https://github.com/apache/airflow/commit/a2c09d203e3831f5e7dc1a28e3daf0d38a545023>`__  2024-05-29   ``Fetch intermediate log async GKEStartPod   (#39348)``
`70121f82f7 <https://github.com/apache/airflow/commit/70121f82f74ef3866f97fc22420dcb806fd94126>`__  2024-05-28   ``Implement 'CloudDataTransferServiceRunJobOperator' (#39154)``
`23e03db2d7 <https://github.com/apache/airflow/commit/23e03db2d79829f91afe29db757a4e4a26b77874>`__  2024-05-27   ``Add method to get metadata from GCS blob in GCSHook (#38398)``
`a12a4a5d93 <https://github.com/apache/airflow/commit/a12a4a5d93f97f6de0be40339421d71bb4b0da05>`__  2024-05-27   ``gcs to gcs deprecation removal (#39726)``
`d4fe325f84 <https://github.com/apache/airflow/commit/d4fe325f8489aa19858b68ea42b71d99e80410a4>`__  2024-05-26   ``Adding params. to create_auto_ml_forecasting_training_job in AutoMl hook (#39767)``
==================================================================================================  ===========  =================================================================================================

10.19.0
.......

Latest change: 2024-05-26

==================================================================================================  ===========  ========================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ========================================================================================
`34500f3a2f <https://github.com/apache/airflow/commit/34500f3a2fa4652272bc831e3c18fd2a6a2da5ef>`__  2024-05-26   ``Prepare docs 3rd wave May 2024 (#39738)``
`4fe55e5992 <https://github.com/apache/airflow/commit/4fe55e5992dfb9ef9a6bfa4e272c30a00e27a336>`__  2024-05-24   ``Deprecate AutoML Tables operators (#39752)``
`57dab1303c <https://github.com/apache/airflow/commit/57dab1303c5850b9b2ff81e64cbbe5bd4d1032f9>`__  2024-05-23   ``typo: wrong OpenLineage facet key in spec (#39782)``
`5aad588ef9 <https://github.com/apache/airflow/commit/5aad588ef933e58c303c1908afc9c42f0d683f5c>`__  2024-05-23   ``Fix BigQueryCursor execute method if the location is missing (#39659)``
`8d5b43443a <https://github.com/apache/airflow/commit/8d5b43443a8925d55fe044d7a12f8b1ffe44cb6e>`__  2024-05-22   ``Reroute AutoML operator links to Google Translation links (#39668)``
`791f3cfc5c <https://github.com/apache/airflow/commit/791f3cfc5cc7f2798ee0fcd18ff72906c48ebd01>`__  2024-05-21   ``Fix acknowledged functionality in deferrable mode for PubSubPullSensor (#39711)``
`0f717ea5e6 <https://github.com/apache/airflow/commit/0f717ea5e61f2028e4eafd70105f551ea2b77910>`__  2024-05-21   ``removed stale code (#39744)``
`4ee46b984d <https://github.com/apache/airflow/commit/4ee46b984da73974f0a30bcf361ac36e995993c3>`__  2024-05-20   ``Remove 'openlineage.common' dependencies in Google and Snowflake providers. (#39614)``
`27b3a22e34 <https://github.com/apache/airflow/commit/27b3a22e341468855c4ef368015ad946a59aa2e3>`__  2024-05-19   ``Introduce anonymous credentials in GCP base hook (#39695)``
`a31169bd63 <https://github.com/apache/airflow/commit/a31169bd6384040fbb00c277f95859f218b1f1f7>`__  2024-05-19   ``Pin google-cloud-bigquery to < 3.21.0 (#39583)``
`74c3fb366e <https://github.com/apache/airflow/commit/74c3fb366ecf830b6e0fb961dd6668216d21cdeb>`__  2024-05-17   ``Remove parent_model version suffix if it is passed to Vertex AI operators (#39640)``
`6621874bf5 <https://github.com/apache/airflow/commit/6621874bf523c0f1caa5ac51e482434528ee13e4>`__  2024-05-14   ``Resolve deprecation warnings in Azure FileShare-to-GCS tests (#39599)``
==================================================================================================  ===========  ========================================================================================

10.18.0
.......

Latest change: 2024-05-12

==================================================================================================  ===========  =============================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =============================================================================================================================================
`97e867f170 <https://github.com/apache/airflow/commit/97e867f1701fae287a20dff7e0f9e9ecbdc38f27>`__  2024-05-12   ``Prepare docs 2nd wave May 2024 (#39565)``
`ffa523f442 <https://github.com/apache/airflow/commit/ffa523f442745123232cb35e5533629673532783>`__  2024-05-12   ``Fix validation of label values in BigQueryInsertJobOperator (#39568)``
`86caf84934 <https://github.com/apache/airflow/commit/86caf84934e056185d688f5b37dd45f630d05b5c>`__  2024-05-11   ``Remove Airflow 2.6 back compact code (#39558)``
`2b1a2f8d56 <https://github.com/apache/airflow/commit/2b1a2f8d561e569df194c4ee0d3a18930738886e>`__  2024-05-11   ``Reapply templates for all providers (#39554)``
`2c05187b07 <https://github.com/apache/airflow/commit/2c05187b07baf7c41a32b18fabdbb3833acc08eb>`__  2024-05-10   ``Faster 'airflow_version' imports (#39552)``
`8dcee5b24d <https://github.com/apache/airflow/commit/8dcee5b24d5ecfc67bdb7800ecd750d37d66be10>`__  2024-05-10   ``Add deprecation warnings and raise exception for already deprecated ones (#38673)``
`c7c680ee3b <https://github.com/apache/airflow/commit/c7c680ee3b5a6f61012c222f092cd8c19f7e1b3d>`__  2024-05-09   ``Add encryption_configuration parameter to BigQueryCheckOperator and BigQueryTableCheckOperator (#39432)``
`5abe7acf66 <https://github.com/apache/airflow/commit/5abe7acf666f8021cbdcd358079c2b8b86c37651>`__  2024-05-09   ``Fix generation temp filename in 'DataprocSubmitPySparkJobOperator' (#39498)``
`73918925ed <https://github.com/apache/airflow/commit/73918925edaf1c94790a6ad8bec01dec60accfa1>`__  2024-05-08   ``Simplify 'airflow_version' imports (#39497)``
`62b845e2d7 <https://github.com/apache/airflow/commit/62b845e2d731e94b3bcbf43ea60ad78fd8bb94f1>`__  2024-05-08   ``Disconnect GKE operators from deprecated hooks (#39434)``
`387acd0a36 <https://github.com/apache/airflow/commit/387acd0a362899347f9444a29688794c86778c3e>`__  2024-05-08   ``Fix logic to cancel the external job if the TaskInstance is not in a running or deferred state for DataprocSubmitJobOperator (#39447)``
`e7aa4d2289 <https://github.com/apache/airflow/commit/e7aa4d2289cd4207f11b697729466717889fda38>`__  2024-05-08   ``Fix logic to cancel the external job if the TaskInstance is not in a running or deferred state for BigQueryInsertJobOperator (#39442)``
`3d575fe78c <https://github.com/apache/airflow/commit/3d575fe78c5fef6796e36901865c45be2b89cbd1>`__  2024-05-08   ``Fix logic to cancel the external job if the TaskInstance is not in a running or deferred state for DataprocCreateClusterOperator (#39446)``
`f00006d1c6 <https://github.com/apache/airflow/commit/f00006d1c6d0ad531a1f783a09ab6e700efac74b>`__  2024-05-08   ``Fix 'DataprocCreateBatchOperator' with 'result_retry' raises 'AttributeError' (#39462)``
`287c107543 <https://github.com/apache/airflow/commit/287c1075439977fbc59ad955c94a5f6dfe1fbd1a>`__  2024-05-07   ``Bugfix yaml parsing for GKEStartKueueInsideClusterOperator (#39234)``
`795592c8ba <https://github.com/apache/airflow/commit/795592c8baf9ae732563e6958c3a0ad3a168c3f6>`__  2024-05-03   ``Add 'job_id' param. to 'BigQueryGetDataOperator' (#39315)``
`fe4605a10e <https://github.com/apache/airflow/commit/fe4605a10e26f1b8a180979ba5765d1cb7fb0111>`__  2024-05-01   ``Prepare docs 1st wave May 2024 (#39328)``
`e3e6aa9b3e <https://github.com/apache/airflow/commit/e3e6aa9b3e6a6c1fb2d5c8a3f1dc10f133980074>`__  2024-04-30   ``Add support for role arn for aws creds (#38911)``
`28a240a18f <https://github.com/apache/airflow/commit/28a240a18f7e5958e69732f61d639e1d8f39152f>`__  2024-04-29   ``Fix deferrable mode for DataflowTemplatedJobStartOperator and DataflowStartFlexTemplateOperator (#39018)``
`78fa36518a <https://github.com/apache/airflow/commit/78fa36518a17f65a2ad2aa98b684c9d1aacd5788>`__  2024-04-27   ``Fix batching for BigQueryToPostgresOperator (#39233)``
`2a913b682d <https://github.com/apache/airflow/commit/2a913b682dae0c4cbb876b2129394f34d74568b7>`__  2024-04-26   ``Fix DataprocSubmitJobOperator in deferrable mode=True when task is marked as failed. (#39230)``
`bea1b7f70c <https://github.com/apache/airflow/commit/bea1b7f70cd08b0cdb3cf0515646374d101c8f27>`__  2024-04-26   ``Improve 'DataprocCreateClusterOperator' Triggers for Better Error Handling and Resource Cleanup (#39130)``
`ead9b00f7c <https://github.com/apache/airflow/commit/ead9b00f7cd5acecf9d575c459bb62633088436a>`__  2024-04-25   ``Bump minimum Airflow version in providers to Airflow 2.7.0 (#39240)``
`09f3446d48 <https://github.com/apache/airflow/commit/09f3446d48f9dca02dcf9be0cad471a433a47a6c>`__  2024-04-25   ``Fix GCSObjectExistenceSensor operator to return the same XCOM value in deferrable and non-deferrable mode (#39206)``
`c434c6b989 <https://github.com/apache/airflow/commit/c434c6b98911d71f27910d7d30cf966462157612>`__  2024-04-24   ``Create 'CloudComposerRunAirflowCLICommandOperator' operator (#38965)``
`4ae85d754e <https://github.com/apache/airflow/commit/4ae85d754e9f8a65d461e86eb6111d3b9974a065>`__  2024-04-23   ``Bugfix BigQueryToMsSqlOperator (#39171)``
`b0e9613125 <https://github.com/apache/airflow/commit/b0e96131251c416f4d32ba60343ef3a6ecdb2346>`__  2024-04-22   ``add templated fields for google llm operators (#39174)``
`59084fd1f4 <https://github.com/apache/airflow/commit/59084fd1f4c200986433f9ff60b28cd6f8a0bcc1>`__  2024-04-21   ``fix: add retry logic in case of google auth refresh credential error (#38961)``
`90acbfbba1 <https://github.com/apache/airflow/commit/90acbfbba1a3e6535b87376aeaf089805b7d3303>`__  2024-04-19   ``Apply PROVIDE_PROJECT_ID mypy workaround across Google provider (#39129)``
`eee17f0a26 <https://github.com/apache/airflow/commit/eee17f0a260f9508724d66ef00bc30c506f64cda>`__  2024-04-19   ``fix: BigQueryCheckOperator skipped value and error check in deferrable mode (#38408)``
`17e60b0a2b <https://github.com/apache/airflow/commit/17e60b0a2b640a6974eeecca0765e600817cd097>`__  2024-04-18   ``fix: Use prefixes instead of all file paths for OpenLineage datasets in GCSDeleteObjectsOperator (#39059)``
`927e3643c2 <https://github.com/apache/airflow/commit/927e3643c2f901a3ac85f8dc94541ba83b3c6755>`__  2024-04-18   ``fix: Use prefixes instead of full file paths for OpenLineage datasets in GCSToGCSOperator (#39058)``
`b41cf629c8 <https://github.com/apache/airflow/commit/b41cf629c8624b906ed29760e14037e8d2f9a370>`__  2024-04-18   ``Deferrable mode for Dataflow sensors (#37693)``
`066708352e <https://github.com/apache/airflow/commit/066708352e6a6a06f213b65324e982f582019b8e>`__  2024-04-17   ``fix: OpenLineage datasets in GCSTimeSpanFileTransformOperator (#39064)``
`0c630fadad <https://github.com/apache/airflow/commit/0c630fadad9a0d37bf8ca928deebe5eb272b78c0>`__  2024-04-15   ``handle KubernetesDeleteJobOperator import (#39036)``
`e237041142 <https://github.com/apache/airflow/commit/e237041142e36349cc62e743105c91b04ddf4253>`__  2024-04-15   ``Add logic to handle on_kill for BigQueryInsertJobOperator when deferrable=True (#38912)``
`f8104325b7 <https://github.com/apache/airflow/commit/f8104325b7a66d4e98ff3a6c3555f90c796071c6>`__  2024-04-15   ``Activate RUF019 that checks for unnecessary key check (#38950)``
`1c9a6609f3 <https://github.com/apache/airflow/commit/1c9a6609f36a6fabddfd6d3858cca049d4088668>`__  2024-04-14   ``Adding MSGraphOperator in Microsoft Azure provider (#38111)``
`c4a106e69b <https://github.com/apache/airflow/commit/c4a106e69bbc396d2527a3b8c94e2d95fced4284>`__  2024-04-12   ``Create GKESuspendJobOperator and GKEResumeJobOperator operators (#38677)``
`5ff26586cd <https://github.com/apache/airflow/commit/5ff26586cd3931d223e76aeb73770f062ff9e409>`__  2024-04-11   ``Deferrable mode for Custom Training Job operators (#38584)``
`1757704d8f <https://github.com/apache/airflow/commit/1757704d8f7c7a335cdf8f90ccb12b4d8e6f9d9a>`__  2024-04-11   ``Enhancement for SSL-support in CloudSQLExecuteQueryOperator (#38894)``
==================================================================================================  ===========  =============================================================================================================================================

10.17.0
.......

Latest change: 2024-04-10

==================================================================================================  ===========  ==================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==================================================================================================================
`5fa80b6aea <https://github.com/apache/airflow/commit/5fa80b6aea60f93cdada66f160e2b54f723865ca>`__  2024-04-10   ``Prepare docs 1st wave (RC1) April 2024 (#38863)``
`42c3eaf23a <https://github.com/apache/airflow/commit/42c3eaf23a1cb76ae9f07b027b09948aabfcbf02>`__  2024-04-09   ``Fix BigQuery connection and add docs (#38430)``
`ca501eff4d <https://github.com/apache/airflow/commit/ca501eff4d552e0183a3323b6e8fe4b06ebf3e72>`__  2024-04-09   ``fix: try002 for provider google (#38803)``
`5c8510a1f1 <https://github.com/apache/airflow/commit/5c8510a1f11fc4891872297a72b1bcf863daa27a>`__  2024-04-05   ``Add google-cloud-bigquery as explicit google-provider dependency (#38753)``
`091d5e6267 <https://github.com/apache/airflow/commit/091d5e62678de943adfce1b8a8cd94dccbbfa98b>`__  2024-04-03   ``fix(google,log): Avoid log name overriding (#38071)``
`c4439713cf <https://github.com/apache/airflow/commit/c4439713cf6485acac1b7bbdc38aec524be3efab>`__  2024-04-02   ``Revert "Delete deprecated AutoML operators and deprecate AutoML hook and links (#38418)" (#38633)``
`d3dc88f084 <https://github.com/apache/airflow/commit/d3dc88f0844bcb377a9e52312e1a99b5ca6e617e>`__  2024-04-01   ``Avoid to use 'functools.lru_cache' in class methods in 'google' provider (#38652)``
`13e9a0d0d5 <https://github.com/apache/airflow/commit/13e9a0d0d562238afe03830a33dd52cf5cea5d12>`__  2024-04-01   ``Fix credentials error for S3ToGCSOperator trigger (#37518)``
`0f513472a7 <https://github.com/apache/airflow/commit/0f513472a72c04757a3fd16d4805b9048253a05c>`__  2024-03-30   ``Add 'impersonation_scopes' to BigQuery (#38169)``
`afb686c95e <https://github.com/apache/airflow/commit/afb686c95ef276ac8d9d473b74303fd1551d00fd>`__  2024-03-26   ``Implement deferrable mode for GKEStartJobOperator (#38454)``
`067fedbb99 <https://github.com/apache/airflow/commit/067fedbb998e855f536bceccceb03cf33ce4fae9>`__  2024-03-26   ``Add the deferrable mode to RunPipelineJobOperator (#37969)``
`32ed83bd0e <https://github.com/apache/airflow/commit/32ed83bd0ef4694668bf74f3afbfaa0f5afa2768>`__  2024-03-25   ``Refactor GKE hooks (#38404)``
`4a4eee113f <https://github.com/apache/airflow/commit/4a4eee113f35f941f8deed3c53b814b67116c6b2>`__  2024-03-24   ``Delete deprecated AutoML operators and deprecate AutoML hook and links (#38418)``
`3ac0aaf748 <https://github.com/apache/airflow/commit/3ac0aaf748faf8d1697282c5b1a11c7c8bdb4032>`__  2024-03-24   ``Fix 'parent_model' parameter in GCP Vertex AI AutoML and Custom Job operators (#38417)``
`da4f6f077c <https://github.com/apache/airflow/commit/da4f6f077c99e66bef2713309cd03b6ac398dcdc>`__  2024-03-22   ``fix(google): add return statement to yield within a while loop in triggers (#38394)``
`8e7b1add43 <https://github.com/apache/airflow/commit/8e7b1add435164112b80b9319ec0b2f2df94fa12>`__  2024-03-20   ``Remove unused loop variable from airflow package (#38308)``
`e0feb7b80b <https://github.com/apache/airflow/commit/e0feb7b80b31ee6fce88cea28ae329b73b70c343>`__  2024-03-20   ``Fix cursor unique name surpasses Postgres identifier limit in 'PostgresToGCSOperator' (#38040)``
`29ac05f496 <https://github.com/apache/airflow/commit/29ac05f4969f54815c82d6af9211798aa53c45c3>`__  2024-03-18   ``Create DeleteKubernetesJobOperator and GKEDeleteJobOperator operators (#37793)``
`0a74928894 <https://github.com/apache/airflow/commit/0a74928894fb57b0160208262ccacad12da23fc7>`__  2024-03-18   ``Bump ruff to 0.3.3 (#38240)``
`80e60d7303 <https://github.com/apache/airflow/commit/80e60d73033765b203d9175ca80a75c15010554d>`__  2024-03-18   ``Create GKEStartKueueJobOperator operator (#37477)``
`0acd6b27af <https://github.com/apache/airflow/commit/0acd6b27af6469e3b35143247388cf0aab3dea5a>`__  2024-03-16   ``templated fields logic checks for cloud_storage_transfer_service (#37519)``
`17ce4ac219 <https://github.com/apache/airflow/commit/17ce4ac219846138d1005d20cffa72bea291b25f>`__  2024-03-16   ``Update GCS hook to get crc32c hash for CMEK-protected objects (#38191)``
`3e2bfb8b3e <https://github.com/apache/airflow/commit/3e2bfb8b3ee80ddc18b00e461de53390dcc5a8b3>`__  2024-03-15   ``Set job labels for traceability in BigQuery jobs (#37736)``
`cbb0cad49c <https://github.com/apache/airflow/commit/cbb0cad49c10400e8e1b56703f6af220ee01a32c>`__  2024-03-15   ``Rename mlengine's operators' fields' names to comply with templated fields validation (#38053)``
`9442435b87 <https://github.com/apache/airflow/commit/9442435b87973e48c6e726d970ab1c8de0dd8265>`__  2024-03-15   ``Rename Vertex AI AutoML operators fields' names to comply with templated fields validation (#38049)``
`83060e16e1 <https://github.com/apache/airflow/commit/83060e16e1f63914b8ca0db135572acf0ba74e52>`__  2024-03-15   ``Rename 'DeleteCustomTrainingJobOperator''s fields' names to comply with templated fields validation (#38048)``
`0e2f2bc0ff <https://github.com/apache/airflow/commit/0e2f2bc0ffb1c132bb93c1b0abbede6fdf0bad52>`__  2024-03-14   ``Fix gcs Anonymous user issue because none token (#38102)``
`8f773a62c1 <https://github.com/apache/airflow/commit/8f773a62c1760b32cc2464343353a28cbfe9211f>`__  2024-03-08   ``Add GKECreateCustomResourceOperator and GKEDeleteCustomResourceOperator operators (#37616)``
`e256badea9 <https://github.com/apache/airflow/commit/e256badea9bd3f7d1ec016a34d7eb154752bda48>`__  2024-03-08   ``Restore delegate_to for Google Transfer Operators retrieving from Google Cloud. (#37925)``
`46666af9ec <https://github.com/apache/airflow/commit/46666af9ecc0f183d7bf0845a646f24fbd91c697>`__  2024-03-07   ``Refactor CreateHyperparameterTuningJobOperator (#37938)``
`1e6140ba25 <https://github.com/apache/airflow/commit/1e6140ba250a9a99b5f1b7d73aa689e89d4152ec>`__  2024-03-06   ``Add VertexAI Language Model and Multimodal Model Operators for Google Cloud Generative AI use (#37721)``
`ca11b7af23 <https://github.com/apache/airflow/commit/ca11b7af239c90f6d7c00ed5116fdd08fda1a5ab>`__  2024-03-06   ``Fix BigQueryTablePartitionExistenceTrigger partition query (#37655)``
`3f52790d42 <https://github.com/apache/airflow/commit/3f52790d425cd51386715c240d9a38a20756de2a>`__  2024-03-06   ``Resolve G004: Logging statement uses f-string (#37873)``
`ec220a8679 <https://github.com/apache/airflow/commit/ec220a8679495e621ef92bdd8fee585ab3dd172b>`__  2024-03-06   ``Deferrable mode for CreateBatchPredictionJobOperator (#37818)``
`ca72f0fd89 <https://github.com/apache/airflow/commit/ca72f0fd89ec05c98045e4b6bcefcf933784cf7d>`__  2024-03-06   ``Add GKEListJobsOperator and GKEDescribeJobOperator (#37598)``
`0c09338556 <https://github.com/apache/airflow/commit/0c093385563e8edce65e84db3e27e22ad478bdf1>`__  2024-03-06   ``Upgrade google-ads version (#37787)``
`4df2d9ce6f <https://github.com/apache/airflow/commit/4df2d9ce6fca0865fe86e68a1c16261603154b79>`__  2024-03-06   ``the resource example file 'example_upload.txt' has been moved to 'airflow-system-tests-resources/gcs' (#37883)``
==================================================================================================  ===========  ==================================================================================================================

10.16.0
.......

Latest change: 2024-03-04

==================================================================================================  ===========  ============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ============================================================================================
`83316b8158 <https://github.com/apache/airflow/commit/83316b81584c9e516a8142778fc509f19d95cc3e>`__  2024-03-04   ``Prepare docs 1st wave (RC1) March 2024 (#37876)``
`30f7b2abe6 <https://github.com/apache/airflow/commit/30f7b2abe6991fe6e565f17f7d0701e80ecba0d3>`__  2024-03-04   ``Avoid to use too broad 'noqa' (#37862)``
`2ab60812a0 <https://github.com/apache/airflow/commit/2ab60812a040cb8b760acaf396f625d0d719e4be>`__  2024-03-01   ``Make 'executemany' keyword arguments only in 'DbApiHook.insert_rows' (#37840)``
`77341ef6a1 <https://github.com/apache/airflow/commit/77341ef6a1e4ffa3f8d3275eade325c89f2c95f2>`__  2024-02-29   ``Avoid non-recommended usage of logging (#37792)``
`2bc103698f <https://github.com/apache/airflow/commit/2bc103698fad1b7c0bebed0d5cbdda0ec7ea83c3>`__  2024-02-28   ``Unify 'aws_conn_id' type to always be 'str | None' (#37768)``
`f001576a94 <https://github.com/apache/airflow/commit/f001576a94bd7e03753ebe37aa663a9f1865ccf5>`__  2024-02-28   ``Fix invalid deprecation of 'DataFusionPipelineLinkHelper' (#37755)``
`9e4bdc9e45 <https://github.com/apache/airflow/commit/9e4bdc9e457c275eb2cead5d80c2f79c3b9a0085>`__  2024-02-27   ``Limit 'pandas' to '<2.2' (#37748)``
`8e42a2e019 <https://github.com/apache/airflow/commit/8e42a2e019dc89d95ed6dce8dff75e18abf6e97a>`__  2024-02-27   ``Remove broken deprecated fallback into the Google provider operators (#37740)``
`b52b227c04 <https://github.com/apache/airflow/commit/b52b227c048674117e11d720dfd01c4eeacea854>`__  2024-02-26   ``Implement AIP-60 Dataset URI formats (#37005)``
`046fb49420 <https://github.com/apache/airflow/commit/046fb49420c0da1d47f308a43d01644a0854b630>`__  2024-02-25   ``fix templated field assignment 'google/cloud/operators/compute.py' (#37659)``
`8c05e59922 <https://github.com/apache/airflow/commit/8c05e59922946ee06bc014d578676581b33dba2c>`__  2024-02-23   ``fix bq_to_mysql init checks (#37653)``
`ca4c559865 <https://github.com/apache/airflow/commit/ca4c55986534a553baea80a7bb5b834f7fdf0ddd>`__  2024-02-23   ``Fix Async GCSObjectsWithPrefixExistenceSensor xcom push (#37634)``
`810fb5f2a8 <https://github.com/apache/airflow/commit/810fb5f2a8dbf624048d5f1a12398114c5fc7953>`__  2024-02-22   ``feat(GKEPodAsyncHook): use async credentials token implementation (#37486)``
`5fc866aebe <https://github.com/apache/airflow/commit/5fc866aebe84caed43562eda1a5743ac60393a05>`__  2024-02-22   ``'CloudRunExecuteJobOperator': Add project_id to hook.get_job calls (#37201)``
`2cb96a8e85 <https://github.com/apache/airflow/commit/2cb96a8e85a328e383561a80b8b5d1fa5c0bef4d>`__  2024-02-21   ``resolve template fields init checks for 'bigquery' (#37586)``
`52d2032887 <https://github.com/apache/airflow/commit/52d20328872b68f0f80986006726f16a6dc56c45>`__  2024-02-21   ``Fix typo on DataflowStartFlexTemplateOperator documentation (#37595)``
`68fc80e42e <https://github.com/apache/airflow/commit/68fc80e42e1cb6666dcea3de379505ee19cf685d>`__  2024-02-20   ``Update docs for the DataprocCreateBatchOperator (#37562)``
`011cd3debb <https://github.com/apache/airflow/commit/011cd3debb4bb166908277c764d65eaf5985c7af>`__  2024-02-20   ``Use offset-naive datetime in _CredentialsToken (#37539)``
`5a0be392e6 <https://github.com/apache/airflow/commit/5a0be392e66f8e5426ba3478621115e92fcf245b>`__  2024-02-16   ``Add comment about versions updated by release manager (#37488)``
`123b656151 <https://github.com/apache/airflow/commit/123b656151be6605712951c672a703d5b7abfc72>`__  2024-02-16   ``Fix GCSSynchronizeBucketsOperator timeout error (#37237)``
`42f8d048d2 <https://github.com/apache/airflow/commit/42f8d048d2dccfcf59a44e00e9b1e8a3e63090a0>`__  2024-02-16   ``Replace usage of 'datetime.utcnow' and 'datetime.utcfromtimestamp' in providers (#37138)``
`32ba99b6c2 <https://github.com/apache/airflow/commit/32ba99b6c27b1e9ec7ebfffceeecb650f6f3d4d7>`__  2024-02-15   ``Create GKEStartJobOperator and KubernetesJobOperator (#36847)``
`107b3e2621 <https://github.com/apache/airflow/commit/107b3e2621977e681080af08555bf2b8464d2df1>`__  2024-02-15   ``Add developer token as authentication method to GoogleAdsHook (#37417)``
`df132b2dd6 <https://github.com/apache/airflow/commit/df132b2dd6fcb9022e1ff5f28841bec7a120853b>`__  2024-02-15   ``Add GKEStartKueueInsideClusterOperator (#37072)``
`270282f4cd <https://github.com/apache/airflow/commit/270282f4cd6eb808873cfbd15d4c35226646d48e>`__  2024-02-13   ``fix (#37391)``
`2d0d78b20a <https://github.com/apache/airflow/commit/2d0d78b20a1582e02251d2ff1c4a24827c194ee7>`__  2024-02-12   ``Add D401 fixes (#37348)``
`d43c804f2b <https://github.com/apache/airflow/commit/d43c804f2bda3bc518682c9b2af94ea30475c879>`__  2024-02-12   ``Add optional 'location' parameter to the BigQueryInsertJobTrigger (#37282)``
`028fbdfed3 <https://github.com/apache/airflow/commit/028fbdfed3a3c6e7e268ac6ee1ba35156dabf206>`__  2024-02-12   ``Use wait_for_operation in DataprocInstantiateInlineWorkflowTemplateOperator (#37145)``
==================================================================================================  ===========  ============================================================================================

10.15.0
.......

Latest change: 2024-02-12

==================================================================================================  ===========  ==========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==========================================================================================================
`bfb054e9e8 <https://github.com/apache/airflow/commit/bfb054e9e867b8b9a6a449e43bfba97f645e025e>`__  2024-02-12   ``Prepare docs 1st wave of Providers February 2024 (#37326)``
`9c4a9d7947 <https://github.com/apache/airflow/commit/9c4a9d7947879a3bfab85ef32b8afcfa77fdd871>`__  2024-02-11   ``D401 lint fixes for all hooks in google provider (#37296)``
`e31aa4e1ea <https://github.com/apache/airflow/commit/e31aa4e1eaecefbdf19197e63e0719cb29e312af>`__  2024-02-10   ``fix(providers/google): fix how GKEPodAsyncHook.service_file_as_context is used (#37306)``
`0a8e771fb7 <https://github.com/apache/airflow/commit/0a8e771fb7e201bf4ee89444e7d50ddb6c00d372>`__  2024-02-10   ``D401 lint fixes for google provider (#37304)``
`90e2b12d6b <https://github.com/apache/airflow/commit/90e2b12d6b99d2f7db43e45f5e8b97d3b8a43b36>`__  2024-02-08   ``Upgrade mypy to 1.8.0 (#36428)``
`6b49bb3a4f <https://github.com/apache/airflow/commit/6b49bb3a4f0994d8beb95b789c07ed894b577abf>`__  2024-02-08   ``Fix metadata override for ComputeEngineSSHHook (#37192)``
`7883bcc85c <https://github.com/apache/airflow/commit/7883bcc85cee3826540b65eb6522320044931436>`__  2024-02-07   ``Fix assignment of template field in '__init__' in 'custom_job' (#36789)``
`1fe8cddde8 <https://github.com/apache/airflow/commit/1fe8cddde8159ecffc61f204b8383f5d1ff39047>`__  2024-02-05   ``Fix location requirement in DataflowTemplatedJobStartOperator (#37069)``
`2372e21d9d <https://github.com/apache/airflow/commit/2372e21d9dd44a9cb1f7cd20bbee7f1c37936faf>`__  2024-02-05   ``add service_file support to GKEPodAsyncHook (#37081)``
`46470aba68 <https://github.com/apache/airflow/commit/46470aba68e5ebeee24a03dc22d012a50ee287ad>`__  2024-02-04   ``Fix assignment of template field in '__init__' in 'CloudDataTransferServiceCreateJobOperator' (#36909)``
`11564a0297 <https://github.com/apache/airflow/commit/11564a0297e3a4791836e26b260ce9428daa387e>`__  2024-02-04   ``Fixed the hardcoded default namespace value for GCP Data Fusion links. (#35379)``
`41503140fc <https://github.com/apache/airflow/commit/41503140fcb063e79d837443eeaf4ab7d7110cb4>`__  2024-01-31   ``Do not ignore the internal_ip_only if set to false in Dataproc cluster config (#37014)``
`fb62cf281e <https://github.com/apache/airflow/commit/fb62cf281e030abcbcbd275cf974fdd4fa54eac6>`__  2024-01-31   ``Revert protection against back-compatibilty issue with google-core-api (#37111)``
`dec2662190 <https://github.com/apache/airflow/commit/dec2662190dd4480d0c631da733e19d2ec9a479d>`__  2024-01-30   ``feat: Switch all class, functions, methods deprecations to decorators (#36876)``
`770a96f4c5 <https://github.com/apache/airflow/commit/770a96f4c577c3af2bcb6c03dcfaac4a5ad051b6>`__  2024-01-26   ``Update GCP Dataproc ClusterGenerator to support GPU params (#37036)``
`0f2670e7ac <https://github.com/apache/airflow/commit/0f2670e7acaabb7110dd800b42b491aac9a8a511>`__  2024-01-26   ``Create DataprocStartClusterOperator and DataprocStopClusterOperator (#36996)``
`35617620a9 <https://github.com/apache/airflow/commit/35617620a9d2aee8fcc76db7fb6429e90c25783e>`__  2024-01-26   ``Implement deferrable mode for CreateHyperparameterTuningJobOperator (#36594)``
`35daa3462b <https://github.com/apache/airflow/commit/35daa3462b128e5972d9e270dc66e6862f934262>`__  2024-01-26   ``Enable '_enable_tcp_keepalive' functionality for GKEPodHook (#36999)``
==================================================================================================  ===========  ==========================================================================================================

10.14.0
.......

Latest change: 2024-01-26

==================================================================================================  ===========  ====================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================================================
`cead3da4a6 <https://github.com/apache/airflow/commit/cead3da4a6f483fa626b81efd27a24dcb5a36ab0>`__  2024-01-26   ``Add docs for RC2 wave of providers for 2nd round of Jan 2024 (#37019)``
`0b680c9492 <https://github.com/apache/airflow/commit/0b680c94922e3f7ca1f3ada8328e315bbae37dc8>`__  2024-01-26   ``Revert "Provide the logger_name param in providers hooks in order to override the logger name (#36675)" (#37015)``
`10ad8d9e38 <https://github.com/apache/airflow/commit/10ad8d9e38351427acfa30c58a7702f0f4d66f05>`__  2024-01-25   ``Add operator to diagnose cluster (#36899)``
`241b50a46e <https://github.com/apache/airflow/commit/241b50a46ecdc27331c7fc7aeda2405ee3e9f323>`__  2024-01-24   ``Add scopes into a GCP token (#36974)``
`fbd21eda1e <https://github.com/apache/airflow/commit/fbd21eda1ec23a8e5c6d1d9dceb6c45a1ab57aca>`__  2024-01-23   ``feat: full support for google credentials in gcloud-aio clients (#36849)``
`1c14767638 <https://github.com/apache/airflow/commit/1c14767638c26dbfaa2b984f9f5bbeb483bd88cf>`__  2024-01-23   ``Fix google operators handling of impersonation chain (#36903)``
`2b4da0101f <https://github.com/apache/airflow/commit/2b4da0101f0314989d148c3c8a02c87e87048974>`__  2024-01-22   ``Prepare docs 2nd wave of Providers January 2024 (#36945)``
`700e9e4890 <https://github.com/apache/airflow/commit/700e9e489014fe1982ff0074421eb8052469773e>`__  2024-01-22   ``docs(providers/google): reword GoogleBaseHookAsync as GoogleBaseAsyncHook in docstring (#36946)``
`e07a42e69d <https://github.com/apache/airflow/commit/e07a42e69d1ab472c4da991fca5782990607ebe0>`__  2024-01-22   ``Check cluster state before defer Dataproc operators to trigger (#36892)``
`9e4f5ba67a <https://github.com/apache/airflow/commit/9e4f5ba67a3b46ced541844a0dd9cfb9ed44e7cd>`__  2024-01-21   ``fix templating field to super constructor (#36934)``
`f1758fdd7d <https://github.com/apache/airflow/commit/f1758fdd7da8e933a701ab1a8df96c43288e8d0d>`__  2024-01-20   ``fix: respect connection ID and impersonation in GKEStartPodOperator (#36861)``
`09bb1a87a5 <https://github.com/apache/airflow/commit/09bb1a87a58dfad7c1de537edb8fc3ae1a944ffa>`__  2024-01-20   ``style(providers/google): improve BigQueryInsertJobOperator type hinting (#36894)``
`681859c7bf <https://github.com/apache/airflow/commit/681859c7bffabce0c294060d811db2fb16851816>`__  2024-01-18   ``Change default 'parquet_row_group_size' in 'BaseSQLToGCSOperator' (#36817)``
`6ff96af480 <https://github.com/apache/airflow/commit/6ff96af4806a4107d48ee2e966c61778045ad584>`__  2024-01-18   ``Fix stacklevel in warnings.warn into the providers (#36831)``
`1ea623a834 <https://github.com/apache/airflow/commit/1ea623a834a003df50af208d583b98452a28d430>`__  2024-01-17   ``Fix deprecations into the GCP Dataproc links (#36834)``
`437d4e4467 <https://github.com/apache/airflow/commit/437d4e44676fe65ce9e9f7b99fb85740332071a7>`__  2024-01-17   ``Deprecate AutoMLTrainModelOperator for Vision and Video (#36473)``
`8e6bfc2956 <https://github.com/apache/airflow/commit/8e6bfc2956254127479e751f94a4adcb3d7552c4>`__  2024-01-13   ``fix assignment of templated field in constructor (#36603)``
`4a5da8e05e <https://github.com/apache/airflow/commit/4a5da8e05e7ce29dff0ac780a9be9bfb55f216da>`__  2024-01-10   ``Remove backward compatibility check for KubernetesPodOperator module (#36724)``
`c439ab87c4 <https://github.com/apache/airflow/commit/c439ab87c421aaa6bd5d8074780e4f63606a1ef1>`__  2024-01-10   ``Standardize airflow build process and switch to Hatchling build backend (#36537)``
`ead75286dc <https://github.com/apache/airflow/commit/ead75286dcbaec7728e64c5277788ad401b7b79d>`__  2024-01-10   ``Remove backward compatibility check for KubernetesPodTrigger module (#36721)``
`6bd450da1e <https://github.com/apache/airflow/commit/6bd450da1eb6cacc2ccfd4544d520ae059b75c3b>`__  2024-01-10   ``Provide the logger_name param in providers hooks in order to override the logger name (#36675)``
`ecb2c9f24d <https://github.com/apache/airflow/commit/ecb2c9f24d1364642604c14f0deb681ab4894135>`__  2024-01-09   ``Set min pandas dependency to 1.2.5 for all providers and airflow (#36698)``
`584087f087 <https://github.com/apache/airflow/commit/584087f0874453d8e44ae4cd6ec282340dbf6c84>`__  2024-01-09   ``Add templated fields to 'BigQueryToSqlBaseOperator' from 'BigQueryToPostgresOperator' (#36663)``
`f7b663d9af <https://github.com/apache/airflow/commit/f7b663d9aff472d0a419e16c262fbae2a8a69ce1>`__  2024-01-07   ``Run mypy checks for full packages in CI (#36638)``
`f28643b7bd <https://github.com/apache/airflow/commit/f28643b7bdc90a61ec5bd12f8505772cd8c3bf7f>`__  2024-01-03   ``Implement Google Analytics Admin (GA4) operators (#36276)``
`75aa4a3385 <https://github.com/apache/airflow/commit/75aa4a33856adefcfe87f76879ed99958e7ed4e0>`__  2024-01-03   ``Preserve ASCII control characters directly through the BigQuery load API (#36533)``
`6937ae7647 <https://github.com/apache/airflow/commit/6937ae76476b3bc869ef912d000bcc94ad642db1>`__  2023-12-30   ``Speed up autocompletion of Breeze by simplifying provider state (#36499)``
`db0679de12 <https://github.com/apache/airflow/commit/db0679de128667ac07402202d5ee92e60a3f1f6b>`__  2023-12-30   ``Added Check for Cancel Workflow Invocation and added new Query Workflow Invocation operator (#36351)``
`f070efa95c <https://github.com/apache/airflow/commit/f070efa95c9c1aafffec76a2a24f2b58961ff39c>`__  2023-12-30   ``remove unecessary templated field (#36491)``
`918552acad <https://github.com/apache/airflow/commit/918552acad136128ea603d765d8be23d3f9bfcbd>`__  2023-12-29   ``prevent templated field logic checks in operators __init__ (#36489)``
==================================================================================================  ===========  ====================================================================================================================

10.13.1
.......

Latest change: 2023-12-28

==================================================================================================  ===========  =================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =================================================================================================
`9b5d6bfe27 <https://github.com/apache/airflow/commit/9b5d6bfe273cf6af0972e28ff97f99ea325cd991>`__  2023-12-28   ``Add documentation for 3rd wave of providers in Deember (#36464)``
`49ce3ed006 <https://github.com/apache/airflow/commit/49ce3ed00677d899e3f7d62ce82577882feeb42e>`__  2023-12-28   ``Remove backcompat code for stackdriver (#36442)``
`cba3ca7067 <https://github.com/apache/airflow/commit/cba3ca70671a1a6dfc2311c7b00659ab0413f746>`__  2023-12-28   ``Remove remaining Airflow 2.5 backcompat code from GCS Task Handler (#36443) (#36457)``
`127c0725b9 <https://github.com/apache/airflow/commit/127c0725b9eb7c8be015ac10d74f963e3d6383ae>`__  2023-12-27   ``Revert "Remove remaining Airflow 2.5 backcompat code from GCS Task Handler (#36443)" (#36453)``
`9e55f51a9f <https://github.com/apache/airflow/commit/9e55f51a9fd0555b910d97dff9482933dd42ed72>`__  2023-12-27   ``Remove unused '_parse_version' function (#36450)``
`75faf1115d <https://github.com/apache/airflow/commit/75faf1115d990746784e25280c0b326b3b557b86>`__  2023-12-27   ``Remove remaining Airflow 2.5 backcompat code from GCS Task Handler (#36443)``
`794ce730aa <https://github.com/apache/airflow/commit/794ce730aa18ded08c06134ed311a39818168728>`__  2023-12-26   ``Revert "Remove remaining Airflow 2.5 backcompat code from Google Provider (#36366)" (#36440)``
==================================================================================================  ===========  =================================================================================================

10.13.0
.......

Latest change: 2023-12-23

==================================================================================================  ===========  ============================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ============================================================================================================================
`b15d5578da <https://github.com/apache/airflow/commit/b15d5578dac73c4c6a3ca94d90ab0dc9e9e74c9c>`__  2023-12-23   ``Re-apply updated version numbers to 2nd wave of providers in December (#36380)``
`f5883d6e7b <https://github.com/apache/airflow/commit/f5883d6e7be83f1ab9468e67164b7ac381fdb49f>`__  2023-12-23   ``Prepare 2nd wave of providers in December (#36373)``
`2c2763f806 <https://github.com/apache/airflow/commit/2c2763f806517ae514d5614d519966da02ff4371>`__  2023-12-22   ``Remove remaining Airflow 2.5 backcompat code from Google Provider (#36366)``
`10c4c352f9 <https://github.com/apache/airflow/commit/10c4c352f93296ff4434fffe863aa249ad3fea5c>`__  2023-12-20   ``Minor fix to DataprocCreateClusterOperator operator docs. (#36322)``
`881d88b4da <https://github.com/apache/airflow/commit/881d88b4da90fbc053f9d911b80d1aa015a12e02>`__  2023-12-19   ``Implement deferrable mode for BeamRunJavaPipelineOperator (#36122)``
`5ab43d5541 <https://github.com/apache/airflow/commit/5ab43d5541a68c5c90fe849f19e344bcdeddd44f>`__  2023-12-19   ``Move KubernetesPodTrigger hook to a cached property (#36290)``
`d793fda391 <https://github.com/apache/airflow/commit/d793fda39161be9281d3d4da54e2e2b4f6344b4d>`__  2023-12-18   ``Add ability to run streaming Job for BeamRunPythonPipelineOperator in non deferrable mode (#36108)``
`92335417d8 <https://github.com/apache/airflow/commit/92335417d881c01b0d2ef77ad254f3f3b491df4c>`__  2023-12-17   ``Add use_glob to GCSObjectExistenceSensor (#34137)``
`e9ba37bb58 <https://github.com/apache/airflow/commit/e9ba37bb58da0e3d6739ec063f7160f50487d3b8>`__  2023-12-17   ``Add code snippet formatting in docstrings via Ruff (#36262)``
`ffb003a58e <https://github.com/apache/airflow/commit/ffb003a58e6bd8dbff4de8c0e35e4b69560e914c>`__  2023-12-17   ``fix(bigquery.py): pass correct project_id to triggerer (#35200)``
`e83a98603e <https://github.com/apache/airflow/commit/e83a98603ef15c7d57910c482ba75eb76ed79553>`__  2023-12-14   ``iterate through blobs before checking prefixes (#36202)``
`4c73d613b1 <https://github.com/apache/airflow/commit/4c73d613b11107eb8ee3cc70fe6233d5ee3a0b29>`__  2023-12-13   ``Fix incompatibility with google-cloud-monitoring 2.18.0 (#36200)``
`8fbacb8a5f <https://github.com/apache/airflow/commit/8fbacb8a5fb4168a335ad080a6b806fee3d85737>`__  2023-12-13   ``Update 'retry' param typing in PubSubAsyncHook (#36198)``
`64931b1a65 <https://github.com/apache/airflow/commit/64931b1a65a22cb5c6fa6921ed5f4d00f011abd9>`__  2023-12-12   ``Prepare docs 1st wave of Providers December 2023 RC2 (#36190)``
`47a9c8a4a4 <https://github.com/apache/airflow/commit/47a9c8a4a4ecc4da34bd210d56331e97f9fe8e7e>`__  2023-12-12   ``Added Datascan Profiling (#35696)``
`3dddfb4a4a <https://github.com/apache/airflow/commit/3dddfb4a4ae112544fd02e09a5633961fa725a36>`__  2023-12-11   ``Add overrides to template fields of Google Cloud Run Jobs Execute Operator (#36133)``
`fcd993b852 <https://github.com/apache/airflow/commit/fcd993b852b91b6227e7a4b316c8c912797ac4a9>`__  2023-12-11   ``Upgrade to latest pre-commit plugins (#36163)``
`343bac956b <https://github.com/apache/airflow/commit/343bac956b48aac80a7daaf0715e04d2cc37b373>`__  2023-12-11   ``Review and mark found potential SSH security issues by bandit (#36162)``
`cd476acd8f <https://github.com/apache/airflow/commit/cd476acd8f1684f613c20dddaa9e988bcfb3ac1c>`__  2023-12-11   ``Follow BaseHook connection fields method signature in child classes (#36086)``
`8d0c5d9008 <https://github.com/apache/airflow/commit/8d0c5d900875ce3b9dda1a86f1de534759e9d7f6>`__  2023-12-09   ``Change retry type for Google Dataflow Client to async one (#36141)``
`aba58adb83 <https://github.com/apache/airflow/commit/aba58adb83435e96e66027de5163756301a6ddf5>`__  2023-12-08   ``Allow storage options to be passed (#35820)``
`999b70178a <https://github.com/apache/airflow/commit/999b70178a1f5d891fd2c88af4831a4ba4c2cbc9>`__  2023-12-08   ``Prepare docs 1st wave of Providers December 2023 (#36112)``
`d0918d77ee <https://github.com/apache/airflow/commit/d0918d77ee05ab08c83af6956e38584a48574590>`__  2023-12-07   ``Bump minimum Airflow version in providers to Airflow 2.6.0 (#36017)``
`ca20f07a16 <https://github.com/apache/airflow/commit/ca20f07a16934d93792773d788b64652009065ce>`__  2023-12-06   ``GCP Secrets Backend Impersonation (#36072)``
`d0f4512ecb <https://github.com/apache/airflow/commit/d0f4512ecb9c0683a60be7b0de8945948444df8e>`__  2023-12-04   ``Fix DataprocSubmitJobOperator to retrieve failed job error message (#36053)``
`86b1bd22d1 <https://github.com/apache/airflow/commit/86b1bd22d14792d89ddc43627e4a72dcb628c5f0>`__  2023-12-01   ``Fix CloudRunExecuteJobOperator not able to retrieve the Cloud Run job status in deferrable mode (#36012)``
`cf052dc64f <https://github.com/apache/airflow/commit/cf052dc64f00e851427a41a34ffe576fd39be51b>`__  2023-12-01   ``Add feature to build "chicken-egg" packages from sources (#35890)``
`5d74ffb320 <https://github.com/apache/airflow/commit/5d74ffb32095d534866f029d085198bc783d82c2>`__  2023-11-27   ``Fix gcs listing - ensure blobs are loaded (#34919)``
`99b68e2db2 <https://github.com/apache/airflow/commit/99b68e2db2af4724a43e50a57480136f8a986e30>`__  2023-11-27   ``Add OpenLineage support to GcsOperators - Delete, Transform and TimeSpanTransform (#35838)``
`373d8a57b2 <https://github.com/apache/airflow/commit/373d8a57b225a1a5e79b92c3d84b618b3522bfa5>`__  2023-11-25   ``Deprecate 'CloudComposerEnvironmentSensor' in favor of 'CloudComposerCreateEnvironmentOperator' with defer mode (#35775)``
`e2a5dbf8b4 <https://github.com/apache/airflow/commit/e2a5dbf8b47b35f2d836c81f8e9e7190a7f66d38>`__  2023-11-25   ``allow multiple elements in impersonation chain (#35694)``
`770f16425c <https://github.com/apache/airflow/commit/770f16425c3b48b8dd11d2a6fb852404e43d88ca>`__  2023-11-25   ``Add support for service account impersonation with computeEngineSSHHook (google provider) and IAP tunnel (#35136)``
==================================================================================================  ===========  ============================================================================================================================

10.12.0
.......

Latest change: 2023-11-24

==================================================================================================  ===========  =========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =========================================================================================================
`0b23d5601c <https://github.com/apache/airflow/commit/0b23d5601c6f833392b0ea816e651dcb13a14685>`__  2023-11-24   ``Prepare docs 2nd wave of Providers November 2023 (#35836)``
`72ba63e0b9 <https://github.com/apache/airflow/commit/72ba63e0b97110a47c9882fd0a644cb0d74dcc20>`__  2023-11-22   ``added Topic params for schema_settings and message_retention_duration. (#35767)``
`2a06e278d2 <https://github.com/apache/airflow/commit/2a06e278d290e36e861bd3c40fdc9318e620aa16>`__  2023-11-21   ``Check attr on parent not self re TaskContextLogger set_context (#35780)``
`1fae1a50e9 <https://github.com/apache/airflow/commit/1fae1a50e97fae9e414d062acb4f1e641523fa5a>`__  2023-11-21   ``Add OpenLineage support to GCSToBigQueryOperator (#35778)``
`9207e7d5e5 <https://github.com/apache/airflow/commit/9207e7d5e5c183d2e63c3030216b14709257668e>`__  2023-11-20   ``Remove usage of deprecated method from BigQueryToBigQueryOperator (#35605)``
`d8075cd04c <https://github.com/apache/airflow/commit/d8075cd04c9b1671dcbabe93c30163d0737d8098>`__  2023-11-20   ``Remove backcompat with Airflow 2.3/2.4 in providers (#35727)``
`99534e47f3 <https://github.com/apache/airflow/commit/99534e47f330ce0efb96402629dda5b2a4f16e8f>`__  2023-11-19   ``Use reproducible builds for provider packages (#35693)``
`f30d5b8ec1 <https://github.com/apache/airflow/commit/f30d5b8ec1fd839592bafb2abd4218fdea959c42>`__  2023-11-19   ``Restore delegate_to param in GoogleDiscoveryApiHook (#35728)``
`ed6fe240c3 <https://github.com/apache/airflow/commit/ed6fe240c307bfadbd9856c9e435469ec9a409d8>`__  2023-11-18   ``Align documentation of 'MSSQLToGCSOperator' (#35715)``
`ce16963e9d <https://github.com/apache/airflow/commit/ce16963e9d69849309aa0a7cf978ed85ab741439>`__  2023-11-17   ``Add OpenLineage support to BigQueryToGCSOperator (#35660)``
`b9f3a5392f <https://github.com/apache/airflow/commit/b9f3a5392f1b2fb8043ca56b2c8ded20f40e2297>`__  2023-11-17   ``Extend task context logging support for remote logging using GCP GCS (#32970)``
`3d77149cac <https://github.com/apache/airflow/commit/3d77149cac688429e598dd3e8a80c4da65edad01>`__  2023-11-17   ``Include remote logging conn_id in GCP GCS remote logging config (#35702)``
`0c6fd5be86 <https://github.com/apache/airflow/commit/0c6fd5be864b26031d388c921ed48058a610983e>`__  2023-11-17   ``Remove usage of deprecated methods from BigQueryCursor (#35606)``
`99df205f42 <https://github.com/apache/airflow/commit/99df205f42a754aa67f80b5983e1d228ff23267f>`__  2023-11-16   ``Fix and reapply templates for provider documentation (#35686)``
`08d15d06ba <https://github.com/apache/airflow/commit/08d15d06ba8675d70fcbd19f0500d67fc5f310cd>`__  2023-11-16   ``Add support for driver pool, instance flexibility policy, and min_num_instances for Dataproc (#34172)``
`a9ce7135ff <https://github.com/apache/airflow/commit/a9ce7135ffbd2df737e6db24a54db58179d8372a>`__  2023-11-16   ``Add "NON_PREEMPTIBLE" as a valid preemptibility type for Dataproc workers (#35669)``
`054904bb9a <https://github.com/apache/airflow/commit/054904bb9a68eb50070a14fe7300cb1e78e2c579>`__  2023-11-15   ``Add ability to pass impersonation_chain to BigQuery triggers (#35629)``
`9d5f726c8a <https://github.com/apache/airflow/commit/9d5f726c8a5705f1b0dec09ff54fe3fea12d4a5f>`__  2023-11-15   ``Add a filter for local files in GoogleDisplayVideo360CreateQueryOperator (#35635)``
`8fd5ac6530 <https://github.com/apache/airflow/commit/8fd5ac6530df5ffd90577d3bd624ac16cdb15335>`__  2023-11-10   ``Fix the logic of checking dataflow job state (#34785)``
==================================================================================================  ===========  =========================================================================================================

10.11.1
.......

Latest change: 2023-11-08

==================================================================================================  ===========  ===============================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===============================================================================
`1b059c57d6 <https://github.com/apache/airflow/commit/1b059c57d6d57d198463e5388138bee8a08591b1>`__  2023-11-08   ``Prepare docs 1st wave of Providers November 2023 (#35537)``
`706878ec35 <https://github.com/apache/airflow/commit/706878ec354cf867440c367a95c85753c19e54de>`__  2023-11-04   ``Remove empty lines in generated changelog (#35436)``
`052e26ad47 <https://github.com/apache/airflow/commit/052e26ad473a9d50f0b96456ed094f2087ee4434>`__  2023-11-04   ``Change security.rst to use includes in providers (#35435)``
`64d1085cb9 <https://github.com/apache/airflow/commit/64d1085cb9003583419fa576392fb087fd950180>`__  2023-11-03   ``Update Google Ads API version from v14 to v15 (#35295)``
`2b0bfea837 <https://github.com/apache/airflow/commit/2b0bfea8374ec0f0289763b064d6425df6d4270f>`__  2023-11-01   ``Add startup_check_interval_seconds to PodManager's await_pod_start (#34231)``
`63cc915cd3 <https://github.com/apache/airflow/commit/63cc915cd38a5034df6bf9c618e12f8690eeade0>`__  2023-10-31   ``Switch from Black to Ruff formatter (#35287)``
==================================================================================================  ===========  ===============================================================================

10.11.0
.......

Latest change: 2023-10-28

==================================================================================================  ===========  ======================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ======================================================================
`d1c58d86de <https://github.com/apache/airflow/commit/d1c58d86de1267d9268a1efe0a0c102633c051a1>`__  2023-10-28   ``Prepare docs 3rd wave of Providers October 2023 - FIX (#35233)``
`3592ff4046 <https://github.com/apache/airflow/commit/3592ff40465032fa041600be740ee6bc25e7c242>`__  2023-10-28   ``Prepare docs 3rd wave of Providers October 2023 (#35187)``
`04e2fbd92b <https://github.com/apache/airflow/commit/04e2fbd92bb6cb2b5abf6f16786b9800a0d49808>`__  2023-10-27   ``AIP-58: Add Airflow ObjectStore (AFS) (#34729)``
`acff4c79dc <https://github.com/apache/airflow/commit/acff4c79dcbb7926923d86adb4c5115e02cf28e6>`__  2023-10-26   ``Make Dataprep system test self-sufficient (#34880)``
`0bb56315e6 <https://github.com/apache/airflow/commit/0bb56315e664875cd764486bb2090e0a2ef747d8>`__  2023-10-25   ``Added 'overrides' parameter to CloudRunExecuteJobOperator (#34874)``
`dd7ba3cae1 <https://github.com/apache/airflow/commit/dd7ba3cae139cb10d71c5ebc25fc496c67ee784e>`__  2023-10-19   ``Pre-upgrade 'ruff==0.0.292' changes in providers (#35053)``
`63f3712d2e <https://github.com/apache/airflow/commit/63f3712d2e5874ced8b3bf3e79eeaf6eaf059df5>`__  2023-10-18   ``Update gcs.py Create and List comment Examples (#35028)``
`b75f9e8806 <https://github.com/apache/airflow/commit/b75f9e880614fa0427e7d24a1817955f5de658b3>`__  2023-10-18   ``Upgrade pre-commits (#35033)``
==================================================================================================  ===========  ======================================================================

10.10.1
.......

Latest change: 2023-10-18

==================================================================================================  ===========  ==============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==============================================================================================
`39e611b43b <https://github.com/apache/airflow/commit/39e611b43b06df0582f0c69de824c4657c3423eb>`__  2023-10-18   ``Prepare docs 2nd wave of Providers in October 2023 (#35020)``
`f16906d13b <https://github.com/apache/airflow/commit/f16906d13b5256e30b7126d119fcf383282f7a64>`__  2023-10-18   ``Create operators for VertexAI Pipeline Job (#34915)``
`86e27c7cd7 <https://github.com/apache/airflow/commit/86e27c7cd7142fc68ff0e01a650d88c8dd786ebe>`__  2023-10-18   ``Fix cloud run operation timeout error (#34755)``
`e444bca140 <https://github.com/apache/airflow/commit/e444bca140cc38619316ca5f6325ba53d4e8e426>`__  2023-10-18   ``Add links between documentation related to Google Cloud Storage (#34994)``
`92204b36b0 <https://github.com/apache/airflow/commit/92204b36b08044db4ed958dfaed7672071cd37d4>`__  2023-10-18   ``Migrate legacy version of AI Platform Prediction to VertexAI (#34922)``
`0b49f338b9 <https://github.com/apache/airflow/commit/0b49f338b9e6fd3264bc0099e8879855bf6c60c9>`__  2023-10-16   ``Cancel workflow in on_kill in DataprocInstantiate{Inline}WorkflowTemplateOperator (#34957)``
==================================================================================================  ===========  ==============================================================================================

10.10.0
.......

Latest change: 2023-10-13

==================================================================================================  ===========  ===================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===================================================================================
`e9987d5059 <https://github.com/apache/airflow/commit/e9987d50598f70d84cbb2a5d964e21020e81c080>`__  2023-10-13   ``Prepare docs 1st wave of Providers in October 2023 (#34916)``
`d27d0bb60b <https://github.com/apache/airflow/commit/d27d0bb60b08ed8550491d4801ba5bf3c0e3da9b>`__  2023-10-13   ``Refactor DataFusionInstanceLink usage (#34514)``
`4dc2c40dfe <https://github.com/apache/airflow/commit/4dc2c40dfefb3495e435aabb99c07fa6e4f32c5d>`__  2023-10-12   ``Fix GCSToGoogleDriveOperator and gdrive system tests (#34545)``
`0c8e30e43b <https://github.com/apache/airflow/commit/0c8e30e43b70e9d033e1686b327eb00aab82479c>`__  2023-10-05   ``Bump min airflow version of providers (#34728)``
`99f320354b <https://github.com/apache/airflow/commit/99f320354b075fb780e54057d223d2d16ddf08b8>`__  2023-10-04   ``Refactor: consolidate import time in providers (#34402)``
`7c440ca184 <https://github.com/apache/airflow/commit/7c440ca18497c4134a9dd9237c2029afa58f85dd>`__  2023-10-03   ``Fix typo in DataplexGetDataQualityScanResultOperator (#34681)``
`562b98a622 <https://github.com/apache/airflow/commit/562b98a6222912d3a3d859ca3881af3f768ba7b5>`__  2023-10-02   ``Fix LookerHook serialize missing 1 argument error (#34678)``
`7ebf4220c9 <https://github.com/apache/airflow/commit/7ebf4220c9abd001f1fa23c95f882efddd5afbac>`__  2023-09-28   ``Refactor usage of str() in providers (#34320)``
`07fe1d2a69 <https://github.com/apache/airflow/commit/07fe1d2a69cbe4f684a1989c047737c0686c4417>`__  2023-09-27   ``Refactor dedent nested loops (#34409)``
`2b082f1e5a <https://github.com/apache/airflow/commit/2b082f1e5a0e7e361df38710689dc1ac22062736>`__  2023-09-27   ``Use 'airflow.models.dag.DAG' in Google Provider examples (#34614)``
`8bea45f37f <https://github.com/apache/airflow/commit/8bea45f37fe400c1d34a46e53f5bdc12d8f961ab>`__  2023-09-26   ``Refactor multiple equals to contains in providers (#34441)``
`20b7cfc395 <https://github.com/apache/airflow/commit/20b7cfc3956e404fe1a6d4ed9e363fca7161ede2>`__  2023-09-26   ``respect soft_fail argument when exception is raised for google sensors (#34501)``
`6a03870d1c <https://github.com/apache/airflow/commit/6a03870d1c1c5871dc9bcb8ea48039ec47676484>`__  2023-09-24   ``improvement: introduce proejct_id in BigQueryIntervalCheckOperator (#34573)``
`f56acdad16 <https://github.com/apache/airflow/commit/f56acdad164586f8be8c21137d927fdfd01e8bb4>`__  2023-09-22   ``Deprecate Life Sciences Operator and Hook (#34549)``
`659d94f0ae <https://github.com/apache/airflow/commit/659d94f0ae89f47a7d4b95d6c19ab7f87bd3a60f>`__  2023-09-21   ``Use 'airflow.exceptions.AirflowException' in providers (#34511)``
`d20c32f6b7 <https://github.com/apache/airflow/commit/d20c32f6b75b4d09c537d6902fae4c1be2e714be>`__  2023-09-20   ``Refactor: reduce some conditions in providers (#34440)``
`a6fcd69fe5 <https://github.com/apache/airflow/commit/a6fcd69fe55f2f54c9bf7c147c70bc36429a2e66>`__  2023-09-15   ``Fix Dataform system tests (#34329)``
`8ecd576de1 <https://github.com/apache/airflow/commit/8ecd576de1043dbea40e5e16b5dc34859cc41725>`__  2023-09-14   ``Refactor shorter defaults in providers (#34347)``
`013c95bfe6 <https://github.com/apache/airflow/commit/013c95bfe6d2b4de44633ab1a0c326cd0969fcf3>`__  2023-09-14   ``Update Vertex AI system tests (#34364)``
==================================================================================================  ===========  ===================================================================================

10.9.0
......

Latest change: 2023-09-14

==================================================================================================  ===========  ================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ================================================================================================================================
`7574e16e75 <https://github.com/apache/airflow/commit/7574e16e751e37cc012139da1a0e39874bab2918>`__  2023-09-14   ``Prepare docs for Sep 2023 2nd wave of Providers (#34360)``
`b042042086 <https://github.com/apache/airflow/commit/b0420420864b6ada45260e0d00b1b6e72595a966>`__  2023-09-14   ``Remove unnecessary call to keys() method on dictionaries (#34260)``
`05036e619c <https://github.com/apache/airflow/commit/05036e619c0c6dafded1451daac4e07e20aee33f>`__  2023-09-13   ``Refactor: Think positively in providers (#34279)``
`3fa9d46ec7 <https://github.com/apache/airflow/commit/3fa9d46ec74ef8453fcf17fbd49280cb6fb37cef>`__  2023-09-12   ``Refactor: Simplify code in providers/google (#33229)``
`4dcdc34996 <https://github.com/apache/airflow/commit/4dcdc349964647ade80702e3d34bbf819ddf7661>`__  2023-09-11   ``Add explicit support of stream (realtime) pipelines for CloudDataFusionStartPipelineOperator (#34271)``
`94d07908a2 <https://github.com/apache/airflow/commit/94d07908a2188eb650bfab21d89a49b287aee35c>`__  2023-09-11   ``Refactor: Simplify comparisons (#34181)``
`0110b22a60 <https://github.com/apache/airflow/commit/0110b22a603f86fbc6f1311ef1c9a23505ca6f87>`__  2023-09-11   ``Fix 'ComputeEngineInsertInstanceOperator' doesn't respect jinja-templated instance name when given in body argument (#34171)``
`050a47add8 <https://github.com/apache/airflow/commit/050a47add822cde6d9abcd609df59c98caae13b0>`__  2023-09-11   ``Add 'expected_terminal_state' parameter to Dataflow operators (#34217)``
`25d463c3e3 <https://github.com/apache/airflow/commit/25d463c3e33f8628e1bcbe4dc6924693ec141dc0>`__  2023-09-11   ``Deprecate AutoMLTrainModelOperator for NL (#34212)``
`cad983dac9 <https://github.com/apache/airflow/commit/cad983dac9f240a2d0658531235acfd003b64760>`__  2023-09-11   ``Fix datastore system tests. (#34215)``
`db38a6fc66 <https://github.com/apache/airflow/commit/db38a6fc667f336d080ad48f66dc814de77c27a6>`__  2023-09-11   ``GKEPodHook ignores gcp_conn_id parameter. (#34194)``
`38ecd4c4da <https://github.com/apache/airflow/commit/38ecd4c4da65310f9461df769d274cb78b122630>`__  2023-09-10   ``Bump min common-sql provider version for Google provider (#34257)``
`c5ec7cd294 <https://github.com/apache/airflow/commit/c5ec7cd294ed9363817b358765ed2a250ae76b6d>`__  2023-09-10   ``Simplify  to bool(...) (#34258)``
`bf9769bebf <https://github.com/apache/airflow/commit/bf9769bebf712bb70033dd927115fff8c75d0f35>`__  2023-09-09   ``Make Google Dataform operators templated_fields more consistent (#34187)``
`774125ae25 <https://github.com/apache/airflow/commit/774125ae253611627229509e672518ce0a58cf2e>`__  2023-09-09   ``fix: BigQuery job error message (#34208)``
==================================================================================================  ===========  ================================================================================================================================

10.8.0
......

Latest change: 2023-09-08

==================================================================================================  ===========  ==========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==========================================================================================================
`21990ed894 <https://github.com/apache/airflow/commit/21990ed8943ee4dc6e060ee2f11648490c714a3b>`__  2023-09-08   ``Prepare docs for 09 2023 - 1st wave of Providers (#34201)``
`ff23a30e5b <https://github.com/apache/airflow/commit/ff23a30e5b51f4ba7316fa803a85b89b7dd5f6fe>`__  2023-09-07   ``fix(providers/google-marketing-platform): respect soft_fail argument when exception is raised (#34165)``
`9c66132af6 <https://github.com/apache/airflow/commit/9c66132af6e75924c5dbc2c4536ab381582a9292>`__  2023-09-07   ``fix: docstring in endpoint_service.py (#34135)``
`9079093291 <https://github.com/apache/airflow/commit/907909329195c6655d1e2989b05609466ef50563>`__  2023-09-07   ``Consolidate importing of os.path.* (#34060)``
`a7310f9c91 <https://github.com/apache/airflow/commit/a7310f9c9127cf87a71e0bfa141c066d6a0bc82b>`__  2023-09-05   ``Refactor regex in providers (#33898)``
`c88e746494 <https://github.com/apache/airflow/commit/c88e746494a0ccc718687fe230b02390309c0ea7>`__  2023-09-04   ``Dynamic setting up of artifact versinos for Datafusion pipelines (#34068)``
`ba59f3475c <https://github.com/apache/airflow/commit/ba59f3475c160102332bb36fb7414ed7b7346383>`__  2023-09-04   ``Add deferrable mode to Dataplex DataQuality. (#33954)``
`4f20b0f442 <https://github.com/apache/airflow/commit/4f20b0f4421f44703f25d5b2970ba065a631d912>`__  2023-09-03   ``Move the try outside the loop when this is possible in Google provider (#33976)``
`d757f6a3af <https://github.com/apache/airflow/commit/d757f6a3af24c3ec0d48c8c983d6ba5d6ed2202e>`__  2023-09-03   ``Fix BigQueryValueCheckOperator deferrable mode optimisation (#34018)``
`fa5e54c4c5 <https://github.com/apache/airflow/commit/fa5e54c4c57631de353102af56633f05346685f9>`__  2023-09-03   ``Combine similar if logics in providers (#33987)``
`47bd5dd0e1 <https://github.com/apache/airflow/commit/47bd5dd0e1e13af45206b94dd5518ada278a9552>`__  2023-09-03   ``Remove useless string join from providers (#33968)``
`b7f84e913b <https://github.com/apache/airflow/commit/b7f84e913b6aa4cee7fa63009082b0608b3a0bf1>`__  2023-09-02   ``Update Azure fileshare hook to use azure-storage-file-share instead of azure-storage-file (#33904)``
`875387afa5 <https://github.com/apache/airflow/commit/875387afa53c207364fa20b515d154100b5d0a8d>`__  2023-09-01   ``Refactor unneeded  jumps in providers (#33833)``
`04e9b0bd78 <https://github.com/apache/airflow/commit/04e9b0bd784e7c0045e029c6ed4ec0ac4ad6066f>`__  2023-09-01   ``fix google CHANGELOG.rst (#34007)``
`0dae1bcf29 <https://github.com/apache/airflow/commit/0dae1bcf292dadda114db5d27b9795ec980c855d>`__  2023-09-01   ``Merge and optimize Cloud Build system tests (#33961)``
`ff7dcf4e82 <https://github.com/apache/airflow/commit/ff7dcf4e829b06d3f8d19b9d14665bac0224b51c>`__  2023-09-01   ``replace loop by any when looking for a positive value in providers (#33984)``
`a9bbb430fc <https://github.com/apache/airflow/commit/a9bbb430fcf6df7ac2677edfe5b0402c23cfe8e2>`__  2023-09-01   ``Replace try - except pass by contextlib.suppress in providers (#33980)``
`5d60c742a7 <https://github.com/apache/airflow/commit/5d60c742a74f419a9f33cbeebcf8fa6bfd2239b7>`__  2023-09-01   ``Fix Google 10.7.0 changelog (#33953)``
`0a5e2281e0 <https://github.com/apache/airflow/commit/0a5e2281e084b228e697ffdd5d825b927fce9483>`__  2023-08-31   ``Remove some useless try/except from providers code (#33967)``
`55976af32e <https://github.com/apache/airflow/commit/55976af32ea7d09831e2bcd21c0f3814d9b0eb3f>`__  2023-08-31   ``Replace sequence concatination by unpacking in Airflow providers (#33933)``
`3b86842120 <https://github.com/apache/airflow/commit/3b868421208f171dd44733c6a3376037b388bcef>`__  2023-08-31   ``Remove a deprecated option from 'BigQueryHook.get_pandas_df' (#33819)``
`a35c0d42cc <https://github.com/apache/airflow/commit/a35c0d42cce17fd0647d58f247a8bb9b8b8fab60>`__  2023-08-30   ``replace unnecessary dict comprehension by dict() in providers (#33857)``
`eaf34718a4 <https://github.com/apache/airflow/commit/eaf34718a4170751c61eb027c0dd30f608595586>`__  2023-08-30   ``Fix Cloud Worflows system test (#33386)``
`d361761dee <https://github.com/apache/airflow/commit/d361761deeffe628f3c17ab0debd0e11515c22da>`__  2023-08-30   ``Early delete a Dataproc cluster if started in the ERROR state. (#33668)``
`075afe5a2a <https://github.com/apache/airflow/commit/075afe5a2add74d9e4e9fd57768b8354489cdb2b>`__  2023-08-30   ``allow impersonation_chain to be set on Google Cloud connection (#33715)``
`3b3650e87d <https://github.com/apache/airflow/commit/3b3650e87d093d57a97b8701834c568f67327ab4>`__  2023-08-29   ``fix entry in Google provider CHANGELOG.rst (#33890)``
`2663b177a6 <https://github.com/apache/airflow/commit/2663b177a666ee150f86bd16ad51526319fa7adb>`__  2023-08-28   ``Generate Python API docs for Google ADS (#33814)``
`6802d4136f <https://github.com/apache/airflow/commit/6802d4136fab9b8a02faf22f48cb9f6d259fd523>`__  2023-08-27   ``Improve modules import in google provider by move some of them into a type-checking block (#33783)``
`6d182beec6 <https://github.com/apache/airflow/commit/6d182beec6e86b372c37fb164a31c2f8811d8c03>`__  2023-08-26   ``Use a single  statement with multiple contexts instead of nested  statements in providers (#33768)``
`b11525702c <https://github.com/apache/airflow/commit/b11525702c72cb53034aa29ccd6d0e1161ac475c>`__  2023-08-26   ``Use literal dict instead of calling dict() in providers (#33761)``
`353b1482d3 <https://github.com/apache/airflow/commit/353b1482d3720c7e962022f25c7e5d3e105ed4f0>`__  2023-08-26   ``remove unnecessary and rewrite it using list in providers (#33763)``
`784e0ef04b <https://github.com/apache/airflow/commit/784e0ef04b5013f4e370e9a0380f5c2589128c7f>`__  2023-08-26   ``Refactor: Simplify a few loops (#33736)``
`3d01919a30 <https://github.com/apache/airflow/commit/3d01919a30acd85eec40fdd81029ed94613d280f>`__  2023-08-26   ``Avoid blocking event loop when using DataFusionAsyncHook by replacing sleep by asyncio.sleep (#33756)``
`2a00f18ebb <https://github.com/apache/airflow/commit/2a00f18ebb7f0e286955a946844c14b72fcc3b05>`__  2023-08-26   ``E731: replace lambda by a def method in Airflow providers (#33757)``
`c90eec9365 <https://github.com/apache/airflow/commit/c90eec936583d482a35f0dc8bfc13afc58a9c322>`__  2023-08-26   ``Use f-string instead of  in Airflow providers (#33752)``
==================================================================================================  ===========  ==========================================================================================================

10.7.0
......

Latest change: 2023-08-26

==================================================================================================  ===========  ==========================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==========================================================================================
`c077d19060 <https://github.com/apache/airflow/commit/c077d190609f931387c1fcd7b8cc34f12e2372b9>`__  2023-08-26   ``Prepare docs for Aug 2023 3rd wave of Providers (#33730)``
`94c8291629 <https://github.com/apache/airflow/commit/94c82916294791df10d30a1cb444daf5d8a34304>`__  2023-08-25   ``Refactor: Use f-strings (#33734)``
`ba0bab0114 <https://github.com/apache/airflow/commit/ba0bab0114a430ef0ac776980f7e29b34d48b726>`__  2023-08-25   ``Refactor: Use random.choices (#33631)``
`66d0222947 <https://github.com/apache/airflow/commit/66d0222947bf6ec779064d25c16391e22c1a9368>`__  2023-08-25   ``Add CloudRunHook and operators (#33067)``
`96efcfb830 <https://github.com/apache/airflow/commit/96efcfb8301ed938ce62d46a12b429b724e7cf0f>`__  2023-08-24   ``Further improvements for provider verification (#33670)``
`85acbb4ae9 <https://github.com/apache/airflow/commit/85acbb4ae9bc26248ca624fa4d289feccba00836>`__  2023-08-24   ``Refactor: Remove useless str() calls (#33629)``
`1953648fda <https://github.com/apache/airflow/commit/1953648fda6b984d27ddcbe151d7286550571f32>`__  2023-08-24   ``Refactor: lists and paths in dev (#33626)``
`4154cc04ce <https://github.com/apache/airflow/commit/4154cc04ce9702b09e6f13d423686fdf4cb7b877>`__  2023-08-24   ``Do not create lists we don't need (#33519)``
`94f70d8184 <https://github.com/apache/airflow/commit/94f70d818482de7defa03c0aff3c213ca6b83e9e>`__  2023-08-23   ``Replace strftime with f-strings where nicer (#33455)``
`92474db6a5 <https://github.com/apache/airflow/commit/92474db6a5321a0c0cd0dc21695f95d51c3aad16>`__  2023-08-23   ``Refactor: Better percentage formatting (#33595)``
`a54c2424df <https://github.com/apache/airflow/commit/a54c2424df51bf1acec420f4792a237dabcfa12b>`__  2023-08-23   ``Fix typos (double words and it's/its) (#33623)``
`08fa814533 <https://github.com/apache/airflow/commit/08fa81453377003aafbdd19563d846fa71155e0d>`__  2023-08-21   ``Add missing template fields to DataformCreateCompilationResultOperator (#33585)``
`c8de9a5f68 <https://github.com/apache/airflow/commit/c8de9a5f686f55a27705a69d69fbc64840df03ce>`__  2023-08-21   ``Adding Support for Google Cloud's Data Pipelines Run Operator (#32846)``
`46fa5a2743 <https://github.com/apache/airflow/commit/46fa5a2743c0c864f5282abd6055c5418585955b>`__  2023-08-21   ``Fix BigQueryCreateExternalTableOperator when using a foramt different to CSV (#33540)``
`3157002eeb <https://github.com/apache/airflow/commit/3157002eeb8d5e2acf62a32ffe7a3647adc23105>`__  2023-08-19   ``Fix DataplexDataQualityJobStatusSensor and add unit tests (#33440)``
`533afb5128 <https://github.com/apache/airflow/commit/533afb5128383958889bc653226f46947c642351>`__  2023-08-19   ``Add parameter sftp_prefetch to SFTPToGCSOperator (#33274)``
`c6a014a370 <https://github.com/apache/airflow/commit/c6a014a3707d2e4a5a9d2fe0b4277be09266b63b>`__  2023-08-18   ``Add 'CloudBatchHook' and operators (#32606)``
`ea8519c055 <https://github.com/apache/airflow/commit/ea8519c0554d16b13d330a686f8479fc10cc58f2>`__  2023-08-18   ``Avoid importing pandas and numpy in runtime and module level (#33483)``
`8e88eb8fa7 <https://github.com/apache/airflow/commit/8e88eb8fa7e1fc12918dcbfcfc8ed28381008d33>`__  2023-08-17   ``Consolidate import and usage of pandas (#33480)``
`bfe08a79db <https://github.com/apache/airflow/commit/bfe08a79db8130c499883f014121be570ec071bd>`__  2023-08-16   ``Import utc from datetime and normalize its import (#33450)``
`843a3b8c3e <https://github.com/apache/airflow/commit/843a3b8c3ecca9582a269cf780144738c9c45d15>`__  2023-08-16   ``Fix system test example_cloud_storage_transfer_service_aws (#33429)``
`88b8ba9861 <https://github.com/apache/airflow/commit/88b8ba986139c35b9cc8efa816bf2fc445c7caa5>`__  2023-08-15   ``Update gcp.rst (#33420)``
`a1e42f6626 <https://github.com/apache/airflow/commit/a1e42f66260447c22c708e49943e3a39ba2b678f>`__  2023-08-14   ``Enable D205 Support (#33398)``
`c17140cb37 <https://github.com/apache/airflow/commit/c17140cb379b461ebe2019f1ea4289d639298a55>`__  2023-08-14   ``Fix Storage Transfer system tests (#33385)``
`b4102ce0b5 <https://github.com/apache/airflow/commit/b4102ce0b55e76baadf3efdec0df54762001f38c>`__  2023-08-14   ``Update Error details for Generic Error Code  (#32847)``
`a2a0d05345 <https://github.com/apache/airflow/commit/a2a0d053456d6e09efe7b8ac62837768f64e3c0b>`__  2023-08-14   ``Add Source Code and Testing for Google Cloud's Data Pipelines Create Operator (#32843)``
`de780e0d08 <https://github.com/apache/airflow/commit/de780e0d08f9516d368930547a5844520617ffe1>`__  2023-08-14   ``Merge system tests for CloudSQLExportInstanceOperator into one test (#33315)``
`416cae48f5 <https://github.com/apache/airflow/commit/416cae48f5a15dd57a242929338a7915e57eefce>`__  2023-08-14   ``Migrate system tests for CloudSQLExecuteQueryOperator (non-SSL) (#33316)``
`dfb2403ec4 <https://github.com/apache/airflow/commit/dfb2403ec4b6d147ac31125631677cee9e12347e>`__  2023-08-14   ``Add Dataplex Data Quality operators. (#32256)``
`7e79997594 <https://github.com/apache/airflow/commit/7e799975948573ca2a1c4b2051d3eadc32bb8ba7>`__  2023-08-11   ``D205 Support - Providers - Final Pass (#33303)``
==================================================================================================  ===========  ==========================================================================================

10.6.0
......

Latest change: 2023-08-09

==================================================================================================  ===========  ================================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ================================================================================================================================================
`f82acc1579 <https://github.com/apache/airflow/commit/f82acc1579ed8e56c32cd7c42bab10f8db5cc024>`__  2023-08-09   ``Prepare docs for RC3 providers (google) (#33253)``
`e1af008711 <https://github.com/apache/airflow/commit/e1af008711039f7f53b2a21cad70a08b514cd8f6>`__  2023-08-09   ``make 'sql' a cached property in 'BigQueryInsertJobOperator' (#33218)``
`e43206eb2e <https://github.com/apache/airflow/commit/e43206eb2e055a78814fcff7e8c35c6fd9c11e85>`__  2023-08-08   ``refactor(providers.google): use module level __getattr__ for DATAPROC_JOB_LOG_LINK to DATAPROC_JOB_LINK and add deprecation warning (#33189)``
`8f27d3ff47 <https://github.com/apache/airflow/commit/8f27d3ff472e6ddd52c08a948d51901adb8a1f1a>`__  2023-08-08   ``Prepare docs for RC2 providers (google, redis) (#33185)``
`15ede4a1a1 <https://github.com/apache/airflow/commit/15ede4a1a1af8bebb52799420bf2f328406c126e>`__  2023-08-07   ``Fix DataflowStartSqlJobOperator system test (#32823)``
`9736143468 <https://github.com/apache/airflow/commit/9736143468cfe034e65afb3df3031ab3626f0f6d>`__  2023-08-07   ``Add a new parameter to SQL operators to specify conn id field (#30784)``
`0e076dceaf <https://github.com/apache/airflow/commit/0e076dceaf169174bbd4d8ee46911b60505eb098>`__  2023-08-07   ``Fix catching 409 error (#33173)``
`8997b5e95f <https://github.com/apache/airflow/commit/8997b5e95f67a14d5e5fdbcb131643d702059359>`__  2023-08-07   ``Alias 'DATAPROC_JOB_LOG_LINK' to 'DATAPROC_JOB_LINK' (#33148)``
`60677b0ba3 <https://github.com/apache/airflow/commit/60677b0ba3c9e81595ec2aa3d4be2737e5b32054>`__  2023-08-05   ``Prepare docs for Aug 2023 1st wave of Providers (#33128)``
`e10aa6ae6a <https://github.com/apache/airflow/commit/e10aa6ae6ad07830cbf5ec59d977654c52012c22>`__  2023-08-04   ``openlineage, bigquery: add openlineage method support for BigQueryExecuteQueryOperator (#31293)``
`e3d82c6be0 <https://github.com/apache/airflow/commit/e3d82c6be0e0e1468ade053c37690aa1e0e4882d>`__  2023-08-04   ``Get rid of Python2 numeric relics (#33050)``
`1ea7ae809b <https://github.com/apache/airflow/commit/1ea7ae809bf0b8d1c8edf97e4d456b3753a1feca>`__  2023-08-03   ``Refactor of links in Dataproc. (#31895)``
`d9121a7b9e <https://github.com/apache/airflow/commit/d9121a7b9e3d2456c1c3cd9c09d8404501a360c8>`__  2023-08-02   ``Fix 'DataFusionAsyncHook' catch 404 (#32855)``
`0c894dbb24 <https://github.com/apache/airflow/commit/0c894dbb24ad9ad90dcb10c81269ccc056789dc3>`__  2023-08-02   ``Handle multiple connections using exceptions (#32365)``
`915f9e4060 <https://github.com/apache/airflow/commit/915f9e40601fbfa3ebcf2fe82ced14191b12ab18>`__  2023-07-31   ``Add GCS Requester Pays bucket support to GCSToS3Operator (#32760)``
`f9cddf332d <https://github.com/apache/airflow/commit/f9cddf332db712ce2121d355dd94c78b392a7bb9>`__  2023-07-31   ``openlineage,gcs: use proper name for openlineage methods (#32956)``
`ce5eebd004 <https://github.com/apache/airflow/commit/ce5eebd00403beabc23b4f0b4bedba5b5c397c42>`__  2023-07-31   ``Fix system test for MetastoreHivePartitionSensor (#32861)``
`c422920c6e <https://github.com/apache/airflow/commit/c422920c6ef9ac2cceb0369cd0ec0989887688d9>`__  2023-07-31   ``Add system test and docs for CloudDataTransferServiceGCSToGCSOperator (#32960)``
==================================================================================================  ===========  ================================================================================================================================================

10.5.0
......

Latest change: 2023-07-29

==================================================================================================  ===========  =======================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =======================================================================================================
`d06b7af69a <https://github.com/apache/airflow/commit/d06b7af69a65c50321ba2a9904551f3b8affc7f1>`__  2023-07-29   ``Prepare docs for July 2023 3rd wave of Providers (#32875)``
`81b85ebcbd <https://github.com/apache/airflow/commit/81b85ebcbd241e1909793d7480aabc81777b225c>`__  2023-07-29   ``Fix 'BigQueryInsertJobOperator' not exiting deferred state (#31591)``
`9d68492f87 <https://github.com/apache/airflow/commit/9d68492f875464f505afef2ecd81a28d8e4922b8>`__  2023-07-27   ``misc: update MLEngine system tests (#32881)``
`b73366799d <https://github.com/apache/airflow/commit/b73366799d98195a5ccc49a2008932186c4763b5>`__  2023-07-27   ``openlineage, gcs: add openlineage methods for GcsToGcsOperator (#31350)``
`583f407c54 <https://github.com/apache/airflow/commit/583f407c54a6683247a6b8a3aed75a184f8a92c6>`__  2023-07-26   ``Fixup docstring for deprecated DataprocSubmitSparkJobOperator and refactoring system tests (#32743)``
`43f7da702f <https://github.com/apache/airflow/commit/43f7da702fae7eb5cb185ed5a5ec74f6ed8e4a25>`__  2023-07-26   ``Add system test and docs for DataprocSubmitJobOperator (Trino job) (#32796)``
`4c2ef99772 <https://github.com/apache/airflow/commit/4c2ef99772203936cdb6387f099a64ec9aa736f2>`__  2023-07-26   ``Add Spot Instances support with Dataproc Operators (#31644)``
`b7a0983b66 <https://github.com/apache/airflow/commit/b7a0983b668ba2d5c817b812daec68943a3d2bc2>`__  2023-07-26   ``docs for 'DataprocSubmitJobOperator' (Presto job) (#32798)``
`82e6226738 <https://github.com/apache/airflow/commit/82e6226738bcf7f3981c5b8db714a849c26a6962>`__  2023-07-23   ``Fix Datafusion system tests (#32749)``
`73b90c48b1 <https://github.com/apache/airflow/commit/73b90c48b1933b49086d34176527947bd727ec85>`__  2023-07-21   ``Allow configuration to be contributed by providers (#32604)``
`0fbb05a459 <https://github.com/apache/airflow/commit/0fbb05a459f62a14896aa5d863685b449ab3e442>`__  2023-07-21   ``Fixup system test for DataprocSubmitJobOperator (SparkSQL job) (#32745)``
`fbeddc3017 <https://github.com/apache/airflow/commit/fbeddc30178eec7bddbafc1d560ff1eb812ae37a>`__  2023-07-21   ``Fixup docstring for deprecated DataprocSubmitPigJobOperator (#32739)``
`440c9eb2b4 <https://github.com/apache/airflow/commit/440c9eb2b4c834d040584a492e23ff4f1212f7f0>`__  2023-07-21   ``Fixup system test for DataprocSubmitJobOperator (PySpark job) (#32740)``
`49921763eb <https://github.com/apache/airflow/commit/49921763eb15f68f91da826a86690ba4c4155c35>`__  2023-07-21   ``Migrate system test for PostgresToGCSOperator to new design AIP-47 (#32641)``
`978adb309a <https://github.com/apache/airflow/commit/978adb309aee755df02aadab72fdafb61bec5c80>`__  2023-07-21   ``Install sqlalchemy-spanner package into Google provider (#31925)``
`99b8a90346 <https://github.com/apache/airflow/commit/99b8a90346b8826756ac165b73464a701e2c33aa>`__  2023-07-20   ``Filtering and ordering results of DataprocListBatchesOperator (#32500)``
`3c14753b03 <https://github.com/apache/airflow/commit/3c14753b03872b259ce2248eda92f7fb6f4d751b>`__  2023-07-20   ``Fix BigQueryGetDataOperator where project_id is not being respected in deferrable mode (#32488)``
`e8287734cb <https://github.com/apache/airflow/commit/e8287734cbc29d45eeab565936afe8c9eb2e5340>`__  2023-07-20   ``Fixup docstring for deprecated DataprocSubmitHiveJobOperator (#32723)``
`8b7ae76026 <https://github.com/apache/airflow/commit/8b7ae760261109f1bfa6c60abbbc9803bd93bb74>`__  2023-07-20   ``Fixup docs and optimize system test for DataprocSubmitJobOperator (Hadoop job) (#32722)``
`848c69a194 <https://github.com/apache/airflow/commit/848c69a194c03ed3a5badc909e26b5c1bda03050>`__  2023-07-20   ``Refresh GKE OAuth2 tokens (#32673)``
`60c49ab2df <https://github.com/apache/airflow/commit/60c49ab2dfabaf450b80a5c7569743dd383500a6>`__  2023-07-19   ``Add more accurate typing for DbApiHook.run method (#31846)``
`e01323635a <https://github.com/apache/airflow/commit/e01323635a88ecf313a415ea41d32d6d28fa0794>`__  2023-07-13   ``Add deprecation info to the providers modules and classes docstring (#32536)``
==================================================================================================  ===========  =======================================================================================================

10.4.0
......

Latest change: 2023-07-12

==================================================================================================  ===========  ====================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================
`e7f59a913e <https://github.com/apache/airflow/commit/e7f59a913e1fcf9052e69f62af9fe23901f1a358>`__  2023-07-12   ``Prepare docs for July 2023 2nd wave of Providers (#32566)``
`410d0c0f86 <https://github.com/apache/airflow/commit/410d0c0f86aaec71e2c0050f5adbc53fb7b441e7>`__  2023-07-11   ``fix google docs (#32472)``
`2ad91a7808 <https://github.com/apache/airflow/commit/2ad91a7808e97a70386513e016bdc08dbb8b72d0>`__  2023-07-11   ``Bugfix GCSToGCSOperator when copy files to folder without wildcard (#32486)``
`86c6cc9a9a <https://github.com/apache/airflow/commit/86c6cc9a9aea58dce5c7691717382d6c6911d1e1>`__  2023-07-11   ``Combine 8 into 1 (#29462)``
`3a8da4b55b <https://github.com/apache/airflow/commit/3a8da4b55b363b5b74d78b7d481dc7544afd36cb>`__  2023-07-11   ``Allow a destination folder to be provided (#31885)``
`0f73647bda <https://github.com/apache/airflow/commit/0f73647bdab79ac6c30961222924f6166f75b55a>`__  2023-07-08   ``D205 Support - Provider: Google (#32356)``
`e70bee00cd <https://github.com/apache/airflow/commit/e70bee00cd12ecf1462485a747c0e3296ef7d48c>`__  2023-07-08   ``Fix 'cache_control' parameter of upload function in 'GCSHook'  (#32440)``
`257136786c <https://github.com/apache/airflow/commit/257136786c9a3eebbae717738637ab24fd6ab563>`__  2023-07-08   ``Moves 'AzureBlobStorageToGCSOperator' from Azure to Google provider (#32306)``
`723eb7d453 <https://github.com/apache/airflow/commit/723eb7d453e50fb82652a8cf1f6a538410be777f>`__  2023-07-07   ``Give better link to job configuration docs in BigQueryInsertJobOperator (#31736)``
`6c854dcb16 <https://github.com/apache/airflow/commit/6c854dcb164caffea640b368eda94a2a9166fa97>`__  2023-07-07   ``Migrating Google AutoML example_dags to sys tests (#32368)``
`53d9421905 <https://github.com/apache/airflow/commit/53d9421905c3c268744c3e43601db63bc7b6fa87>`__  2023-07-07   ``build(pre-commit): check deferrable default value (#32370)``
`2d690de110 <https://github.com/apache/airflow/commit/2d690de110825ba09b9445967b47c44edd8f151c>`__  2023-07-07   ``Fix BigQuery transfer operators to respect project_id arguments (#32232)``
`e7587b3369 <https://github.com/apache/airflow/commit/e7587b3369af30848c3cf1c7eff9e801b1440793>`__  2023-07-06   ``Fix the gcp_gcs_delete_objects on empty list (#32383)``
`becfb3c64f <https://github.com/apache/airflow/commit/becfb3c64f42533d6b8c6806c290952d84bc76a0>`__  2023-07-06   ``Fix endless loop of defer in cloud_build (#32387)``
`e4757d6dfa <https://github.com/apache/airflow/commit/e4757d6dfa6e7385eb90c38c60ab8fefa24e7a0e>`__  2023-07-06   ``Fix GCSToGCSOperator copy without wildcard and exact_match=True (#32376)``
==================================================================================================  ===========  ====================================================================================

10.3.0
......

Latest change: 2023-07-06

==================================================================================================  ===========  =============================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =============================================================================================================
`225e3041d2 <https://github.com/apache/airflow/commit/225e3041d269698d0456e09586924c1898d09434>`__  2023-07-06   ``Prepare docs for July 2023 wave of Providers (RC2) (#32381)``
`3878fe6fab <https://github.com/apache/airflow/commit/3878fe6fab3ccc1461932b456c48996f2763139f>`__  2023-07-05   ``Remove spurious headers for provider changelogs (#32373)``
`cb4927a018 <https://github.com/apache/airflow/commit/cb4927a01887e2413c45d8d9cb63e74aa994ee74>`__  2023-07-05   ``Prepare docs for July 2023 wave of Providers (#32298)``
`f8593503cb <https://github.com/apache/airflow/commit/f8593503cbe252c2f4dc5ff48a3f292c9e13baad>`__  2023-07-05   ``Add default_deferrable config (#31712)``
`4501f8b352 <https://github.com/apache/airflow/commit/4501f8b352aee9c2cd29126a64cab62fa19fc49d>`__  2023-06-30   ``Update gcp.rst (#32281)``
`ef49e595f1 <https://github.com/apache/airflow/commit/ef49e595f1ab729cdb72198a3ee47c7dcd182da2>`__  2023-06-30   ``Update references to restructured documentation from airflow core (#32282)``
`ead2530d35 <https://github.com/apache/airflow/commit/ead2530d3500dd27df54383a0802b6c94828c359>`__  2023-06-30   ``Separate out advanced logging configuration (#32131)``
`d6e254db68 <https://github.com/apache/airflow/commit/d6e254db689db070f2f181006e7d6bc593482300>`__  2023-06-30   ``Deprecate 'delimiter' param and source object's wildcards in GCS, introduce 'match_glob' param. (#31261)``
`dd937e51fe <https://github.com/apache/airflow/commit/dd937e51fe1ae3cd36a6993bd42e425960644e1d>`__  2023-06-30   ``Add 'on_finish_action' to 'KubernetesPodOperator' (#30718)``
`c0eaa9b25d <https://github.com/apache/airflow/commit/c0eaa9b25d11eeb6fba1b716323c4ff2c2dbd5e1>`__  2023-06-29   ``Add deferrable mode to CloudSQLExportInstanceOperator (#30852)``
`f3f69bf1e0 <https://github.com/apache/airflow/commit/f3f69bf1e0c025d260be91daada04476d2418e9d>`__  2023-06-29   ``Refactor GKECreateClusterOperator's body validation (#31923)``
`7d2ec76c72 <https://github.com/apache/airflow/commit/7d2ec76c72f70259b67af0047aa785b28668b411>`__  2023-06-29   ``Make the deferrable version of DataprocCreateBatchOperator handle a batch_id that already exists (#32216)``
`09d4718d3a <https://github.com/apache/airflow/commit/09d4718d3a46aecf3355d14d3d23022002f4a818>`__  2023-06-27   ``Improve provider documentation and README structure (#32125)``
`b156db3a70 <https://github.com/apache/airflow/commit/b156db3a70cca5b3d231c0c49f013fbd0af5d194>`__  2023-06-23   ``Adding 'src_fmt_configs' to the list of template fields. (#32097)``
`fa07812d10 <https://github.com/apache/airflow/commit/fa07812d1013f964a4736eade3ba3e1a60f12692>`__  2023-06-23   ``doc: fix Google authorization token command (#31893)``
`59d64d8f2e <https://github.com/apache/airflow/commit/59d64d8f2ed3c0e7b93d3c07041d47883cabb908>`__  2023-06-22   ``[Issue-32069] Fix name format in the batch requests (#32070)``
`fd116cc196 <https://github.com/apache/airflow/commit/fd116cc1964c49e21aaac6062fff596764833c59>`__  2023-06-22   ``Google provider docstring improvements (#31731)``
`8f41584777 <https://github.com/apache/airflow/commit/8f41584777d5121b5323cc14f7c29f5ebaf736fb>`__  2023-06-21   ``Optimize deferrable mode execution for 'BigQueryValueCheckOperator' (#31872)``
`fe7a1aa096 <https://github.com/apache/airflow/commit/fe7a1aa0962538a99f5e73dbd3890a6f210d22ed>`__  2023-06-21   ``Switch Google Ads API version from v13 to v14 (#32028)``
`43fa157e51 <https://github.com/apache/airflow/commit/43fa157e51ac6abe6de8475c7fd356507f453d8f>`__  2023-06-20   ``Fix 'BigQueryInsertJobOperator'  error handling in deferrable mode (#32034)``
`2a79fb74fd <https://github.com/apache/airflow/commit/2a79fb74fd7203fe82b9384af42a59b3a41f84e9>`__  2023-06-20   ``Fix 'BIGQUERY_JOB_DETAILS_LINK_FMT' in 'BigQueryConsoleLink' (#31953)``
==================================================================================================  ===========  =============================================================================================================

10.2.0
......

Latest change: 2023-06-20

==================================================================================================  ===========  ========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ========================================================================================================
`79bcc2e668 <https://github.com/apache/airflow/commit/79bcc2e668e648098aad6eaa87fe8823c76bc69a>`__  2023-06-20   ``Prepare RC1 docs for June 2023 wave of Providers (#32001)``
`8b146152d6 <https://github.com/apache/airflow/commit/8b146152d62118defb3004c997c89c99348ef948>`__  2023-06-20   ``Add note about dropping Python 3.7 for providers (#32015)``
`f2ebc292fe <https://github.com/apache/airflow/commit/f2ebc292fe63d2ddd0686d90c3acc0630f017a07>`__  2023-06-19   ``Provide missing project id and creds for TabularDataset (#31991)``
`66299338eb <https://github.com/apache/airflow/commit/66299338eb24aa71eb2e27ebd8b76079b39fd305>`__  2023-06-18   ``add a return when the event is yielded in a loop to stop the execution (#31985)``
`e6960f1ad6 <https://github.com/apache/airflow/commit/e6960f1ad63f40ff4ccde6c86b17e051b302c104>`__  2023-06-15   ``Revert "Fix 'BIGQUERY_JOB_DETAILS_LINK_FMT' in 'BigQueryConsoleLink' (#31457)" (#31935)``
`c7072c0490 <https://github.com/apache/airflow/commit/c7072c0490cb80b448622a27eb1056576d6b92a4>`__  2023-06-15   ``Fix 'BIGQUERY_JOB_DETAILS_LINK_FMT' in 'BigQueryConsoleLink' (#31457)``
`a81ac70b33 <https://github.com/apache/airflow/commit/a81ac70b33a589c58b59864df931d3293fada382>`__  2023-06-15   ``Add deferrable mode to PubsubPullSensor (#31284)``
`b502e665d6 <https://github.com/apache/airflow/commit/b502e665d633262f3ce52d9c002c0a25e6e4ec9d>`__  2023-06-14   ``Add a new param to set parquet row group size in 'BaseSQLToGCSOperator' (#31831)``
`f32371c96b <https://github.com/apache/airflow/commit/f32371c96bf3671727502db0f4bd0f61e0033b80>`__  2023-06-14   ``Clean up BigQuery async docs (#31727)``
`810d46776a <https://github.com/apache/airflow/commit/810d46776ad1a52f27ec578e5be875c39c90fc45>`__  2023-06-11   ``Implement MetastoreHivePartitionSensor (#31016)``
`233663046d <https://github.com/apache/airflow/commit/233663046d5210359ce9f4db2fe3db4f5c38f6ee>`__  2023-06-08   ``Add 'cacheControl' field to google cloud storage (#31338)``
`ba3665f76a <https://github.com/apache/airflow/commit/ba3665f76a2205bad4553ba00537026a1346e9ae>`__  2023-06-08   ``Bigquery: fix links for already existing tables and datasets. (#31589)``
`fbeb01cb17 <https://github.com/apache/airflow/commit/fbeb01cb17b7cb9c2e27ac7010f423a2bced78b4>`__  2023-06-07   ``Replace unicodecsv with standard csv library (#31693)``
`d91861d3bd <https://github.com/apache/airflow/commit/d91861d3bdbde18c937978c878d137d6c758e2c6>`__  2023-06-07   ``Optimize deferrable mode (#31758)``
`9e268e13b1 <https://github.com/apache/airflow/commit/9e268e13b147401a5665e497aee87ac107ade8d1>`__  2023-06-07   ``Replace spelling directive with spelling:word-list (#31752)``
`36ffbee4aa <https://github.com/apache/airflow/commit/36ffbee4aae37b83b188d35aedd36add8dedf50e>`__  2023-06-05   ``Add D400 pydocstyle check - Google provider only (#31422)``
`495ae23d45 <https://github.com/apache/airflow/commit/495ae23d45eda52f2b368d0afa4213f4e69e97cd>`__  2023-06-05   ``Optimize deferrable mode execution for 'DataprocSubmitJobOperator' (#31317)``
`86b5ba2802 <https://github.com/apache/airflow/commit/86b5ba28026fc6e8b7d868b83080189df9b09306>`__  2023-06-04   ``Remove return statement after yield from triggers class (#31703)``
`ec2db30267 <https://github.com/apache/airflow/commit/ec2db302675f41d1ba43673895cfc44b13b25349>`__  2023-06-02   ``update path of KubernetesPodOperator in docs (#31682)``
`dc5bf3fd02 <https://github.com/apache/airflow/commit/dc5bf3fd02c589578209cb0dd5b7d005b1516ae9>`__  2023-06-02   ``Add discoverability for triggers in provider.yaml (#31576)``
`47c2023df2 <https://github.com/apache/airflow/commit/47c2023df273654bb6ea4b1ec08ab86dfb633092>`__  2023-05-31   ``Add 'preserveAsciiControlCharacters' to 'src_fmt_configs' (#31643)``
`e3ec1ac72e <https://github.com/apache/airflow/commit/e3ec1ac72eac9aa6a9f3a99154fe0bf53a8d283a>`__  2023-05-30   ``Add support for credential configuation file auth to Google Secrets Manager secrets backend (#31597)``
`9fa75aaf7a <https://github.com/apache/airflow/commit/9fa75aaf7a391ebf0e6b6949445c060f6de2ceb9>`__  2023-05-29   ``Remove Python 3.7 support (#30963)``
`ef40148170 <https://github.com/apache/airflow/commit/ef40148170ce1110a4c9a859207d40dcc6ad1cd5>`__  2023-05-26   ``Add credential configuration file support to Google Cloud Hook (#31548)``
`22e44ab9f2 <https://github.com/apache/airflow/commit/22e44ab9f2f3a68aa2ed236cfe514554dd479a38>`__  2023-05-26   ``FIPS environments: Mark uses of md5 as "not-used-for-security" (#31171)``
`5ae9728db7 <https://github.com/apache/airflow/commit/5ae9728db7d34d287907ca3a919ac1a94c776799>`__  2023-05-25   ``Add deferrable mode to 'GCSUploadSessionCompleteSensor' (#31081)``
`28f2e70916 <https://github.com/apache/airflow/commit/28f2e709165a56f0bc1097d7457149330914cea9>`__  2023-05-25   ``Optimize deferrable mode execution for 'BigQueryInsertJobOperator' (#31249)``
`769e204d53 <https://github.com/apache/airflow/commit/769e204d533769a50f4b40b9f6cfe718960877df>`__  2023-05-24   ``Add append_job_name parameter in DataflowStartFlexTemplateOperator (#31511)``
==================================================================================================  ===========  ========================================================================================================

10.1.1
......

Latest change: 2023-05-24

==================================================================================================  ===========  ==============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==============================================================================================
`d745cee3db <https://github.com/apache/airflow/commit/d745cee3dbde6b437a817aa64e385a1a948389d5>`__  2023-05-24   ``Prepare adhoc wave of Providers (#31478)``
`c082aec089 <https://github.com/apache/airflow/commit/c082aec089405ed0399cfee548011b0520be0011>`__  2023-05-23   ``Fix accessing a GKE cluster through the private endpoint in 'GKEStartPodOperator' (#31391)``
`0d6e626b05 <https://github.com/apache/airflow/commit/0d6e626b050a860462224ad64dc5e9831fe8624d>`__  2023-05-22   ``Fix 'BigQueryGetDataOperator''s query job bugs in deferrable mode (#31433)``
==================================================================================================  ===========  ==============================================================================================

10.1.0
......

Latest change: 2023-05-19

==================================================================================================  ===========  ===========================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===========================================================================================================================
`45548b9451 <https://github.com/apache/airflow/commit/45548b9451fba4e48c6f0c0ba6050482c2ea2956>`__  2023-05-19   ``Prepare RC2 docs for May 2023 wave of Providers (#31416)``
`54f1fb0574 <https://github.com/apache/airflow/commit/54f1fb0574a6ecf8f415bbf6da1aaf6f1999bb29>`__  2023-05-19   ``Docstring improvements (#31375)``
`cfe759dc59 <https://github.com/apache/airflow/commit/cfe759dc59bfc3390e7ba07184f0de9eb725122d>`__  2023-05-19   ``Switch default Google ads to v13 (#31382)``
`abea189022 <https://github.com/apache/airflow/commit/abea18902257c0250fedb764edda462f9e5abc84>`__  2023-05-18   ``Use '__version__' in providers not 'version' (#31393)``
`db8cbf6ab5 <https://github.com/apache/airflow/commit/db8cbf6ab5e144f58555e0c30361d8d6ec31ef21>`__  2023-05-18   ``Add get_namespace to GKEPodHook (#31397)``
`f5aed58d9f <https://github.com/apache/airflow/commit/f5aed58d9fb2137fa5f0e3ce75b6709bf8393a94>`__  2023-05-18   ``Fixing circular import error in providers caused by airflow version check (#31379)``
`d677a263be <https://github.com/apache/airflow/commit/d677a263be0a55fcbbb905f7f47b67bf0f77f59d>`__  2023-05-18   ``Switch to google ads v13 (#31369)``
`28d1bf8dfc <https://github.com/apache/airflow/commit/28d1bf8dfc03787cc2b4373bbaa27527bdd91846>`__  2023-05-18   ``Update SDKs for google provider package (#30067)``
`7ebda3898d <https://github.com/apache/airflow/commit/7ebda3898db2eee72d043a9565a674dea72cd8fa>`__  2023-05-17   ``Fix missing line in index.rst for provider documentation (#31343)``
`d9ff55cf6d <https://github.com/apache/airflow/commit/d9ff55cf6d95bb342fed7a87613db7b9e7c8dd0f>`__  2023-05-16   ``Prepare docs for May 2023 wave of Providers (#31252)``
`cf1e26b046 <https://github.com/apache/airflow/commit/cf1e26b04669ad2b232618fee623e6bc7797a13a>`__  2023-05-16   ``Add BigQueryToPostgresOperator (#30658)``
`d9f70dffd1 <https://github.com/apache/airflow/commit/d9f70dffd1813fa6356d8981167eca6d5f317bb1>`__  2023-05-16   ``Add CloudBuild build id log (#30516)``
`caeca2d143 <https://github.com/apache/airflow/commit/caeca2d143152ef037ccbaae858f1e2fa6763674>`__  2023-05-15   ``Add protocol to define methods relied upon by KubernetesPodOperator (#31298)``
`d3a2dbe028 <https://github.com/apache/airflow/commit/d3a2dbe028e4a8c2da9fcb2b3257e2117c413a73>`__  2023-05-15   ``GKEPodHook needs to have all methods KPO calls (#31266)``
`fb6c501124 <https://github.com/apache/airflow/commit/fb6c501124186f695b9dfa497cde10298ac12e9f>`__  2023-05-13   ``Add flag apply_gcs_prefix to S3ToGCSOperator (b/245077385) (#31127)``
`a66edcbb2c <https://github.com/apache/airflow/commit/a66edcbb2c9c04031326a3965c76a419043338ff>`__  2023-05-13   ``'CreateBatchPredictionJobOperator' Add batch_size param for Vertex AI BatchPredictionJob objects (#31118)``
`d1fe67184d <https://github.com/apache/airflow/commit/d1fe67184da26fb0bca2416e26f321747fa4aa5d>`__  2023-05-12   ``Add 'use_legacy_sql' param to 'BigQueryGetDataOperator' (#31190)``
`b8f73768ec <https://github.com/apache/airflow/commit/b8f73768ec13f8d4cc1605cca3fa93be6caac473>`__  2023-05-09   ``Add 'as_dict' param to 'BigQueryGetDataOperator' (#30887)``
`e68d4a7764 <https://github.com/apache/airflow/commit/e68d4a77645a5f0c199d5618912a99be71281920>`__  2023-05-08   ``implement gcs_schema_object for BigQueryCreateExternalTableOperator (#30961)``
`810b5d4da4 <https://github.com/apache/airflow/commit/810b5d4da4396cedcd483d20e50873c2b81cf5ad>`__  2023-05-08   ``'DataflowTemplatedJobStartOperator' fix overwriting of location with default value, when a region is provided. (#31082)``
`ac46902154 <https://github.com/apache/airflow/commit/ac46902154c060246dec942f921f7670015e6031>`__  2023-05-04   ``Move TaskInstanceKey to a separate file (#31033)``
`0a30706aa7 <https://github.com/apache/airflow/commit/0a30706aa7c581905ca99a8b6e2f05960d480729>`__  2023-05-03   ``Use 'AirflowProviderDeprecationWarning' in providers (#30975)``
`eef5bc7f16 <https://github.com/apache/airflow/commit/eef5bc7f166dc357fea0cc592d39714b1a5e3c14>`__  2023-05-03   ``Add full automation for min Airflow version for providers (#30994)``
`b0a40bb812 <https://github.com/apache/airflow/commit/b0a40bb8129aeddd3e7ed78417c64406ebb50063>`__  2023-04-30   ``Optimize deferred execution mode (#30946)``
`a7eb32a5b2 <https://github.com/apache/airflow/commit/a7eb32a5b222e236454d3e474eec478ded7c368d>`__  2023-04-30   ``Bump minimum Airflow version in providers (#30917)``
`f89d7b9848 <https://github.com/apache/airflow/commit/f89d7b98487d993387ebea4af526fe20204ce02a>`__  2023-04-28   ``Poke once before defer for GCSObjectsWithPrefixExistenceSensor (#30939)``
`a3741e0e02 <https://github.com/apache/airflow/commit/a3741e0e0216bacbd18d7dc9d83c9370af82a665>`__  2023-04-28   ``Optimize deferrable mode execution (#30920)``
`0d95acef1d <https://github.com/apache/airflow/commit/0d95acef1d0d47fd95545645a75e64fe7c4bb6a6>`__  2023-04-28   ``Add deferrable mode to DataprocInstantiateInlineWorkflowTemplateOperator (#30878)``
`3a5b583c91 <https://github.com/apache/airflow/commit/3a5b583c916fff4603cdb2f2be815ccc5c281750>`__  2023-04-27   ``Optimize deferrable mode in 'GCSObjectExistenceSensor' (#30901)``
`eed5d5b7cc <https://github.com/apache/airflow/commit/eed5d5b7cc8b95a7e7ab0ac5f92c1d3a173dfc75>`__  2023-04-27   ``Add deferrable mode to 'GCSObjectsWithPrefixExistenceSensor' (#30618)``
`48c9625c70 <https://github.com/apache/airflow/commit/48c9625c700e20f03fcddf97d41cbd749058b053>`__  2023-04-24   ``Add 'priority' parameter to BigQueryHook (#30655)``
`9409446097 <https://github.com/apache/airflow/commit/940944609751e2584b191aa776b6221aa78703d3>`__  2023-04-24   ``Add cli cmd to list the provider trigger info (#30822)``
`432697d90c <https://github.com/apache/airflow/commit/432697d90cdcea35607bcaa970c694c88053222c>`__  2023-04-23   ``allow multiple prefixes in gcs delete/list hooks and operators (#30815)``
`c499b6beb2 <https://github.com/apache/airflow/commit/c499b6beb20737addc03aa4266d61f10f660c2b8>`__  2023-04-22   ``Small refactors in ClusterGenerator of dataproc (#30714)``
`c585ad51c5 <https://github.com/apache/airflow/commit/c585ad51c522c6e9f3bbbf7ae6e0132e25a3a378>`__  2023-04-22   ``Upgrade ruff to 0.0.262 (#30809)``
`676a95b220 <https://github.com/apache/airflow/commit/676a95b2207e4eb97403bbe78b35716538901b8e>`__  2023-04-22   ``Fix removed delegate_to parameter in deferrable GCS sensor (#30810)``
`9e49d91a0a <https://github.com/apache/airflow/commit/9e49d91a0a9462696d9b3cebc55275e704943fbf>`__  2023-04-22   ``Add deferrable mode to 'GCSObjectUpdateSensor' (#30579)``
==================================================================================================  ===========  ===========================================================================================================================

10.0.0
......

Latest change: 2023-04-21

==================================================================================================  ===========  ===============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===============================================================================================
`e46ce78b66 <https://github.com/apache/airflow/commit/e46ce78b66953146c04de5da00cab6299787adad>`__  2023-04-21   ``Prepare docs for adhoc release of providers (#30787)``
`fbc1382514 <https://github.com/apache/airflow/commit/fbc13825140cc6cc6b3d4b27db6d329692a1c451>`__  2023-04-21   ``remove delegate_to from GCP operators and hooks (#30748)``
`b48f959ae9 <https://github.com/apache/airflow/commit/b48f959ae93703f52721999ef04f459fe56dcf58>`__  2023-04-21   ``Update DataprocCreateCluster operator to use 'label' parameter properly (#30741)``
`da2749cae5 <https://github.com/apache/airflow/commit/da2749cae56d6e0da322695b3286acd9393052c8>`__  2023-04-15   ``Update Google Campaign Manager360 operators to use API v4 (#30598)``
`4eab616e9f <https://github.com/apache/airflow/commit/4eab616e9f0a89c1a6268d5b5eaba526bfa9be6d>`__  2023-04-15   ``add missing project_id in BigQueryGetDataOperator (#30651)``
`57c09e59ee <https://github.com/apache/airflow/commit/57c09e59ee9273ff64cd4a85b020a4df9b1d9eca>`__  2023-04-14   ``Display Video 360 cleanup v1 API usage (#30577)``
`058b6ebdd8 <https://github.com/apache/airflow/commit/058b6ebdd863ff9178007f5750cc4cde4d3c463f>`__  2023-04-13   ``Updating the links to the Dataform product documentation to fix 404 redirect error (#30631)``
==================================================================================================  ===========  ===============================================================================================

9.0.0
.....

Latest change: 2023-04-12

==================================================================================================  ===========  =========================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =========================================================================
`0f3b6579cb <https://github.com/apache/airflow/commit/0f3b6579cb67d3cf8bd9fa8f9abd502fc774201a>`__  2023-04-12   ``Prepare docs for RC2 of provider wave (#30606)``
`7421b3e053 <https://github.com/apache/airflow/commit/7421b3e053831b4939c9b09c7de97955508c1eea>`__  2023-04-10   ``Update dataproc.rst (#30566)``
`874ea9588e <https://github.com/apache/airflow/commit/874ea9588e3ce7869759440302e53bb6a730a11e>`__  2023-04-09   ``Prepare docs for ad hoc release of Providers (#30545)``
`71db47a73d <https://github.com/apache/airflow/commit/71db47a73d741015d8ffeaa2276635f19d51f8e7>`__  2023-04-09   ``Update DV360 operators to use API v2 (#30326)``
`3d2c96e3f5 <https://github.com/apache/airflow/commit/3d2c96e3f5d238955bccba190726d0fba860eb7a>`__  2023-04-08   ``Add deferrable mode to GKEStartPodOperator (#29266)``
`4703f9a0e5 <https://github.com/apache/airflow/commit/4703f9a0e589557f5176a6f466ae83fe52644cf6>`__  2023-04-08   ``BigQueryHook list_rows/get_datasets_list can return iterator (#30543)``
`d9896fd96e <https://github.com/apache/airflow/commit/d9896fd96eb91a684a512a86924a801db53eb945>`__  2023-04-08   ``Fix dynamic imports in google ads vendored in library (#30544)``
`d23a3bbed8 <https://github.com/apache/airflow/commit/d23a3bbed89ae04369983f21455bf85ccc1ae1cb>`__  2023-04-04   ``Add mechanism to suspend providers (#30422)``
`2ba1e63c37 <https://github.com/apache/airflow/commit/2ba1e63c37d56a4bba6f69c07497112a5e7cb157>`__  2023-04-04   ``Fix cloud build async credentials (#30441)``
`cc6fd5c0d9 <https://github.com/apache/airflow/commit/cc6fd5c0d915e7f77feff70fef23519515b12083>`__  2023-04-03   ``Small quotation fix (#30448)``
==================================================================================================  ===========  =========================================================================

8.12.0
......

Latest change: 2023-04-02

==================================================================================================  ===========  ========================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ========================================================================================================================================
`55dbf1ff1f <https://github.com/apache/airflow/commit/55dbf1ff1fb0b22714f695a66f6108b3249d1199>`__  2023-04-02   ``Prepare docs for April 2023 wave of Providers (#30378)``
`25048fa6b2 <https://github.com/apache/airflow/commit/25048fa6b21b1e75a0c6fb6d626c67860e8cecff>`__  2023-04-01   ``Switch to using vendored-in google ads. (#30410)``
`2e65c70e99 <https://github.com/apache/airflow/commit/2e65c70e99e73d4bc39e26da88f9e0102dd41f65>`__  2023-04-01   ``Merging of the google ads vendored-in code. (#30399)``
`540a076801 <https://github.com/apache/airflow/commit/540a0768012c82794add3ec159768521e01a0fe2>`__  2023-03-30   ``merge BigQueryTableExistenceAsyncSensor into BigQueryTableExistenceSensor (#30235)``
`29eba167ea <https://github.com/apache/airflow/commit/29eba167eac5d08862a85dd1358a8b6c43f61200>`__  2023-03-22   ``Merge BigQueryTableExistencePartitionAsyncSensor into BigQueryTableExistencePartitionSensor (#30231)``
`79a2fa7db9 <https://github.com/apache/airflow/commit/79a2fa7db9d1689c5fe8a0afaa3883c4e0ccc00d>`__  2023-03-21   ``Merge GCSObjectExistenceAsyncSensor logic to GCSObjectExistenceSensor (#30014)``
`af4627fec9 <https://github.com/apache/airflow/commit/af4627fec988995537de7fa172875497608ef710>`__  2023-03-20   ``fix setting project_id for gs to bq and bq to gs (#30053)``
`75fd5e8c54 <https://github.com/apache/airflow/commit/75fd5e8c54cdc0465ed43c9b36b3d0672bd7e059>`__  2023-03-16   ``Add missing 'poll_interval' in Bigquery operator (#30132)``
`5a3be7256b <https://github.com/apache/airflow/commit/5a3be7256b2a848524d3635d7907b6829a583101>`__  2023-03-15   ``Handling project location param on async BigQuery dts trigger (#29786)``
`a6715805c7 <https://github.com/apache/airflow/commit/a6715805c7e4694e85b8f3ebff162a2c3905110e>`__  2023-03-14   ``Add poll_interval param in BigQueryInsertJobOperator (#30091)``
`57fb80cff0 <https://github.com/apache/airflow/commit/57fb80cff020a3e405c7d6a72037a7757ccdd5f5>`__  2023-03-14   ``Support CloudDataTransferServiceJobStatusSensor without specifying a project_id (#30035)``
`def1f89e70 <https://github.com/apache/airflow/commit/def1f89e702d401f67a94f34a01f6a4806ea92e6>`__  2023-03-10   ``Fix location on cloud build operators (#29937)``
`599c587e26 <https://github.com/apache/airflow/commit/599c587e26d5e0b8fa0a0967f3dc4fa92d257ed0>`__  2023-03-10   ``Add 'job_id' to 'BigQueryToGCSOperator' templated_fields (#30006)``
`c3867781e0 <https://github.com/apache/airflow/commit/c3867781e09b7e0e0d19c0991865a2453194d9a8>`__  2023-03-08   ``adding trigger info to provider yaml (#29950)``
`b6392ae5fd <https://github.com/apache/airflow/commit/b6392ae5fd466fa06ca92c061a0f93272e27a26b>`__  2023-03-07   ``Support deleting the local log files when using remote logging (#29772)``
`464ab1b7ca <https://github.com/apache/airflow/commit/464ab1b7caa78637975008fcbb049d5b52a8b005>`__  2023-03-05   ``Wait insert_job result in normal mode (#29925)``
`f55b9576b1 <https://github.com/apache/airflow/commit/f55b9576b1363d2cada0a25daf79501c8aad8b54>`__  2023-03-05   ``'GoogleDriveHook': Fixing log message + adding more verbose documentation (#29694)``
`035ad26d79 <https://github.com/apache/airflow/commit/035ad26d79848c63049307a94c04a9a3916d8a38>`__  2023-03-04   ``Add "BOOLEAN" to type_map of MSSQLToGCSOperator, fix incorrect bit->int type conversion by specifying BIT fields explicitly (#29902)``
`5a632f78eb <https://github.com/apache/airflow/commit/5a632f78eb6e3dcd9dc808e73b74581806653a89>`__  2023-03-04   ``Google Cloud Providers - Fix _MethodDefault deepcopy failure (#29518)``
`971039454a <https://github.com/apache/airflow/commit/971039454a3684d0ea7261dfe91f34ac4b62af72>`__  2023-03-04   ``Align cncf provider file names with AIP-21 (#29905)``
`864ff2e3ce <https://github.com/apache/airflow/commit/864ff2e3ce185dfa3df0509a4bd3c6b5169e907f>`__  2023-03-04   ``Remove  unnecessary upper constraints from google provider (#29915)``
==================================================================================================  ===========  ========================================================================================================================================

8.11.0
......

Latest change: 2023-03-03

==================================================================================================  ===========  ======================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ======================================================================================================
`fcd3c0149f <https://github.com/apache/airflow/commit/fcd3c0149f17b364dfb94c0523d23e3145976bbe>`__  2023-03-03   ``Prepare docs for 03/2023 wave of Providers (#29878)``
`3fc9461654 <https://github.com/apache/airflow/commit/3fc946165458f203162ddb229bee133e1a6fcac2>`__  2023-03-03   ``Add 'CloudSQLCloneInstanceOperator' (#29726)``
`47ab0ca629 <https://github.com/apache/airflow/commit/47ab0ca6295f301d393dbb29e134fa90be0ad7df>`__  2023-03-03   ``Move help message to the google auth code (#29888)``
`972fca2253 <https://github.com/apache/airflow/commit/972fca22532121493d49753bd6d8388af5943689>`__  2023-02-28   ``Fix 'NoneType' object is not subscriptable. (#29820)``
`ec844eaa0a <https://github.com/apache/airflow/commit/ec844eaa0a3864d1da74d9ee6c3cf7edb36fbe8c>`__  2023-02-27   ``Add deferrable mode to BigQueryTablePartitionExistenceSensor. (#29735)``
`a5adb87ab4 <https://github.com/apache/airflow/commit/a5adb87ab4ee537eb37ef31aba755b40f6f29a1e>`__  2023-02-26   ``Add a new param for BigQuery operators to support additional actions when resource exists (#29394)``
`1e7c064560 <https://github.com/apache/airflow/commit/1e7c064560b8504b45e3a53dc8f294b143b4ec7d>`__  2023-02-25   ``Google Cloud Providers - Introduce GoogleCloudBaseOperator (#29680)``
`ad08f66228 <https://github.com/apache/airflow/commit/ad08f662280612f44549a71f9c835595cfd05f0a>`__  2023-02-22   ``Remove <2.0.0 limit on google-cloud-bigtable (#29644)``
`dba390e323 <https://github.com/apache/airflow/commit/dba390e32330675e1b94442c8001ea980754c189>`__  2023-02-22   ``Fix and augment 'check-for-inclusive-language' CI check (#29549)``
`f51742d20b <https://github.com/apache/airflow/commit/f51742d20b2e53bcd90a19db21e4e12d2a287677>`__  2023-02-21   ``Don't push secret in XCOM in BigQueryCreateDataTransferOperator (#29348)``
`3dbcf99d20 <https://github.com/apache/airflow/commit/3dbcf99d20d47cde0debdd5faf9bd9b2ebde1718>`__  2023-02-21   ``Update google cloud dlp package and adjust hook and operators (#29234)``
`6ef5ba9104 <https://github.com/apache/airflow/commit/6ef5ba9104f5a658b003f8ade274f19d7ec1b6a9>`__  2023-02-20   ``Refactor Dataproc Trigger (#29364)``
`7e3a9fc858 <https://github.com/apache/airflow/commit/7e3a9fc8586d0e6d9eddbf833a75280e68050da8>`__  2023-02-20   ``Dataproc batches (#29136)``
`1677d80e65 <https://github.com/apache/airflow/commit/1677d80e6573acfc7a706ac25c4ee3a353071f7b>`__  2023-02-20   ``Add deferrable mode to DataprocInstantiateWorkflowTemplateOperator (#28618)``
==================================================================================================  ===========  ======================================================================================================

8.10.0
......

Latest change: 2023-02-18

==================================================================================================  ===========  ====================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================
`470fdaea27 <https://github.com/apache/airflow/commit/470fdaea275660970777c0f72b8867b382eabc14>`__  2023-02-18   ``Prepare docs for 02 2023 midmonth wave of Providers (#29589)``
`f37772adfd <https://github.com/apache/airflow/commit/f37772adfdfdee8763147e0563897e4d5d5657c8>`__  2023-02-18   ``'GoogleDriveHook': Add folder_id param to upload_file (#29477)``
`28126c12fb <https://github.com/apache/airflow/commit/28126c12fbdd2cac84e0fbcf2212154085aa5ed9>`__  2023-02-14   ``Add defer mode to GKECreateClusterOperator and GKEDeleteClusterOperator (#28406)``
`32c571e592 <https://github.com/apache/airflow/commit/32c571e5926983903ac8b9017c36f14137a797a5>`__  2023-02-14   ``Move cloud_sql_binary_path from connection to Hook (#29499)``
`41fade2d21 <https://github.com/apache/airflow/commit/41fade2d219c1841fafa439cc5dbb036f34ee32a>`__  2023-02-13   ``Upgrade Mypy to 1.0 (#29468)``
`5e6f8eb4d5 <https://github.com/apache/airflow/commit/5e6f8eb4d5fdcaa713022ee46b1ca9bd2e3ab44e>`__  2023-02-13   ``Check that cloud sql provider version is valid (#29497)``
`f9e9d23457 <https://github.com/apache/airflow/commit/f9e9d23457cba5d3e18b5bdb7b65ecc63735b65b>`__  2023-02-11   ``Restore trigger logging (#29482)``
`7ee1a56244 <https://github.com/apache/airflow/commit/7ee1a5624497fc457af239e93e4c1af94972bbe6>`__  2023-02-11   ``Add documentation for BigQuery transfer operators (#29466)``
`60d4bcd1d1 <https://github.com/apache/airflow/commit/60d4bcd1d101bb56955081d14e3e138a0c960c5f>`__  2023-02-10   ``Revert "Enable individual trigger logging (#27758)" (#29472)``
`6c1eeb5839 <https://github.com/apache/airflow/commit/6c1eeb58393173895944d5414793b38abdc7510d>`__  2023-02-11   ``Revert "Upgrade mypy to 0.991 (#28926)" (#29470)``
`6ae0a80cba <https://github.com/apache/airflow/commit/6ae0a80cbaf1d33343b763c7f82612b4522afc40>`__  2023-02-11   ``Upgrade mypy to 0.991 (#28926)``
==================================================================================================  ===========  ====================================================================================

8.9.0
.....

Latest change: 2023-02-08

==================================================================================================  ===========  ===================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===================================================================================================
`ce6ae2457e <https://github.com/apache/airflow/commit/ce6ae2457ef3d9f44f0086b58026909170bbf22a>`__  2023-02-08   ``Prepare docs for Feb 2023 wave of Providers (#29379)``
`1b18a501fe <https://github.com/apache/airflow/commit/1b18a501fe818079e535838fa4f232b03365fc75>`__  2023-02-03   ``Enable individual trigger logging (#27758)``
`872df121e2 <https://github.com/apache/airflow/commit/872df121e2ae24520eeb29fe606183a566e35dd8>`__  2023-02-03   ``Add deferrable capability to existing ''DataprocDeleteClusterOperator'' (#29349)``
`70a174c47f <https://github.com/apache/airflow/commit/70a174c47f14f43445d59b8249ee4f0dab4ea995>`__  2023-02-03   ``Fixup some punctuation and grammar (#29342)``
`094d6bf01b <https://github.com/apache/airflow/commit/094d6bf01b9d8b1a5d358dc10fd561cf3a04c51b>`__  2023-01-30   ``Add deferrable mode to dataflow operators (#27776)``
`9d9351728c <https://github.com/apache/airflow/commit/9d9351728cac9f9ed3bea0504dcfa8da15a7461b>`__  2023-01-30   ``Add deferrable mode to DataprocCreateBatchOperator (#28457)``
`9fd80130e2 <https://github.com/apache/airflow/commit/9fd80130e2351c7ec31bbeb6c10f6b11708b318b>`__  2023-01-25   ``Add deferrable mode to DataprocCreateClusterOperator and DataprocUpdateClusterOperator (#28529)``
`02bebf897b <https://github.com/apache/airflow/commit/02bebf897b5a7d166f8cc9304eb58290aea1eba6>`__  2023-01-25   ``Add deferrable mode to MLEngineStartTrainingJobOperator (#27405)``
`cf90a1a567 <https://github.com/apache/airflow/commit/cf90a1a5673d4c7a72b7209439eca6c03b07b99a>`__  2023-01-25   ``Keyfile dict can be dict not str (#29135)``
`b4c50dadd3 <https://github.com/apache/airflow/commit/b4c50dadd36d66e4d222c627a61771653767afd6>`__  2023-01-24   ``GCSTaskHandler may use remote log conn id (#29117)``
`b2825e1185 <https://github.com/apache/airflow/commit/b2825e11852890cf0b0f4d0bcaae592311781cdf>`__  2023-01-24   ``Fix GoogleDriveHook writing files to trashed folders on upload v2 (#29119)``
`be0e35321f <https://github.com/apache/airflow/commit/be0e35321f0bbd7d21c75096cad45dbe20c2359a>`__  2023-01-24   ``fix Google provider CHANGELOG.rst (#29122)``
`3374fdfcbd <https://github.com/apache/airflow/commit/3374fdfcbddb630b4fc70ceedd5aed673e6c0a0d>`__  2023-01-23   ``Deprecate 'delegate_to' param in GCP operators and update docs (#29088)``
`7e2493e3c8 <https://github.com/apache/airflow/commit/7e2493e3c8b2dbeb378dba4e40110ab1e4ad24da>`__  2023-01-23   ``fix Google provider CHANGELOG.rst (#29114)``
`90e6277da6 <https://github.com/apache/airflow/commit/90e6277da6b4102cf565134739af10bafa9d3894>`__  2023-01-23   ``Auto ML assets (#25466)``
`e926bb9bb0 <https://github.com/apache/airflow/commit/e926bb9bb0ce97b4bb32e49279bde237ba8935ed>`__  2023-01-20   ``Add deferrable mode to DataFusionStartPipelineOperator (#28690)``
`5fcdd321c5 <https://github.com/apache/airflow/commit/5fcdd321c5b9f220991af4c552401c8dd00fbffe>`__  2023-01-20   ``Add deferrable mode for Big Query Transfer operator (#27833)``
`5350be2194 <https://github.com/apache/airflow/commit/5350be2194250366536db7f78b88dc8e49c9620e>`__  2023-01-19   ``Add support for write_on_empty in BaseSQLToGCSOperator (#28959)``
`dc3a3c7c52 <https://github.com/apache/airflow/commit/dc3a3c7c52aab815ddd49b33aba4e6040d8512af>`__  2023-01-16   ``Add DataprocCancelOperationOperator (#28456)``
==================================================================================================  ===========  ===================================================================================================

8.8.0
.....

Latest change: 2023-01-14

==================================================================================================  ===========  =========================================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =========================================================================================================================================================
`911b708ffd <https://github.com/apache/airflow/commit/911b708ffddd4e7cb6aaeac84048291891eb0f1f>`__  2023-01-14   ``Prepare docs for Jan 2023 mid-month wave of Providers (#28929)``
`ce858a5d71 <https://github.com/apache/airflow/commit/ce858a5d719fb1dff85ad7e4747f0777404d1f56>`__  2023-01-12   ``Switch to ruff for faster static checks (#28893)``
`f1eb2f1af4 <https://github.com/apache/airflow/commit/f1eb2f1af42c537f7c49a891f238083fd5d9e762>`__  2023-01-12   ``'BigQueryCreateExternalTableOperator' fix field delimiter not working with csv (#28856)``
`a337e6209a <https://github.com/apache/airflow/commit/a337e6209ad1ded42db3f1d788c3f4df4f1d645a>`__  2023-01-11   ``Fix using private _get_credentials instead of public get_credentials (#28588)``
`44d3082ef9 <https://github.com/apache/airflow/commit/44d3082ef9e71dad1e51f2215ae31fca61f1ad90>`__  2023-01-11   ``Small Typo Fixed (#28684)``
`284cd52989 <https://github.com/apache/airflow/commit/284cd529898fbadd14308004a0b0cb6f389b4318>`__  2023-01-10   ``Add deferrable ''GCSObjectExistenceSensorAsync'' (#28763)``
`35a8ffc55a <https://github.com/apache/airflow/commit/35a8ffc55af220b16ea345d770f80f698dcae3fb>`__  2023-01-10   ``Support partition_columns in BaseSQLToGCSOperator (#28677)``
`c0b2fcff24 <https://github.com/apache/airflow/commit/c0b2fcff24184aa0c5beb9c0d06ce7d67b5c5b7e>`__  2023-01-09   ``assign "datasetReference" attribute to dataset_reference dict. by default if not already set in create_empty_dataset method of bigquery hook (#28782)``
`71306b31f1 <https://github.com/apache/airflow/commit/71306b31f1842ee2b1eb1cc2980b90f0fb6b11dc>`__  2023-01-09   ``Fix'GoogleCampaignManagerReportSensor' with 'QUEUED' status (#28735)``
`c67f4af667 <https://github.com/apache/airflow/commit/c67f4af667948e654585e6df102663670804819e>`__  2023-01-09   ``Fix BigQueryColumnCheckOperator runtime error (#28796)``
`10ddfe756f <https://github.com/apache/airflow/commit/10ddfe756feed62709a90f20a41ff687817c683a>`__  2023-01-03   ``corrected typo (#28699)``
==================================================================================================  ===========  =========================================================================================================================================================

8.7.0
.....

Latest change: 2023-01-02

==================================================================================================  ===========  =============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =============================================================================================
`5246c009c5 <https://github.com/apache/airflow/commit/5246c009c557b4f6bdf1cd62bf9b89a2da63f630>`__  2023-01-02   ``Prepare docs for Jan 2023 wave of Providers (#28651)``
`fec1460eb7 <https://github.com/apache/airflow/commit/fec1460eb7896da6bfad69e95c92b8e531e35485>`__  2023-01-01   ``Push job_id in xcom for dataproc submit job op (#28639)``
`0fae6a0c9e <https://github.com/apache/airflow/commit/0fae6a0c9e6e303f4b897a79829f119b44550e01>`__  2022-12-28   ``Add table_resource to template fields for BigQueryCreateEmptyTableOperator (#28235)``
`d7f5f6d737 <https://github.com/apache/airflow/commit/d7f5f6d737cf06cc8e216f523534aeaf48065793>`__  2022-12-24   ``GCSToBigQueryOperator allows autodetect None and infers schema (#28564)``
`034039beb2 <https://github.com/apache/airflow/commit/034039beb2568850d29b34390d3dc1e2a91b8367>`__  2022-12-24   ``Remove 'pylint' messages control instructions (#28555)``
`8fb7be2fb5 <https://github.com/apache/airflow/commit/8fb7be2fb5c64cc2f31a05034087923328b1137a>`__  2022-12-22   ``Set bigquery ''use_legacy_sql'' param in job config correctly (#28522)``
`23264fb820 <https://github.com/apache/airflow/commit/23264fb820c179e9951ea9706f68b13a9b3fdbc0>`__  2022-12-21   ``Fix for issue with reading schema fields for JSON files in GCSToBigQueryOperator (#28284)``
`7950fb9711 <https://github.com/apache/airflow/commit/7950fb9711384f8ac4609fc19f319edb17e296ef>`__  2022-12-21   ``Remove deprecated AIPlatformConsoleLinkk from google/provider.yaml (#28449)``
`820f5a9374 <https://github.com/apache/airflow/commit/820f5a9374b4cc0c5fd2f82b644d55683c42d3a8>`__  2022-12-20   ``Use object instead of array in config.yml for config template (#28417)``
`9eacf607be <https://github.com/apache/airflow/commit/9eacf607be109eb6ab80f7e27d234a17fb128ae0>`__  2022-12-20   ``Fix GCSToBigQueryOperator not respecting schema_obj (#28444)``
`bdf3175e96 <https://github.com/apache/airflow/commit/bdf3175e9616bad3d8b4d8c9f9bbce5530b2cffb>`__  2022-12-06   ``Improve memory usage in Dataproc deferrable operators (#28117)``
`3fef462838 <https://github.com/apache/airflow/commit/3fef46283857114aab46e72d4799c335e9e79f05>`__  2022-12-06   ``Fix GCSToGCSOperator copying list of objects without wildcard (#28111)``
`c8e348dcb0 <https://github.com/apache/airflow/commit/c8e348dcb0bae27e98d68545b59388c9f91fc382>`__  2022-12-05   ``Add automated version replacement in example dag indexes (#28090)``
`2d663df055 <https://github.com/apache/airflow/commit/2d663df0552542efcef6e59bc2bc1586f8d1c7f3>`__  2022-12-04   ``Fix: re-enable use of parameters in gcs_to_bq which had been disabled (#27961)``
`5cdff50557 <https://github.com/apache/airflow/commit/5cdff505574822ad3d2a226056246500e4adea2f>`__  2022-12-04   ``Add retry param in GCSObjectExistenceSensor (#27943)``
`8f98bfeb53 <https://github.com/apache/airflow/commit/8f98bfeb5372c7f61c77f081afb9b277c35b88ed>`__  2022-12-03   ``Add preserveAsciiControlCharacters to src_fmt_configs (#27679)``
`4a3a429658 <https://github.com/apache/airflow/commit/4a3a42965801823c39baaccfa96c5e4cffae4012>`__  2022-12-03   ``[misc] Get rid of 'pass' statement in conditions (#27775)``
`04cf66dcc5 <https://github.com/apache/airflow/commit/04cf66dcc5139fd083f7d07ad8053851d3e33dc3>`__  2022-12-03   ``Clarify that logging credentials differ from google_cloud_default (#28084)``
`6b3bb3c3e9 <https://github.com/apache/airflow/commit/6b3bb3c3e9f8a8d3ff33e5c2b09b0491a4bb6481>`__  2022-12-03   ``Change log level to DEBUG when secret not found for google secret manager (#27856)``
`527b948856 <https://github.com/apache/airflow/commit/527b948856584320f74d385f58477af79506834d>`__  2022-12-03   ``[misc] Replace XOR '^' conditions by 'exactly_one' helper in providers (#27858)``
`c931d88893 <https://github.com/apache/airflow/commit/c931d888936a958ae40b69077d35215227bf1dff>`__  2022-12-03   ``Add deferrable mode to CloudBuildCreateBuildOperator (#27783)``
==================================================================================================  ===========  =============================================================================================

8.6.0
.....

Latest change: 2022-11-26

==================================================================================================  ===========  ==================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==================================================================================
`25bdbc8e67 <https://github.com/apache/airflow/commit/25bdbc8e6768712bad6043618242eec9c6632618>`__  2022-11-26   ``Updated docs for RC3 wave of providers (#27937)``
`f0820e8d9e <https://github.com/apache/airflow/commit/f0820e8d9e8a36325987278bcda2bd69bd53f3a5>`__  2022-11-25   ``Add Export Format to Template Fields in BigQueryToGCSOperator (#27910)``
`2e20e9f7eb <https://github.com/apache/airflow/commit/2e20e9f7ebf5f43bf27069f4c0063cdd72e6b2e2>`__  2022-11-24   ``Prepare for follow-up relase for November providers (#27774)``
`80c327bd3b <https://github.com/apache/airflow/commit/80c327bd3b45807ff2e38d532325bccd6fe0ede0>`__  2022-11-24   ``Bump common.sql provider to 1.3.1 (#27888)``
`bc0063af99 <https://github.com/apache/airflow/commit/bc0063af99629e6b3eb5c76c88ac5bfaf92afaaf>`__  2022-11-16   ``Fix to read location parameter properly in BigQueryToBigQueryOperator (#27661)``
`0cb6450d6d <https://github.com/apache/airflow/commit/0cb6450d6df853e1061dbcafbc437c07a8e0e555>`__  2022-11-16   ``Persist DataprocLink for workflow operators regardless of job status (#26986)``
`ddbc758540 <https://github.com/apache/airflow/commit/ddbc75854019cf6b1e6e5e866eff2796c4f36eff>`__  2022-11-16   ``Deferrable mode for BigQueryToGCSOperator (#27683)``
`911d90d669 <https://github.com/apache/airflow/commit/911d90d669ab5d1fe1f5edb1d2353c7214611630>`__  2022-11-16   ``Migrate Dataflow system tests (#27375)``
==================================================================================================  ===========  ==================================================================================

8.5.0
.....

Latest change: 2022-11-15

==================================================================================================  ===========  ==========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==========================================================================================================
`12c3c39d1a <https://github.com/apache/airflow/commit/12c3c39d1a816c99c626fe4c650e88cf7b1cc1bc>`__  2022-11-15   ``pRepare docs for November 2022 wave of Providers (#27613)``
`00af5c007e <https://github.com/apache/airflow/commit/00af5c007ef2200401b53c40236e664758e47f27>`__  2022-11-14   ``Replace urlparse with urlsplit (#27389)``
`1059de6294 <https://github.com/apache/airflow/commit/1059de6294cf89a085c02036d117000bd98435dc>`__  2022-11-11   ``Dataform operators, links, update system tests and docs (#27144)``
`3aed495f50 <https://github.com/apache/airflow/commit/3aed495f50e8bc0e22ff90efee7671a73168b19e>`__  2022-11-11   ``Rename  hook bigquery function '_bq_cast' to 'bq_cast' (#27543)``
`e8ab8ccc0e <https://github.com/apache/airflow/commit/e8ab8ccc0e7b82efc0dbf8bd31e0bbf57b1d5637>`__  2022-11-11   ``Add backward compatibility with old versions of Apache Beam (#27263)``
`59e3198f7e <https://github.com/apache/airflow/commit/59e3198f7e5f3f4d6999d930fa505e6bd307f325>`__  2022-11-10   ``Change dataprep system tests assets (#26488)``
`98a9c574e3 <https://github.com/apache/airflow/commit/98a9c574e3e30b3aea710c23e18955e88871c9e6>`__  2022-11-08   ``set project_id and location when canceling BigQuery job (#27521)``
`a691ab56a6 <https://github.com/apache/airflow/commit/a691ab56a6544dfab8b3facbceeeee0993beb7c0>`__  2022-11-08   ``Add new Compute Engine Operators and fix system tests (#25608)``
`199359bb38 <https://github.com/apache/airflow/commit/199359bb3886699904ca075de7bd5fdfe5105c5f>`__  2022-11-07   ``Use non-deprecated method for on_kill in BigQueryHook (#27547)``
`7297892558 <https://github.com/apache/airflow/commit/7297892558e94c8cc869b175e904ca96e0752afe>`__  2022-11-07   ``Remove unnecessary newlines around single arg in signature (#27525)``
`5cd78cf425 <https://github.com/apache/airflow/commit/5cd78cf425f6fedc380662ec9a9e37be51403ccb>`__  2022-11-06   ``Upgrade dependencies in order to avoid backtracking (#27531)``
`332c01d6e0 <https://github.com/apache/airflow/commit/332c01d6e0bef41740e8fbc2c9600e7b3066615b>`__  2022-10-31   ``Allow values in WorkflowsCreateExecutionOperator execution argument to be dicts (#27361)``
`50d217a129 <https://github.com/apache/airflow/commit/50d217a1290f891be5d6be743b00b552fc10da20>`__  2022-10-31   ``DataflowStopJobOperator Operator (#27033)``
`eb8c0cf0d2 <https://github.com/apache/airflow/commit/eb8c0cf0d2c657824f666e874ec4e21940931ea4>`__  2022-10-31   ``Migration of System Tests: Cloud Composer (AIP-47)  (#27227)``
`528ecbbc00 <https://github.com/apache/airflow/commit/528ecbbc005566e13f7a6a1cafb4962733c6efb0>`__  2022-10-31   ``Rewrite system tests for ML Engine service (#26915)``
`bcb026bf7c <https://github.com/apache/airflow/commit/bcb026bf7c8031ff64c8b6019d248b12d6aa71e0>`__  2022-10-31   ``use the proper key to retrieve the dataflow job_id (#27336)``
`42841f70d5 <https://github.com/apache/airflow/commit/42841f70d5d385bb19d28a48db93b004b3b34098>`__  2022-10-31   ``Migration of System Tests: Cloud BigQuery Data Transfer (AIP-47) (#27312)``
`1447158e69 <https://github.com/apache/airflow/commit/1447158e690f3d63981b3d8ec065665ec91ca54e>`__  2022-10-31   ``Typecast biquery job response col value (#27236)``
`95e5675714 <https://github.com/apache/airflow/commit/95e5675714f12c177e30d83a14d28222b06d217b>`__  2022-10-31   ``Migration of System Tests: Dataplex (AIP-47) (#26989)``
`124fb3948d <https://github.com/apache/airflow/commit/124fb3948d18c4fe4b2aad12eecfd5ba1efca4bc>`__  2022-10-31   ``Add deferrable mode to GCPToBigQueryOperator + tests (#27052)``
`7a7c5f8fc4 <https://github.com/apache/airflow/commit/7a7c5f8fc4284adfedcb0667ec7c935b913660cf>`__  2022-10-31   ``Add system tests for Vertex AI operators in new approach (#27053)``
`4e55d7fa2b <https://github.com/apache/airflow/commit/4e55d7fa2b7d5f8d63465d2c5270edf2d85f08c6>`__  2022-10-31   ``Migration of System Tests: Cloud Vision Operators (AIP-47) (#26963)``
`896479d1a0 <https://github.com/apache/airflow/commit/896479d1a0624f10a5a9c462071b9c61502cda87>`__  2022-10-31   ``Google Drive to local - system tests migrations (AIP-47) (#26798)``
`3d5f34cb0f <https://github.com/apache/airflow/commit/3d5f34cb0f294d21dd1ba244af0fa06873377f11>`__  2022-10-28   ``Allow and prefer non-prefixed extra fields for dataprep hook (#27039)``
`04f674c13b <https://github.com/apache/airflow/commit/04f674c13bca9af78b65a643240da53aa556e2e1>`__  2022-10-27   ``Migrate Bigtable operators system tests according to AIP-47 (#26911)``
`58d61826a3 <https://github.com/apache/airflow/commit/58d61826a3f47a071c1f0ed4d5b8a5bd01131acb>`__  2022-10-27   ``Migrate Dataproc Metastore system tests according to AIP-47 (#26858)``
`9ab1a6a3e7 <https://github.com/apache/airflow/commit/9ab1a6a3e70b32a3cddddf0adede5d2f3f7e29ea>`__  2022-10-27   ``Update old style typing (#26872)``
`87eb46bbc6 <https://github.com/apache/airflow/commit/87eb46bbc69c20148773d72e990fbd5d20076342>`__  2022-10-26   ``Common sql bugfixes and improvements (#26761)``
`7653c61df8 <https://github.com/apache/airflow/commit/7653c61df894e6c845dde558f5b27f7995415428>`__  2022-10-26   ``Make GSheetsHook return an empty list when there are no values (#27261)``
`78b8ea2f22 <https://github.com/apache/airflow/commit/78b8ea2f22239db3ef9976301234a66e50b47a94>`__  2022-10-24   ``Move min airflow version to 2.3.0 for all providers (#27196)``
`2a34dc9e84 <https://github.com/apache/airflow/commit/2a34dc9e8470285b0ed2db71109ef4265e29688b>`__  2022-10-23   ``Enable string normalization in python formatting - providers (#27205)``
`58378cfd42 <https://github.com/apache/airflow/commit/58378cfd42b137a31032404783b2957284a1e538>`__  2022-10-23   ``Cloud ML Engine operators assets (AIP-47) (#26836)``
`de9633f93a <https://github.com/apache/airflow/commit/de9633f93a366ebc0a46d1ec4df2c4aa9a18357d>`__  2022-10-22   ``Update google hooks to prefer non-prefixed extra fields (#27023)``
`b54a2de8c7 <https://github.com/apache/airflow/commit/b54a2de8c74feb1ea215a98ffaddc5c46713c5cb>`__  2022-10-09   ``Local filesystem to Google Drive Operator - system tests migration (AIP-47) (#26797)``
`b4cef6da21 <https://github.com/apache/airflow/commit/b4cef6da219815b0d5517b4c82fa79bf5274d67a>`__  2022-10-09   ``SFTP to Google Cloud Storage Transfer system tests migration (AIP-47) (#26799)``
`6f0b600293 <https://github.com/apache/airflow/commit/6f0b600293ad53c1c4e3036b0572ca29b98b2fb2>`__  2022-10-09   ``Fix delay in Dataproc CreateBatch operator (#26126)``
`2f326a6c03 <https://github.com/apache/airflow/commit/2f326a6c03efed8788fe0263df96b68abb801088>`__  2022-10-06   ``Remove <2 limit on google-cloud-storage (#26922)``
`a67bcf3eca <https://github.com/apache/airflow/commit/a67bcf3ecaabdff80c551cff1f987523211e7af4>`__  2022-10-06   ``Allow for the overriding of stringify_dict for json/jsonb column data type in Postgres #26875 (#26876)``
==================================================================================================  ===========  ==========================================================================================================

8.4.0
.....

Latest change: 2022-10-04

==================================================================================================  ===========  ========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ========================================================================================================
`403ed7163f <https://github.com/apache/airflow/commit/403ed7163f3431deb7fc21108e1743385e139907>`__  2022-10-04   ``Add docs for Google/Slack RC providers (#26860)``
`fa0cb363b8 <https://github.com/apache/airflow/commit/fa0cb363b860b553af2ef9530ea2de706bd16e5d>`__  2022-10-01   ``Correcting the transfer config name. (#25719)``
`cee610ae5c <https://github.com/apache/airflow/commit/cee610ae5cf14c117527cdfc9ac2ef0ddb5dcf3b>`__  2022-10-01   ``Fix parsing of optional 'mode' field in BigQuery Result Schema (#26786)``
`b7203cd36e <https://github.com/apache/airflow/commit/b7203cd36eef20de583df3e708f49073d689ac84>`__  2022-10-01   ``Fix MaxID logic for GCSToBigQueryOperator (#26768)``
`f8db64c35c <https://github.com/apache/airflow/commit/f8db64c35c8589840591021a48901577cff39c07>`__  2022-09-28   ``Update docs for September Provider's release (#26731)``
`dce27557eb <https://github.com/apache/airflow/commit/dce27557eb57a4f5748617ba584f9204ac09b10b>`__  2022-09-28   ``Fix GCS sensor system tests failing with DebugExecutor (#26742)``
`26f94c5370 <https://github.com/apache/airflow/commit/26f94c5370587f73ebd935cecf208c6a36bdf9b6>`__  2022-09-26   ``Cloud Data Loss Prevention Operators assets (#26618)``
`01ac40af75 <https://github.com/apache/airflow/commit/01ac40af759c920f4b2d159bcf18001fdaa24ea4>`__  2022-09-22   ``Update gcs.py (#26570)``
`e61d823f18 <https://github.com/apache/airflow/commit/e61d823f18238a82570203b62fe986bd0bc91b51>`__  2022-09-21   ``Cloud Storage Transfer Operators assets & system tests migration (AIP-47) (#26072)``
`a60e3b9317 <https://github.com/apache/airflow/commit/a60e3b9317b2a86e0de44497bfe52fe3b2375c3e>`__  2022-09-21   ``Migrate Data Loss Prevention system tests according to AIP-47 (#26060)``
`c4256ca1a0 <https://github.com/apache/airflow/commit/c4256ca1a029240299b83841bdd034385665cdda>`__  2022-09-21   ``Add BigQuery Column and Table Check Operators (#26368)``
`4c33f6bcf5 <https://github.com/apache/airflow/commit/4c33f6bcf527448283a738ef11478b75ba339422>`__  2022-09-20   ``Merge deferrable BigQuery operators to exisitng one (#26433)``
`8e98b1c6df <https://github.com/apache/airflow/commit/8e98b1c6df067f41226b7f5e4c091955deb83490>`__  2022-09-20   ``Google Drive to Google Cloud Storage Transfer Operator - system tests migration (AIP-47) (#26487)``
`e315900396 <https://github.com/apache/airflow/commit/e31590039634ff722ad005fe9f1fc02e5a669699>`__  2022-09-20   ``specifying project id when calling wait_for_operation in delete/create cluster (#26418)``
`6045f7ad69 <https://github.com/apache/airflow/commit/6045f7ad697e2bdb934add1a8aeae5a817306b22>`__  2022-09-19   ``Cloud Functions Operators assets & system tests migration (AIP-47) (#26073)``
`1f7b296227 <https://github.com/apache/airflow/commit/1f7b296227fee772de9ba15af6ce107937ef9b9b>`__  2022-09-18   ``Auto tail file logs in Web UI (#26169)``
`07fe356de0 <https://github.com/apache/airflow/commit/07fe356de0743ca64d936738b78704f7c05774d1>`__  2022-09-18   ``GCSToBigQueryOperator Resolve 'max_id_key' job retrieval and xcom return (#26285)``
`b4f8a069f0 <https://github.com/apache/airflow/commit/b4f8a069f07b18ce98c9b1286da5a5fcde2bff9f>`__  2022-09-18   ``Allow for the overriding of 'stringify_dict' for json export format on BaseSQLToGCSOperator (#26277)``
`706a618014 <https://github.com/apache/airflow/commit/706a618014a6f94d5ead0476f26f79d9714bf93d>`__  2022-09-18   ``Append GoogleLink base in the link class (#26057)``
`97b144fbed <https://github.com/apache/airflow/commit/97b144fbede1cfecda9e2519eef8183af444e738>`__  2022-09-18   ``Fix JSONDecodeError in Datafusion operators (#26202)``
`9444d9789b <https://github.com/apache/airflow/commit/9444d9789bc88e1063d81d28e219446b2251c0e1>`__  2022-09-14   ``Work around pyupgrade edge cases (#26384)``
`d67ac5932d <https://github.com/apache/airflow/commit/d67ac5932dabbf06ae733fc57b48491a8029b8c2>`__  2022-09-14   ``Apply PEP-563 (Postponed Evaluation of Annotations) to core airflow (#26290)``
`06acf40a43 <https://github.com/apache/airflow/commit/06acf40a4337759797f666d5bb27a5a393b74fed>`__  2022-09-13   ``Apply PEP-563 (Postponed Evaluation of Annotations) to non-core airflow (#26289)``
`23ad7e292a <https://github.com/apache/airflow/commit/23ad7e292a29e43436170078ae132569f8fbf1e4>`__  2022-09-10   ``Cloud Video Intelligence Operators assets & system tests migration (AIP-47) (#26132)``
`3a539ff663 <https://github.com/apache/airflow/commit/3a539ff6631109dc58514339ac60672f031c7054>`__  2022-09-09   ``Life Science assets & system tests migration (AIP-47) (#25548)``
`5066844513 <https://github.com/apache/airflow/commit/50668445137e4037bb4a3b652bec22e53d1eddd7>`__  2022-09-09   ``D400 first line should end with period batch02 (#25268)``
`f938cd4fc8 <https://github.com/apache/airflow/commit/f938cd4fc867513e729aa9a005d663c9713f74e6>`__  2022-09-08   ``Add deferrable big query operators and sensors (#26156)``
`8cac96918b <https://github.com/apache/airflow/commit/8cac96918becf19a4a04eef1e5bcf175f815f204>`__  2022-09-07   ``GCSToBigQueryOperator allow for schema_object in alternate GCS Bucket (#26190)``
`12cbc0f1dd <https://github.com/apache/airflow/commit/12cbc0f1ddd9e8a66c5debe7f97b55a2c8001502>`__  2022-09-07   ``Don't throw an exception when a BQ cusor job has no schema (#26096)``
`8acdc2a834 <https://github.com/apache/airflow/commit/8acdc2a834b9c4e287fe612ed56ab8908d777609>`__  2022-08-30   ``Replace SQL with Common SQL in pre commit (#26058)``
`1d06374194 <https://github.com/apache/airflow/commit/1d06374194586d6dd857e95c866925e9034d9a48>`__  2022-08-30   ``Hook into Mypy to get rid of those cast() (#26023)``
`da8f133053 <https://github.com/apache/airflow/commit/da8f133053f7483cfe45109142943a7ded1ed1a2>`__  2022-08-29   ``Use AsyncClient for Composer Operators in deferrable mode (#25951)``
`1ed014647e <https://github.com/apache/airflow/commit/1ed014647e7293d342d9d1c2706343a68f003655>`__  2022-08-29   ``Add 'output' property to MappedOperator (#25604)``
`d4eb60712d <https://github.com/apache/airflow/commit/d4eb60712dc7bb34960ae10b9e6dd8624a554dfc>`__  2022-08-27   ``Use project_id to get authenticated client (#25984)``
`4c3fb1ff2b <https://github.com/apache/airflow/commit/4c3fb1ff2b789320cc2f19bd921ac0335fc8fdf1>`__  2022-08-27   ``Google Cloud Tasks Sensor for queue being empty (#25622)``
`c81178063a <https://github.com/apache/airflow/commit/c81178063aad41925be4de4eb3ee89e3d3e31fa0>`__  2022-08-27   ``Cloud Build assets & system tests migration (AIP-47) (#25895)``
`62a46c1e18 <https://github.com/apache/airflow/commit/62a46c1e1812422966b5af33cd4b42e24fe0edc5>`__  2022-08-27   ``Added append_job_name parameter to DataflowTemplatedJobStartOperator (#25746)``
`15b49add28 <https://github.com/apache/airflow/commit/15b49add282e88b02711a2d3afec614fd31f12c5>`__  2022-08-23   ``Sql to GSC operators update docs for parquet format (#25878)``
`25a9ae3b2e <https://github.com/apache/airflow/commit/25a9ae3b2eec85dfd500b0a921045fc95ab8ffd6>`__  2022-08-23   ``Limit Google Protobuf for compatibility with biggtable client (#25886)``
`ecf0460b7d <https://github.com/apache/airflow/commit/ecf0460b7d9c9e9b6462c3dfa92cdf4e373dbfd5>`__  2022-08-22   ``Dataproc submit job operator async (#25302)``
`bbb6b7c54b <https://github.com/apache/airflow/commit/bbb6b7c54b6a166366d8cff4db16d430c8f9b2a5>`__  2022-08-21   ``Fix broken link for google cloud (#25642)``
`fc6dfa338a <https://github.com/apache/airflow/commit/fc6dfa338a76d02a426e2b7f0325d37ea5e95ac3>`__  2022-08-20   ``Support project_id argument in BigQueryGetDataOperator (#25782)``
`6e66dd7776 <https://github.com/apache/airflow/commit/6e66dd7776707936345927f8fccee3ddb7f23a2b>`__  2022-08-19   ``Make GoogleBaseHook credentials functions public (#25785)``
`6e41c7eb33 <https://github.com/apache/airflow/commit/6e41c7eb33a68ea3ccd6b67fb169ea2cf1ecc162>`__  2022-08-16   ``Fixed never ending loop to in CreateWorkflowInvocation (#25737)``
`6c5b0776c0 <https://github.com/apache/airflow/commit/6c5b0776c07c6317e6e2eea67964a07cdadf2394>`__  2022-08-14   ``Adding a parameter for exclusion of trashed files in GoogleDriveHook (#25675)``
`1b412c9cbe <https://github.com/apache/airflow/commit/1b412c9cbe48235cf02bb57a94c0d47d3f86df20>`__  2022-08-10   ``Consolidate to one 'schedule' param (#25410)``
==================================================================================================  ===========  ========================================================================================================

8.3.0
.....

Latest change: 2022-08-10

==================================================================================================  ===========  ==================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==================================================================================
`e5ac6c7cfb <https://github.com/apache/airflow/commit/e5ac6c7cfb189c33e3b247f7d5aec59fe5e89a00>`__  2022-08-10   ``Prepare docs for new providers release (August 2022) (#25618)``
`2e2d4bffd5 <https://github.com/apache/airflow/commit/2e2d4bffd53a94fda04e7d88843545f7070b6f32>`__  2022-08-09   ``Dataform operators (#25587)``
`c8c4a42723 <https://github.com/apache/airflow/commit/c8c4a4272354d090ebf01a5cf7a9f49026e65511>`__  2022-08-08   ``Fix GCSListObjectsOperator docstring (#25614)``
`029e3ae96f <https://github.com/apache/airflow/commit/029e3ae96f50074e9b524f0b820573741432f44a>`__  2022-08-05   ``Remove deprecated modules (#25543)``
`7d2c2ee879 <https://github.com/apache/airflow/commit/7d2c2ee879656faf47829d1ad89fc4441e19a66e>`__  2022-08-04   ``add description method in BigQueryCursor class (#25366)``
`e84d753015 <https://github.com/apache/airflow/commit/e84d753015e5606c29537741cdbe8ae08012c3b6>`__  2022-08-04   ``Fix BigQueryInsertJobOperator cancel_on_kill (#25342)``
`803c0e252f <https://github.com/apache/airflow/commit/803c0e252fc78a424a181a34a93e689fa9aaaa09>`__  2022-08-03   ``Fix BaseSQLToGCSOperator approx_max_file_size_bytes (#25469)``
`faf3c4fe47 <https://github.com/apache/airflow/commit/faf3c4fe474733965ab301465f695e3cc311169c>`__  2022-08-02   ``Fix PostgresToGCSOperat bool dtype (#25475)``
`c8cacad4d6 <https://github.com/apache/airflow/commit/c8cacad4d63361b52b5790b4a75c8f928f1eca83>`__  2022-08-02   ``Migrate Google example trino_to_gcs to new design AIP-47 (#25420)``
`d2900022a2 <https://github.com/apache/airflow/commit/d2900022a27373b09a3a2a68f8bbc26fbba4a64e>`__  2022-08-02   ``Migrate Google example automl_nl_text_extraction to new design AIP-47 (#25418)``
`acab8f52dd <https://github.com/apache/airflow/commit/acab8f52dd8d90fd6583779127895dd343780f79>`__  2022-07-29   ``Move all "old" SQL operators to common.sql providers (#25350)``
`f6b48ac6df <https://github.com/apache/airflow/commit/f6b48ac6dfaf931a5433ec16369302f68f038c65>`__  2022-07-28   ``Memorystore assets & system tests migration (AIP-47) (#25361)``
`f4b93cc097 <https://github.com/apache/airflow/commit/f4b93cc097dab95437c9c4b37474f792f80fd14e>`__  2022-07-28   ``Translate system tests migration (AIP-47) (#25340)``
`a8e4519815 <https://github.com/apache/airflow/commit/a8e451981572fa09a96660992e68e046c4baa75f>`__  2022-07-28   ``Fix Vertex AI Custom Job training issue (#25367)``
`5d4abbd58c <https://github.com/apache/airflow/commit/5d4abbd58c33e7dfa8505e307d43420459d3df55>`__  2022-07-27   ``Deprecate hql parameters and synchronize DBApiHook method APIs (#25299)``
`8bc147192c <https://github.com/apache/airflow/commit/8bc147192c8e7174f9e0c9b55b2f5461f7227bcf>`__  2022-07-27   ``Fix Flask Login user setting for Flask 2.2 and Flask-Login 0.6.2 (#25318)``
`28db8c10b2 <https://github.com/apache/airflow/commit/28db8c10b2422d99217658a039cc6dc45a38ff51>`__  2022-07-26   ``Migrate Google example life_sciences to new design AIP-47 (#25264)``
`10c9a3697a <https://github.com/apache/airflow/commit/10c9a3697a52ba54996df42740d1e929b3a78d43>`__  2022-07-26   ``Migrate Google example natural_language to new design AIP-47 (#25262)``
`b288bf4da4 <https://github.com/apache/airflow/commit/b288bf4da44301d91ae62131976eb2925decd0aa>`__  2022-07-26   ``Delete redundant system test bigquery_to_bigquery (#25261)``
`c8af0592c0 <https://github.com/apache/airflow/commit/c8af0592c08017ee48f69f608ad4a6529ee14292>`__  2022-07-26   ``Improve taskflow type hints with ParamSpec (#25173)``
`df00436569 <https://github.com/apache/airflow/commit/df00436569bb6fb79ce8c0b7ca71dddf02b854ef>`__  2022-07-22   ``Unify DbApiHook.run() method with the methods which override it (#23971)``
`66b3ca1d28 <https://github.com/apache/airflow/commit/66b3ca1d2837610e01cf1d2314fadcc4be0a111c>`__  2022-07-21   ``Migrate Google example bigquery_to_mssql to new design AIP-47 (#25174)``
`9644451676 <https://github.com/apache/airflow/commit/96444516761a3be34616b773d5108795ea514fdb>`__  2022-07-19   ``Migrate Google example compute_igm to new design AIP-47 (#25132)``
`3a80b36ed9 <https://github.com/apache/airflow/commit/3a80b36ed98be62dd42ede0f4afab0f16a8306be>`__  2022-07-19   ``Migrate Google example automl_vision to new design AIP-47 (#25152)``
`c0ce8a8375 <https://github.com/apache/airflow/commit/c0ce8a83757043110025b57d7fdc3825454d54d2>`__  2022-07-18   ``Migrate Google example gcs_to_sftp to new design AIP-47 (#25107)``
`e32e9c5880 <https://github.com/apache/airflow/commit/e32e9c58802fe9363cc87ea283a59218df7cec3a>`__  2022-07-18   ``Bump typing-extensions and mypy for ParamSpec (#25088)``
`4473b27d08 <https://github.com/apache/airflow/commit/4473b27d089ff28d3d73af7c4a8bc6e011134b50>`__  2022-07-16   ``Migrate Google campaign manager example to new design AIP-47 (#25069)``
`9b7e4a7324 <https://github.com/apache/airflow/commit/9b7e4a732496e60ef1c275c1ac17c7ed05b27b54>`__  2022-07-16   ``Migrate Google analytics example to new design AIP-47 (#25006)``
`77626b7fc8 <https://github.com/apache/airflow/commit/77626b7fc8ad57e71b3e93f81429424bdfa002a3>`__  2022-07-13   ``Add project_id as a templated variable in two BQ operators (#24768)``
==================================================================================================  ===========  ==================================================================================

8.2.0
.....

Latest change: 2022-07-13

==================================================================================================  ===========  ====================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================
`d2459a241b <https://github.com/apache/airflow/commit/d2459a241b54d596ebdb9d81637400279fff4f2d>`__  2022-07-13   ``Add documentation for July 2022 Provider's release (#25030)``
`93992f2361 <https://github.com/apache/airflow/commit/93992f2361a24bad61fc71a6078fa553cd66b302>`__  2022-07-12   ``PubSub assets & system tests migration (AIP-47) (#24867)``
`a13c51e224 <https://github.com/apache/airflow/commit/a13c51e224e6299387d8b704e12cb7b4c8f61718>`__  2022-07-12   ``Migrate Google sheets example to new design AIP-47 (#24975)``
`a038b52b5a <https://github.com/apache/airflow/commit/a038b52b5a3bd4a0c97edf9f95da25b2316d305e>`__  2022-07-12   ``Migrate Google ads example to new design AIP-47 (#24941)``
`c618da444e <https://github.com/apache/airflow/commit/c618da444e841afcfd73eeb0bce9c87648c89140>`__  2022-07-12   ``Modify BigQueryCreateExternalTableOperator to use updated hook function (#24363)``
`626d9db290 <https://github.com/apache/airflow/commit/626d9db2908563c4b7675db5de2cb1e3acde82e9>`__  2022-07-12   ``Migrate Google example gcs_to_gdrive to new design AIP-47 (#24949)``
`fb51e04cfd <https://github.com/apache/airflow/commit/fb51e04cfdbe1a5f80eb51d9ffc3db4bb57a7c34>`__  2022-07-12   ``Migrate Google firestore example to new design AIP-47 (#24830)``
`b777514253 <https://github.com/apache/airflow/commit/b7775142530d053527b0f21f48e04b95ca8861ab>`__  2022-07-12   ``Add handling state of existing Dataproc batch (#24924)``
`acaa0635c8 <https://github.com/apache/airflow/commit/acaa0635c8477c98ab78da9f6d86e6f1bad2737d>`__  2022-07-08   ``Automatically detect if non-lazy logging interpolation is used (#24910)``
`fb7162418e <https://github.com/apache/airflow/commit/fb7162418eeacac626467871a7ed5567f20840ac>`__  2022-07-07   ``Add links for Google Kubernetes Engine operators (#24786)``
`46bbfdade0 <https://github.com/apache/airflow/commit/46bbfdade0638cb8a5d187e47034b84e68ddf762>`__  2022-07-07   ``Move all SQL classes to common-sql provider (#24836)``
`80b6754746 <https://github.com/apache/airflow/commit/80b6754746dc0dbb680c181f6292225f4d4a080d>`__  2022-07-06   ``Migrate Google example sql_to_sheets to new design AIP-47 (#24814)``
`3b35325840 <https://github.com/apache/airflow/commit/3b35325840e484f86df00e087410f5d5da4b9130>`__  2022-07-06   ``Add test_connection method to 'GoogleBaseHook' (#24682)``
`6476afda20 <https://github.com/apache/airflow/commit/6476afda208eb6aabd58cc00db8328451c684200>`__  2022-07-06   ``Fix docs build errors for Sphinx 5 (#24870)``
`96b01a8012 <https://github.com/apache/airflow/commit/96b01a8012d164df7c24c460149d3b79ecad3901>`__  2022-07-05   ``Remove "bad characters" from our codebase (#24841)``
`9227d56e68 <https://github.com/apache/airflow/commit/9227d56e681a40e9caf2eefae87f7046c0d0c9f4>`__  2022-07-04   ``Datacatalog assets & system tests migration (AIP-47) (#24600)``
`fe13eae3bf <https://github.com/apache/airflow/commit/fe13eae3bf0542025e622e51a487f8d6a8b6d2c5>`__  2022-07-04   ``perf(BigQuery): pass table_id as str type (#23141)``
`37ea530cb7 <https://github.com/apache/airflow/commit/37ea530cb786c994d5d02c9719ca4ae3ed8b44b2>`__  2022-07-04   ``Migrate Google example DAG mssql_to_gcs to new design AIP-47 (#24541)``
`46ac083f7e <https://github.com/apache/airflow/commit/46ac083f7e92cf8af046c8b5741e7c26ebffc05e>`__  2022-07-01   ``Align Black and blacken-docs configs (#24785)``
`0de31bd73a <https://github.com/apache/airflow/commit/0de31bd73a8f41dded2907f0dee59dfa6c1ed7a1>`__  2022-06-29   ``Move provider dependencies to inside provider folders (#24672)``
`45b11d4ed1 <https://github.com/apache/airflow/commit/45b11d4ed1412c00ebf32a03ab5ea3a06274f208>`__  2022-06-29   ``Use our yaml util in all providers (#24720)``
`510a6bab45 <https://github.com/apache/airflow/commit/510a6bab4595cce8bd5b1447db957309d70f35d9>`__  2022-06-28   ``Remove 'hook-class-names' from provider.yaml (#24702)``
`7a7ca50160 <https://github.com/apache/airflow/commit/7a7ca5016019f93ebee052a2bf99772145b7fc03>`__  2022-06-28   ``Migrate Google example DAG s3_to_gcs to new design AIP-47 (#24641)``
`abb304c92f <https://github.com/apache/airflow/commit/abb304c92f63261e55c5dca1a7be9aa5ac18ec85>`__  2022-06-25   ``Migrate Google example DAG bigquery_transfer to new design AIP-47 (#24543)``
`ded22eb5b6 <https://github.com/apache/airflow/commit/ded22eb5b65bbc789c3f1842402e343070b96f19>`__  2022-06-24   ``Add gcp_conn_id argument to GoogleDriveToLocalOperator (#24622)``
`e2f19505bf <https://github.com/apache/airflow/commit/e2f19505bf3622935480e80bee55bf5b6d80097b>`__  2022-06-22   ``Upgrade FAB to 4.1.1 (#24399)``
`9c59831ee7 <https://github.com/apache/airflow/commit/9c59831ee78f14de96421c74986933c494407afa>`__  2022-06-21   ``Update providers to use functools compat for ''cached_property'' (#24582)``
`88ddf65708 <https://github.com/apache/airflow/commit/88ddf65708ce65bc166e7e0d0bd21c3896dc3053>`__  2022-06-20   ``Migrate Google example DAG oracle_to_gcs to new design AIP-47 (#24542)``
`32fc4be502 <https://github.com/apache/airflow/commit/32fc4be502b3d1b60681e38b7b6947445987ec19>`__  2022-06-20   ``Migrate Google example DAG mysql_to_gcs to new design AIP-47 (#24540)``
`a35f342833 <https://github.com/apache/airflow/commit/a35f3428333f9ee793fac9998d76784044e3d85c>`__  2022-06-20   ``Migrate Google search_ads DAG to new design AIP-47 (#24298)``
`e7a1c50d62 <https://github.com/apache/airflow/commit/e7a1c50d62680a521ef90a424b7eff03635081d5>`__  2022-06-20   ``GCSDeleteObjectsOperator empty prefix bug fix (#24353)``
`dd35fdaf35 <https://github.com/apache/airflow/commit/dd35fdaf35b6e46fd69a1b1da36ae7ffc0505dcb>`__  2022-06-20   ``Migrate Google gcs_to_sheets DAG to new design AIP-47 (#24501)``
`0561c1aac4 <https://github.com/apache/airflow/commit/0561c1aac4d0ba6ddebfe086243e2d148a394214>`__  2022-06-19   ``Add DeprecationWarning for column_transformations parameter in AutoML (#24467)``
==================================================================================================  ===========  ====================================================================================

8.1.0
.....

Latest change: 2022-06-15

==================================================================================================  ===========  ============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ============================================================================================
`952a5ea8d8 <https://github.com/apache/airflow/commit/952a5ea8d87bd1a53228e8645538a2d0c545e0d2>`__  2022-06-15   ``Update release docs for Google and Oracle providers (#24461)``
`ce50d3731a <https://github.com/apache/airflow/commit/ce50d3731a049047d31d09c6d38a470b84cf57e7>`__  2022-06-15   ``Use insert_job in the BigQueryToGCPOpertor and adjust links (#24416)``
`2a084ee8d7 <https://github.com/apache/airflow/commit/2a084ee8d7fb27cbc3ad28f4845c5d20c82f0cbe>`__  2022-06-14   ``Update Oracle library to latest version (#24311)``
`69c46252dd <https://github.com/apache/airflow/commit/69c46252dd222fbcbfdd035ce6de1868b719023f>`__  2022-06-14   ``fix typo in google provider additional extras (#24431)``
`08b675cf66 <https://github.com/apache/airflow/commit/08b675cf6642171cb1c5ddfb09607b541db70b29>`__  2022-06-13   ``Fix links to sources for examples (#24386)``
`94257f48f4 <https://github.com/apache/airflow/commit/94257f48f4a3f123918b0d55c34753c7c413eb74>`__  2022-06-13   ``Expose SQL to GCS Metadata (#24382)``
`8e0bddaea6 <https://github.com/apache/airflow/commit/8e0bddaea69db4d175f03fa99951f6d82acee84d>`__  2022-06-12   ``Deprecate remaining occurrences of 'bigquery_conn_id' in favor of 'gcp_conn_id' (#24376)``
`6eb60f816c <https://github.com/apache/airflow/commit/6eb60f816cb6103d42c023ce5fba9ac31a64f9ce>`__  2022-06-12   ``Migrate Google calendar example DAG to new design AIP-47 (#24333)``
`bc3fc8c9fc <https://github.com/apache/airflow/commit/bc3fc8c9fcb5d1291797aa5f4fc8da954573c694>`__  2022-06-12   ``Migrate Google azure_fileshare example DAG to new design AIP-47 (#24349)``
`6ab02b69a0 <https://github.com/apache/airflow/commit/6ab02b69a0bbc398e9e41c70d78487d3255b0585>`__  2022-06-12   ``Remove bigquery example already migrated to AIP-47 (#24379)``
`cb90ca7afb <https://github.com/apache/airflow/commit/cb90ca7afbbca9911fc2104f331354b6d1a63758>`__  2022-06-12   ``Migrate Google sheets example DAG to new design AIP-47 (#24351)``
==================================================================================================  ===========  ============================================================================================

8.0.0
.....

Latest change: 2022-06-09

==================================================================================================  ===========  =======================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =======================================================================================================================
`dcdcf3a2b8 <https://github.com/apache/airflow/commit/dcdcf3a2b8054fa727efb4cd79d38d2c9c7e1bd5>`__  2022-06-09   ``Update release notes for RC2 release of Providers for May 2022 (#24307)``
`047a6162b0 <https://github.com/apache/airflow/commit/047a6162b0b4cbf07fe2fd978e335839a7d3900b>`__  2022-06-08   ``Workaround job race bug on biguery to gcs transfer (#24330)``
`717a7588bc <https://github.com/apache/airflow/commit/717a7588bc8170363fea5cb75f17efcf68689619>`__  2022-06-07   ``Update package description to remove double min-airflow specification (#24292)``
`b1ad017cee <https://github.com/apache/airflow/commit/b1ad017cee66f5e042144cc7baa2d44b23b47c4f>`__  2022-06-07   ``pydocstyle D202 added (#24221)``
`aeabe994b3 <https://github.com/apache/airflow/commit/aeabe994b3381d082f75678a159ddbb3cbf6f4d3>`__  2022-06-07   ``Prepare docs for May 2022 provider's release (#24231)``
`c3a9ef1ada <https://github.com/apache/airflow/commit/c3a9ef1adadc1e39536f60db46017870860fc633>`__  2022-06-07   ``AIP-47 - Migrate google leveldb DAGs to new design ##22447 (#24233)``
`c23826915d <https://github.com/apache/airflow/commit/c23826915dcdca4f22b52b74633336cb2f4a1eca>`__  2022-06-07   ``Apply per-run log templates to log handlers (#24153)``
`80c1ce76e1 <https://github.com/apache/airflow/commit/80c1ce76e19d363916f2253cdd536372f6a43aee>`__  2022-06-06   ``Cloud Storage assets & StorageLink update (#23865)``
`ec84ffe71c <https://github.com/apache/airflow/commit/ec84ffe71cfa8246155b9b4cb10bf2167e75adcf>`__  2022-06-06   ``Fix GCSToGCSOperator cannot copy a single file/folder without copying other files/folders with that prefix (#24039)``
`027b707d21 <https://github.com/apache/airflow/commit/027b707d215a9ff1151717439790effd44bab508>`__  2022-06-05   ``Add explanatory note for contributors about updating Changelog (#24229)``
`55fd02a389 <https://github.com/apache/airflow/commit/55fd02a38919526776cfe69d715873da75d6f26f>`__  2022-06-04   ``Add key_secret_project_id parameter which specifies a project with KeyFile (#23930)``
`90233bc7cb <https://github.com/apache/airflow/commit/90233bc7cbb95d7de6e4de3b7b1206eebf5ad28c>`__  2022-06-04   ``Added impersonation_chain for DataflowStartFlexTemplateOperator and DataflowStartSqlJobOperator (#24046)``
`c01a5a50b4 <https://github.com/apache/airflow/commit/c01a5a50b44bf2cd0d980123549e3c8d5cfe7521>`__  2022-06-04   ``Fix BigQuery system tests (#24013)``
`a597a76e8f <https://github.com/apache/airflow/commit/a597a76e8f893865e7380b072de612763639bfb9>`__  2022-06-03   ``fix BigQueryInsertJobOperator (#24165)``
`e13b15946e <https://github.com/apache/airflow/commit/e13b15946ee2db956040f81ca374cb4619d07cf1>`__  2022-06-03   ``Workflows assets & system tests migration (AIP-47) (#24105)``
`368f292ca1 <https://github.com/apache/airflow/commit/368f292ca12f13e1520ad77ab500123e13c82932>`__  2022-06-03   ``Update credentials when using ADC in Compute Engine (#23773)``
`96e8fb4a07 <https://github.com/apache/airflow/commit/96e8fb4a07d559946ad5889d1af2c80607f78cfc>`__  2022-06-01   ``Fix the link to google workplace (#24080)``
`3dd7b1ddba <https://github.com/apache/airflow/commit/3dd7b1ddbaa3170fbda30a8323286abf075f30ba>`__  2022-06-01   ``set color to operators in cloud_sql.py (#24000)``
`841ed27101 <https://github.com/apache/airflow/commit/841ed271017ff35a3124f1d1a53a5c74730fed60>`__  2022-06-01   ``Spanner assets & system tests migration (AIP-47) (#23957)``
`fedab9d64a <https://github.com/apache/airflow/commit/fedab9d64a58f1b5d3c88fe7a67f1f4021db8d26>`__  2022-06-01   ``Remove hack from BigQuery DTS hook (#23887)``
`e58985598f <https://github.com/apache/airflow/commit/e58985598f202395098e15b686aec33645a906ff>`__  2022-05-30   ``Ensure @contextmanager decorates generator func (#23103)``
`92ddcf4ac6 <https://github.com/apache/airflow/commit/92ddcf4ac6fa452c5056b1f7cad1fca4d5759802>`__  2022-05-27   ``Introduce 'flake8-implicit-str-concat' plugin to static checks (#23873)``
`ec6761a5c0 <https://github.com/apache/airflow/commit/ec6761a5c0d031221d53ce213c0e42813606c55d>`__  2022-05-23   ``Clean up f-strings in logging calls (#23597)``
`65f3b18fc1 <https://github.com/apache/airflow/commit/65f3b18fc1142c0d23e715fa1a98f21662df9584>`__  2022-05-22   ``Sql to gcs with exclude columns (#23695)``
`a43e98d050 <https://github.com/apache/airflow/commit/a43e98d05047d9c4d5a7778bcb10efc4bdef7a01>`__  2022-05-22   ``Fix DataprocJobBaseOperator not being compatible with dotted names (#23439). (#23791)``
`5bfacf81c6 <https://github.com/apache/airflow/commit/5bfacf81c63668ea63e7cb48f4a708a67d0ac0a2>`__  2022-05-20   ``[Issue#22846] allow option to encode or not encode UUID when uploading from Cassandra to GCS (#23766)``
`54aa234052 <https://github.com/apache/airflow/commit/54aa23405240b9db553bf639de85b2d86364420b>`__  2022-05-20   ``update CloudSqlInstanceImportOperator to CloudSQLImportInstanceOperator (#23800)``
`f60fa98a2e <https://github.com/apache/airflow/commit/f60fa98a2ef587f02f93dac95d4db39c825a87b1>`__  2022-05-19   ``Cloud SQL assets & system tests migration (AIP-47) (#23583)``
`d3b0880286 <https://github.com/apache/airflow/commit/d3b08802861b006fc902f895802f460a72d504b0>`__  2022-05-17   ``Speech To Text assets & system tests migration (AIP-47) (#23643)``
`3bf9a1df38 <https://github.com/apache/airflow/commit/3bf9a1df38b1ccfaf965a207d047b30452df1ba5>`__  2022-05-16   ``Add fields to CLOUD_SQL_EXPORT_VALIDATION. (#23724)``
`bc0dcddfb5 <https://github.com/apache/airflow/commit/bc0dcddfb5e286f0be445f6d09f190a1cbcb6093>`__  2022-05-12   ``Migrate Dataproc to new system tests design (#22777)``
==================================================================================================  ===========  =======================================================================================================================

7.0.0
.....

Latest change: 2022-05-12

==================================================================================================  ===========  ===================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===================================================================================================================================
`75c60923e0 <https://github.com/apache/airflow/commit/75c60923e01375ffc5f71c4f2f7968f489e2ca2f>`__  2022-05-12   ``Prepare provider documentation 2022.05.11 (#23631)``
`cd49a8b9f6 <https://github.com/apache/airflow/commit/cd49a8b9f64c57b5622025baee9247712c692e72>`__  2022-05-11   ``[FEATURE] google provider - BigQueryInsertJobOperator log query (#23648)``
`60a1d9d191 <https://github.com/apache/airflow/commit/60a1d9d191fb8fc01893024c897df9632ad5fbf4>`__  2022-05-10   ``[FEATURE] google provider - split GkeStartPodOperator execute (#23518)``
`74557e41e3 <https://github.com/apache/airflow/commit/74557e41e3dcedec241ea583123d53176994cccc>`__  2022-05-10   ``Add exportContext.offload flag to CLOUD_SQL_EXPORT_VALIDATION. (#23614)``
`428a439953 <https://github.com/apache/airflow/commit/428a43995390b3623a51aa7bac7e21da69a8db22>`__  2022-05-09   ``Clean up in-line f-string concatenation (#23591)``
`766726f2e3 <https://github.com/apache/airflow/commit/766726f2e3a282fcd2662f5dc6e9926dc38a6540>`__  2022-05-09   ``Fix 'PostgresToGCSOperator' does not allow nested JSON (#23063)``
`82c244f9c7 <https://github.com/apache/airflow/commit/82c244f9c7f24735ee952951bcb5add45422d186>`__  2022-05-08   ``Fix GCSToGCSOperator ignores replace parameter when there is no wildcard (#23340)``
`627b5698ec <https://github.com/apache/airflow/commit/627b5698ec6b1b62c75a57953bb7ee7a45c56f3c>`__  2022-05-04   ``Add Stackdriver assets and migrate system tests to AIP-47 (#23320)``
`3977e1798d <https://github.com/apache/airflow/commit/3977e1798d8294ba628b5f330f43702c1a5c79fc>`__  2022-05-04   ``CloudTasks assets & system tests migration (AIP-47) (#23282)``
`dfe0f75938 <https://github.com/apache/airflow/commit/dfe0f759381c13a2c81212368d3c0c43f57da660>`__  2022-05-04   ``TextToSpeech assets & system tests migration (AIP-47) (#23247)``
`2d109401b3 <https://github.com/apache/airflow/commit/2d109401b3566aef613501691d18cf7e4c776cd2>`__  2022-05-04   ``Bump pre-commit hook versions (#22887)``
`427e14b763 <https://github.com/apache/airflow/commit/427e14b763d2a29432a999ba6b984fcccc11977a>`__  2022-05-03   ``Fix code-snippets in google provider (#23438)``
`fa0cc7cec7 <https://github.com/apache/airflow/commit/fa0cc7cec7572c948ebd250a6d7f008ddf222433>`__  2022-05-02   ``Cleanup Google provider CHANGELOG.rst (#23390)``
`3f6d5eef42 <https://github.com/apache/airflow/commit/3f6d5eef427f3ea33d0cd342143983f54226bf05>`__  2022-05-01   ``'DataprocHook': Remove deprecated function 'submit' (#23389)``
`511d0ee256 <https://github.com/apache/airflow/commit/511d0ee256b819690ccf0f6b30d12340b1dd7f0a>`__  2022-04-30   ``Bigquery assets (#23165)``
`3f9845095e <https://github.com/apache/airflow/commit/3f9845095e5e51595af73c237491c04012ddbbd9>`__  2022-04-29   ``Remove redundant docstring in 'BigQueryUpdateTableSchemaOperator' (#23349)``
`0fcdc5e1fb <https://github.com/apache/airflow/commit/0fcdc5e1fb4f49bc9c35eec99a6c3ea65f704588>`__  2022-04-29   ``'S3ToGCSOperator': Remove 'dest_gcs_conn_id' (#23348)``
`05ccfd42f2 <https://github.com/apache/airflow/commit/05ccfd42f28db7d0a8fe3ed023b0e7a8ec188609>`__  2022-04-29   ``Dataproc: Remove default value of 'region' (#23350)``
`359dc58207 <https://github.com/apache/airflow/commit/359dc582078e0d128f42a983c285ffec7ad41686>`__  2022-04-29   ``Google provider: Remove 'bigquery_conn_id', 'google_cloud_storage_conn_id' (#23326)``
`c82b3b9466 <https://github.com/apache/airflow/commit/c82b3b94660a38360f61d47676ed180a0d32c189>`__  2022-04-28   ``'GCSFileTransformOperator': New templated fields 'source_object', 'destination_object' (#23328)``
`9449a107f0 <https://github.com/apache/airflow/commit/9449a107f092f2f6cfa9c8bbcf5fd62fadfa01be>`__  2022-04-28   ``'DatastoreHook': Remove 'datastore_conn_id' (#23323)``
`1f32603549 <https://github.com/apache/airflow/commit/1f3260354988b304cf31d5e1d945ce91798bed48>`__  2022-04-28   ``update processor to fix broken download URLs (#23299)``
`8a7b61a8e4 <https://github.com/apache/airflow/commit/8a7b61a8e4e912627af0b84128ad87c0a347b1d8>`__  2022-04-28   ``Migrate gcs to new system tests design (#22778)``
`72e2ea68a1 <https://github.com/apache/airflow/commit/72e2ea68a13f6494d1d95d6e03bc5ed72f4c8342>`__  2022-04-27   ``'CloudBuildCreateBuildOperator': Remove deprecated 'body' parameter (#23263)``
`6cf0176f2a <https://github.com/apache/airflow/commit/6cf0176f2a676008a6fbe5b950ab2e3231fd1f76>`__  2022-04-27   ``Remove deprecated parameters from PubSub operators: (#23261)``
`4d9c55c9d9 <https://github.com/apache/airflow/commit/4d9c55c9d962f179ae4d7c9e7c697b01cea8d0d2>`__  2022-04-27   ``Remove deprecated parameters from BigQueryHook: (#23269)``
`915b0c689e <https://github.com/apache/airflow/commit/915b0c689eb1e40a2e4496991b74379fed2cfe90>`__  2022-04-27   ``add missing docstring in 'BigQueryHook.create_empty_table' (#23270)``
`710eb6f3e6 <https://github.com/apache/airflow/commit/710eb6f3e606c32aa8a518915d2930abeb69f659>`__  2022-04-26   ``* 'CloudDatastoreImportEntitiesOperator' : Remove 'xcom_push'. Please use 'BaseOperator.do_xcom_push' (#23252)``
`2d569fdaf0 <https://github.com/apache/airflow/commit/2d569fdaf0727bfe7f3a92fa4ce9ae47236d3615>`__  2022-04-26   ``Create links for Biqtable operators (#23164)``
`434ab5a03c <https://github.com/apache/airflow/commit/434ab5a03ce2f34570bb4d9b7fb1e22c8e6762e2>`__  2022-04-26   ``'BigtableCreateInstanceOperator' & 'BigtableHook.create_instance' Remove 'replica_cluster_id', 'replica_cluster_zone'. (#23251)``
`5ca1f3bf70 <https://github.com/apache/airflow/commit/5ca1f3bf706f6ac8437bef0c7c4944cc2d7fca04>`__  2022-04-26   ``Dataproc : remove 'location' in favor of 'region' (#23250)``
`1416ac4195 <https://github.com/apache/airflow/commit/1416ac4195654088b10e9af107282f6b0464105c>`__  2022-04-26   ``'PubSubPullSensor': Remove 'project' and 'return_immediately' (#23231)``
`06dfc2536c <https://github.com/apache/airflow/commit/06dfc2536c0bcddec478ff61cdc8677d9bc64435>`__  2022-04-26   ``Remove deprecated 'params' from google operators (#23230)``
`37a7b27242 <https://github.com/apache/airflow/commit/37a7b27242fa06e0c805cbc01cf3cfe3557daf8e>`__  2022-04-26   ``'LookerStartPdtBuildOperator', 'LookerCheckPdtBuildSensor' : fix empty materialization id handling (#23025)``
`967140e6c3 <https://github.com/apache/airflow/commit/967140e6c3bd0f359393e018bf27b7f2310a2fd9>`__  2022-04-25   ``Add location support to BigQueryDataTransferServiceTransferRunSensor.``
`d6094e58ba <https://github.com/apache/airflow/commit/d6094e58ba3e96b54c5480fbffa5f3906222f414>`__  2022-04-25   ``Fix static checks``
`22ea28f23e <https://github.com/apache/airflow/commit/22ea28f23ece16f34597c103d64cab78884a8bf4>`__  2022-04-25   ``Remove run_in_gke_cluster flag``
`c46d04eb2d <https://github.com/apache/airflow/commit/c46d04eb2d62d3bf8a74a4a84c6fad9d12a96792>`__  2022-04-25   ``Create system test for K8s and dataproc operators``
`35cbc89c3a <https://github.com/apache/airflow/commit/35cbc89c3a0a81f462da15b6416453c8323ae486>`__  2022-04-25   ``Create Dataproc operators for GKE``
`27ad3b7827 <https://github.com/apache/airflow/commit/27ad3b7827c5faa116bf43c5530a3d0928fd252d>`__  2022-04-25   ``Remove 'GCSObjectsWtihPrefixExistenceSensor'``
`544d658921 <https://github.com/apache/airflow/commit/544d658921cb2c9ac1abc5a89f2e275255cb924b>`__  2022-04-25   ``Change CloudDatastoreExportEntitiesLink to StorageLink``
`b3cc2f5d10 <https://github.com/apache/airflow/commit/b3cc2f5d102214067c40b3c120364918556e7cca>`__  2022-04-25   ``Fix pre-commit check``
`43ded6c877 <https://github.com/apache/airflow/commit/43ded6c877e90f53e4f5849499a6ed9585b309b7>`__  2022-04-25   ``Add links for Cloud Datastore operators``
`de65a5cc5a <https://github.com/apache/airflow/commit/de65a5cc5acaa1fc87ae8f65d367e101034294a6>`__  2022-04-25   ``Support serviceAccount attr for dataflow in the Apache beam``
`76dc7375b2 <https://github.com/apache/airflow/commit/76dc7375b27976968d37143f7e6dfab1049665f6>`__  2022-04-25   ``Migrate Datastore system tests to new design (AIP-47)``
`0373fb0247 <https://github.com/apache/airflow/commit/0373fb024797bc83be5184886bf94fd4da78a395>`__  2022-04-25   ``'GoogleDriveToGCSOperator': Remove 'destination_bucket' and 'destination_object'``
`6b459995b2 <https://github.com/apache/airflow/commit/6b459995b260cc7023e4720974ef4f59893cd283>`__  2022-04-25   ``Add the format of Vertex Endpoint ID to the docstrings``
`27af0b7ebe <https://github.com/apache/airflow/commit/27af0b7ebe1641d998b890858b0081ccf1472add>`__  2022-04-25   ``Add the new parameter to the docstring``
`48abf571be <https://github.com/apache/airflow/commit/48abf571bec483b0198802e79fb9b948ba41fdd1>`__  2022-04-25   ``Add 'endpoint_id' arg to 'google.cloud.operators.vertex_ai.CreateEndpointOperator'``
`8b6b0848a3 <https://github.com/apache/airflow/commit/8b6b0848a3cacf9999477d6af4d2a87463f03026>`__  2022-04-23   ``Use new Breese for building, pulling and verifying the images. (#23104)``
`07a13bb708 <https://github.com/apache/airflow/commit/07a13bb7088d4a8ba50efbf14981150656b020a7>`__  2022-04-21   ``Change ComputeSSH to throw provider import error instead paramiko (#23035)``
`c36bcc4c06 <https://github.com/apache/airflow/commit/c36bcc4c06c93dce11e2306a4aff66432bffd5a5>`__  2022-04-15   ``Upgrade to support Google Ads v10 (#22965)``
`fbfbc26a7a <https://github.com/apache/airflow/commit/fbfbc26a7ad591b1076f50b11ba2e9c41916685c>`__  2022-04-15   ``Update gcs_to_local.rst (#23026)``
`ea1ae1963e <https://github.com/apache/airflow/commit/ea1ae1963ecf1b543e4f5e8deb59d623df42d44a>`__  2022-04-14   ``Fix cancel_on_kill after execution timeout for DataprocSubmitJobOperator (#22955)``
`9a623e94cb <https://github.com/apache/airflow/commit/9a623e94cb3e4f02cbe566e02f75f4a894edc60d>`__  2022-04-13   ``migrate system test gcs_to_bigquery into new design (#22753)``
`aa317d92ea <https://github.com/apache/airflow/commit/aa317d92ea4dd38fbc27501048ee78b1c0c0aeb5>`__  2022-04-13   ``Fix select * query xcom push for BigQueryGetDataOperator (#22936)``
`27b3e31178 <https://github.com/apache/airflow/commit/27b3e31178a4d64c09c6125bcc69e973275b84be>`__  2022-04-11   ``implements #22859 - Add .sql as templatable extension (#22920)``
`03e1c9b152 <https://github.com/apache/airflow/commit/03e1c9b1521fea46ad3c7e15690810e4548f52c9>`__  2022-04-11   ``MSSQLToGCSOperator fails: datetime is not JSON Serializable (#22882)``
`6933022e94 <https://github.com/apache/airflow/commit/6933022e94acf139b2dea9a589bb8b25c62a5d20>`__  2022-04-10   ``Fix new MyPy errors in main (#22884)``
`6aa65a38e0 <https://github.com/apache/airflow/commit/6aa65a38e0be3fee18ae9c1541e6091a47ab1f76>`__  2022-04-08   ``Add example DAG for demonstrating usage of GCS sensors (#22808)``
==================================================================================================  ===========  ===================================================================================================================================

6.8.0
.....

Latest change: 2022-04-07

==================================================================================================  ===========  ===============================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===============================================================================================================================
`56ab82ed7a <https://github.com/apache/airflow/commit/56ab82ed7a5c179d024722ccc697b740b2b93b6a>`__  2022-04-07   ``Prepare mid-April provider documentation. (#22819)``
`838cf401b9 <https://github.com/apache/airflow/commit/838cf401b9a424ad0fbccd5fb8d3040a8f4a7f44>`__  2022-04-06   ``Fail ''LocalFilesystemToGCSOperator'' if src does not exist (#22772)``
`99b0211d50 <https://github.com/apache/airflow/commit/99b0211d5087cf486415b5fc8399d3f15d84ed69>`__  2022-04-04   ``Modify transfer operators to handle more data (#22495)``
`f9e18472c0 <https://github.com/apache/airflow/commit/f9e18472c0c228fc3de7c883c7c3d26d7ee49e81>`__  2022-04-04   ``Add autodetect arg in BQCreateExternalTable Operator (#22710)``
`327eab3e26 <https://github.com/apache/airflow/commit/327eab3e26a3fb3e40a995facebb512cebb0fec2>`__  2022-03-31   ``Add links for BigQuery Data Transfer (#22280)``
`02976bef88 <https://github.com/apache/airflow/commit/02976bef885a5da29a8be59b32af51edbf94466c>`__  2022-03-27   ``Refactor: BigQuery to GCS Operator (#22506)``
`719135ade0 <https://github.com/apache/airflow/commit/719135ade06f4a7017d68dafbd79662a1c1d2948>`__  2022-03-27   ``Remove references to deprecated operators/params in PubSub operators (#22519)``
`ca4b8d1744 <https://github.com/apache/airflow/commit/ca4b8d1744cd1de9b6af97dacb0e03de0f014006>`__  2022-03-27   ``Create Endpoint and Model Service, Batch Prediction and Hyperparameter Tuning Jobs operators for Vertex AI service (#22088)``
`388723950d <https://github.com/apache/airflow/commit/388723950de9ca519108e0a8f6818f0fc0dd91d4>`__  2022-03-27   ``PostgresToGoogleCloudStorageOperator - BigQuery schema type for time zone naive fields (#22536)``
`c063fc688c <https://github.com/apache/airflow/commit/c063fc688cf20c37ed830de5e3dac4a664fd8241>`__  2022-03-25   ``Update black precommit (#22521)``
`3c7cd47319 <https://github.com/apache/airflow/commit/3c7cd4731937652271fc1180a74e9a3af3dd211d>`__  2022-03-25   ``New design of system tests (#22311)``
`7ab45d41d6 <https://github.com/apache/airflow/commit/7ab45d41d6c4de322dc8afe8a74b712d0bae4ee7>`__  2022-03-24   ``Update secrets backends to use get_conn_value instead of get_conn_uri (#22348)``
`d231e9b448 <https://github.com/apache/airflow/commit/d231e9b448d76cd35fd6b6d04305b86a5c5ad94e>`__  2022-03-24   ``Remove coerce_datetime usage from GCSTimeSpanFileTransformOperator (#22501)``
`82a26c0591 <https://github.com/apache/airflow/commit/82a26c05913ef1ac323270363e1cd6d15ee651d2>`__  2022-03-24   ``Fix the docstrings (#22497)``
`38fde2ea79 <https://github.com/apache/airflow/commit/38fde2ea795f69ebd5f4ecc5668e162ce4694ac4>`__  2022-03-23   ``Fix 'download_media' url in 'GoogleDisplayVideo360SDFtoGCSOperator' (#22479)``
`0f0a1a7d22 <https://github.com/apache/airflow/commit/0f0a1a7d22dffab4487c35d3598b3b6aaf24c4c6>`__  2022-03-23   ``Fix to 'CloudBuildRunBuildTriggerOperator' fails to find build id. (#22419)``
==================================================================================================  ===========  ===============================================================================================================================

6.7.0
.....

Latest change: 2022-03-22

==================================================================================================  ===========  ===================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===================================================================
`d7dbfb7e26 <https://github.com/apache/airflow/commit/d7dbfb7e26a50130d3550e781dc71a5fbcaeb3d2>`__  2022-03-22   ``Add documentation for bugfix release of Providers (#22383)``
`7b851edc91 <https://github.com/apache/airflow/commit/7b851edc916281bb5d3a8358c46b013d6cae84b2>`__  2022-03-21   ``Add 'LocalFilesystemToGoogleDriveOperator' (#22219)``
`14e6b657c2 <https://github.com/apache/airflow/commit/14e6b657c26df6aa3844c4f4531c623cddd143d7>`__  2022-03-21   ``Add timeout and retry to the BigQueryInsertJobOperator (#22395)``
`a3ffbee7c9 <https://github.com/apache/airflow/commit/a3ffbee7c9b5cd8cc5b7b246116f0254f1daa505>`__  2022-03-20   ``Fix skipping non-GCS located jars (#22302)``
`88402038ca <https://github.com/apache/airflow/commit/88402038cac10597a67d3dba6af66eb1bc14377d>`__  2022-03-19   ``Add dataflow_default_options to templated_fields (#22367)``
`6448b2458c <https://github.com/apache/airflow/commit/6448b2458cbeb93c33bfe0ca03261498aa69a186>`__  2022-03-15   ``[FIX] typo doc of gcs operator (#22290)``
==================================================================================================  ===========  ===================================================================

6.6.0
.....

Latest change: 2022-03-14

==================================================================================================  ===========  ==========================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ==========================================================================================
`16adc035b1 <https://github.com/apache/airflow/commit/16adc035b1ecdf533f44fbb3e32bea972127bb71>`__  2022-03-14   ``Add documentation for Classifier release for March 2022 (#22226)``
`87c1246b79 <https://github.com/apache/airflow/commit/87c1246b79769f20214a339aadc6a8270d453953>`__  2022-03-14   ``Add Dataplex operators (#20377)``
`c1ab8e2d7b <https://github.com/apache/airflow/commit/c1ab8e2d7b68a31408e750129592e16432474512>`__  2022-03-14   ``Protect against accidental misuse of XCom.get_value() (#22244)``
`c108f264ab <https://github.com/apache/airflow/commit/c108f264abde68e8f458a401296a53ccbe7a47f6>`__  2022-03-13   ``Change the default 'chunk_size' to a clear representation & add documentation (#22222)``
`45435399fe <https://github.com/apache/airflow/commit/45435399fe16c48d11584245a04c357242b23f40>`__  2022-03-13   ``Support Uploading Bigger Files to Google Drive (#22179)``
`42a891d605 <https://github.com/apache/airflow/commit/42a891d6053a9b449909290786c4248c76d4a41f>`__  2022-03-13   ``Update ''GKEDeleteClusterOperator', ''GKECreateClusterOperator'' docstrings (#22212)``
`d08284ed25 <https://github.com/apache/airflow/commit/d08284ed251b7c5712190181623b500a38cd640d>`__  2022-03-11   `` Add map_index to XCom model and interface (#22112)``
`da34ff4a65 <https://github.com/apache/airflow/commit/da34ff4a652b38c7b3c953332dbb010039ec409c>`__  2022-03-10   ``Update cloud_composer.rst (#22124)``
`828d1cba4d <https://github.com/apache/airflow/commit/828d1cba4d9b85a166debdd8a8dfe363935c22cd>`__  2022-03-10   ``Add support for ARM platform (#22127)``
`4ac771c316 <https://github.com/apache/airflow/commit/4ac771c3161acb293a39db0ce031bf40d0778803>`__  2022-03-09   ``Fix spelling (#22107)``
`dd0724fdd2 <https://github.com/apache/airflow/commit/dd0724fdd2386576755c5e49d8adb41f0d164116>`__  2022-03-08   ``Add guide for DataprocInstantiateInlineWorkflowTemplateOperator (#22062)``
`dfd9805a23 <https://github.com/apache/airflow/commit/dfd9805a23b2d366f5c332f4cb4131462c5ba82e>`__  2022-03-08   ``Use yaml safe load (#22091)``
`eba9703751 <https://github.com/apache/airflow/commit/eba9703751081d3a7ca8a8754b742fbf12a68bd0>`__  2022-03-08   ``Revert "Use yaml safe load (#22085)" (#22089)``
`7f4935bab3 <https://github.com/apache/airflow/commit/7f4935bab36c41d5927610e38c46a30da2b80906>`__  2022-03-08   ``Use yaml safe load (#22085)``
`a11d831e3f <https://github.com/apache/airflow/commit/a11d831e3f978826d75e62bd70304c5277a8a1ea>`__  2022-03-07   ``Allow for uploading metadata with GCS Hook Upload (#22058)``
==================================================================================================  ===========  ==========================================================================================

6.5.0
.....

Latest change: 2022-03-07

==================================================================================================  ===========  ================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ================================================================================================
`f5b96315fe <https://github.com/apache/airflow/commit/f5b96315fe65b99c0e2542831ff73a3406c4232d>`__  2022-03-07   ``Add documentation for Feb Providers release (#22056)``
`6db9b0029b <https://github.com/apache/airflow/commit/6db9b0029b98611dd748638ab4834a2275e4fa48>`__  2022-03-07   ``Add Looker PDT operators (#20882)``
`d8b730a57b <https://github.com/apache/airflow/commit/d8b730a57b8eb4e6bc408b3553b16ada2386ae8e>`__  2022-03-06   ``Fix typo in docs (#22024)``
`9020b3a89d <https://github.com/apache/airflow/commit/9020b3a89d4572572c50d6ac0f1724e09092e0b5>`__  2022-03-06   ``Add autodetect arg to external table creation in GCSToBigQueryOperator (#21944)``
`a0e2ebaa27 <https://github.com/apache/airflow/commit/a0e2ebaa27e5422b7e6ea8d04021fddbbb759bef>`__  2022-03-02   ``Unpin 'google-cloud-memcache' (#21912)``
`84ed747db8 <https://github.com/apache/airflow/commit/84ed747db8e333d2b24ee3a7f59666b89816aa52>`__  2022-03-02   ``Unpin ''pandas-gbq'' and remove unused code (#21915)``
`fb6b2d1fee <https://github.com/apache/airflow/commit/fb6b2d1fee6af366a3311a8012eb35b8f665348a>`__  2022-03-01   ``Make project_id argument optional in all dataproc operators (#21866)``
`08575ddd8a <https://github.com/apache/airflow/commit/08575ddd8a72f96a3439f73e973ee9958188eb83>`__  2022-03-01   ``Change BaseOperatorLink interface to take a ti_key, not a datetime (#21798)``
`6ca118dff1 <https://github.com/apache/airflow/commit/6ca118dff1ede2b1541c43c3738e547b43818f7f>`__  2022-03-01   ``Allow templates in more DataprocUpdateClusterOperator fields (#21865)``
`0c55ca2cda <https://github.com/apache/airflow/commit/0c55ca2cda2433ba79b2f4868361576d41d2b41c>`__  2022-02-28   ``Suppress hook warnings from the Bigquery transfers (#20119)``
`73eb24f25c <https://github.com/apache/airflow/commit/73eb24f25c2d60fb3a2d8fe2ed64b3c165f8d4c6>`__  2022-02-24   ``Fix bigquery_dts parameter docstring typo (#21786)``
`3b4c26eb3a <https://github.com/apache/airflow/commit/3b4c26eb3a1c8d4938be80ab7fa0711561e91f8f>`__  2022-02-23   ``Add Dataproc assets/links (#21756)``
`6061cc4219 <https://github.com/apache/airflow/commit/6061cc42196053e3540d35f5fdcdedf7bb72cb4a>`__  2022-02-20   ``Add Auto ML operators for Vertex AI service (#21470)``
`295efd36ea <https://github.com/apache/airflow/commit/295efd36eac074578e4b54a69d71c2924984326d>`__  2022-02-17   ``Dataflow Assets (#21639)``
`af2c047320 <https://github.com/apache/airflow/commit/af2c047320c5f0742f466943c171ec761d275bab>`__  2022-02-16   ``Add GoogleCalendarToGCSOperator (#20769)``
`8d980cb6bb <https://github.com/apache/airflow/commit/8d980cb6bb9cc1b7e2d71975b5a5c00a81409685>`__  2022-02-15   ``Implement multiple API auth backends (#21472)``
`1b568d73e1 <https://github.com/apache/airflow/commit/1b568d73e1dfb838a3a0446e3a6063b9f27f04b8>`__  2022-02-15   ``Extract ClientInfo to module level (#21554)``
`dc03000de8 <https://github.com/apache/airflow/commit/dc03000de80e672de661c84f5fbb916413211550>`__  2022-02-15   ``Datafusion assets (#21518)``
`56365b102c <https://github.com/apache/airflow/commit/56365b102c0b0850f27a64fe9b08da4e07fedee1>`__  2022-02-15   ``Dataproc metastore assets (#21267)``
`6692e9191d <https://github.com/apache/airflow/commit/6692e9191df61c8637adbfa249ebbf9882dbba5d>`__  2022-02-15   ``Normalize *_conn_id parameters in BigQuery sensors (#21430)``
`2eb10565b2 <https://github.com/apache/airflow/commit/2eb10565b2075d89eb283bd53462c00f5d54ab55>`__  2022-02-15   ``Fixed PostgresToGCSOperator fail on empty resultset for use_server_side_cursor=True (#21307)``
`da1e6578e0 <https://github.com/apache/airflow/commit/da1e6578e0207b7f2acab794ed3c5bf730719bf8>`__  2022-02-15   ``Fix multi query scenario in bigquery example DAG (#21575)``
==================================================================================================  ===========  ================================================================================================

6.4.0
.....

Latest change: 2022-02-14

==================================================================================================  ===========  ============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ============================================================================================
`28378d867a <https://github.com/apache/airflow/commit/28378d867afaac497529bd2e1d2c878edf66f460>`__  2022-02-14   ``Add documentation for RC3 release of providers for Jan 2022 (#21553)``
`6bb0857df9 <https://github.com/apache/airflow/commit/6bb0857df94c0f959e7ebe421a00b942fd60b199>`__  2022-02-13   ``(providers_google) add a location check in bigquery (#19571)``
`6579648af2 <https://github.com/apache/airflow/commit/6579648af2a21aa01cb93f051d091569a03c04a4>`__  2022-02-13   ``Fix bigquery-hook when no  engine_kwargs are passed``
`da485da29a <https://github.com/apache/airflow/commit/da485da29a06ecdda720a7ba75f04a2680aac0a2>`__  2022-02-13   ``Add support for BeamGoPipelineOperator (#20386)``
`05a883b35e <https://github.com/apache/airflow/commit/05a883b35e34853ec9326bd579551a8e161d6cdc>`__  2022-02-11   ``Google Cloud Composer opearators (#21251)``
`833087f4f9 <https://github.com/apache/airflow/commit/833087f4f9e86ee063d6a754593d80e9e5cd4100>`__  2022-02-10   ``Enable asynchronous job submission in BigQuery hook (#21385)``
`51aff276ca <https://github.com/apache/airflow/commit/51aff276ca4a33ee70326dd9eea6fba59f1463a3>`__  2022-02-10   ``Optionally raise an error if source file does not exist in GCSToGCSOperator (#21391)``
`07fe9e8c6a <https://github.com/apache/airflow/commit/07fe9e8c6acf8826ac1dcaf2ad8c94297a0f0c24>`__  2022-02-09   ``Never set DagRun.state to State.NONE (#21263)``
`0a3ff43d41 <https://github.com/apache/airflow/commit/0a3ff43d41d33d05fb3996e61785919effa9a2fa>`__  2022-02-08   ``Add pre-commit check for docstring param types (#21398)``
`d94fa37830 <https://github.com/apache/airflow/commit/d94fa378305957358b910cfb1fe7cb14bc793804>`__  2022-02-08   ``Fixed changelog for January 2022 (delayed) provider's release (#21439)``
`e973740208 <https://github.com/apache/airflow/commit/e9737402081aa9c9bac748de1d75b387b3b8da42>`__  2022-02-08   ``Create CustomJob and Datasets operators for Vertex AI service (#21253)``
`34d63fabc0 <https://github.com/apache/airflow/commit/34d63fabc0f2a85df38a78a89f9929e110951d11>`__  2022-02-08   ``Fix BigQueryDataTransferServiceHook.get_transfer_run() request parameter (#21293)``
`6b88d432d9 <https://github.com/apache/airflow/commit/6b88d432d959df73433528fe3d62194239f13edd>`__  2022-02-06   ``Support to upload file to Google Shared Drive (#21319)``
`1a77bc6481 <https://github.com/apache/airflow/commit/1a77bc6481580ab6817267b6e075634caaa025be>`__  2022-02-06   ``:bug: (BigQueryHook) fix compatibility with sqlalchemy engine (#19508)``
`6c3a67d4fc <https://github.com/apache/airflow/commit/6c3a67d4fccafe4ab6cd9ec8c7bacf2677f17038>`__  2022-02-05   ``Add documentation for January 2021 providers release (#21257)``
`39e395f981 <https://github.com/apache/airflow/commit/39e395f9816c04ef2f033eb0b4f635fc3018d803>`__  2022-02-04   ``Add more SQL template fields renderers (#21237)``
`e840acf8d1 <https://github.com/apache/airflow/commit/e840acf8d1840761b72b596ccd4280efece0c974>`__  2022-02-04   ``Fix BigQuery system test (#21320)``
`ddb5246bd1 <https://github.com/apache/airflow/commit/ddb5246bd1576e2ce6abf8c80c3328d7d71a75ce>`__  2022-02-03   ``Refactor operator links to not create ad hoc TaskInstances (#21285)``
`1d4b709e20 <https://github.com/apache/airflow/commit/1d4b709e20b07c6f0b5d1bab1935e19557df2913>`__  2022-01-28   ``Revert "Create CustomJob and Datasets operators for Vertex AI service (#20077)" (#21203)``
`48d44b885b <https://github.com/apache/airflow/commit/48d44b885b0b205a8a4f8ff864716127476ff7f4>`__  2022-01-28   ``Cloudsql import links fix. (#21199)``
`640c0b6763 <https://github.com/apache/airflow/commit/640c0b67631c5f2c8ee866b0726fa7a8a452cd3c>`__  2022-01-28   ``Create CustomJob and Datasets operators for Vertex AI service (#20077)``
`cb73053211 <https://github.com/apache/airflow/commit/cb73053211367e2c2dd76d5279cdc7dc7b190124>`__  2022-01-27   ``Add optional features in providers. (#21074)``
`60aa518ebf <https://github.com/apache/airflow/commit/60aa518ebfe8d794ee216c8283cba841d6510189>`__  2022-01-26   ``batch as templated field in DataprocCreateBatchOperator (#20905)``
`623163f16a <https://github.com/apache/airflow/commit/623163f16ad2bbdd47d499e423fd5e37d36a028b>`__  2022-01-25   ``Extend dataproc example dag (#21091)``
`86ef016eab <https://github.com/apache/airflow/commit/86ef016eabd90819163503ef07c0da50373142ad>`__  2022-01-23   ``Make timeout Optional for wait_for_operation (#20981)``
`506efb6fa3 <https://github.com/apache/airflow/commit/506efb6fa3999ac21a8539e863d81dc684abe52a>`__  2022-01-21   ``Squelch more deprecation warnings (#21003)``
`372849486c <https://github.com/apache/airflow/commit/372849486cd455a4ff4821b01805a442f1a78417>`__  2022-01-21   ``Fix last google provider MyPy errors (#21010)``
`73c0d241d8 <https://github.com/apache/airflow/commit/73c0d241d804507abc651a365f93d60c543349d5>`__  2022-01-21   ``Remove a few stray ':type's in docs (#21014)``
`602abe8394 <https://github.com/apache/airflow/commit/602abe8394fafe7de54df7e73af56de848cdf617>`__  2022-01-20   ``Remove ':type' lines now sphinx-autoapi supports typehints (#20951)``
`b8526abc2c <https://github.com/apache/airflow/commit/b8526abc2c220b1e07eed83694dfee972c2e2609>`__  2022-01-19   ``Add encoding parameter to 'GCSToLocalFilesystemOperator' to fix #20901 (#20919)``
`58452f97db <https://github.com/apache/airflow/commit/58452f97dbcddb4c57a021e9c7fc76139aa9633b>`__  2022-01-03   ``Add hook for integrating with Google Calendar (#20542)``
==================================================================================================  ===========  ============================================================================================

6.3.0
.....

Latest change: 2021-12-31

==================================================================================================  ===========  =====================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =====================================================================================
`f77417eb0d <https://github.com/apache/airflow/commit/f77417eb0d3f12e4849d80645325c02a48829278>`__  2021-12-31   ``Fix K8S changelog to be PyPI-compatible (#20614)``
`97496ba2b4 <https://github.com/apache/airflow/commit/97496ba2b41063fa24393c58c5c648a0cdb5a7f8>`__  2021-12-31   ``Update documentation for provider December 2021 release (#20523)``
`a22d5bd076 <https://github.com/apache/airflow/commit/a22d5bd07696d9cafe10a3e246ea9f3a381585ee>`__  2021-12-31   ``Fix mypy errors in Google Cloud provider (#20611)``
`4233ebe5ce <https://github.com/apache/airflow/commit/4233ebe5cea4862dbf16c9d7c72c4fdd11db9774>`__  2021-12-31   ``Fix setting of project ID in ''provide_authorized_gcloud'' (#20428)``
`83f8e178ba <https://github.com/apache/airflow/commit/83f8e178ba7a3d4ca012c831a5bfc2cade9e812d>`__  2021-12-31   ``Even more typing in operators (template_fields/ext) (#20608)``
`746ee587da <https://github.com/apache/airflow/commit/746ee587da485acdc816129fe71df23e4f024e0b>`__  2021-12-31   ``Delete pods by default in KubernetesPodOperator (#20575)``
`41dbe2c4fc <https://github.com/apache/airflow/commit/41dbe2c4fcfe39c7f5fb5a4b8a341561dd7e3cc1>`__  2021-12-30   ``Fix mypy errors in google/cloud/operators/stackdriver (#20601)``
`dda688776c <https://github.com/apache/airflow/commit/dda688776c196eea708abfda0462af6c92809031>`__  2021-12-30   ``Fix Google mlengine MyPy errors (#20569)``
`d56e7b56bb <https://github.com/apache/airflow/commit/d56e7b56bb9827daaf8890557147fd10bdf72a7e>`__  2021-12-30   ``Fix template_fields type to have MyPy friendly Sequence type (#20571)``
`bd9e8cef26 <https://github.com/apache/airflow/commit/bd9e8cef2687de0b047003e159fd8f3f08c6c61f>`__  2021-12-30   ``Fix Google Mypy Dataproc errors (#20570)``
`a6e60ce25d <https://github.com/apache/airflow/commit/a6e60ce25d9f3d621a7b4089834ca5e50cd123db>`__  2021-12-30   ``Change download_video parameter to resourceName (#20528)``
`af4a2b0240 <https://github.com/apache/airflow/commit/af4a2b0240fbf79a0a6774a9662243050e8fea9c>`__  2021-12-30   ``Fix big query to mssql/mysql transfer issues (#20001)``
`a0821235fb <https://github.com/apache/airflow/commit/a0821235fb6877a471973295fe42283ef452abf6>`__  2021-12-30   ``Use typed Context EVERYWHERE (#20565)``
`da88ed1943 <https://github.com/apache/airflow/commit/da88ed1943e85850fcdf32c663ec2940c65dbe75>`__  2021-12-29   ``Fix MyPy errors in Google Cloud (again) (#20469)``
`3a480f5ff4 <https://github.com/apache/airflow/commit/3a480f5ff41c2da4ae4fd6b2289e064ee42048a5>`__  2021-12-29   ``Fix passing the gzip compression parameter on sftp_to_gcs. (#20553)``
`bfd6d45cec <https://github.com/apache/airflow/commit/bfd6d45cecbc7714cea8e2ce5d8920bdb4819887>`__  2021-12-29   ``switch to follow_redirects on httpx.get call in CloudSQL provider (#20239)``
`7d4d38b546 <https://github.com/apache/airflow/commit/7d4d38b546c44287f8a9d09c4fc141cbea736511>`__  2021-12-29   ``avoid deprecation warnings in BigQuery transfer operators (#20502)``
`b7086f9815 <https://github.com/apache/airflow/commit/b7086f9815d3856cb4f3ee5bbc78657f19df9d2d>`__  2021-12-28   ``Use Python3.7+ syntax in pyupgrade (#20501)``
`a4622e19fa <https://github.com/apache/airflow/commit/a4622e19fa0edc983cb0b29ca6a92969d0cb46fd>`__  2021-12-22   ``Support regional GKE cluster (#18966)``
`2ffdcf4b41 <https://github.com/apache/airflow/commit/2ffdcf4b41158b21e5a08314691d4159dbd44dcb>`__  2021-12-21   ``Fixes docstring for PubSubCreateSubscriptionOperator (#20237)``
`d4c4f9e09e <https://github.com/apache/airflow/commit/d4c4f9e09ee8b0453ff8503c30274eeaa80e7fde>`__  2021-12-21   ``Fix mypy errors for google.cloud_build (#20234)``
`c6dbb3f885 <https://github.com/apache/airflow/commit/c6dbb3f8856be75ff2619476ab3ca587a52e033a>`__  2021-12-21   ``Fix MyPy for Google Bigquery (#20329)``
`ed604b62f3 <https://github.com/apache/airflow/commit/ed604b62f3dfb4d76d6f1eaf4d639dc65956d8f2>`__  2021-12-18   ``Fix remaining MyPy errors in Google Provider (#20358)``
`17404f1f10 <https://github.com/apache/airflow/commit/17404f1f10efd41f98eb8a0317b578ff40f9c77d>`__  2021-12-16   ``Move source_objects datatype check out of GCSToBigQueryOperator.__init__ (#20347)``
`174681911f <https://github.com/apache/airflow/commit/174681911f96f17d41a4f560ca08d5e200944f7f>`__  2021-12-16   ``Fix MyPy Errors for dataproc package (#20327)``
`2fb5e1d0ec <https://github.com/apache/airflow/commit/2fb5e1d0ec306839a3ff21d0bddbde1d022ee8c7>`__  2021-12-15   ``Fix cached_property MyPy declaration and related MyPy errors (#20226)``
`21b8661886 <https://github.com/apache/airflow/commit/21b866188662b08bac0de778daec83cb28864097>`__  2021-12-15   ``Fix missing get_backup method for Dataproc Metastore (#20326)``
`cdaa9a2529 <https://github.com/apache/airflow/commit/cdaa9a252900091f4c0e912a6d2a8890b7cb571a>`__  2021-12-15   ``Fix MyPy errors for google.cloud.tasks (#20233)``
`43efde6230 <https://github.com/apache/airflow/commit/43efde6230487b003f715e04d195126f63f261ff>`__  2021-12-15   ``Fix MyPy Errors for Apache Beam (and Dataflow) provider. (#20301)``
`c4b3694101 <https://github.com/apache/airflow/commit/c4b369410155dfc461d2b95ee66cb1927f8e4230>`__  2021-12-15   ``Fix MyPy errors in leveldb (#20222)``
`1570519a97 <https://github.com/apache/airflow/commit/1570519a976dfb9de1aba9c2c0bee169e7ab5ee1>`__  2021-12-14   ``Fix MyPy errors for google.cloud.transfers (#20229)``
`632bd0133e <https://github.com/apache/airflow/commit/632bd0133e0920c036f1cd83d100f477726fcb41>`__  2021-12-13   ``Fix MyPY errors for google.cloud.example_dags (#20232)``
`644051abcb <https://github.com/apache/airflow/commit/644051abcbb87aab906e050eacce3a70379060dd>`__  2021-12-13   ``Fix MyPy errors for google/marketing_platform and suite (#20227)``
`a208463802 <https://github.com/apache/airflow/commit/a2084638020613979fa1ed9ba944050f274bb160>`__  2021-12-13   ``Organize S3 Classes in Amazon Provider (#20167)``
`98514cc159 <https://github.com/apache/airflow/commit/98514cc1599751d7611b3180c60887da0a25ff5e>`__  2021-12-13   ``Add optional location to bigquery data transfer service (#15088) (#20221)``
`1f662571b2 <https://github.com/apache/airflow/commit/1f662571b2133df09da22aea35936bb10b8ebffa>`__  2021-12-12   ``Fix MyPy errors in google.cloud.sensors (#20228)``
`22341b90da <https://github.com/apache/airflow/commit/22341b90da1d7efb0d9c1d6c4dc054e0238d1f27>`__  2021-12-11   ``Add Google Cloud Tasks how-to documentation (#20145)``
`e9262752dc <https://github.com/apache/airflow/commit/e9262752dce86225e960b420287a51c532b21107>`__  2021-12-11   ``Finalised Datastore documentation (#20138)``
`fa96b09395 <https://github.com/apache/airflow/commit/fa96b093952f96449d6d328a2b9e9300b81cf08e>`__  2021-12-09   ``Update Sphinx and Sphinx-AutoAPI (#20079)``
`ed8b63ba24 <https://github.com/apache/airflow/commit/ed8b63ba2460f47744f4dcf40019592816bb89b5>`__  2021-12-08   ``Providers facebook hook multiple account (#19377)``
`704ec82404 <https://github.com/apache/airflow/commit/704ec82404dea0001e67a74596d82e138ef0b7ca>`__  2021-12-08   ``Update a link in the Google provider documentation (#20126)``
`50bf536656 <https://github.com/apache/airflow/commit/50bf5366564957cc0f057ca923317c421fffdeaa>`__  2021-12-08   ``Remove deprecated method call (blob.download_as_string) (#20091)``
`564fe635bd <https://github.com/apache/airflow/commit/564fe635bdb0ba0b26a7b55f63fbe92d4f173e9d>`__  2021-12-06   ``Added example DAG for MSSQL to Google Cloud Storage (GCS) (#19873)``
`cb082d361a <https://github.com/apache/airflow/commit/cb082d361a61da7040e044ff2c1f7758142a9b2d>`__  2021-12-02   ``Remove deprecated template_fields from GoogleDriveToGCSOperator (#19991)``
`6977c47572 <https://github.com/apache/airflow/commit/6977c475720aa18889cd11117a0135e857f2efca>`__  2021-12-01   ``BigQueryHook fix typo in run_load doc string (#19924)``
`43de625d42 <https://github.com/apache/airflow/commit/43de625d4246af7014f64941f8effb09997731cb>`__  2021-12-01   ``Correctly capitalize names and abbreviations in docs (#19908)``
`f6dca1fa5e <https://github.com/apache/airflow/commit/f6dca1fa5e70ef08798adeb5a6bfc70f41229646>`__  2021-12-01   ``Update doc reference links (#19909)``
==================================================================================================  ===========  =====================================================================================

6.2.0
.....

Latest change: 2021-11-30

==================================================================================================  ===========  ========================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ========================================================================================================
`853576d901 <https://github.com/apache/airflow/commit/853576d9019d2aca8de1d9c587c883dcbe95b46a>`__  2021-11-30   ``Update documentation for November 2021 provider's release (#19882)``
`fb478c00cd <https://github.com/apache/airflow/commit/fb478c00cdc5e78d5e85fe5ac103707c829be2fb>`__  2021-11-28   ``Move 'bucket_name' validation out of '__init__' in Google Marketing Platform operators (#19383)``
`e9e530979a <https://github.com/apache/airflow/commit/e9e530979a9176fa6842a2365ce3ff1bb42dfae2>`__  2021-11-28   ``Update 'default_args' value in example_functions DAG from str to int (#19865)``
`bf68b9a846 <https://github.com/apache/airflow/commit/bf68b9a8461eda634a7d91aa56575fb950960eaa>`__  2021-11-26   ``Create dataproc serverless spark batches operator (#19248)``
`a192cecf6b <https://github.com/apache/airflow/commit/a192cecf6bb9b22e058b8c0015c351131185282b>`__  2021-11-26   ``updates pipeline_timeout CloudDataFusionStartPipelineOperator (#18773)``
`eb163c81d1 <https://github.com/apache/airflow/commit/eb163c81d16532252d6196fd70c85e7ea6236279>`__  2021-11-25   ``Fix GCS system tests (#19227)``
`744d11bdb2 <https://github.com/apache/airflow/commit/744d11bdb2acd52794a959572695943df8729a37>`__  2021-11-25   ``Clean up ''default_args'' usage in docs (#19803)``
`0b2e1a8744 <https://github.com/apache/airflow/commit/0b2e1a8744ac0d5965cb11f6a6fa74cee1d03f3d>`__  2021-11-22   ``Added wait mechanizm to the DataprocJobSensor to avoid 509 errors when Job is not available (#19740)``
`3336bb6c3c <https://github.com/apache/airflow/commit/3336bb6c3cfeea3f5fe9c17f3958db47cc867f61>`__  2021-11-19   ``Fix badly merged impersonation in GKEPodOperator (#19696)``
`952ef908bc <https://github.com/apache/airflow/commit/952ef908bc8965641865aaeee9fbcd52a76d700b>`__  2021-11-19   ``Support impersonation_chain parameter in the GKEStartPodOperator (#19518)``
`853c16465a <https://github.com/apache/airflow/commit/853c16465a4d304a3b7d135356270fee87d3461b>`__  2021-11-18   ``Clean-up of google cloud example dags - batch 3 (#19664)``
`355dec8fea <https://github.com/apache/airflow/commit/355dec8fea5e2ef1a9b88363f201fce4f022fef3>`__  2021-11-17   ``Misc. documentation typos and language improvements (#19599)``
`b9d31cd449 <https://github.com/apache/airflow/commit/b9d31cd44962fc376fcf98380eaa1ea60fb6c835>`__  2021-11-17   ``Cleanup dynamic 'start_date' use for miscellaneous Google example DAGs (#19400)``
`daf234bd5e <https://github.com/apache/airflow/commit/daf234bd5e62d076b9bb861119355ab8c18e27a4>`__  2021-11-16   ``Remove reference to deprecated operator in example_dataproc (#19619)``
`48f228cf9e <https://github.com/apache/airflow/commit/48f228cf9ef7602df9bea6ce20d663ac0c4393e1>`__  2021-11-15   ``#16691 Providing more information in docs for DataprocCreateCluster operator migration (#19446)``
`6ef44b6a50 <https://github.com/apache/airflow/commit/6ef44b6a507a8e8d5f41a6731a0773046623d171>`__  2021-11-15   ``Clean-up of google cloud example dags - batch 2 (#19527)``
`dc0159e7e4 <https://github.com/apache/airflow/commit/dc0159e7e47a7f524ea937634472ffe78d906a16>`__  2021-11-14   ``Add support in GCP connection for reading key from Secret Manager (#19164)``
`4212c49324 <https://github.com/apache/airflow/commit/4212c4932433a50bda09f3e771a02f5ded4553a7>`__  2021-11-14   ``Update Azure modules to comply with AIP-21 (#19431)``
`d185c66542 <https://github.com/apache/airflow/commit/d185c66542cf089628e23d617ba095c7a1c57bc9>`__  2021-11-12   ``Small formatting tweak to GCP SSH conn doc (#19562)``
`aa2cb5545f <https://github.com/apache/airflow/commit/aa2cb5545f09d694b9143b323efcd4f6b6c66e60>`__  2021-11-12   ``Remove remaining 'pylint: disable' comments (#19541)``
`c8dc0311da <https://github.com/apache/airflow/commit/c8dc0311dadbcd1b85923a1018e954d979e74d36>`__  2021-11-08   ``Fix Cloud SQL system tests (#19014)``
`26ad55beb0 <https://github.com/apache/airflow/commit/26ad55beb00f5a0915ba4bec541e3d67044834e9>`__  2021-11-08   ``Add dataproc metastore operators (#18945)``
`9efb989d19 <https://github.com/apache/airflow/commit/9efb989d19e657a2cde2eef98804c5007f148ee1>`__  2021-11-07   ``Clean-up of google cloud example dags (#19436)``
`f421409b4d <https://github.com/apache/airflow/commit/f421409b4d431a2055eb273e7bc355819c880bd9>`__  2021-11-05   ``Fix typos in warnings, docstrings, exceptions (#19424)``
`a3c9956f79 <https://github.com/apache/airflow/commit/a3c9956f79310b529a79c1e43fb881c5e173d321>`__  2021-10-30   ``Add support of 'path' parameter for GCloud Storage Transfer Service operators (#17446)``
==================================================================================================  ===========  ========================================================================================================

6.1.0
.....

Latest change: 2021-10-29

==================================================================================================  ===========  ======================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ======================================================================================
`d9567eb106 <https://github.com/apache/airflow/commit/d9567eb106929b21329c01171fd398fbef2dc6c6>`__  2021-10-29   ``Prepare documentation for October Provider's release (#19321)``
`55abc2f620 <https://github.com/apache/airflow/commit/55abc2f620a96832661d1797442a834bf958bb3e>`__  2021-10-28   ``Support query timeout as an argument in CassandraToGCSOperator (#18927)``
`e4aa377da7 <https://github.com/apache/airflow/commit/e4aa377da7fe1801dff04d54c5ed4fd525af94c4>`__  2021-10-28   ``Update BigQueryCreateExternalTableOperator doc and parameters (#18676)``
`20847fdbf8 <https://github.com/apache/airflow/commit/20847fdbf8ecd3be394d24d47ce151c26d018ea1>`__  2021-10-27   ``Add value to "namespaceId" of query (#19163)``
`3c08c025c5 <https://github.com/apache/airflow/commit/3c08c025c5445ffc0533ac28d07ccf2e69a19ca8>`__  2021-10-27   ``Move validation of templated input params to run after the context init (#19048)``
`eba1b68b30 <https://github.com/apache/airflow/commit/eba1b68b30ad2818df0b8fde3be30688ec5c0042>`__  2021-10-27   ``Update dataflow.py (#19231)``
`7ecf29f70d <https://github.com/apache/airflow/commit/7ecf29f70d3fbb1d6174fe693334a0f7fce38a70>`__  2021-10-26   ``Fix hard-coded /tmp directory in CloudSQL Hook (#19229)``
`726a1517ec <https://github.com/apache/airflow/commit/726a1517ec368e0f5906368350d6fa96836943ae>`__  2021-10-26   ``Fix bug in Dataflow hook when no jobs are returned (#18981)``
`d9192a55ba <https://github.com/apache/airflow/commit/d9192a55bacab339c4634f090160bd2d8ed77d7f>`__  2021-10-22   ``Replacing non-attribute template_fields for BigQueryToMsSqlOperator (#19052)``
`4fae04a471 <https://github.com/apache/airflow/commit/4fae04a47119c9f2319ae5e533edcf457e4df003>`__  2021-10-21   ``Upgrade the Dataproc package to 3.0.0 and migrate from v1beta2 to v1 api (#18879)``
`0e95b57772 <https://github.com/apache/airflow/commit/0e95b5777242b00f41812c099f1cf8e2fc0df40c>`__  2021-10-19   ``Google provider catch invalid secret name (#18790)``
`86a2a19ad2 <https://github.com/apache/airflow/commit/86a2a19ad2bdc87a9ad14bb7fde9313b2d7489bb>`__  2021-10-17   ``More f-strings (#18855)``
`a418fd96f7 <https://github.com/apache/airflow/commit/a418fd96f70eac1d4d7dc91553f41d5153beda93>`__  2021-10-17   ``Use google cloud credentials when executing beam command in subprocess (#18992)``
`5c3e453820 <https://github.com/apache/airflow/commit/5c3e4538208cc317e6e45ae7b247e7fb83840f49>`__  2021-10-15   ``Fix BigQueryToMsSqlOperator documentation (#18995)``
`406b38b2e3 <https://github.com/apache/airflow/commit/406b38b2e3fcf9d7fad28573bf77bb9fee5847d1>`__  2021-10-15   ``Replace default api_version of FacebookAdsReportToGcsOperator (#18996)``
`1571f80546 <https://github.com/apache/airflow/commit/1571f80546853688778c2a3ec5194e5c8be0edbd>`__  2021-10-14   ``Add pre-commit hook for common misspelling check in files (#18964)``
`20df60de24 <https://github.com/apache/airflow/commit/20df60de24e1dbeab2dcf5b989b69080d1b3ed34>`__  2021-10-07   ``Dataflow Operators - use project and location from job in on_kill method. (#18699)``
`2a6cadbd58 <https://github.com/apache/airflow/commit/2a6cadbd587bc20ebb36625f43b692671b9cd385>`__  2021-10-06   ``Small improvements for Airflow UI (#18715)``
`86bf2a29ba <https://github.com/apache/airflow/commit/86bf2a29ba784b25c335408eb4647ad2eb48b525>`__  2021-10-04   ``Simplify strings previously split across lines (#18679)``
`af4a5e006e <https://github.com/apache/airflow/commit/af4a5e006e4f5c9f203afeac039b22c6adee317f>`__  2021-10-01   ``Remove cargo-culted local in-page ToCs (#18668)``
==================================================================================================  ===========  ======================================================================================

6.0.0
.....

Latest change: 2021-09-30

==================================================================================================  ===========  =============================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =============================================================================================
`840ea3efb9 <https://github.com/apache/airflow/commit/840ea3efb9533837e9f36b75fa527a0fbafeb23a>`__  2021-09-30   ``Update documentation for September providers release (#18613)``
`9279c44c91 <https://github.com/apache/airflow/commit/9279c44c91274b7ee31c244d41090c93e5753394>`__  2021-09-29   ``Fix part of Google system tests (#18494)``
`2fadf3c3cf <https://github.com/apache/airflow/commit/2fadf3c3cf6e8a5d26953ebce6401ab5059ee05f>`__  2021-09-27   ``Fix kubernetes engine system test (#18548)``
`a458fcc573 <https://github.com/apache/airflow/commit/a458fcc573845ff65244a2dafd204ed70129f3e8>`__  2021-09-27   ``Updating miscellaneous provider DAGs to use TaskFlow API where applicable (#18278)``
`97d6892318 <https://github.com/apache/airflow/commit/97d6892318ce2866f09f2c21247ed3b1b9975695>`__  2021-09-25   ``Rename AzureDataLakeStorage to ADLS (#18493)``
`56a69b7c3e <https://github.com/apache/airflow/commit/56a69b7c3e4fb3984b1e509ce2880c427a86e6ba>`__  2021-09-24   ``Pin ''google-cloud-dataproc'' to ''<2.6.0'' due to removal of ''v1beta2'' client (#18486)``
`a5439eee72 <https://github.com/apache/airflow/commit/a5439eee72cd380f8434e622e8bef7c35786ce39>`__  2021-09-23   ``Add index to the dataset name to have separate dataset for each example DAG (#18459)``
`060345c0d9 <https://github.com/apache/airflow/commit/060345c0d982765e39da5fa8b2e2c6a01e89e394>`__  2021-09-21   ``Add docs for AIP 39: Timetables (#17552)``
`18d7e1e227 <https://github.com/apache/airflow/commit/18d7e1e2270ffcbc8077ba700f209ae69eccef99>`__  2021-09-21   ``Fix BigQuery system test (#18373)``
`e25eea052f <https://github.com/apache/airflow/commit/e25eea052fd54c94b490a377de05c6bae4c24dbb>`__  2021-09-19   ``Inclusive Language (#18349)``
`7458f1e786 <https://github.com/apache/airflow/commit/7458f1e7861e5146da61cbff9393d72c88a3608c>`__  2021-09-18   ``Remove check for at least one schema in GCSToBigquery (#18150)``
`4308a8c364 <https://github.com/apache/airflow/commit/4308a8c364d410ea8c32d2af7cc8ca3261054696>`__  2021-09-17   ``Refactor installation pages (#18282)``
`2474f8922d <https://github.com/apache/airflow/commit/2474f8922d0cb7435040f5e21ca61fb6b633dec2>`__  2021-09-13   ``Migrate Google Cloud Build from Discovery API to Python SDK (#18184)``
`8ae2bb9bfa <https://github.com/apache/airflow/commit/8ae2bb9bfa8cfd62a8ae5f6edabce47800ccb140>`__  2021-09-13   ``Fix error when create external table using table resource (#17998)``
`1cb456cba1 <https://github.com/apache/airflow/commit/1cb456cba1099198bbdba50c2d1ad79664be8ce6>`__  2021-09-12   ``Add official download page for providers (#18187)``
`9140ad8d8f <https://github.com/apache/airflow/commit/9140ad8d8f6dadd56bc592f5cdbf5585c2a8ce89>`__  2021-09-11   ``Use parameters instead of params (#18143)``
`3d4bfdcbb9 <https://github.com/apache/airflow/commit/3d4bfdcbb97c5d68761e5bfd2699a50ca0edd12a>`__  2021-09-10   ``Add missing __init__.py files for some test packages (#18142)``
`cfb602a33d <https://github.com/apache/airflow/commit/cfb602a33dc1904e2f51d74fa711722c8b702726>`__  2021-09-10   ``Fix ''BigQuery'' data extraction in ''BigQueryToMySqlOperator'' (#18073)``
`2fd3f27ebd <https://github.com/apache/airflow/commit/2fd3f27ebd2a4f695968fb7cc5d119e087820928>`__  2021-09-10   ``Make next_dagrun_info take a data interval (#18088)``
`046f02e5a7 <https://github.com/apache/airflow/commit/046f02e5a7097a6e6c928c28196b38b37e776916>`__  2021-09-09   ``fix misspelling (#18121)``
`944dcfbb91 <https://github.com/apache/airflow/commit/944dcfbb918050274fd3a1cc51d8fdf460ea2429>`__  2021-09-07   ``Change TaskInstance and TaskReschedule PK from execution_date to run_id (#17719)``
`bfad233b91 <https://github.com/apache/airflow/commit/bfad233b91875fb2dec4217f1b0ae2ba8dd9820c>`__  2021-09-06   ``Fix providers tests in main branch with eager upgrades (#18040)``
`21348c194d <https://github.com/apache/airflow/commit/21348c194d4149237e357e0fff9ed444d27fa71d>`__  2021-09-03   ``fix(CloudSqlProxyRunner): don't query connections from Airflow DB (#18006)``
`9a0c10ba3f <https://github.com/apache/airflow/commit/9a0c10ba3fac3bb88f4f103114d4590b3fb191cb>`__  2021-09-01   ``deduplicate running jobs on BigQueryInsertJobOperator (#17496)``
`fe34582fc2 <https://github.com/apache/airflow/commit/fe34582fc2f418b96a5dc5c10b8b6a8b48bdb7ea>`__  2021-09-01   ``New google operator: SQLToGoogleSheetsOperator (#17887)``
`500780651c <https://github.com/apache/airflow/commit/500780651cfef9254d5e365c0de6f8c7af6d05bf>`__  2021-08-31   ``Add possibility to run DAGs from system tests and see DAGs logs (#17868)``
==================================================================================================  ===========  =============================================================================================

5.1.0
.....

Latest change: 2021-08-30

==================================================================================================  ===========  =========================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =========================================================================================================================
`0a68588479 <https://github.com/apache/airflow/commit/0a68588479e34cf175d744ea77b283d9d78ea71a>`__  2021-08-30   ``Add August 2021 Provider's documentation (#17890)``
`b5da846dd1 <https://github.com/apache/airflow/commit/b5da846dd1f27d798dc7dc4f4227de4418919874>`__  2021-08-30   ``Fix missing Data Fusion sensor integration (#17914)``
`07405e6df4 <https://github.com/apache/airflow/commit/07405e6df4508fbf3e67d879479e2afd37df8421>`__  2021-08-30   ``[AIRFLOW-9300] Add DatafusionPipelineStateSensor and aync option to the CloudDataFusionStartPipelineOperator (#17787)``
`42e13e1a5a <https://github.com/apache/airflow/commit/42e13e1a5a4c97a2085ddf96f7d93e7bf71949b8>`__  2021-08-30   ``Remove all deprecation warnings in providers (#17900)``
`220678dc61 <https://github.com/apache/airflow/commit/220678dc61749c41927f04a809de357cdaac63ff>`__  2021-08-27   ``Allow google-auth < 3 and google-api-core < 3 (#17671)``
`aa5952e58c <https://github.com/apache/airflow/commit/aa5952e58c58cab65f49b9e2db2adf66f17e7599>`__  2021-08-27   ``Gcp ai hyperparameter tuning (#17790)``
`87769db98f <https://github.com/apache/airflow/commit/87769db98f963338855f59cfc440aacf68e008c9>`__  2021-08-27   ``Allow omission of 'initial_node_count' if 'node_pools' is specified (#17820)``
`bcc7665684 <https://github.com/apache/airflow/commit/bcc76656844be47f923527c0a6cd1de546655cb4>`__  2021-08-23   ``Improve discoverability of Provider packages' functionality``
`be75dcd39c <https://github.com/apache/airflow/commit/be75dcd39cd10264048c86e74110365bd5daf8b7>`__  2021-08-23   ``Update description about the new ''connection-types'' provider meta-data``
`d04aa13526 <https://github.com/apache/airflow/commit/d04aa135268b8e0230be3af6598a3b18e8614c3c>`__  2021-08-20   ``[Airflow 13779] use provided parameters in the wait_for_pipeline_state hook (#17137)``
`76ed2a49c6 <https://github.com/apache/airflow/commit/76ed2a49c6cd285bf59706cf04f39a7444c382c9>`__  2021-08-19   ``Import Hooks lazily individually in providers manager (#17682)``
`b68d1935f9 <https://github.com/apache/airflow/commit/b68d1935f958a480f1e7d8dc1e3415707a14646b>`__  2021-08-19   ``Add error check for config_file parameter in GKEStartPodOperator (#17700)``
`29aab6434f <https://github.com/apache/airflow/commit/29aab6434ffe0fb8c83b6fd6c9e44310966d496a>`__  2021-08-17   ``Adds secrets backend/logging/auth information to provider yaml (#17625)``
`b06d528603 <https://github.com/apache/airflow/commit/b06d52860327cc0a52bcfc4f2305344b3f7c2b1d>`__  2021-08-11   ``Don't cache Google Secret Manager client (#17539)``
`82bda99eed <https://github.com/apache/airflow/commit/82bda99eed8f4846cc4d96cce55baae0ecc784c6>`__  2021-08-05   ``Fix Google Cloud Operators docs (#17440)``
`67cbb0f181 <https://github.com/apache/airflow/commit/67cbb0f181f806edb16ca12fb7a2638b5f31eb58>`__  2021-08-02   ``Enable specifying dictionary paths in 'template_fields_renderers' (#17321)``
`c384f9b0f5 <https://github.com/apache/airflow/commit/c384f9b0f509bab704a70380465be18754800a52>`__  2021-07-29   ``GCP Secret Manager error handling for missing credentials (#17264)``
==================================================================================================  ===========  =========================================================================================================================

5.0.0
.....

Latest change: 2021-07-26

==================================================================================================  ===========  =======================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =======================================================================================
`87f408b1e7 <https://github.com/apache/airflow/commit/87f408b1e78968580c760acb275ae5bb042161db>`__  2021-07-26   ``Prepares docs for Rc2 release of July providers (#17116)``
`448e50bd23 <https://github.com/apache/airflow/commit/448e50bd23b4493980a41a5d4241ad3ecef087fb>`__  2021-07-26   ``Updating Google Cloud example DAGs to use XComArgs (#16875)``
`aaf44ccace <https://github.com/apache/airflow/commit/aaf44ccace2336d00240e7e093094a9b808402d9>`__  2021-07-26   ``Updating miscellaneous Google example DAGs to use XComArgs (#16876)``
`d01cc945dd <https://github.com/apache/airflow/commit/d01cc945ddb03620216159335729a36c1a20f9f2>`__  2021-07-26   ``Fixes several failing tests after broken main (#17222)``
`babc4250f3 <https://github.com/apache/airflow/commit/babc4250f3c5420e8d8059d500ba8d0e95d70873>`__  2021-07-26   ``Fixes statich check failures (#17218)``
`5d2224795b <https://github.com/apache/airflow/commit/5d2224795b3548516311025d5549094a9b168f3b>`__  2021-07-25   ``Google Ads Hook: Support newer versions of the google-ads library (#17160)``
`966b250199 <https://github.com/apache/airflow/commit/966b2501995279b7b5f2e1d0bf1c63a511dd382e>`__  2021-07-25   ``Fix GCStoGCS operator with replace diabled and existing destination object (#16991)``
`763919d415 <https://github.com/apache/airflow/commit/763919d4152ffa13433e2489fec85ed286b7b196>`__  2021-07-25   ``Adding custom Salesforce connection type + SalesforceToS3Operator updates (#17162)``
`81bd40933e <https://github.com/apache/airflow/commit/81bd40933ea85a0d7807cf7f9a841157ec885cdf>`__  2021-07-23   ``[CASSANDRA-16814] Fix cassandra to gcs type inconsistency. (#17183)``
`026ffe65d4 <https://github.com/apache/airflow/commit/026ffe65d4738674512f691a56b922e82d0a2309>`__  2021-07-19   ``fix: dataprocpysparkjob project_id as self.project_id (#17075)``
`d02ded65ea <https://github.com/apache/airflow/commit/d02ded65eaa7d2281e249b3fa028605d1b4c52fb>`__  2021-07-15   ``Fixed wrongly escaped characters in amazon's changelog (#17020)``
`b916b75079 <https://github.com/apache/airflow/commit/b916b7507921129dc48d6add1bdc4b923b60c9b9>`__  2021-07-15   ``Prepare documentation for July release of providers. (#17015)``
`d14a000571 <https://github.com/apache/airflow/commit/d14a0005713d8a601674c83ee8119c3f5c836e0a>`__  2021-07-14   ``Remove extra forward slash in stackdriver address. (#16990)``
`a3f5c93806 <https://github.com/apache/airflow/commit/a3f5c93806258b5ad396a638ba0169eca7f9d065>`__  2021-07-13   ``Update alias for field_mask in Google Memmcache (#16975)``
`b0f7f91fe2 <https://github.com/apache/airflow/commit/b0f7f91fe29d1314b71c76de0f11d2dbe81c5c4a>`__  2021-07-07   ``Standardise dataproc location param to region (#16034)``
`866a601b76 <https://github.com/apache/airflow/commit/866a601b76e219b3c043e1dbbc8fb22300866351>`__  2021-06-28   ``Removes pylint from our toolchain (#16682)``
==================================================================================================  ===========  =======================================================================================

4.0.0
.....

Latest change: 2021-06-18

==================================================================================================  ===========  =========================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =========================================================================================
`bbc627a3da <https://github.com/apache/airflow/commit/bbc627a3dab17ba4cf920dd1a26dbed6f5cebfd1>`__  2021-06-18   ``Prepares documentation for rc2 release of Providers (#16501)``
`cbf8001d76 <https://github.com/apache/airflow/commit/cbf8001d7630530773f623a786f9eb319783b33c>`__  2021-06-16   ``Synchronizes updated changelog after buggfix release (#16464)``
`8a9c337838 <https://github.com/apache/airflow/commit/8a9c3378385454f16560d82e885ebc00c5ec069c>`__  2021-06-15   ``Remove class references in changelogs (#16454)``
`1fba5402bb <https://github.com/apache/airflow/commit/1fba5402bb14b3ffa6429fdc683121935f88472f>`__  2021-06-15   ``More documentation update for June providers release (#16405)``
`3c5cc42e13 <https://github.com/apache/airflow/commit/3c5cc42e13322e9b2bc35be73bd04a8d59aa2447>`__  2021-06-14   ``Fix deprecation warnings location in google provider (#16403)``
`b272f9cec9 <https://github.com/apache/airflow/commit/b272f9cec99fd0e3373d23b706f33892cbcb9626>`__  2021-06-13   ``fix: ensure datetime-related values fully compatible with MySQL and BigQuery (#15026)``
`7f8f75eb80 <https://github.com/apache/airflow/commit/7f8f75eb80790d4be3167f5e1ffccc669a281d55>`__  2021-06-12   ``Add BigQueryToMsSqlOperator (#15422)``
`0c80a7d411 <https://github.com/apache/airflow/commit/0c80a7d41100bf8d18b661c8286d6056e6d5d2f1>`__  2021-06-11   ``Fixes AzureFileShare connection extras (#16388)``
`9c94b72d44 <https://github.com/apache/airflow/commit/9c94b72d440b18a9e42123d20d48b951712038f9>`__  2021-06-07   ``Updated documentation for June 2021 provider release (#16294)``
`1e647029e4 <https://github.com/apache/airflow/commit/1e647029e469c1bb17e9ad051d0184f3357644c3>`__  2021-06-01   ``Rename the main branch of the Airflow repo to be 'main' (#16149)``
`99d1535287 <https://github.com/apache/airflow/commit/99d1535287df7f8cfced39baff7a08f6fcfdf8ca>`__  2021-05-31   ``Fix: GCS To BigQuery source_object (#16160)``
`e1137523d4 <https://github.com/apache/airflow/commit/e1137523d4e9cb5d5cfe8584963620677a4ad789>`__  2021-05-30   ``Fix: Unnecessary downloads in ''GCSToLocalFilesystemOperator'' (#16171)``
`904709d34f <https://github.com/apache/airflow/commit/904709d34fbe0b6062d72932b72954afe13ec148>`__  2021-05-27   ``Check synctatic correctness for code-snippets (#16005)``
`86768859c6 <https://github.com/apache/airflow/commit/86768859c689bf02ced96e71996a3a30da1b5888>`__  2021-05-26   ``Fix bigquery type error when export format is parquet (#16027)``
`6ae9aeec3f <https://github.com/apache/airflow/commit/6ae9aeec3f866ecfce83945ad1e831be9f8e5ebb>`__  2021-05-26   ``pass wait_for_done parameter down to _DataflowJobsController (#15541)``
`476d0f6e3d <https://github.com/apache/airflow/commit/476d0f6e3d2059f56532cda36cdc51aa86bafb37>`__  2021-05-22   ``Bump pyupgrade v2.13.0 to v2.18.1 (#15991)``
`aa4713e43f <https://github.com/apache/airflow/commit/aa4713e43f92d3e4c68c3ad00e2d44caaf29aafe>`__  2021-05-21   ``Use api version only in GoogleAdsHook not operators (#15266)``
`76a80bb17c <https://github.com/apache/airflow/commit/76a80bb17c9cecbe3767dab471f6a79084c822ea>`__  2021-05-19   ``Move plyvel to google provider extra (#15812)``
`bb115da0b7 <https://github.com/apache/airflow/commit/bb115da0b78036ace5e31e2139c12ca044b3a97d>`__  2021-05-17   ``Get rid of requests as core dependency (#15781)``
`9c8391a13f <https://github.com/apache/airflow/commit/9c8391a13f6ba29749675cf23f2f874f96b0cc8c>`__  2021-05-10   ``Fix spelling (#15699)``
`3711a29e5e <https://github.com/apache/airflow/commit/3711a29e5e253ede4ab12efe5990e83240e8a9a9>`__  2021-05-09   ``Fix argument ordering and type of bucket and object (#15738)``
`a01567c471 <https://github.com/apache/airflow/commit/a01567c47159da8c2824ac5f15629b51f49af958>`__  2021-05-08   ``Fix sql_to_gcs docstring lint error (#15730)``
`f3fada9101 <https://github.com/apache/airflow/commit/f3fada91013f7916b188ceceb0284bc9860d1388>`__  2021-05-07   ``Add short description to BaseSQLToGCSOperator docstring (#15728)``
`37681bca00 <https://github.com/apache/airflow/commit/37681bca0081dd228ac4047c17631867bba7a66f>`__  2021-05-07   ``Auto-apply apply_default decorator (#15667)``
`b8c0fde38a <https://github.com/apache/airflow/commit/b8c0fde38a7df9d00185bf53e9f303b98fd064dc>`__  2021-05-07   ``Add extra links for google dataproc (#10343)``
`b9f6e9c28c <https://github.com/apache/airflow/commit/b9f6e9c28c5297c60d48f75335e2861cc7d1172e>`__  2021-05-07   ``Fixes syntax of terraform script. (#15710)``
`3b4fdd0a7a <https://github.com/apache/airflow/commit/3b4fdd0a7a176bfb2e9a17d4627b1d4ed40f1c86>`__  2021-05-06   ``add oracle  connection link (#15632)``
`cf6324e43b <https://github.com/apache/airflow/commit/cf6324e43b2f7c183c3872704733b69d1498cda1>`__  2021-05-04   ``Implement BigQuery Table Schema Update Operator (#15367)``
`0f97a3970d <https://github.com/apache/airflow/commit/0f97a3970d2c652beedbf2fbaa33e2b2bfd69bce>`__  2021-05-04   ``Rename example bucket names to use INVALID BUCKET NAME by default (#15651)``
==================================================================================================  ===========  =========================================================================================

3.0.0
.....

Latest change: 2021-05-01

==================================================================================================  ===========  ====================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================================
`807ad32ce5 <https://github.com/apache/airflow/commit/807ad32ce59e001cb3532d98a05fa7d0d7fabb95>`__  2021-05-01   ``Prepares provider release after PIP 21 compatibility (#15576)``
`df143aee8d <https://github.com/apache/airflow/commit/df143aee8d9e7e0089b747bdd27addf63bb4962f>`__  2021-04-29   ``An initial rework of the "Concepts" docs (#15444)``
`814e471d13 <https://github.com/apache/airflow/commit/814e471d137aad68bd64a21d20736e7b88403f97>`__  2021-04-29   ``Update pre-commit checks (#15583)``
`bf2b48174a <https://github.com/apache/airflow/commit/bf2b48174a1ccfe398eefba7f04a5cacac421266>`__  2021-04-27   ``Add Connection Documentation for Providers (#15499)``
`4b031d39e1 <https://github.com/apache/airflow/commit/4b031d39e12110f337151cda6693e2541bf71c2c>`__  2021-04-27   ``Make Airflow code Pylint 2.8 compatible (#15534)``
`e229f3541d <https://github.com/apache/airflow/commit/e229f3541dd764db54785625875a7c5e94225736>`__  2021-04-27   ``Use Pip 21.* to install airflow officially (#15513)``
`71c673e427 <https://github.com/apache/airflow/commit/71c673e427a89cae2a9f3174c32c5c85556d6342>`__  2021-04-22   ``Update Docstrings of Modules with Missing Params (#15391)``
`3b9a91806e <https://github.com/apache/airflow/commit/3b9a91806ea102cc2bc00b545f63f57031f458c9>`__  2021-04-22   ``Bugfix: Fix rendering of ''object_name'' in ''GCSToLocalFilesystemOperator'' (#15487)``
`a17db78830 <https://github.com/apache/airflow/commit/a17db7883044889b2b2001cefc41a8960359a23f>`__  2021-04-22   ``Fix the operator name - LocalFileSystemToGCSOperator (#15478)``
`c5e302030d <https://github.com/apache/airflow/commit/c5e302030de7512a07120f71f388ad1859b26ca2>`__  2021-04-21   ``Fix typo in DataprocCreateClusterOperator (#15462)``
`42a1ca8aab <https://github.com/apache/airflow/commit/42a1ca8aab905a0eb1ffb3da30cef9c76830abff>`__  2021-04-20   ``Fixes wrongly specified path for leveldb hook (#15453)``
`6da36bad2c <https://github.com/apache/airflow/commit/6da36bad2c5c86628284d91ad6de418bae7cd029>`__  2021-04-18   ``[Airflow-15245] - passing custom image family name to the DataProcClusterCreateoperator (#15250)``
`f649905606 <https://github.com/apache/airflow/commit/f6499056069fd2331b121144e67f6c6e95d7ca5b>`__  2021-04-15   ``fix docstring typos (#15392)``
`cb9b9b3e3f <https://github.com/apache/airflow/commit/cb9b9b3e3fa448298978d456da66105b3cbddccf>`__  2021-04-12   ``Fix 'sendgrid' -> 'google'. (#15334)``
`7bf69edca0 <https://github.com/apache/airflow/commit/7bf69edca0d0622deb171f5a16af754dbcd04ce2>`__  2021-04-08   ``Fix typo in a docstring (#15276)``
`b62ca0ad5d <https://github.com/apache/airflow/commit/b62ca0ad5d8550a72257ce59c8946e7f134ed70b>`__  2021-04-07   ``Docs: Fix name of setting to use internal IP (#15251)``
==================================================================================================  ===========  ====================================================================================================

2.2.0
.....

Latest change: 2021-04-07

==================================================================================================  ===========  ====================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ====================================================================================
`4e018a870c <https://github.com/apache/airflow/commit/4e018a870ccdece6b0985db0c8ae68d10ae1d055>`__  2021-04-07   ``Refreshed provider's upcoming release with k8s retries (#15239)``
`042be2e4e0 <https://github.com/apache/airflow/commit/042be2e4e06b988f5ba2dc146f53774dabc8b76b>`__  2021-04-06   ``Updated documentation for provider packages before April release (#15236)``
`eae22cec9c <https://github.com/apache/airflow/commit/eae22cec9c87e8dad4d6e8599e45af1bdd452062>`__  2021-04-06   ``Adds 'Trino' provider (with lower memory footprint for tests) (#15187)``
`e49722859b <https://github.com/apache/airflow/commit/e49722859b81cfcdd7e4bb8e8aba4efb049a8590>`__  2021-04-05   ``Updates 3.6 limits for latest versions of a few libraries (#15209)``
`1d641d8f11 <https://github.com/apache/airflow/commit/1d641d8f114660eee18c6246081cfe991bb74baa>`__  2021-04-01   ``update remaining old import paths of operators (#15127)``
`099c490cff <https://github.com/apache/airflow/commit/099c490cffae9556e56e141addcb41e9676e0d8f>`__  2021-03-28   ``Override project in dataprocSubmitJobOperator (#14981)``
`5379698892 <https://github.com/apache/airflow/commit/53796988929d7b5de98cd322fdea9e0a8edec0a1>`__  2021-03-27   ``Improve docstrings for various modules (#15047)``
`a7ca1b3b0b <https://github.com/apache/airflow/commit/a7ca1b3b0bdf0b7677e53be1b11e833714dfbbb4>`__  2021-03-26   ``Fix Sphinx Issues with Docstrings (#14968)``
`a7e144bec8 <https://github.com/apache/airflow/commit/a7e144bec855f6ccf0fa5ae8447894195ffe170f>`__  2021-03-23   ``Google Dataflow Hook to handle no Job Type (#14914)``
`72ea841b4b <https://github.com/apache/airflow/commit/72ea841b4bb439495b0f58e043774d38f701100e>`__  2021-03-22   ``GCS to BigQuery Transfer Operator with Labels and Description parameter (#14881)``
`e172bd0e16 <https://github.com/apache/airflow/commit/e172bd0e16d5b13105734fe9eb8effc44d593c29>`__  2021-03-22   ``Update docstrings to adhere to sphinx standards (#14918)``
`68e4c4dcb0 <https://github.com/apache/airflow/commit/68e4c4dcb0416eb51a7011a3bb040f1e23d7bba8>`__  2021-03-20   ``Remove Backport Providers (#14886)``
`ddc9133d36 <https://github.com/apache/airflow/commit/ddc9133d36f88dbecd260a4f28ac2dec39395edf>`__  2021-03-15   ``Add GCS timespan transform operator (#13996)``
`943baff670 <https://github.com/apache/airflow/commit/943baff6701f9f8591090bf76219571d7f5e2cc5>`__  2021-03-10   ``Add job labels to bigquery check operators. (#14685)``
`6dc24c95e3 <https://github.com/apache/airflow/commit/6dc24c95e3bb46ac42fc80b1948aa79ae6c6fbd1>`__  2021-03-07   ``Fix grammar and remove duplicate words (#14647)``
`e7bb17aeb8 <https://github.com/apache/airflow/commit/e7bb17aeb83b2218620c5320241b0c9f902d74ff>`__  2021-03-06   ``Use built-in 'cached_property' on Python 3.8 where possible (#14606)``
`7daebefd15 <https://github.com/apache/airflow/commit/7daebefd15355b3f1331c6c58f66f3f88d38a10a>`__  2021-03-05   ``Use libyaml C library when available. (#14577)``
`35c9a90292 <https://github.com/apache/airflow/commit/35c9a902929b79cf7cf53ac5b90c3565dddb97dc>`__  2021-03-01   ``Add Google leveldb hook and operator (#13109) (#14105)``
==================================================================================================  ===========  ====================================================================================

2.1.0
.....

Latest change: 2021-02-27

==================================================================================================  ===========  ===============================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ===============================================================================================================================================
`589d6dec92 <https://github.com/apache/airflow/commit/589d6dec922565897785bcbc5ac6bb3b973d7f5d>`__  2021-02-27   ``Prepare to release the next wave of providers: (#14487)``
`50a1504c52 <https://github.com/apache/airflow/commit/50a1504c524257e53eff06589b71973cfab5bf54>`__  2021-02-27   ``Fix spellings (#14483)``
`bfef559cf6 <https://github.com/apache/airflow/commit/bfef559cf6138eec3ac77c64289fb1d45133d8be>`__  2021-02-27   ``Corrects order of argument in docstring in GCSHook.download method (#14497)``
`33214d9326 <https://github.com/apache/airflow/commit/33214d9326bb0bb52f06e230895f4f68fc952664>`__  2021-02-26   ``Refactor SQL/BigQuery/Qubole/Druid Check operators (#12677)``
`c281979982 <https://github.com/apache/airflow/commit/c281979982c36f16c4c346c996a0c8d6ca7c630d>`__  2021-02-23   ``Documentation and example dag for CloudDLPDeidentifyContentOperator, GCSObjectExistenceSensor, GCSObjectsWithPrefixExistenceSensor (#14033)``
`ca35bd7f7f <https://github.com/apache/airflow/commit/ca35bd7f7f6bc2fb4f2afd7762114ce262c61941>`__  2021-02-21   ``By default PIP will install all packages in .local folder (#14125)``
`a7e4266d67 <https://github.com/apache/airflow/commit/a7e4266d675d5283cdd34c6451c8ef0f2858a501>`__  2021-02-21   ``Refactor GoogleDriveToGCSOperator to use common methods (#14276)``
`1b82c244c0 <https://github.com/apache/airflow/commit/1b82c244c055517a5439f524018f0b9e961667d5>`__  2021-02-20   ``Docs: Corrected code example description (#14339)``
`1ab406663e <https://github.com/apache/airflow/commit/1ab406663ead7475ac14644553ac48466777bd78>`__  2021-02-16   ``Add GoogleDriveToLocalOperator (#14191)``
`59c94c679e <https://github.com/apache/airflow/commit/59c94c679e996ab7a75b4feeb1755353f60d030f>`__  2021-02-13   ``Add 'exists_ok' flag to BigQueryCreateEmptyTable(Dataset)Operator (#14026)``
`e31b27d593 <https://github.com/apache/airflow/commit/e31b27d593f7379f38ced34b6e4ce8947b91fcb8>`__  2021-02-13   ``Add materialized view support for BigQuery (#14201)``
`e3bcaa3ba3 <https://github.com/apache/airflow/commit/e3bcaa3ba351234effe52ad380345c4e39003fcb>`__  2021-02-12   ``Correct typo in GCSObjectsWtihPrefixExistenceSensor  (#14179)``
`7faa2d978c <https://github.com/apache/airflow/commit/7faa2d978c3a4e1eb2f7c6a931c9475712015f9f>`__  2021-02-10   ``Add BigQueryUpdateTableOperator (#14149)``
`1da6972165 <https://github.com/apache/airflow/commit/1da69721651455c9108c00ca5f6723d6557524a9>`__  2021-02-10   ``Fixes to dataproc operators and hook (#14086)``
`02288cf2ba <https://github.com/apache/airflow/commit/02288cf2baf590e448cd008f6216ccf8b776a67a>`__  2021-02-10   ``Add param to CloudDataTransferServiceOperator (#14118)``
`ebd39ca486 <https://github.com/apache/airflow/commit/ebd39ca486f9cf0386a18a249a8246059f58d613>`__  2021-02-10   ``Fix docs for Google Cloud Secret Manager backend (#14164)``
`7d38645472 <https://github.com/apache/airflow/commit/7d38645472b0502212504b09d85b0e1271d74274>`__  2021-02-09   ``#9803 fix bug in copy operation without wildcard  (#13919)``
`b0c382426c <https://github.com/apache/airflow/commit/b0c382426c943cbf7bd7c09583d9c5d3137413ee>`__  2021-02-07   ``Add gdrive_to_gcs operator, drive sensor, additional functionality to drive hook, and supporting tests (#13982)``
`5d7d46bb33 <https://github.com/apache/airflow/commit/5d7d46bb33c1d529c1549b593ee27bbc7f56ea29>`__  2021-02-05   ``Improve GCSToSFTPOperator paths handling (#11284)``
`10343ec29f <https://github.com/apache/airflow/commit/10343ec29f8f0abc5b932ba26faf49bc63c6bcda>`__  2021-02-05   ``Corrections in docs and tools after releasing provider RCs (#14082)``
==================================================================================================  ===========  ===============================================================================================================================================

2.0.0
.....

Latest change: 2021-02-04

==================================================================================================  ===========  =========================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  =========================================================================================
`88bdcfa0df <https://github.com/apache/airflow/commit/88bdcfa0df5bcb4c489486e05826544b428c8f43>`__  2021-02-04   ``Prepare to release a new wave of providers. (#14013)``
`1872d8719d <https://github.com/apache/airflow/commit/1872d8719d24f94aeb1dcba9694837070b9884ca>`__  2021-02-03   ``Add Apache Beam operators (#12814)``
`0e8c77b93a <https://github.com/apache/airflow/commit/0e8c77b93a5ca5ecfdcd1c4bd91f54846fc15d57>`__  2021-02-03   ``Support google-cloud-logging' >=2.0.0 (#13801)``
`833e338323 <https://github.com/apache/airflow/commit/833e3383230e1f6f73f8022ddf439d3d531eff01>`__  2021-02-02   ``Fix four bugs in StackdriverTaskHandler (#13784)``
`d2efb33239 <https://github.com/apache/airflow/commit/d2efb33239d36e58fb69066fd23779724cb11a90>`__  2021-02-02   ``Support google-cloud-monitoring>=2.0.0 (#13769)``
`ac2f72c98d <https://github.com/apache/airflow/commit/ac2f72c98dc0821b33721054588adbf2bb53bb0b>`__  2021-02-01   ``Implement provider versioning tools (#13767)``
`823741cfea <https://github.com/apache/airflow/commit/823741cfea3e7a2584d1e68126db3d6e6739b08f>`__  2021-01-28   ``Improve GCS system test envs (#13946)``
`6d6588fe2b <https://github.com/apache/airflow/commit/6d6588fe2b8bb5fa33e930646d963df3e0530f23>`__  2021-01-28   ``Add Google Cloud Workflows Operators (#13366)``
`810c15ed85 <https://github.com/apache/airflow/commit/810c15ed85d7bcde8d5b8bc44e1cbd4859e29d2e>`__  2021-01-27   ``Fix and improve GCP BigTable hook and system test (#13896)``
`6616617331 <https://github.com/apache/airflow/commit/6616617331bf6e8548bf6391cebb636220c1cc53>`__  2021-01-27   ``Add env variables to PubSub example dag (#13794)``
`f473ca7130 <https://github.com/apache/airflow/commit/f473ca7130f844bc59477674e641b42b80698bb7>`__  2021-01-24   ``Replace 'google_cloud_storage_conn_id' by 'gcp_conn_id' when using 'GCSHook' (#13851)``
`a9ac2b040b <https://github.com/apache/airflow/commit/a9ac2b040b64de1aa5d9c2b9def33334e36a8d22>`__  2021-01-23   ``Switch to f-strings using flynt. (#13732)``
`9592be88e5 <https://github.com/apache/airflow/commit/9592be88e57cc7f59b9eac978292abd4d7692c0b>`__  2021-01-22   ``Fix Google Spanner example dag (#13842)``
`af52fdb511 <https://github.com/apache/airflow/commit/af52fdb51152a72441a44a271e498b1ec20dfd57>`__  2021-01-22   ``Improve environment variables in GCP Dataflow system test (#13841)``
`e7946f1cb7 <https://github.com/apache/airflow/commit/e7946f1cb7c144181443cbcc843d90bd597b09b5>`__  2021-01-22   ``Improve environment variables in GCP Datafusion system test (#13837)``
`61c1d6ec6c <https://github.com/apache/airflow/commit/61c1d6ec6ce638f8ccd76705f69e9474c308389a>`__  2021-01-22   ``Improve environment variables in GCP Memorystore system test (#13833)``
`202f66093a <https://github.com/apache/airflow/commit/202f66093ad12c293f97204b0775bef2b077cd9a>`__  2021-01-22   ``Improve environment variables in GCP Lifeciences system test (#13834)``
`70bf307f38 <https://github.com/apache/airflow/commit/70bf307f3894214c523701940b89ac0b991a3a63>`__  2021-01-21   ``Add How To Guide for Dataflow (#13461)``
`3fd5ef3555 <https://github.com/apache/airflow/commit/3fd5ef355556cf0ad7896bb570bbe4b2eabbf46e>`__  2021-01-21   ``Add missing logos for integrations (#13717)``
`309788e5e2 <https://github.com/apache/airflow/commit/309788e5e2023c598095a4ee00df417d94b6a5df>`__  2021-01-18   ``Refactor DataprocOperators to support google-cloud-dataproc 2.0 (#13256)``
`7ec858c452 <https://github.com/apache/airflow/commit/7ec858c4523b24e7a3d6dd1d49e3813e6eee7dff>`__  2021-01-17   ``updated Google DV360 Hook to fix SDF issue (#13703)``
`ef8617ec9d <https://github.com/apache/airflow/commit/ef8617ec9d6e4b7c433a29bd388f5102a7a17c11>`__  2021-01-14   ``Support google-cloud-tasks>=2.0.0 (#13347)``
`189af54043 <https://github.com/apache/airflow/commit/189af54043a6aa6e7557bda6cf7cfca229d0efd2>`__  2021-01-13   ``Add system tests for Stackdriver operators (#13644)``
`a6f999b62e <https://github.com/apache/airflow/commit/a6f999b62e3c9aeb10ab24342674d3670a8ad259>`__  2021-01-11   ``Support google-cloud-automl >=2.1.0 (#13505)``
`947dbb73bb <https://github.com/apache/airflow/commit/947dbb73bba736eb146f33117545a18fc2fd3c09>`__  2021-01-11   ``Support google-cloud-datacatalog>=3.0.0 (#13534)``
`2fb68342b0 <https://github.com/apache/airflow/commit/2fb68342b01da4cb5d79ac9e5c0f7687d74351f3>`__  2021-01-07   ``Replace deprecated module and operator in example_tasks.py (#13527)``
`003584bbf1 <https://github.com/apache/airflow/commit/003584bbf1d66a3545ad6e6fcdceb0410fc83696>`__  2021-01-05   ``Fix failing backport packages test (#13497)``
`7d1ea4cb10 <https://github.com/apache/airflow/commit/7d1ea4cb102e7d9878eeeaab5b098ae7767b844b>`__  2021-01-05   ``Replace deprecated module and operator in example_tasks.py (#13473)``
`c7d75ad887 <https://github.com/apache/airflow/commit/c7d75ad887cd12d5603563c5fa873c0e2f8975aa>`__  2021-01-05   ``Revert "Support google-cloud-datacatalog 3.0.0 (#13224)" (#13482)``
`feb84057d3 <https://github.com/apache/airflow/commit/feb84057d34b2f64e3b5dcbaae2d3b18f5f564e4>`__  2021-01-04   ``Support google-cloud-datacatalog 3.0.0 (#13224)``
`3a3e739981 <https://github.com/apache/airflow/commit/3a3e7399810fd399d08f136e6936743c16508fc6>`__  2021-01-04   ``Fix insert_all method of BigQueryHook to support tables without schema (#13138)``
`c33d2c06b6 <https://github.com/apache/airflow/commit/c33d2c06b68c8b9a5a36c965ab8be540a2dca967>`__  2021-01-02   ``Fix another pylint c-extension-no-member (#13438)``
`f6518dd6a1 <https://github.com/apache/airflow/commit/f6518dd6a1217d906d863fe13dc37916efd78b3e>`__  2021-01-02   ``Generalize MLEngineStartTrainingJobOperator to custom images (#13318)``
`9de7127083 <https://github.com/apache/airflow/commit/9de71270838ad3cc59043f1ab0bb6ca97af13622>`__  2020-12-31   ``Support google-cloud-bigquery-datatransfer>=3.0.0 (#13337)``
`406181d64a <https://github.com/apache/airflow/commit/406181d64ac32d133523ca52f954bc50a07defc4>`__  2020-12-31   ``Add Parquet data type to BaseSQLToGCSOperator (#13359)``
`295d66f914 <https://github.com/apache/airflow/commit/295d66f91446a69610576d040ba687b38f1c5d0a>`__  2020-12-30   ``Fix Grammar in PIP warning (#13380)``
`13a9747bf1 <https://github.com/apache/airflow/commit/13a9747bf1d92020caa5d4dc825e096ce583f2df>`__  2020-12-28   ``Revert "Support google-cloud-tasks>=2.0.0 (#13334)" (#13341)``
`04ec45f045 <https://github.com/apache/airflow/commit/04ec45f045419ec87432ee285ac0828ab68008c3>`__  2020-12-28   ``Add DataprocCreateWorkflowTemplateOperator (#13338)``
`1f712219fa <https://github.com/apache/airflow/commit/1f712219fa8971d98bc486896603ce8109c42844>`__  2020-12-28   ``Support google-cloud-tasks>=2.0.0 (#13334)``
`f4745c8ce1 <https://github.com/apache/airflow/commit/f4745c8ce1955c28676b5afe129a88a61aa743b9>`__  2020-12-26   ``Fix typo in example (#13321)``
`e9d65bd458 <https://github.com/apache/airflow/commit/e9d65bd4582b083914f2fc1213bea44cf41d1a08>`__  2020-12-24   ``Decode Remote Google Logs (#13115)``
`e7aeacf335 <https://github.com/apache/airflow/commit/e7aeacf335d373007a32ac65680ba6b5b19f5c9f>`__  2020-12-24   ``Add OracleToGCS Transfer (#13246)``
`323084e97d <https://github.com/apache/airflow/commit/323084e97ddacbc5512709bf0cad8f53082d16b0>`__  2020-12-24   ``Add timeout option to gcs hook methods. (#13156)``
`0b626c8042 <https://github.com/apache/airflow/commit/0b626c8042b304a52d6c481fa6eb689d655f33d3>`__  2020-12-22   ``Support google-cloud-redis>=2.0.0 (#13117)``
`9042a58553 <https://github.com/apache/airflow/commit/9042a585539a18953d688fff455438f4061732d1>`__  2020-12-22   ``Add more operators to example DAGs for Cloud Tasks (#13235)``
`8c00ec89b9 <https://github.com/apache/airflow/commit/8c00ec89b97aa6e725379d08c8ff29a01be47e73>`__  2020-12-22   ``Support google-cloud-pubsub>=2.0.0 (#13127)``
`b26b0df5b0 <https://github.com/apache/airflow/commit/b26b0df5b03c4cd826fd7b2dff5771d64e18e6b7>`__  2020-12-22   ``Update compatibility with google-cloud-kms>=2.0 (#13124)``
`9a1d3820d6 <https://github.com/apache/airflow/commit/9a1d3820d6f1373df790da8751f25e723f9ce037>`__  2020-12-22   ``Support google-cloud-datacatalog>=1.0.0 (#13097)``
`f95b1c9c95 <https://github.com/apache/airflow/commit/f95b1c9c95c059e85ad5676daaa191929785fee2>`__  2020-12-21   ``Add regional support to dataproc workflow template operators (#12907)``
`6cf76d7ac0 <https://github.com/apache/airflow/commit/6cf76d7ac01270930de7f105fb26428763ee1d4e>`__  2020-12-18   ``Fix typo in pip upgrade command :( (#13148)``
`23f27c1b1c <https://github.com/apache/airflow/commit/23f27c1b1cdbcb6bb50fd2aa772aeda7151d5634>`__  2020-12-18   ``Add system tests for CloudKMSHook (#13122)``
`cddbf81b12 <https://github.com/apache/airflow/commit/cddbf81b12650ee5905b0f762c1213caa1d3a7ed>`__  2020-12-17   ``Fix Google BigQueryHook method get_schema() (#13136)``
`1259c712a4 <https://github.com/apache/airflow/commit/1259c712a42d69135dc389de88f79942c70079a3>`__  2020-12-17   ``Update compatibility with google-cloud-os-login>=2.0.0 (#13126)``
`bcf77586ef <https://github.com/apache/airflow/commit/bcf77586eff9907fa057cf2633115d5ab3e4142b>`__  2020-12-16   ``Fix Data Catalog operators (#13096)``
`f6448b4e48 <https://github.com/apache/airflow/commit/f6448b4e482fd96339ae65c26d08e6a2bdb51aaf>`__  2020-12-15   ``Add link to PyPI Repository to provider docs (#13064)``
`5090fb0c89 <https://github.com/apache/airflow/commit/5090fb0c8967d2d8719c6f4a468f2151395b5444>`__  2020-12-15   ``Add script to generate integrations.json (#13073)``
`b4b9cf5597 <https://github.com/apache/airflow/commit/b4b9cf55970ca41fa7852ab8d25e59f4c379f8c2>`__  2020-12-14   ``Check for missing references to operator guides (#13059)``
`1c1ef7ee69 <https://github.com/apache/airflow/commit/1c1ef7ee693fead93e269dfd9774a72b6eed2e85>`__  2020-12-14   ``Add project_id to client inside BigQuery hook update_table method (#13018)``
==================================================================================================  ===========  =========================================================================================

1.0.0
.....

Latest change: 2020-12-09

==================================================================================================  ===========  ======================================================================================================================================================================
Commit                                                                                              Committed    Subject
==================================================================================================  ===========  ======================================================================================================================================================================
`32971a1a2d <https://github.com/apache/airflow/commit/32971a1a2de1db0b4f7442ed26facdf8d3b7a36f>`__  2020-12-09   ``Updates providers versions to 1.0.0 (#12955)``
`b40dffa085 <https://github.com/apache/airflow/commit/b40dffa08547b610162f8cacfa75847f3c4ca364>`__  2020-12-08   ``Rename remaing modules to match AIP-21 (#12917)``
`9b39f24780 <https://github.com/apache/airflow/commit/9b39f24780e85f859236672e9060b2fbeee81b36>`__  2020-12-08   ``Add support for dynamic connection form fields per provider (#12558)``
`23e743ec09 <https://github.com/apache/airflow/commit/23e743ec09bffe30a9a2b17cc873af5ef9d3cd9f>`__  2020-12-07   ``Move task handlers guides to provider docs (#12826)``
`1257b5c6aa <https://github.com/apache/airflow/commit/1257b5c6aa84d6e6173bf1dc3e3bbb1d3fef1320>`__  2020-12-06   ``Fix doc preview error in editor for google operators doc (#10962)``
`1dcd3e13fd <https://github.com/apache/airflow/commit/1dcd3e13fd0a078fc9440e91b77f6f87aa60dd3b>`__  2020-12-05   ``Add support for extra links coming from the providers (#12472)``
`2037303eef <https://github.com/apache/airflow/commit/2037303eef93fd36ab13746b045d1c1fee6aa143>`__  2020-11-29   ``Adds support for Connection/Hook discovery from providers (#12466)``
`02d94349be <https://github.com/apache/airflow/commit/02d94349be3d201ce9d37d7358573c937fd010df>`__  2020-11-29   ``Don't use time.time() or timezone.utcnow() for duration calculations (#12353)``
`76bcd08dca <https://github.com/apache/airflow/commit/76bcd08dcae8d62307f5e9b8c2e182b54ed22a27>`__  2020-11-28   ``Added '@apply_defaults' decorator. (#12620)``
`de3b1e687b <https://github.com/apache/airflow/commit/de3b1e687b26c524c6909b7b4dfbb60d25019751>`__  2020-11-28   ``Move connection guides to provider documentation packages (#12653)``
`e1ebfa68b1 <https://github.com/apache/airflow/commit/e1ebfa68b109b5993c47891cfd0b9b7e46b6d770>`__  2020-11-27   ``Add DataflowJobMessagesSensor and DataflowAutoscalingEventsSensor (#12249)``
`3fa51f94d7 <https://github.com/apache/airflow/commit/3fa51f94d7a17f170ddc31908d36c91f4456a20b>`__  2020-11-24   ``Add check for duplicates in provider.yaml files (#12578)``
`f2569de7d1 <https://github.com/apache/airflow/commit/f2569de7d1a7b100774f397a641e977c307cbb91>`__  2020-11-22   ``Add example DAGs to provider docs (#12528)``
`c34ef853c8 <https://github.com/apache/airflow/commit/c34ef853c890e08f5468183c03dc8f3f3ce84af2>`__  2020-11-20   ``Separate out documentation building per provider  (#12444)``
`9e3b2c554d <https://github.com/apache/airflow/commit/9e3b2c554dadf58972198e4e16f15af2f15ec37a>`__  2020-11-19   ``GCP Secrets Optional Lookup (#12360)``
`0080354502 <https://github.com/apache/airflow/commit/00803545023b096b8db4fbd6eb473843096d7ce4>`__  2020-11-18   ``Update provider READMEs for 1.0.0b2 batch release (#12449)``
`7ca0b6f121 <https://github.com/apache/airflow/commit/7ca0b6f121c9cec6e25de130f86a56d7c7fbe38c>`__  2020-11-18   ``Enable Markdownlint rule MD003/heading-style/header-style (#12427) (#12438)``
`8d09506464 <https://github.com/apache/airflow/commit/8d09506464c8480fa42e8bfe6a36c6f631cd23f6>`__  2020-11-18   ``Fix download method in GCSToBigQueryOperator (#12442)``
`2c0920fba5 <https://github.com/apache/airflow/commit/2c0920fba5d2f05d2e29cead91127686af277ec2>`__  2020-11-17   ``Adds mechanism for provider package discovery. (#12383)``
`2cda2f2a0a <https://github.com/apache/airflow/commit/2cda2f2a0a94e5aaed87f0998fa57b4f8bff5e43>`__  2020-11-17   ``Add missing pre-commit definition - provider-yamls (#12393)``
`80a957f142 <https://github.com/apache/airflow/commit/80a957f142f260daed262b8e93a4d02c12cfeabc>`__  2020-11-17   ``Add Dataflow sensors - job metrics (#12039)``
`ae7cb4a1e2 <https://github.com/apache/airflow/commit/ae7cb4a1e2a96351f1976cf5832615e24863e05d>`__  2020-11-17   ``Update wrong commit hash in backport provider changes (#12390)``
`917e6c4424 <https://github.com/apache/airflow/commit/917e6c4424985271c53dd8c413b211896ee55726>`__  2020-11-16   ``Add provide_file_and_upload to GCSHook (#12310)``
`cfa4ecfeb0 <https://github.com/apache/airflow/commit/cfa4ecfeb02661f40b4778733384ac085fb5f04b>`__  2020-11-15   ``Add DataflowJobStatusSensor and support non-blocking execution of jobs (#11726)``
`6889a333cf <https://github.com/apache/airflow/commit/6889a333cff001727eb0a66e375544a28c9a5f03>`__  2020-11-15   ``Improvements for operators and hooks ref docs (#12366)``
`7825e8f590 <https://github.com/apache/airflow/commit/7825e8f59034645ab3247229be83a3aa90baece1>`__  2020-11-13   ``Docs installation improvements (#12304)``
`32b59f8350 <https://github.com/apache/airflow/commit/32b59f8350f55793df6838a32de662a80483ecda>`__  2020-11-12   ``Fixes the sending of an empty list to BigQuery 'list_rows' (#12307)``
`250436d962 <https://github.com/apache/airflow/commit/250436d962c8c950d38c1eb5e54a998891648cc9>`__  2020-11-10   ``Fix spelling in Python files (#12230)``
`502ba309ea <https://github.com/apache/airflow/commit/502ba309ea470943f0e99c634269e3d2d13ce6ca>`__  2020-11-10   ``Enable Markdownlint rule - MD022/blanks-around-headings (#12225)``
`dd2095f4a8 <https://github.com/apache/airflow/commit/dd2095f4a8b07c9b1a4c279a3578cd1e23b71a1b>`__  2020-11-10   ``Simplify string expressions & Use f-string (#12216)``
`f37c6e6fce <https://github.com/apache/airflow/commit/f37c6e6fce8b704f5af28caa16d0ed7d873a0e4a>`__  2020-11-10   ``Add Compute Engine SSH hook (#9879)``
`85a18e13d9 <https://github.com/apache/airflow/commit/85a18e13d9dec84275283ff69e34704b60d54a75>`__  2020-11-09   ``Point at pypi project pages for cross-dependency of provider packages (#12212)``
`59eb5de78c <https://github.com/apache/airflow/commit/59eb5de78c70ee9c7ae6e4cba5c7a2babb8103ca>`__  2020-11-09   ``Update provider READMEs for up-coming 1.0.0beta1 releases (#12206)``
`61feb6ec45 <https://github.com/apache/airflow/commit/61feb6ec453f8dda1a0e1fe3ebcc0f1e3224b634>`__  2020-11-09   ``Provider's readmes generated for elasticsearch and google packages (#12194)``
`b2a28d1590 <https://github.com/apache/airflow/commit/b2a28d1590410630d66966aa1f2b2a049a8c3b32>`__  2020-11-09   ``Moves provider packages scripts to dev (#12082)``
`fcb6b00efe <https://github.com/apache/airflow/commit/fcb6b00efef80c81272a30cfc618202a29e0c6a9>`__  2020-11-08   ``Add authentication to AWS with Google credentials (#12079)``
`2ef3b7ef8c <https://github.com/apache/airflow/commit/2ef3b7ef8cafe3bdc8bf8db70fbc519b98576366>`__  2020-11-08   ``Fix ERROR - Object of type 'bytes' is not JSON serializable when using store_to_xcom_key parameter (#12172)``
`0caec9fd32 <https://github.com/apache/airflow/commit/0caec9fd32bee2b3036b5d7bdcb56bd6a3b9dccf>`__  2020-11-06   ``Dataflow - add waiting for successful job cancel (#11501)``
`cf9437d79f <https://github.com/apache/airflow/commit/cf9437d79f9658d1309e4bfe847fe63d52ec7b99>`__  2020-11-06   ``Simplify string expressions (#12123)``
`91a64db505 <https://github.com/apache/airflow/commit/91a64db505e50712cd53928b4f2b84aece3cc1c0>`__  2020-11-04   ``Format all files (without excepions) by black (#12091)``
`fd3db778e7 <https://github.com/apache/airflow/commit/fd3db778e715d0f164dda7ee8f672d477a323291>`__  2020-11-04   ``Add server side cursor support for postgres to GCS operator (#11793)``
`f1f1940261 <https://github.com/apache/airflow/commit/f1f1940261744b4fdb67b0b5654488494efa9c64>`__  2020-11-04   ``Add DataflowStartSQLQuery operator (#8553)``
`41bf172c1d <https://github.com/apache/airflow/commit/41bf172c1dc75099f4f9d8b3f3350b4b1f523ef9>`__  2020-11-04   ``Simplify string expressions (#12093)``
`5f5244b74d <https://github.com/apache/airflow/commit/5f5244b74df93cadbb99643cec76281460ca4411>`__  2020-11-04   ``Add template fields renderers to Biguery and Dataproc operators (#12067)``
`4e8f9cc8d0 <https://github.com/apache/airflow/commit/4e8f9cc8d02b29c325b8a5a76b4837671bdf5f68>`__  2020-11-03   ``Enable Black - Python Auto Formmatter (#9550)``
`8c42cf1b00 <https://github.com/apache/airflow/commit/8c42cf1b00c90f0d7f11b8a3a455381de8e003c5>`__  2020-11-03   ``Use PyUpgrade to use Python 3.6 features (#11447)``
`45ae145c25 <https://github.com/apache/airflow/commit/45ae145c25a19b4185c33ac0c4da920324b3987e>`__  2020-11-03   ``Log BigQuery job id in insert method of BigQueryHook (#12056)``
`e324b37a67 <https://github.com/apache/airflow/commit/e324b37a67e32c368df50604a00160d7766b5c33>`__  2020-11-03   ``Add job name and progress logs to Cloud Storage Transfer Hook (#12014)``
`6071fdd584 <https://github.com/apache/airflow/commit/6071fdd58470bb2a6c23fc16481e292b7247d0bb>`__  2020-11-02   ``Improve handling server errors in DataprocSubmitJobOperator (#11947)``
`2f703df12d <https://github.com/apache/airflow/commit/2f703df12dfd6511722ff9a82d5a569d092fccc2>`__  2020-10-30   ``Add SalesforceToGcsOperator (#10760)``
`e5713e00b3 <https://github.com/apache/airflow/commit/e5713e00b3afcba6f78006ec0e360da317858e4d>`__  2020-10-29   ``Add drain option when canceling Dataflow pipelines (#11374)``
`37eaac3c5d <https://github.com/apache/airflow/commit/37eaac3c5dc93804413c10a6ca124fd7831befc0>`__  2020-10-29   ``The PRs which are not approved run subset of tests (#11828)``
`79cb771992 <https://github.com/apache/airflow/commit/79cb771992279d40ddd9eb6b0277382313a32898>`__  2020-10-28   ``Fixing re pattern and changing to use a single character class. (#11857)``
`5a439e84eb <https://github.com/apache/airflow/commit/5a439e84eb6c0544dc6c3d6a9f4ceeb2172cd5d0>`__  2020-10-26   ``Prepare providers release 0.0.2a1 (#11855)``
`240c7d4d72 <https://github.com/apache/airflow/commit/240c7d4d72aac8f6aab98f5913e8f54c4f1372ff>`__  2020-10-26   ``Google Memcached hooks - improve protobuf messages handling (#11743)``
`8afdb6ac6a <https://github.com/apache/airflow/commit/8afdb6ac6a7997cb14806bc2734c81c00ed8da97>`__  2020-10-26   ``Fix spellings (#11825)``
`872b1566a1 <https://github.com/apache/airflow/commit/872b1566a11cb73297e657ff325161721b296574>`__  2020-10-25   ``Generated backport providers readmes/setup for 2020.10.29 (#11826)``
`6ce855af11 <https://github.com/apache/airflow/commit/6ce855af118daeaa4c249669079ab9d9aad23945>`__  2020-10-24   ``Fix spelling (#11821)``
`4830687453 <https://github.com/apache/airflow/commit/48306874538eea7cfd42358d5ebb59705204bfc4>`__  2020-10-24   ``Use Python 3 style super classes (#11806)``
`727c739afb <https://github.com/apache/airflow/commit/727c739afb565d4d394a8faedc969334cb8e738e>`__  2020-10-22   ``Improve Cloud Memorystore for Redis example (#11735)``
`1da8379c91 <https://github.com/apache/airflow/commit/1da8379c913843834353b44861c62f332a461bdf>`__  2020-10-22   ``Fix static checks after merging #10121 (#11737)``
`91503308c7 <https://github.com/apache/airflow/commit/91503308c723b186ce6f4026f2a3e2c21030f6e5>`__  2020-10-22   ``Add Google Cloud Memorystore Memcached Operators (#10121)``
`950c16d0b0 <https://github.com/apache/airflow/commit/950c16d0b0ab67bb7af11909de751029faf0313a>`__  2020-10-21   ``Retry requests in case of error in Google ML Engine Hook (#11712)``
`2bfc53b5eb <https://github.com/apache/airflow/commit/2bfc53b5eb67406d418371b74dc9bc5a07be238e>`__  2020-10-21   ``Fix doc errors in google provider files. (#11713)``
`53e6062105 <https://github.com/apache/airflow/commit/53e6062105be0ae1761a354e2055eb0779d12e73>`__  2020-10-21   ``Enforce strict rules for yamllint (#11709)``
`349b0811c3 <https://github.com/apache/airflow/commit/349b0811c3022605426ba57d30936240a7c2848a>`__  2020-10-20   ``Add D200 pydocstyle check (#11688)``
`2d854c3505 <https://github.com/apache/airflow/commit/2d854c3505ccad66e9a7d94267e51bed800433c2>`__  2020-10-19   ``Add service_account to Google ML Engine operator (#11619)``
`46a121fb7b <https://github.com/apache/airflow/commit/46a121fb7b77c0964e053b58750e2d8bc2bd0b2a>`__  2020-10-18   ``docs: Update Bigquery clustering docstrings (#11232)``
`49c58147fe <https://github.com/apache/airflow/commit/49c58147fed8a52869d0b0ecc00c102c11972ad0>`__  2020-10-18   ``Strict type checking for provider Google (#11609)``
`0823d46a7f <https://github.com/apache/airflow/commit/0823d46a7f267f2e45195a175021825367938add>`__  2020-10-16   ``Add type annotations for AWS operators and hooks (#11434)``
`3c10ca6504 <https://github.com/apache/airflow/commit/3c10ca6504be37fabff9a10caefea3fe4df31a02>`__  2020-10-16   ``Add DataflowStartFlexTemplateOperator (#8550)``
`8865d14df4 <https://github.com/apache/airflow/commit/8865d14df4d58dd5f1a4d2ff81c77469959f175a>`__  2020-10-16   ``Strict type checking for provider google cloud  (#11548)``
`16e7129719 <https://github.com/apache/airflow/commit/16e7129719f1c0940aef2a93bed81368e997a746>`__  2020-10-13   ``Added support for provider packages for Airflow 2.0 (#11487)``
`06141d6d01 <https://github.com/apache/airflow/commit/06141d6d01398115e5e54c5766a46ae5514ba2f7>`__  2020-10-12   ``Google cloud operator strict type check (#11450)``
`d305876bee <https://github.com/apache/airflow/commit/d305876bee328287ff391a29cc1cd632468cc731>`__  2020-10-12   ``Remove redundant None provided as default to dict.get() (#11448)``
`1845cd11b7 <https://github.com/apache/airflow/commit/1845cd11b77f302777ab854e84bef9c212c604a0>`__  2020-10-11   ``Strict type check for google ads and cloud hooks (#11390)``
`bd204bb91b <https://github.com/apache/airflow/commit/bd204bb91b4bc069284f9a44757c6baba8884140>`__  2020-10-11   ``Optionally set null marker in csv exports in BaseSQLToGCSOperator (#11409)``
`75071831ba <https://github.com/apache/airflow/commit/75071831baa936d292354f98aac46cd808a4b2b8>`__  2020-10-10   ``Remove redundant parentheses from Python files (#10967)``
`8baf657fc2 <https://github.com/apache/airflow/commit/8baf657fc2b21a601b99b752e4f1176bf8a934ce>`__  2020-10-09   ``Fix regression in DataflowTemplatedJobStartOperator (#11167)``
`b0fcf67559 <https://github.com/apache/airflow/commit/b0fcf675595494b306800e1a516548dc0dc671f8>`__  2020-10-07   ``Add AzureFileShareToGCSOperator (#10991)``
`47b05a87f0 <https://github.com/apache/airflow/commit/47b05a87f004dc273a4757ba49f03808a86f77e7>`__  2020-10-07   ``Improve handling of job_id in BigQuery operators (#11287)``
`0a0e1af800 <https://github.com/apache/airflow/commit/0a0e1af80038ef89974c3c8444461fe867945daa>`__  2020-10-03   ``Fix Broken Markdown links in Providers README TOC (#11249)``
`ca4238eb4d <https://github.com/apache/airflow/commit/ca4238eb4d9a2aef70eb641343f59ee706d27d13>`__  2020-10-02   ``Fixed month in backport packages to October (#11242)``
`5220e4c384 <https://github.com/apache/airflow/commit/5220e4c3848a2d2c81c266ef939709df9ce581c5>`__  2020-10-02   ``Prepare Backport release 2020.09.07 (#11238)``
`cb52fb0ae1 <https://github.com/apache/airflow/commit/cb52fb0ae1de1f1140babaed0e97299e4aaf96bf>`__  2020-09-27   ``Add example DAG and system test for MySQLToGCSOperator (#10990)``
`99accec29d <https://github.com/apache/airflow/commit/99accec29d71b0a57fd4e90151b9d4d10321be07>`__  2020-09-25   ``Fix incorrect Usage of Optional[str] & Optional[int] (#11141)``
`e3f96ce7a8 <https://github.com/apache/airflow/commit/e3f96ce7a8ac098aeef5e9930e6de6c428274d57>`__  2020-09-24   ``Fix incorrect Usage of Optional[bool] (#11138)``
`daf8f31080 <https://github.com/apache/airflow/commit/daf8f31080f06c044b4336071bd383bbbcdc6085>`__  2020-09-23   ``Add template fields renderers for better UI rendering (#11061)``
`f3e87c5030 <https://github.com/apache/airflow/commit/f3e87c503081a3085dff6c7352640d7f08beb5bc>`__  2020-09-22   ``Add D202 pydocstyle check (#11032)``
`cb979f9f21 <https://github.com/apache/airflow/commit/cb979f9f213bb3c9835a3dc924f84a07f5387378>`__  2020-09-22   ``Get Airflow configs with sensitive data from CloudSecretManagerBackend (#11024)``
`76545bb3d6 <https://github.com/apache/airflow/commit/76545bb3d6fa82ce8eae072dbc74a3b76d8fd53c>`__  2020-09-16   ``Add example dag and system test for S3ToGCSOperator (#10951)``
`22c631625f <https://github.com/apache/airflow/commit/22c631625fd68abe280528f33b7cfd7603ebf66c>`__  2020-09-16   ``Fix more docs spellings (#10965)``
`12a652f534 <https://github.com/apache/airflow/commit/12a652f5344c7f03c3d780556ca1829b235fdb2d>`__  2020-09-13   ``Fix parameter name collision in AutoMLBatchPredictOperator #10723 (#10869)``
`41a62735ed <https://github.com/apache/airflow/commit/41a62735edcebbd9c39e505280646ef5d25aa1d5>`__  2020-09-11   ``Add on_kill method to BigQueryInsertJobOperator (#10866)``
`3e91da56e8 <https://github.com/apache/airflow/commit/3e91da56e8c63a90dc859d8996a896b5d9f8cd43>`__  2020-09-11   ``fix typo in firebase/example_filestore DAG (#10875)``
`68cc7273bf <https://github.com/apache/airflow/commit/68cc7273bf0c0f562748b5f663da5c12d2cba6a7>`__  2020-09-10   ``Add on_kill method to DataprocSubmitJobOperator (#10847)``
`f920957214 <https://github.com/apache/airflow/commit/f92095721450c14605c986e165544a7bfb712a3d>`__  2020-09-10   ``Fix and remove some more typos from spelling_wordlist.txt (#10845)``
`9549274d11 <https://github.com/apache/airflow/commit/9549274d110f689a0bd709db829a4d69e274eed9>`__  2020-09-09   ``Upgrade black to 20.8b1 (#10818)``
`078bfaf60a <https://github.com/apache/airflow/commit/078bfaf60adc5aebac8c347e7f6e5339ab9b56c0>`__  2020-09-08   ``Extract missing gcs_to_local example DAG from gcs example (#10767)``
`10ce31127f <https://github.com/apache/airflow/commit/10ce31127f1ff87176158935925afce46a989917>`__  2020-09-08   ``Deprecate using global as the default region in Google Dataproc operators and hooks (#10772)``
`f14f379716 <https://github.com/apache/airflow/commit/f14f3797163cc45fdcdabfb36ee7d638f70e470d>`__  2020-09-07   ``[AIRFLOW-10672] Refactor BigQueryToGCSOperator to use new method (#10773)``
`c8ee455685 <https://github.com/apache/airflow/commit/c8ee4556851c36b3b6e644a7746a49583dd53db1>`__  2020-09-07   ``Refactor DataprocCreateCluster operator to use simpler interface (#10403)``
`ece685b5b8 <https://github.com/apache/airflow/commit/ece685b5b895ad1175440b49bf9e620dffd8248d>`__  2020-09-05   ``Asynchronous execution of Dataproc jobs with a Sensor (#10673)``
`6e3d7b63d3 <https://github.com/apache/airflow/commit/6e3d7b63d3b34c34f8b38a7b41f4a5876e1f731f>`__  2020-09-04   ``Add masterConfig parameter to MLEngineStartTrainingJobOperator (#10578)``
`804548d58f <https://github.com/apache/airflow/commit/804548d58f2036fd4516824a38d0639ba5d5ab0e>`__  2020-09-01   ``Add Dataprep operators (#10304)``
`11c00bc820 <https://github.com/apache/airflow/commit/11c00bc820483691a87cdb16d519dce8dc57c40e>`__  2020-08-30   ``Fix typos: duplicated "the" (#10647)``
`2ca615cffe <https://github.com/apache/airflow/commit/2ca615cffefe97dfa38e1b7f60d9ed33c6628992>`__  2020-08-29   ``Update Google Cloud branding (#10642)``
`1b533f617e <https://github.com/apache/airflow/commit/1b533f617e2e0200597d114d7570f6c0d69da1a0>`__  2020-08-28   ``Fix broken master - DLP (#10635)``
`5ae82a56da <https://github.com/apache/airflow/commit/5ae82a56dab599de44f1be7027cecc4ef86f7bb6>`__  2020-08-28   ``Fix Google DLP example and improve ops idempotency (#10608)``
`3867f76625 <https://github.com/apache/airflow/commit/3867f7662559761864ec4e7be26b776c64c2f199>`__  2020-08-28   ``Update Google Cloud branding (#10615)``
`91ff31ad10 <https://github.com/apache/airflow/commit/91ff31ad1021235bd21c87ad9dbc0b216a908671>`__  2020-08-27   ``Documentation for Google Cloud Data Loss Prevention (#8201) (#9651)``
`fdd9b6f65b <https://github.com/apache/airflow/commit/fdd9b6f65b608c516b8a062b058972d9a45ec9e3>`__  2020-08-25   ``Enable Black on Providers Packages (#10543)``
`d760265452 <https://github.com/apache/airflow/commit/d7602654526fdd2876466371404784bd17cfe0d2>`__  2020-08-25   ``PyDocStyle: No whitespaces allowed surrounding docstring text (#10533)``
`d1bce91bb2 <https://github.com/apache/airflow/commit/d1bce91bb21d5a468fa6a0207156c28fe1ca6513>`__  2020-08-25   ``PyDocStyle: Enable D403: Capitalized first word of docstring (#10530)``
`866701c801 <https://github.com/apache/airflow/commit/866701c8019f49dcb02c9696e4f6e9ce67d13ca6>`__  2020-08-25   ``Fix typo in "Cloud" (#10534)``
`47265e7b58 <https://github.com/apache/airflow/commit/47265e7b58bc28bcbbffc981442b6cc27a3af39c>`__  2020-08-24   ``Fix typo in PostgresHook (#10529)``
`3696c34c28 <https://github.com/apache/airflow/commit/3696c34c28c6bc7b442deab999d9ecba24ed0e34>`__  2020-08-24   ``Fix typo in the word "release" (#10528)``
`2f2d8dbfaf <https://github.com/apache/airflow/commit/2f2d8dbfafefb4be3dd80f22f31c649c8498f148>`__  2020-08-25   ``Remove all "noinspection" comments native to IntelliJ (#10525)``
`3734876d98 <https://github.com/apache/airflow/commit/3734876d9898067ee933b84af522d53df6160d7f>`__  2020-08-24   ``Implement impersonation in google operators (#10052)``
`b0598b5351 <https://github.com/apache/airflow/commit/b0598b5351d2d027286e2333231b6c0c0704dba2>`__  2020-08-24   ``Add support for creating multiple replicated clusters in Bigtable hook and operator (#10475)``
`ee7ca128a1 <https://github.com/apache/airflow/commit/ee7ca128a17937313566f2badb6cc569c614db94>`__  2020-08-22   ``Fix broken Markdown refernces in Providers README (#10483)``
`515cc72c99 <https://github.com/apache/airflow/commit/515cc72c995429c8c007f853ade385d79fcbac90>`__  2020-08-22   ``Fix typo in timed_out (#10459)``
`7c206a82a6 <https://github.com/apache/airflow/commit/7c206a82a6f074abcc4898a005ecd2c84a920054>`__  2020-08-22   ``Replace assigment with Augmented assignment (#10468)``
`88c7d2e526 <https://github.com/apache/airflow/commit/88c7d2e526af4994066f65f830e2fa8edcbbce2e>`__  2020-08-21   ``Dataflow operators don't not always create a virtualenv (#10373)``
`083c3c129b <https://github.com/apache/airflow/commit/083c3c129bc3458d410f5ff37d7f5a9a7ad548b7>`__  2020-08-18   ``Simplified GCSTaskHandler configuration (#10365)``
`1ae5bdf23e <https://github.com/apache/airflow/commit/1ae5bdf23e3ac7cca05325ef8b255a7cf067e18e>`__  2020-08-17   ``Add test for GCSTaskHandler (#9600) (#9861)``
`e195a980bc <https://github.com/apache/airflow/commit/e195a980bc8e9d42f3eb4ac134950977b9e5158f>`__  2020-08-16   ``Add type annotations for mlengine_operator_utils (#10297)``
`382c1011b6 <https://github.com/apache/airflow/commit/382c1011b6bcebd22760e2f98419281ef1a09d1b>`__  2020-08-16   ``Add Bigtable Update Instance Hook/Operator (#10340)``
`bfa5a8d5f1 <https://github.com/apache/airflow/commit/bfa5a8d5f10458c14d380c4042ecfbac627d0639>`__  2020-08-15   ``CI: Fix failing docs-build (#10342)``
`be46d20fb4 <https://github.com/apache/airflow/commit/be46d20fb431cc1d91c935e8894dfc7756c18993>`__  2020-08-15   ``Improve idempotency of BigQueryInsertJobOperator (#9590)``
`47387a69e6 <https://github.com/apache/airflow/commit/47387a69e623676b57b6d42ff07e729da2d21bff>`__  2020-08-14   ``Catch Permission Denied exception when getting secret from GCP Secret Manager. (#10326)``
`2f0613b0c2 <https://github.com/apache/airflow/commit/2f0613b0c2fdf176d9f13a8cd12162c60c64b644>`__  2020-08-13   ``Implement Google BigQuery Table Partition Sensor (#10218)``
`f6734b3b85 <https://github.com/apache/airflow/commit/f6734b3b850d33d3712763f93c114e80f5af9ffb>`__  2020-08-12   ``Enable Sphinx spellcheck for doc generation (#10280)``
`8f8db8959e <https://github.com/apache/airflow/commit/8f8db8959e526be54d700845d36ee9f315bae2ea>`__  2020-08-12   ``DbApiHook: Support kwargs in get_pandas_df (#9730)``
`ef088314f8 <https://github.com/apache/airflow/commit/ef088314f8f1b29ac636a7584cf9dda04b1df816>`__  2020-08-09   ``Added DataprepGetJobsForJobGroupOperator (#10246)``
`b43f90abf4 <https://github.com/apache/airflow/commit/b43f90abf4c7219d5d59cccb0514256bd3f2fdc7>`__  2020-08-09   ``Fix various typos in the repo (#10263)``
`c29533888f <https://github.com/apache/airflow/commit/c29533888fadd40f5e9ce63e728bd8691182e542>`__  2020-08-08   ``Add labels param to Google MLEngine Operators (#10222)``
`cdec301254 <https://github.com/apache/airflow/commit/cdec3012542b45d23a05f62d69110944ba542e2a>`__  2020-08-07   ``Add correct signature to all operators and sensors (#10205)``
`eff0f03210 <https://github.com/apache/airflow/commit/eff0f03210d30a4aed9ed457eaaea9c9f05d54d1>`__  2020-08-06   `` Update guide for Google Cloud Secret Manager Backend (#10172)``
`24c8e4c2d6 <https://github.com/apache/airflow/commit/24c8e4c2d6e359ecc2c7d6275dccc68de4a82832>`__  2020-08-06   ``Changes to all the constructors to remove the args argument (#10163)``
`010322692e <https://github.com/apache/airflow/commit/010322692e6e3f0adc156f0beb81e267da0e97bb>`__  2020-08-06   ``Improve handling Dataproc cluster creation with ERROR state (#9593)``
`1437cb7495 <https://github.com/apache/airflow/commit/1437cb74955f4e10af5d70ebadde1e6b163fb9b7>`__  2020-08-04   ``Add correct signatures for operators in google provider package (#10144)``
`6efa1b9cb7 <https://github.com/apache/airflow/commit/6efa1b9cb763ae0bdbc884a54d24dbdc39d9e3a6>`__  2020-08-03   ``Add additional Cloud Datastore operators (#10032)``
`27020f8e58 <https://github.com/apache/airflow/commit/27020f8e588575d53e63f9f9daecd3a522656644>`__  2020-08-03   ``Add try clause to DataFusionHook.wait_for_pipeline_state (#10031)``
`4e3799fec4 <https://github.com/apache/airflow/commit/4e3799fec4c23d0f43603a0489c5a6158aeba035>`__  2020-08-02   ``[AIRFLOW-4541] Replace os.mkdirs usage with pathlib.Path(path).mkdir (#10117)``
`85c56b1737 <https://github.com/apache/airflow/commit/85c56b1737c2bf61751836571300445c0aebae1a>`__  2020-08-02   ``Add missing params to GCP Pub/Sub creation_subscription (#10106)``
`b79466c12f <https://github.com/apache/airflow/commit/b79466c12f3ae717c31804acc2e9ffcd60f9611c>`__  2020-08-02   ``Fix sensor not providing arguments for GCSHook (#10074)``
`4ee35d0279 <https://github.com/apache/airflow/commit/4ee35d027988c6456767faeb108a7f686d5117f2>`__  2020-08-02   ``Fix hook not passing gcp_conn_id to base class (#10075)``
`aeea71274d <https://github.com/apache/airflow/commit/aeea71274d4527ff2351102e94aa38bda6099e7f>`__  2020-08-02   ``Remove 'args' parameter from provider operator constructors (#10097)``
`4c84661adb <https://github.com/apache/airflow/commit/4c84661adb5bb5c581bb4193b4c7e935cbe07758>`__  2020-07-31   ``Split Display Video 360 example into smaler DAGs (#10077)``
`59cbff0874 <https://github.com/apache/airflow/commit/59cbff0874dd5318cda4b9ce7b7eeb1aad1dad4d>`__  2020-07-29   ``Fix docstrings in BigQueryGetDataOperator (#10042)``
`81b87d48ed <https://github.com/apache/airflow/commit/81b87d48ed002d7a7f7bcb72a58e82d40a176fe2>`__  2020-07-27   ``Add unit tests for GcpBodyFieldSanitizer in Google providers (#9996)``
`7d24b088cd <https://github.com/apache/airflow/commit/7d24b088cd736cfa18f9214e4c9d6ce2d5865f3d>`__  2020-07-25   ``Stop using start_date in default_args in example_dags (2) (#9985)``
`8b10a4b35e <https://github.com/apache/airflow/commit/8b10a4b35e45d536a6475bfe1491ee75fad50186>`__  2020-07-25   ``Stop using start_date in default_args in example_dags (#9982)``
`ef98edf4da <https://github.com/apache/airflow/commit/ef98edf4da2d9b74d5cf5b21e81577b3151edb79>`__  2020-07-23   ``Add more information about using GoogleAdsHook (#9951)``
`33f0cd2657 <https://github.com/apache/airflow/commit/33f0cd2657b2e77ea3477e0c93f13f1474be628e>`__  2020-07-22   ``apply_default keeps the function signature for mypy (#9784)``
`39a0288a47 <https://github.com/apache/airflow/commit/39a0288a47536dfd9b651ecd075887d3e45fcfc4>`__  2020-07-22   ``Add Google Authentication for experimental API (#9848)``
`c2db0dfeb1 <https://github.com/apache/airflow/commit/c2db0dfeb13ee679bf4d7b57874f0fcb39c0f0ed>`__  2020-07-22   ``More strict rules in mypy (#9705) (#9906)``
`c4244e18bb <https://github.com/apache/airflow/commit/c4244e18bb894eb2180b8972052e56110fe5cbc9>`__  2020-07-22   ``Fix calling 'get_client' in BigQueryHook.table_exists (#9916)``
`5eacc16420 <https://github.com/apache/airflow/commit/5eacc164201a121cd06126aff613cbe0919d35cc>`__  2020-07-22   ``Add support for impersonation in GCP hooks (#9915)``
`1cfdebf5f8 <https://github.com/apache/airflow/commit/1cfdebf5f8841d61a11540b88c7913686e89e085>`__  2020-07-21   ``Fix insert_job method of BigQueryHook (#9899)``
`c8c52e69c8 <https://github.com/apache/airflow/commit/c8c52e69c8d9cc1f26f63d95aecc0a6498d40b6f>`__  2020-07-21   ``Remove type hint causing DeprecationWarning in Firestore operators (#9819)``
`eb6f1d1cf0 <https://github.com/apache/airflow/commit/eb6f1d1cf0503fa763c0d8d34a2fe16efb390b9c>`__  2020-07-16   ``Fix typo in datafusion operator (#9859)``
`b01d95ec22 <https://github.com/apache/airflow/commit/b01d95ec22b01ed79123178acd74ef40d57aaa7c>`__  2020-07-15   ``Change DAG.clear to take dag_run_state (#9824)``
`6d65c15d15 <https://github.com/apache/airflow/commit/6d65c15d156a41d5e735e44a1170426559a17d1f>`__  2020-07-15   ``Add guide for AI Platform (previously Machine Learning Engine) Operators  (#9798)``
`770de53eb5 <https://github.com/apache/airflow/commit/770de53eb57bd57ffc555ad15b18f0c058dbebe7>`__  2020-07-15   ``BigQueryTableExistenceSensor needs to specify keyword arguments (#9832)``
`2d8dbacdf6 <https://github.com/apache/airflow/commit/2d8dbacdf6c19a598a7f55bcf65e28703aed6201>`__  2020-07-15   ``Add CloudVisionDeleteReferenceImageOperator  (#9698)``
`9f017951b9 <https://github.com/apache/airflow/commit/9f017951b94d9bf52b5ee66d72aa8dd822f07269>`__  2020-07-15   ``Add Google Deployment Manager Hook (#9159)``
`ed5004cca7 <https://github.com/apache/airflow/commit/ed5004cca753650dc222fbb8e67573938c6c16d9>`__  2020-07-14   ``Allow 'replace' flag in gcs_to_gcs operator. (#9667)``
`553bb7af7c <https://github.com/apache/airflow/commit/553bb7af7cb7a50f7141b5b89297713cee6d19f6>`__  2020-07-13   ``Keep functions signatures in decorators (#9786)``
`68925904e4 <https://github.com/apache/airflow/commit/68925904e49aac6968defb6834863f4e6347fe59>`__  2020-07-13   ``Add multiple file upload functionality to GCS hook (#8849)``
`1de78e8f97 <https://github.com/apache/airflow/commit/1de78e8f97f48f8f4abd167a0120ffab8af6127a>`__  2020-07-12   ``Add Google Stackdriver link (#9765)``
`092d33f298 <https://github.com/apache/airflow/commit/092d33f298a7dbb871b1e1b4c17aad3989e89b79>`__  2020-07-11   ``Fix StackdriverTaskHandler + add system tests (#9761)``
`b2305660f0 <https://github.com/apache/airflow/commit/b2305660f0eb55ebd31fdc7fe4e8aeed8c1f8c00>`__  2020-07-09   ``Update example DAG for AI Platform operators (#9727)``
`23f80f34ad <https://github.com/apache/airflow/commit/23f80f34adec86da24e4896168c53d213d01a7f6>`__  2020-07-08   ``Move gcs & wasb task handlers to their respective provider packages (#9714)``
`44d4ae809c <https://github.com/apache/airflow/commit/44d4ae809c1e3784ff95b6a5e95113c3412e56b3>`__  2020-07-06   ``Upgrade to latest pre-commit checks (#9686)``
`a79e2d4c4a <https://github.com/apache/airflow/commit/a79e2d4c4aa105f3fac5ae6a28e29af9cd572407>`__  2020-07-06   ``Move provider's log task handlers to the provider package (#9604)``
`cd3d9d9340 <https://github.com/apache/airflow/commit/cd3d9d93402f06a08f35e3586802f11a18c4f1f3>`__  2020-07-02   ``Fix using .json template extension in GMP operators (#9566)``
`4799af30ee <https://github.com/apache/airflow/commit/4799af30ee02c596647d1538854769124f9f4961>`__  2020-06-30   ``Extend BigQuery example with include clause (#9572)``
`e33f1a12d7 <https://github.com/apache/airflow/commit/e33f1a12d72ac234e4897f44b326a332acf85901>`__  2020-06-30   ``Add template_ext to BigQueryInsertJobOperator (#9568)``
`40add26d45 <https://github.com/apache/airflow/commit/40add26d459c2511a6d9d305ae7300f0d6104211>`__  2020-06-29   ``Remove almost all references to airflow.contrib (#9559)``
`c420dbd6e1 <https://github.com/apache/airflow/commit/c420dbd6e13e17867eb4ccc4271b37966310ac0f>`__  2020-06-27   ``Bump Pylint to 2.5.3 (#9294)``
`0051c89cba <https://github.com/apache/airflow/commit/0051c89cba02d55236c913ce0110f7d5111ba436>`__  2020-06-26   ``nitpick fix (#9527)``
`87fdbd0708 <https://github.com/apache/airflow/commit/87fdbd0708d942af98d35604fe5962962e25d246>`__  2020-06-25   ``Use literal syntax instead of function calls to create data structure (#9516)``
`7256f4caa2 <https://github.com/apache/airflow/commit/7256f4caa226f8f8632d6e2d38d8c94cb3250a6f>`__  2020-06-22   ``Pylint fixes and deprecation of rare used methods in Connection (#9419)``
`e13a14c873 <https://github.com/apache/airflow/commit/e13a14c8730f4f633d996dd7d3468fe827136a84>`__  2020-06-21   ``Enable & Fix Whitespace related PyDocStyle Checks (#9458)``
`5b680e27e8 <https://github.com/apache/airflow/commit/5b680e27e8118861ef484c00a4b87c6885b0a518>`__  2020-06-19   ``Don't use connection to store task handler credentials (#9381)``
`d0e7db4024 <https://github.com/apache/airflow/commit/d0e7db4024806af35e3c9a2cae460fdeedd4d2ec>`__  2020-06-19   ``Fixed release number for fresh release (#9408)``
`416334e2ec <https://github.com/apache/airflow/commit/416334e2ecd21d8a532af6102f1cfa9ac921a97a>`__  2020-06-19   ``Properly propagated warnings in operators (#9348)``
`12af6a0800 <https://github.com/apache/airflow/commit/12af6a08009b8776e00d8a0aab92363eb8c4e8b1>`__  2020-06-19   ``Final cleanup for 2020.6.23rc1 release preparation (#9404)``
`c7e5bce57f <https://github.com/apache/airflow/commit/c7e5bce57fe7f51cefce4f8a41ce408ac5675d13>`__  2020-06-19   ``Prepare backport release candidate for 2020.6.23rc1 (#9370)``
`4e09c64423 <https://github.com/apache/airflow/commit/4e09c64423bfaabd02a18b5fe7757dc15451ab73>`__  2020-06-18   ``Adds GCP Secret Manager Hook (#9368)``
`40bf8f28f9 <https://github.com/apache/airflow/commit/40bf8f28f97f17f40d993d207ea740eba54593ee>`__  2020-06-18   ``Detect automatically the lack of reference to the guide in the operator descriptions (#9290)``
`f6bd817a3a <https://github.com/apache/airflow/commit/f6bd817a3aac0a16430fc2e3d59c1f17a69a15ac>`__  2020-06-16   ``Introduce 'transfers' packages (#9320)``
`639972d995 <https://github.com/apache/airflow/commit/639972d995d848b16a3f283576efdbde28b8fdef>`__  2020-06-16   ``Add support for latest Apache Beam SDK in Dataflow operators (#9323)``
`1459970b3b <https://github.com/apache/airflow/commit/1459970b3b9780e139ce029ae889fd8f69a37bc7>`__  2020-06-15   ``Rename CloudBuildCreateBuildOperator to CloudBuildCreateOperator (#9314)``
`431ea3291c <https://github.com/apache/airflow/commit/431ea3291c9bf236bccdf8446d753c630ada2b25>`__  2020-06-15   ``Resolve upstream tasks when template field is XComArg (#8805)``
`aee6ab94eb <https://github.com/apache/airflow/commit/aee6ab94eb956347ad560cfe2673bc6011074513>`__  2020-06-15   ``Wait for pipeline state in Data Fusion operators (#8954)``
`fb1c8b83d4 <https://github.com/apache/airflow/commit/fb1c8b83d400506a16c10e3d6623a913847e5cf5>`__  2020-06-10   ``Add test for BQ operations using location (#9206)``
`a26afbfa51 <https://github.com/apache/airflow/commit/a26afbfa51b0981ae742c6171938b57a80aace2b>`__  2020-06-10   ``Make generated job_id more informative in BQ insert_job (#9203)``
`c41192fa1f <https://github.com/apache/airflow/commit/c41192fa1fc5c2b3e7b8414c59f656ab67bbef28>`__  2020-06-10   ``Upgrade pendulum to latest major version ~2.0 (#9184)``
`b1c8c5ed5b <https://github.com/apache/airflow/commit/b1c8c5ed5bba3a852a5446f3fdd1131b4b22637a>`__  2020-06-09   ``Allows using private endpoints in GKEStartPodOperator (#9169)``
`5918efc86a <https://github.com/apache/airflow/commit/5918efc86a2217caa641a6ada289eee1c21407f8>`__  2020-06-05   ``Add 3.8 to the test matrices (#8836)``
`9bcdadaf7e <https://github.com/apache/airflow/commit/9bcdadaf7e6e73d3d2246fbbd32a9f30a1b43ca9>`__  2020-06-05   ``Add 'main' param to template_fields in DataprocSubmitPySparkJobOperator (#9154)``
`f56811dff3 <https://github.com/apache/airflow/commit/f56811dff3af66cbceb0418f11e00507bab58674>`__  2020-06-05   ``[AIRFLOW-6290] Create guide for GKE operators (#8883)``
`76962867b5 <https://github.com/apache/airflow/commit/76962867b5877cf5ffd1b6004453f783c0732ab1>`__  2020-06-04   ``Fix sql_to_gcs hook gzip of schema_file (#9140)``
`17adcea835 <https://github.com/apache/airflow/commit/17adcea835cb7b0cf2d8da0ac7dda5549cfa3e45>`__  2020-06-02   ``Fix handling of subprocess error handling in s3_file_transform and gcs (#9106)``
`7898525468 <https://github.com/apache/airflow/commit/78985254683c359f7444a7eb5f6ee4967c37d61f>`__  2020-06-01   ``Add BigQueryInsertJobOperator (#8868)``
`29eb68b90b <https://github.com/apache/airflow/commit/29eb68b90b5df692ac322be0939af5e7fa9b71bc>`__  2020-05-31   ``Create guide for Dataproc Operators (#9037)``
`886afaf622 <https://github.com/apache/airflow/commit/886afaf622602aa97f925bc3ee4fc27aa995c445>`__  2020-05-29   ``Add example dag and system test for LocalFilesystemToGCSOperator (#9043)``
`a779c4dfc2 <https://github.com/apache/airflow/commit/a779c4dfc278d6ece480b012764ea5814dc78dee>`__  2020-05-29   ``add separate example dags and system tests for GCSToGoogleSheetsOperator (#9066)``
`ada26be23c <https://github.com/apache/airflow/commit/ada26be23c913796c2ae77b91cb7d113dfec75a6>`__  2020-05-29   ``Add correct description for dst param in LocalFilesystemToGCSOperator (#9055)``
`81b2761b86 <https://github.com/apache/airflow/commit/81b2761b86dae2d21a6ee859d49c08d46fea6def>`__  2020-05-29   ``add example dag and system test for GoogleSheetsToGCSOperator (#9056)``
`0b0e4f7a4c <https://github.com/apache/airflow/commit/0b0e4f7a4cceff3efe15161fb40b984782760a34>`__  2020-05-26   ``Preparing for RC3 relase of backports (#9026)``
`00642a46d0 <https://github.com/apache/airflow/commit/00642a46d019870c4decb3d0e47c01d6a25cb88c>`__  2020-05-26   ``Fixed name of 20 remaining wrongly named operators. (#8994)``
`3994030ea6 <https://github.com/apache/airflow/commit/3994030ea678727daaf9c2bfed0ca94a096f8d2a>`__  2020-05-26   ``Refactor BigQuery operators (#8858)``
`cdb3f25456 <https://github.com/apache/airflow/commit/cdb3f25456e49d0199cd7ccd680626dac01c9be6>`__  2020-05-26   ``All classes in backport providers are now importable in Airflow 1.10 (#8991)``
`1d36b0303b <https://github.com/apache/airflow/commit/1d36b0303b8632fce6de78ca4e782ae26ee06fea>`__  2020-05-23   ``Fix references in docs (#8984)``
`cf5cf45e1c <https://github.com/apache/airflow/commit/cf5cf45e1c0dff9a40e02f0dc221542f974831a7>`__  2020-05-23   ``Support YAML input for CloudBuildCreateOperator (#8808)``
`499493c5c5 <https://github.com/apache/airflow/commit/499493c5c5cf324ab8452ead80a10b71ce0c3b14>`__  2020-05-19   ``[AIRFLOW-6586] Improvements to gcs sensor (#7197)``
`375d1ca229 <https://github.com/apache/airflow/commit/375d1ca229464617780623c61c6e8a1bf570c87f>`__  2020-05-19   ``Release candidate 2 for backport packages 2020.05.20 (#8898)``
`841d816647 <https://github.com/apache/airflow/commit/841d81664737c25d73d095a7dab5de80d369c87c>`__  2020-05-19   ``Allow setting the pooling time in DLPHook (#8824)``
`12c5e5d8ae <https://github.com/apache/airflow/commit/12c5e5d8ae25fa633efe63ccf4db389e2b796d79>`__  2020-05-17   ``Prepare release candidate for backport packages (#8891)``
`f3521fb0e3 <https://github.com/apache/airflow/commit/f3521fb0e36733d8bd356123e56a453fd37a6dca>`__  2020-05-16   ``Regenerate readme files for backport package release (#8886)``
`15273f0ea0 <https://github.com/apache/airflow/commit/15273f0ea05ec579c631ce26b5d620233ebdc4d2>`__  2020-05-16   ``Check for same task instead of Equality to detect Duplicate Tasks (#8828)``
`92585ca4cb <https://github.com/apache/airflow/commit/92585ca4cb375ac879f4ab331b3a063106eb7b92>`__  2020-05-15   ``Added automated release notes generation for backport operators (#8807)``
`e1e833bb26 <https://github.com/apache/airflow/commit/e1e833bb260879ecb9a1f80f28450a3656c0e598>`__  2020-05-13   ``Update GoogleBaseHook to not follow 308 and use 60s timeout (#8816)``
`8b54919711 <https://github.com/apache/airflow/commit/8b54919711a203c3f35d98c6310a55d4df5da590>`__  2020-05-12   ``Refactor BigQuery hook methods to use python library (#8631)``
`6911dfe837 <https://github.com/apache/airflow/commit/6911dfe8372a33df67ce1fdd3c2bca1047718f60>`__  2020-05-12   ``Fix template fields in Google operators (#8840)``
`4b06fde0f1 <https://github.com/apache/airflow/commit/4b06fde0f10ce178b3c336c5d901e3b089f2863d>`__  2020-05-12   ``Fix Flake8 errors (#8841)``
`1d12c347cb <https://github.com/apache/airflow/commit/1d12c347cb258e7081804da1f9f5ffdedc003163>`__  2020-05-12   ``Refactor BigQuery check operators (#8813)``
`493b685d78 <https://github.com/apache/airflow/commit/493b685d7879cfee532390ba0909d4b1d8764267>`__  2020-05-10   ``Add separate example DAGs and system tests for google cloud speech (#8778)``
`79ef8bed89 <https://github.com/apache/airflow/commit/79ef8bed891c22eb76adf99158288d1b44426dc0>`__  2020-05-10   ``Added Upload Multiple Entity Read Files to specified big query dataset (#8610)``
`280f1f0c4c <https://github.com/apache/airflow/commit/280f1f0c4cc49aba1b2f8b456326795733769d18>`__  2020-05-10   ``Correctly restore upstream_task_ids when deserializing Operators (#8775)``
`58aefb23b1 <https://github.com/apache/airflow/commit/58aefb23b1d456bbb24876a4e3ff14f25d6274b0>`__  2020-05-08   ``Added SDFtoGCSOperator (#8740)``
`723c52c942 <https://github.com/apache/airflow/commit/723c52c942b49b0e8c8fa8667a4a6a45fa249498>`__  2020-05-07   ``Add documentation for SpannerDeployInstanceOperator (#8750)``
`25ee4211b3 <https://github.com/apache/airflow/commit/25ee4211b345ce7c19fb7366fd230838c34f1d47>`__  2020-05-06   ``Support all RuntimeEnvironment parameters in DataflowTemplatedJobStartOperator (#8531)``
`8d6f1aa4b5 <https://github.com/apache/airflow/commit/8d6f1aa4b5bb8809ffc55dc0c62e6d0e89f331e5>`__  2020-05-05   ``Support num_retries field in env var for GCP connection (#8700)``
`67caae0f25 <https://github.com/apache/airflow/commit/67caae0f25db4eec42b8e81c85683aabdd8d6c1a>`__  2020-05-04   ``Add system test for gcs_to_bigquery (#8556)``
`bc45fa6759 <https://github.com/apache/airflow/commit/bc45fa6759203b4c26b52e693dac97486a84204e>`__  2020-05-03   ``Add system test and docs for Facebook Ads operators (#8503)``
`a28c66f23d <https://github.com/apache/airflow/commit/a28c66f23d373cd0f8bfc765a515f21d4b66a0e9>`__  2020-04-30   ``[AIRFLOW-4734] Upsert functionality for PostgresHook.insert_rows() (#8625)``
`992a24ce41 <https://github.com/apache/airflow/commit/992a24ce41067d3b73f293878e71835892cbb632>`__  2020-04-28   ``Split and improve BigQuery example DAG (#8529)``
`c1fb28230f <https://github.com/apache/airflow/commit/c1fb28230fa0d36ef86c452c70254b253a113f9c>`__  2020-04-28   ``Refactor BigQueryHook dataset operations (#8477)``
`e8d0f8feab <https://github.com/apache/airflow/commit/e8d0f8feab0ec08e248cd381359112ad6a832f5b>`__  2020-04-26   ``Improve idempodency in CloudDataTransferServiceCreateJobOperator (#8430)``
`37fdfa9775 <https://github.com/apache/airflow/commit/37fdfa9775f43a5fa15de9c53ab33ecdf97513c5>`__  2020-04-26   ``[AIRFLOW-6281] Create guide for GCS to GCS transfer operators (#8442)``
`14b22e6ffe <https://github.com/apache/airflow/commit/14b22e6ffeb3af1f68e8362a1d0061b41364019c>`__  2020-04-25   ``Add hook and operator for Google Cloud Life Sciences (#8481)``
`72ddc94d1e <https://github.com/apache/airflow/commit/72ddc94d1ee08b414102e0b8ac197a3d8e965707>`__  2020-04-23   ``Pass location using parmamter in Dataflow integration (#8382)``
`912aa4b423 <https://github.com/apache/airflow/commit/912aa4b4237695275db6379cf2f0a633ea6087bc>`__  2020-04-23   ``Added GoogleDisplayVideo360DownloadLineItemsOperator (#8174)``
`57c8c05839 <https://github.com/apache/airflow/commit/57c8c05839f66ed2909b1bee8ff6976432db82aa>`__  2020-04-22   ``Use python client in BQ hook create_empty_table/dataset and table_exists (#8377)``
`5d3a7eef30 <https://github.com/apache/airflow/commit/5d3a7eef30b30fa466d8173f13abe4c356d73aef>`__  2020-04-20   ``Allow multiple extra_packages in Dataflow (#8394)``
`79c99b1b6a <https://github.com/apache/airflow/commit/79c99b1b6ae2ff5b0c8ab892f7f3fb1b44724121>`__  2020-04-18   ``Added location parameter to BigQueryCheckOperator (#8273)``
`79d3f33c1b <https://github.com/apache/airflow/commit/79d3f33c1b65c9c7e7b1a75e25d38cab9aa4517f>`__  2020-04-17   ``Clean up temporary files in Dataflow operators (#8313)``
`efcffa323d <https://github.com/apache/airflow/commit/efcffa323ddb5aa9f5907aa86808f3f3b4f5bd87>`__  2020-04-16   ``Add Dataproc SparkR Example (#8240)``
`b198a1fa94 <https://github.com/apache/airflow/commit/b198a1fa94c44228dc7358552aeb6a5371ae0da2>`__  2020-04-15   ``Create guide for BigQuery operators (#8276)``
`2636cc932c <https://github.com/apache/airflow/commit/2636cc932c3b156644edd46635cf9ff995c83159>`__  2020-04-14   ``Raise exception when GCP credential doesn't support account impersonation (#8213)``
`eee4ebaeeb <https://github.com/apache/airflow/commit/eee4ebaeeb1991480ee178ddb600bc69b2a88764>`__  2020-04-14   ``Added Facebook Ads Operator #7887 (#8008)``
`8cae07ea18 <https://github.com/apache/airflow/commit/8cae07ea1873a90516120d9ffbd28e7fdd2f78a4>`__  2020-04-14   ``fixed typo (#8294)``
`45c8983306 <https://github.com/apache/airflow/commit/45c8983306ab1c54abdacd8f870e790fad25cb37>`__  2020-04-13   ``Less aggressive eager upgrade of requirements (#8267)``
`1fd9ed3840 <https://github.com/apache/airflow/commit/1fd9ed3840361afa1e9456ccb0dfd5a60fba4e85>`__  2020-04-13   ``Add mypy plugin for decorators. (#8145)``
`327b0a9f77 <https://github.com/apache/airflow/commit/327b0a9f77bbcbe3f977a37de04264c2eff4bee1>`__  2020-04-13   ``Added GoogleDisplayVideo360UploadLineItemsOperator (#8216)``
`bb5e403a32 <https://github.com/apache/airflow/commit/bb5e403a320e7377e5040cb180f61b4f5a9ea558>`__  2020-04-10   ``Honor schema type for MySQL to GCS data pre-process (#8090)``
`87969a350d <https://github.com/apache/airflow/commit/87969a350ddd41e9e77776af6d780b31e363eaca>`__  2020-04-09   ``[AIRFLOW-6515] Change Log Levels from Info/Warn to Error (#8170)``
`3fc89f29f5 <https://github.com/apache/airflow/commit/3fc89f29f5bcd1529089fa6cb9c44843614f9ec5>`__  2020-04-06   ``[AIRFLOW-7106] Cloud data fusion integration - Allow to pass args to start pipeline (#7849)``
`7ef75d2393 <https://github.com/apache/airflow/commit/7ef75d2393f30d155de550e6d1ee8c055e2abfee>`__  2020-04-03   ``[AIRFLOW-7117] Honor self.schema in sql_to_gcs as schema to upload (#8049)``
`ed2bc00576 <https://github.com/apache/airflow/commit/ed2bc00576b39a88e3e1fb79092494f4bfdcbf5c>`__  2020-04-02   ``Add Google Ads list accounts operator (#8007)``
`3808a6206e <https://github.com/apache/airflow/commit/3808a6206e70d4af84b39ea7078df54f02c1435e>`__  2020-04-01   ``Unify Google class/package names (#8033)``
`8a02402576 <https://github.com/apache/airflow/commit/8a02402576f83869d5134b4bddef5d73c15a8320>`__  2020-03-31   ``Rename CloudBaseHook to GoogleBaseHook and move it to google.common (#8011)``
`8e89780071 <https://github.com/apache/airflow/commit/8e897800716c8ccedd1c53f2d083cb295786aa50>`__  2020-03-31   ``Add more refactor steps for providers.google (#8010)``
`aae3b8fb27 <https://github.com/apache/airflow/commit/aae3b8fb27870cb3cfba5ed73e35e08d520ef014>`__  2020-03-31   ``Individual package READMEs (#8012)``
`779023968f <https://github.com/apache/airflow/commit/779023968f983c91701f687bc823dc338934cdad>`__  2020-03-30   ``[AIRFLOW-7075] Operators for storing information from GCS into GA (#7743)``
`49abce5217 <https://github.com/apache/airflow/commit/49abce52178c81954f8a25608f70ffe02fcf7b19>`__  2020-03-30   ``Improve system tests for Cloud Build (#8003)``
`0f19a930d1 <https://github.com/apache/airflow/commit/0f19a930d1a7dec2a96bab0de144829f83cc0626>`__  2020-03-29   ``Remove GKEStartPodOperator when backporting (#7908)``
`0e1c238b2f <https://github.com/apache/airflow/commit/0e1c238b2fff3a092c93368125bc8d82abc4b308>`__  2020-03-28   ``Get Airflow Variables from GCP Secrets Manager (#7946)``
`eb4af4f944 <https://github.com/apache/airflow/commit/eb4af4f944c77e67e167bbb6b0a2aaf075a95b50>`__  2020-03-28   ``Make BaseSecretsBackend.build_path generic (#7948)``
`01f99426fd <https://github.com/apache/airflow/commit/01f99426fddd2a24552f352edcb271fa78cf3b15>`__  2020-03-28   ``Add download/upload operators for GCS and Google Sheets (#7866)``
`892522f8e2 <https://github.com/apache/airflow/commit/892522f8e2aeedc1ad842a08aaea967b0cae077f>`__  2020-03-26   ``Change signature of GSheetsHook methods (#7853)``
`bfd425157a <https://github.com/apache/airflow/commit/bfd425157a746402b516f8fc9e48f4ddccd794ce>`__  2020-03-26   ``Improve idempotency in MLEngineHook.create_model (#7811)``
`f9c226343d <https://github.com/apache/airflow/commit/f9c226343d94a7732da280d1dd086bf1ba291c77>`__  2020-03-26   ``Fix CloudSecretsManagerBackend invalid connections_prefix (#7861)``
`e3920f12f4 <https://github.com/apache/airflow/commit/e3920f12f483b53950507c50f6ab6a4318072859>`__  2020-03-26   ``Improve setUp/tearDown in Cloud Firestore system test (#7862)``
`8ba8a7295a <https://github.com/apache/airflow/commit/8ba8a7295a31f6b44894bfcaea36fa93b8d8c0d0>`__  2020-03-26   ``Improve example DAGs for Cloud Memorystore (#7855)``
`f7d1a437c1 <https://github.com/apache/airflow/commit/f7d1a437c17461b5ab768b75d58f0cb026b2a818>`__  2020-03-26   ``Fix CloudMemorystoreCreateInstanceAndImportOperator operator (#7856)``
`beef6c230e <https://github.com/apache/airflow/commit/beef6c230e4ff266af7c16b639bfda659b2bf6c0>`__  2020-03-26   ``Improve authorization in GCP system tests (#7863)``
`5f165f3e42 <https://github.com/apache/airflow/commit/5f165f3e4231ebd420ce643211a93e1fecf4877e>`__  2020-03-26   ``[AIRFLOW-5801] Get GCP credentials from file instead of JSON blob (#7869)``
`686d7d50bd <https://github.com/apache/airflow/commit/686d7d50bd21622724d6818021355bc6885fd3de>`__  2020-03-25   ``Standardize SecretBackend class names (#7846)``
`1982c3fdca <https://github.com/apache/airflow/commit/1982c3fdca1f04cfc41fc5b5e285d8f01c6b76ab>`__  2020-03-24   ``Run Dataflow for ML Engine summary in venv (#7809)``
`eef87b9953 <https://github.com/apache/airflow/commit/eef87b9953347a65421f315a07dbef37ded9df66>`__  2020-03-23   ``[AIRFLOW-7105] Unify Secrets Backend method interfaces (#7830)``
`529db07b2e <https://github.com/apache/airflow/commit/529db07b2ee73d886e37e8b3415462c730187b15>`__  2020-03-23   ``Improve Google PubSub hook publish method (#7831)``
`4bde99f132 <https://github.com/apache/airflow/commit/4bde99f1323d72f6c84c1548079d5e98fc0a2a9a>`__  2020-03-23   ``Make airflow/providers pylint compatible (#7802)``
`a001489b59 <https://github.com/apache/airflow/commit/a001489b5928ebfc35f990a29d1c9c2ecb80bd61>`__  2020-03-23   ``Improve example DAG for ML Engine (#7810)``
`9e5a8e7f83 <https://github.com/apache/airflow/commit/9e5a8e7f83cf2368315fce62f8d81304f7ba2f04>`__  2020-03-23   ``Add call to Super class in 'google' providers (#7823)``
`b86bf79bff <https://github.com/apache/airflow/commit/b86bf79bff615e61de98bead4d02eace5690d5fb>`__  2020-03-23   ``Fix typo in GCP credentials_provider's docstring (#7818)``
`56c013ce92 <https://github.com/apache/airflow/commit/56c013ce922eb18e5f7dd4410986afbcc6f29025>`__  2020-03-23   ``Add missing docstring in BigQueryHook.create_empty_table (#7817)``
`426a79847c <https://github.com/apache/airflow/commit/426a79847ced832ca3f67c135fd8830ebf1de7d2>`__  2020-03-23   ``Imrove support for laatest API in  MLEngineStartTrainingJobOperator (#7812)``
`cdf1809fce <https://github.com/apache/airflow/commit/cdf1809fce0e59c8379a799f1738d8d813abbf51>`__  2020-03-23   ``[AIRFLOW-7104] Add Secret backend for GCP Secrets Manager (#7795)``
`27dac00e12 <https://github.com/apache/airflow/commit/27dac00e125b87626a0b87074d61e6d38031bf47>`__  2020-03-22   ``[AIRFLOW-7099] Improve system test for cloud transfer service (#7794)``
`0daf5d729a <https://github.com/apache/airflow/commit/0daf5d729acef4e9aef5226452dff774e80430cd>`__  2020-03-22   ``Add ability to specify a maximum modified time for objects in GCSToGCSOperator (#7791)``
`c8088c2bd7 <https://github.com/apache/airflow/commit/c8088c2bd70a16605a5d4b1a66a22309359d6712>`__  2020-03-20   ``[AIRFLOW-7100] Add GoogleAnalyticsGetAdsLinkOperator (#7781)``
`5106a29314 <https://github.com/apache/airflow/commit/5106a29314b413d168bcba7a64bf91c04fdb5dfe>`__  2020-03-20   ``[AIRFLOW-6752] Add GoogleAnalyticsRetrieveAdsLinksListOperator (#7748)``
`759ce2a80c <https://github.com/apache/airflow/commit/759ce2a80c95832fe4773c9f4fde23e1b03cbc6f>`__  2020-03-20   ``[AIRFLOW-6978] Add PubSubPullOperator (#7766)``
`6b9b214e4c <https://github.com/apache/airflow/commit/6b9b214e4c3b3afa8ea2e1a5c1e24993013d60ac>`__  2020-03-20   ``[AIRFLOW-6732] Add GoogleAdsHook and GoogleAdsToGcsOperator (#7692)``
`b118916969 <https://github.com/apache/airflow/commit/b11891696946d1461174b385c88d6af8abb99768>`__  2020-03-19   ``[AIRFLOW-7069] Fix cloudsql system tests (#7770)``
`ae854cae5a <https://github.com/apache/airflow/commit/ae854cae5a2cf8cae37edf7e0813ad01bccfbc30>`__  2020-03-19   ``[AIRFLOW-7082] Remove catch_http_exception decorator in GCP hooks (#7756)``
`7e1e954d23 <https://github.com/apache/airflow/commit/7e1e954d23ce272b0a71188f0f535e20d54be443>`__  2020-03-19   ``[AIRFLOW-7085] Cache credentials, project_id in GCP Base Hook (#7759)``
`6e21c139b3 <https://github.com/apache/airflow/commit/6e21c139b3cce3f895040939f0b02e3e0ba36141>`__  2020-03-19   ``[AIRFLOW-XXXX] Fix reference to GCP classes in guides (#7762)``
`ce022a3f72 <https://github.com/apache/airflow/commit/ce022a3f72b7735087d4c3bbe81d293a0ab75327>`__  2020-03-19   ``[AIRFLOW-XXXX] Add cross-references for operators guide (#7760)``
`029c84e552 <https://github.com/apache/airflow/commit/029c84e5527b6db6bdbdbe026f455da325bedef3>`__  2020-03-18   ``[AIRFLOW-5421] Add Presto to GCS transfer operator (#7718)``
`63a3102ede <https://github.com/apache/airflow/commit/63a3102ede8fb8f764d251b20cad5ee5bef84f50>`__  2020-03-18   ``[AIRFLOW-7064] Add CloudFirestoreExportDatabaseOperator (#7725)``
`73305c7bd5 <https://github.com/apache/airflow/commit/73305c7bd57f14444804c13b8b290f479832d3db>`__  2020-03-18   ``[AIRFLOW-7081] Remove env variables from GCP guide (#7755)``
`60fdbf6d92 <https://github.com/apache/airflow/commit/60fdbf6d9255d34a8967400e9585b1cd5d29d3e9>`__  2020-03-18   ``[AIRFLOW-5610] Add ability to specify multiple objects to copy in GCSToGCSOperator (#7728)``
`de7e934ca3 <https://github.com/apache/airflow/commit/de7e934ca3f21ce82f67accf92811b3ac044476f>`__  2020-03-17   ``[AIRFLOW-7079] Remove redundant code for storing template_fields (#7750)``
`0de0347b27 <https://github.com/apache/airflow/commit/0de0347b27a961c46ee49da6dfa9205321657749>`__  2020-03-17   ``[AIRFLOW-6855]: Escape project_dataset_table in SQL query in gcs to bq … (#7475)``
`91557c6f87 <https://github.com/apache/airflow/commit/91557c6f87529c010b8ad1110ece35fd7fd751e4>`__  2020-03-17   ``[AIRFLOW-7073] GKEStartPodOperator always use connection credentials (#7738)``
`51161dbd9d <https://github.com/apache/airflow/commit/51161dbd9de0c966016cec4d5036877890daee7c>`__  2020-03-16   ``[AIRFLOW-5664] Store timestamps with microseconds precision (#6354)``
`2bc020c431 <https://github.com/apache/airflow/commit/2bc020c43112dd3a769311de8d5012e8e8f399ee>`__  2020-03-14   ``[AIRFLOW-7055] Verbose logging option for google provider (#7711)``
`c997cab42d <https://github.com/apache/airflow/commit/c997cab42d8695ac444e63dfe4b948a7ea82ed89>`__  2020-03-13   ``[AIRFLOW-6724] Add Google Analytics 360 Accounts Retrieve Operator (#7630)``
`137896f326 <https://github.com/apache/airflow/commit/137896f326cd29b59902a887e4c4e58f940ff62b>`__  2020-03-12   ``[AIRFLOW-7034] Remove feature: Assigning Dag to task using Bitshift Op (#7685)``
`1f77f943d5 <https://github.com/apache/airflow/commit/1f77f943d5d85f66b6a988e8ef6506525eaf4732>`__  2020-03-10   ``[AIRFLOW-6980] Improve system tests and building providers package (#7615)``
`bf9b6b6d70 <https://github.com/apache/airflow/commit/bf9b6b6d70455352bbf807871c8eeb6324be7e54>`__  2020-03-09   ``[AIRFLOW-5013] Add GCP Data Catalog Hook and operators (#7664)``
`e5130dc9fe <https://github.com/apache/airflow/commit/e5130dc9fe89187e95071e678ea3b46600866762>`__  2020-03-09   ``[AIRFLOW-2911] Add job cancellation capability to Dataflow service (#7659)``
`faf0df4b94 <https://github.com/apache/airflow/commit/faf0df4b9460b7f037ee390addbd2c6effcae013>`__  2020-03-09   ``[AIRFLOW-XXXX] Fix upsert operator in BQ example DAG (#7666)``
`42eef38217 <https://github.com/apache/airflow/commit/42eef38217e709bc7a7f71bf0286e9e61293a43e>`__  2020-03-07   ``[AIRFLOW-6877] Add cross-provider dependencies as extras (#7506)``
`b5b9795f04 <https://github.com/apache/airflow/commit/b5b9795f0446bb484a91ee485f49ea456f1c26c4>`__  2020-03-07   ``[AIRFLOW-6973] Make GCSCreateBucketOperator idempotent (fix) (#7624)``
`6b65038fb4 <https://github.com/apache/airflow/commit/6b65038fb409ba1040e70305444816d8f5cfdc47>`__  2020-03-06   ``[AIRFLOW-6990] Improve system tests for Google Marketing Platform (#7631)``
`755fe52249 <https://github.com/apache/airflow/commit/755fe52249ba1cd965cf2f87fa7a428b8197a38a>`__  2020-03-05   ``[AIRFLOW-6915] Add AI Platform Console Link for MLEngineStartTrainingJobOperator (#7535)``
`cb2f339116 <https://github.com/apache/airflow/commit/cb2f339116cf2093da447748892fac68aecbb888>`__  2020-03-04   ``[AIRFLOW-6973] Make GCSCreateBucketOperator idempotent (#7609)``
`09fea3ce8e <https://github.com/apache/airflow/commit/09fea3ce8e4d7816281963bb8f2cb06f4de6db5c>`__  2020-03-04   ``[AIRFLOW-6977] Fix BigQuery DTS example DAG (#7612)``
`8230ccc48b <https://github.com/apache/airflow/commit/8230ccc48b157c89b2b893d42c6fe1523b83363a>`__  2020-03-04   ``[AIRFLOW-6926] Fix Google Tasks operators return types and idempotency (#7547)``
`0d1e3088aa <https://github.com/apache/airflow/commit/0d1e3088aa9f16eaeeb7b18eccec8f35c79a53df>`__  2020-03-04   ``[AIRFLOW-6970] Improve GCP Video Intelligence system tests (#7604)``
`ab6bb0012c <https://github.com/apache/airflow/commit/ab6bb0012c38740b76e864d42d299c5c7a9972a3>`__  2020-03-03   ``[AIRFLOW-6971] Fix return type in CloudSpeechToTextRecognizeSpeechOperator (#7607)``
`3db4ade3dc <https://github.com/apache/airflow/commit/3db4ade3dc9660c21c28187100a22008552f2bd3>`__  2020-02-29   ``[AIRFLOW-6924] Fix Google DLP operators return types (#7546)``
`008b4bab14 <https://github.com/apache/airflow/commit/008b4bab14222da068b737d6332db4963b994007>`__  2020-02-27   ``[AIRFLOW-6730] Use total_seconds instead of seconds (#7363)``
`bb552b2d9f <https://github.com/apache/airflow/commit/bb552b2d9fd595cc3eb1b3a2f637f29b814878d7>`__  2020-02-25   ``[AIRFLOW-6908] Lazy load AirflowException (#7528)``
`d1a34246ac <https://github.com/apache/airflow/commit/d1a34246ac593901f8599b102dc3d7efa4dd61e4>`__  2020-02-25   ``[AIRFLOW-6593] Add GCP Stackdriver Alerting Hooks and Operators (#7322)``
`3320e432a1 <https://github.com/apache/airflow/commit/3320e432a129476dbc1c55be3b3faa3326a635bc>`__  2020-02-24   ``[AIRFLOW-6817] Lazy-load 'airflow.DAG' to keep user-facing API untouched (#7517)``
`dcf8743521 <https://github.com/apache/airflow/commit/dcf87435219307d4e916a8abc2b819ad75e2b1cf>`__  2020-02-24   ``[AIRFLOW-6894] Prevent db query in example_dags (#7516)``
`4d03e33c11 <https://github.com/apache/airflow/commit/4d03e33c115018e30fa413c42b16212481ad25cc>`__  2020-02-22   ``[AIRFLOW-6817] remove imports from 'airflow/__init__.py', replaced implicit imports with explicit imports, added entry to 'UPDATING.MD' - squashed/rebased (#7456)``
`35b9616378 <https://github.com/apache/airflow/commit/35b9616378d1cfba7c2eb3c71e20acb6734b7c77>`__  2020-02-21   ``[AIRFLOW-4973] Add Cloud Data Fusion Pipeline integration (#7486)``
`aff3a361b4 <https://github.com/apache/airflow/commit/aff3a361b4092212c0757f9ce88fa2e40d25d1f4>`__  2020-02-20   ``[AIRFLOW-6558] Campaign Manager operators for conversions (#7420)``
`9cbd7de6d1 <https://github.com/apache/airflow/commit/9cbd7de6d115795aba8bfb8addb060bfdfbdf87b>`__  2020-02-18   ``[AIRFLOW-6792] Remove _operator/_hook/_sensor in providers package and add tests (#7412)``
`5b199cb86b <https://github.com/apache/airflow/commit/5b199cb86be5b1aefbd8620185033d6f635713c1>`__  2020-02-17   ``[AIRFLOW-XXXX] Typo in example_bigquery DAG (#7429)``
`2c9345a8e0 <https://github.com/apache/airflow/commit/2c9345a8e03d37a2676efa2f2ea7e8b7814c5345>`__  2020-02-17   ``[AIRFLOW-6759] Added MLEngine operator/hook to cancel MLEngine jobs (#7400)``
`946bdc23c0 <https://github.com/apache/airflow/commit/946bdc23c039637b0383e1269f99bdd1b2426565>`__  2020-02-16   ``[AIRFLOW-6405] Add GCP BigQuery Table Upsert Operator (#7126)``
`2381c820c8 <https://github.com/apache/airflow/commit/2381c820c8aaeffc1c9b4ed47832038833400eb8>`__  2020-02-13   ``[AIRFLOW-6505] Let emoji encoded properly for json.dumps() (#7399)``
`04c1fefbf2 <https://github.com/apache/airflow/commit/04c1fefbf26a73ed13881d2ec14eada48028ff72>`__  2020-02-03   ``[AIRFLOW-6676] added GCSDeleteBucketOperator (#7307)``
`a0252748ff <https://github.com/apache/airflow/commit/a0252748ff312daede15c6f0a3d39e16c774461c>`__  2020-02-03   ``[AIRFLOW-6717] Remove non-existent field from templated_fields (#7340)``
`97a429f9d0 <https://github.com/apache/airflow/commit/97a429f9d0cf740c5698060ad55f11e93cb57b55>`__  2020-02-02   ``[AIRFLOW-6714] Remove magic comments about UTF-8 (#7338)``
`9d8d075578 <https://github.com/apache/airflow/commit/9d8d0755789d4aeadc5d3015f3cdde62901f85b8>`__  2020-02-03   ``[AIRFLOW-6715] Fix Google Cloud DLP Example DAG (#7337)``
`cf141506a2 <https://github.com/apache/airflow/commit/cf141506a25dbba279b85500d781f7e056540721>`__  2020-02-02   ``[AIRFLOW-6708] Set unique logger names (#7330)``
`373c6aa4a2 <https://github.com/apache/airflow/commit/373c6aa4a208284b5ff72987e4bd8f4e2ada1a1b>`__  2020-01-30   ``[AIRFLOW-6682] Move GCP classes to providers package (#7295)``
`83c037873f <https://github.com/apache/airflow/commit/83c037873ff694eed67ba8b30f2d9c88b2c7c6f2>`__  2020-01-30   ``[AIRFLOW-6674] Move example_dags in accordance with AIP-21 (#7287)``
`057f3ae3a4 <https://github.com/apache/airflow/commit/057f3ae3a4afedf6d462ecf58b01dd6304d3e135>`__  2020-01-29   ``[AIRFLOW-6670][depends on AIRFLOW-6669] Move contrib operators to providers package (#7286)``
`ceea293c16 <https://github.com/apache/airflow/commit/ceea293c1652240e7e856c201e4341a87ef97a0f>`__  2020-01-28   ``[AIRFLOW-6656] Fix AIP-21 moving (#7272)``
`c42a375e79 <https://github.com/apache/airflow/commit/c42a375e799e5adb3f9536616372dc90ff47e6c8>`__  2020-01-27   ``[AIRFLOW-6644][AIP-21] Move service classes to providers package (#7265)``
`059eda05f8 <https://github.com/apache/airflow/commit/059eda05f82fefce4410f44f761f945a27d83daf>`__  2020-01-21   ``[AIRFLOW-6610] Move software classes to providers package (#7231)``
`f4d3e5e545 <https://github.com/apache/airflow/commit/f4d3e5e54507f52a00a9b95aa48eb0260e17224d>`__  2020-01-13   ``[AIRFLOW-6102] [AIP-21] Rename Dataproc operators (#7151)``
`e7bf8ecb48 <https://github.com/apache/airflow/commit/e7bf8ecb48f0299af8091433535ac573c2afd1cf>`__  2020-01-13   ``[AIRFLOW-6119] [AIP-21] Rename GCS operators, hooks and sensors (#7125)``
`5b6772cb83 <https://github.com/apache/airflow/commit/5b6772cb8391b248cb4b7be5fd3d5c035280fac1>`__  2020-01-09   ``[AIRFLOW-6125] [AIP-21] Rename S3 operator and SFTP operator (#7112)``
`4f8592ae8f <https://github.com/apache/airflow/commit/4f8592ae8f52ab7f42623d3b43eef0928c9aafb2>`__  2020-01-08   ``[AIRFLOW-6118] [AIP-21] Rename Pubsub operators and hook (#7046)``
`20299473f1 <https://github.com/apache/airflow/commit/20299473f11add6531f607256ee8a0f7f9507ab8>`__  2020-01-03   ``[AIRFLOW-6115] [AIP-21] Rename GCP vision operators (#7020)``
`18e8cea4e7 <https://github.com/apache/airflow/commit/18e8cea4e7487a7dfefc03661e5ebe54c4104ead>`__  2020-01-03   ``[AIRFLOW-6428] Fix import path for airflow.utils.dates.days_ago in Example DAGs (#7007)``
`95087af140 <https://github.com/apache/airflow/commit/95087af14091f28a83ced8ff1860b86dfd93f93d>`__  2019-12-31   ``[AIRFLOW-6110] [AIP-21] Rename natural_language service (#6968)``
`69629a5a94 <https://github.com/apache/airflow/commit/69629a5a948ab2c4ac04a4a4dca6ac86d19c11bd>`__  2019-12-09   ``[AIRFLOW-5807] Move SFTP from contrib to providers. (#6464)``
`25e9047a4a <https://github.com/apache/airflow/commit/25e9047a4a4da5fad4f85c366e3a6262c0a4f68e>`__  2019-12-09   ``[AIRFLOW-6193] Do not use asserts in Airflow main code (#6749)``
`ed0a14f321 <https://github.com/apache/airflow/commit/ed0a14f321b9dab3554ae395c11c147258536ce8>`__  2019-12-09   ``[AIRFLOW-6120] Rename GoogleCloudBaseHook (#6734)``
`2f2f89c148 <https://github.com/apache/airflow/commit/2f2f89c148e2b694aee9402707f68065ee7320f8>`__  2019-12-01   ``[AIRFLOW-6139] Consistent spaces in pylint enable/disable (#6701)``
`03c870a617 <https://github.com/apache/airflow/commit/03c870a6172ab232af6319a30ad8d46622359b10>`__  2019-11-26   ``[AIRFLOW-6010] Remove cyclic imports and pylint hacks (#6601)``
`5c4cfea8c0 <https://github.com/apache/airflow/commit/5c4cfea8c0f488496c1cbcc4c6c5db13d8210979>`__  2019-11-15   ``[AIRFLOW-5718] Add SFTPToGoogleCloudStorageOperator (#6393)``
`44a8c37a9a <https://github.com/apache/airflow/commit/44a8c37a9a8668469aa825ad21057cca6ac2c186>`__  2019-11-13   ``[AIRFLOW-XXX] Fix the docstring for Dataproc get_job method (#6581)``
`d633d3ac44 <https://github.com/apache/airflow/commit/d633d3ac44c395e6c43cd388f98fba1ce1c435a3>`__  2019-11-13   ``[AIRFLOW-5691] Rewrite Dataproc operators to use python library (#6371)``
`d985c02d9f <https://github.com/apache/airflow/commit/d985c02d9fa3d9ec946abc1735b0551fd61fb9f0>`__  2019-11-05   ``[AIRFLOW-XXX] Add How-To-Guide to GCP PubSub (#6497)``
`a296cdabdb <https://github.com/apache/airflow/commit/a296cdabdb9c9c65cf9a48329cb776aed5c82d43>`__  2019-11-04   ``[AIRFLOW-5743] Move Google PubSub to providers package (#6476)``
`470b2a779d <https://github.com/apache/airflow/commit/470b2a779d031406a3d5925f2fa2ec40e5c3bccb>`__  2019-10-30   ``[AIRFLOW-5741] Move Cloud Natural Language to providers (#6421)``
`f2caa451fc <https://github.com/apache/airflow/commit/f2caa451fc2b8ee59163314f9ec1cc372acbadf1>`__  2019-10-27   ``[AIRFLOW-5742] Move Google Cloud Vision to providers package (#6424)``
`16d7accb22 <https://github.com/apache/airflow/commit/16d7accb22c866d4fbf368e4d979dc1c4a41d93c>`__  2019-10-22   ``[AIRFLOW-4971] Add Google Display & Video 360 integration (#6170)``
`4e661f535d <https://github.com/apache/airflow/commit/4e661f535dea613f9b2e0075676f9a73a97461fe>`__  2019-10-22   ``[AIRFLOW-5379] Add Google Search Ads 360 operators (#6228)``
`19e32b4e2c <https://github.com/apache/airflow/commit/19e32b4e2c798f662e5d8d1e7c65036c5e7ac125>`__  2019-10-18   ``[AIRFLOW-5656] Rename provider to providers module (#6333)``
==================================================================================================  ===========  ======================================================================================================================================================================
